(PackageInfo named: 'Graphics') postscript: '
" Reset DejaVu to current version "
StrikeFont initialize.'!
SystemOrganization addCategory: #'Graphics-Display Objects'!
SystemOrganization addCategory: #'Graphics-External-Ffenestri'!
SystemOrganization addCategory: #'Graphics-Files'!
SystemOrganization addCategory: #'Graphics-Fonts'!
SystemOrganization addCategory: #'Graphics-Primitives'!
SystemOrganization addCategory: #'Graphics-Text'!
SystemOrganization addCategory: #'Graphics-Transformations'!

Object subclass: #AbstractFont
	instanceVariableNames: ''
	classVariableNames: 'ForceNonSubPixelCount'
	poolDictionaries: ''
	category: 'Graphics-Fonts'!

!AbstractFont commentStamp: '<historical>' prior: 0!
AbstractFont defines the generic interface that all fonts need to implement.!

!AbstractFont class methodsFor: 'utilities' stamp: 'nice 3/10/2011 00:30'!
emphasisStringFor: emphasisCode
	"Answer a translated string that represents the attributes given in emphasisCode."

	| emphases |
	emphasisCode = 0 ifTrue: [ ^'Normal' translated ].

	emphases := #('Bold' 'Italic' 'Underlined' 'Narrow' 'StruckOut').

	^String streamContents: [ :s |
		1 to: emphases size do: [ :i |
			(emphasisCode bitAt: i) isZero ifFalse: [ s nextPutAll: (emphases at: i) translated; space ] ].
		s position isZero ifFalse: [ s skip: -1 ] ]! !

!AbstractFont class methodsFor: 'utilities' stamp: 'ar 8/30/2009 16:48'!
forceNonSubPixelCount
	"Answer the force non-subpixel count"
	^ForceNonSubPixelCount ifNil:[ForceNonSubPixelCount := 0]! !

!AbstractFont class methodsFor: 'utilities' stamp: 'ar 8/30/2009 14:03'!
forceNonSubPixelDuring: aBlock
	"Forces all font rendering to suppress subpixel anti-aliasing during the execution of aBlock"
	ForceNonSubPixelCount ifNil:[ForceNonSubPixelCount := 0].
	ForceNonSubPixelCount := ForceNonSubPixelCount + 1.
	aBlock ensure:[ForceNonSubPixelCount := ForceNonSubPixelCount - 1]! !

!AbstractFont methodsFor: 'measuring' stamp: 'ul 11/15/2010 11:17'!
approxWidthOfText: aText
"Return the width of aText -- quickly, and a little bit dirty. Used by lists morphs containing Text objects to get a quick, fairly accurate measure of the width of a list item."

    | w |
    
    (aText isNil or: [aText size = 0 ])
        ifTrue:[^0].
       
    w := self
        widthOfString: aText asString.

     "If the text has no emphasis, just return the string size.  If it is empasized, 
    just approximate the width by adding about 20% to the width"   
    (((aText runLengthFor: 1) = aText size)
        and: [(aText emphasisAt: 1) = 0 ])
            ifTrue:[^w]
            ifFalse:[ ^w * 6 // 5 ]. ! !

!AbstractFont methodsFor: 'accessing' stamp: 'yo 1/7/2005 11:19'!
ascent

	self subclassResponsibility.
! !

!AbstractFont methodsFor: 'accessing' stamp: 'yo 1/7/2005 11:18'!
ascentOf: aCharacter

	^ self ascent.
! !

!AbstractFont methodsFor: 'accessing' stamp: 'nk 4/2/2004 11:06'!
baseKern
	^0! !

!AbstractFont methodsFor: 'accessing' stamp: 'yo 1/7/2005 11:18'!
basicAscentOf: aCharacter

	^ self ascent.
! !

!AbstractFont methodsFor: 'accessing' stamp: 'yo 1/7/2005 11:19'!
basicDescentOf: aCharacter

	^ self descent.
! !

!AbstractFont methodsFor: 'testing' stamp: 'topa 6/1/2016 11:11'!
basicHasGlyphOf: aCharacter

	self subclassResponsibility! !

!AbstractFont methodsFor: 'accessing' stamp: 'ar 5/19/2000 14:56'!
characterToGlyphMap
	"Return the character to glyph mapping table. If the table is not provided the character scanner will query the font directly for the width of each individual character."
	^nil! !

!AbstractFont methodsFor: 'accessing' stamp: 'mt 5/9/2016 16:57'!
depth
	"Returns the glyphs' color depth."
	
	self subclassResponsibility.! !

!AbstractFont methodsFor: 'accessing' stamp: 'nk 3/15/2004 18:57'!
derivativeFonts
	^#()! !

!AbstractFont methodsFor: 'accessing' stamp: 'yo 1/7/2005 11:20'!
descent

	self subclassResponsibility.
! !

!AbstractFont methodsFor: 'accessing' stamp: 'yo 1/7/2005 11:20'!
descentOf: aCharacter

	^ self descent.
! !

!AbstractFont methodsFor: 'displaying' stamp: 'tween 7/29/2006 14:36'!
displayStrikeoutOn: aDisplayContext from: baselineStartPoint to: baselineEndPoint
	"display the strikeout if appropriate for the receiver"! !

!AbstractFont methodsFor: 'displaying' stamp: 'ar 5/19/2000 14:59'!
displayString: aString on: aDisplayContext from: startIndex to: stopIndex at: aPoint kern: kernDelta
	"Draw the given string from startIndex to stopIndex 
	at aPoint on the (already prepared) display context."
	^self subclassResponsibility! !

!AbstractFont methodsFor: 'displaying' stamp: 'yo 1/7/2005 11:36'!
displayString: aString on: aDisplayContext from: startIndex to: stopIndex at: aPoint kern: kernDelta baselineY: baselineY
	"Draw the given string from startIndex to stopIndex 
	at aPoint on the (already prepared) display context."
	^self subclassResponsibility! !

!AbstractFont methodsFor: 'displaying' stamp: 'tween 7/29/2006 13:51'!
displayUnderlineOn: aDisplayContext from: baselineStartPoint to: baselineEndPoint
	"display the underline if appropriate for the receiver"! !

!AbstractFont methodsFor: 'accessing' stamp: 'tween 8/10/2006 07:16'!
emphasisString
	"Answer a translated string that represents the receiver's emphasis."
	
	^self emphasisStringFor: self emphasis! !

!AbstractFont methodsFor: 'accessing' stamp: 'tween 8/10/2006 07:13'!
emphasisStringFor: emphasisCode
	"Answer a translated string that represents the attributes given in emphasisCode."
	
	^self class emphasisStringFor: emphasisCode! !

!AbstractFont methodsFor: 'accessing' stamp: 'nk 8/31/2004 09:15'!
familyName
	"Answer the name to be used as a key in the TextConstants dictionary."
	^self subclassResponsibility! !

!AbstractFont methodsFor: 'testing' stamp: 'tween 3/29/2007 13:43'!
hasDistinctGlyphsForAll: asciiString
	"Answer true if the receiver has glyphs for all the characters
	in asciiString and no single glyph is shared by more than one character, false otherwise.
	The default behaviour is to answer true, but subclasses may reimplement"
	
	^true! !

!AbstractFont methodsFor: 'testing' stamp: 'topa 6/1/2016 11:11'!
hasGlyphOf: aCharacter

	^ self basicHasGlyphOf: aCharacter! !

!AbstractFont methodsFor: 'testing' stamp: 'tween 3/29/2007 13:25'!
hasGlyphsForAll: asciiString
	"Answer true if the receiver has glyphs for all the characters
	in asciiString, false otherwise.
	The default behaviour is to answer true, but subclasses may reimplement"
	
	^true! !

!AbstractFont methodsFor: 'accessing' stamp: 'nk 8/31/2004 09:14'!
height
	"Answer the height of the receiver, total of maximum extents of 
	characters above and below the baseline."

	^self subclassResponsibility! !

!AbstractFont methodsFor: 'displaying' stamp: 'ar 5/19/2000 14:59'!
installOn: aDisplayContext foregroundColor: foregroundColor backgroundColor: backgroundColor
	"Install the receiver on the given DisplayContext (either BitBlt or Canvas) for further drawing operations."
	^self subclassResponsibility! !

!AbstractFont methodsFor: 'testing' stamp: 'yo 2/12/2007 19:34'!
isFontSet

	^ false.
! !

!AbstractFont methodsFor: 'testing' stamp: 'tpr 9/4/2013 13:21'!
isPairKerningCapable
"a hopefully temporary test method; better factoring of scan/measure/display should remove the need for it.
Only FreeType fonts would currently add this to return true"
	^false! !

!AbstractFont methodsFor: 'accessing' stamp: 'nk 5/26/2003 09:45'!
isRegular
	^false! !

!AbstractFont methodsFor: 'testing' stamp: 'tween 4/6/2007 12:58'!
isSubPixelPositioned
	"Answer true if the receiver is currently using subpixel positioned
	glyphs, false otherwise. This affects how padded space sizes are calculated
	when composing text. 
	Currently, only FreeTypeFonts are subPixelPositioned, and only when not
	Hinted"
	
	^false ! !

!AbstractFont methodsFor: 'testing' stamp: 'tween 3/29/2007 13:32'!
isSymbolFont
	"Answer true if the receiver is a Symbol font, false otherwise.
	The default is to answer false, subclasses can reimplement"
	
	^false! !

!AbstractFont methodsFor: 'testing' stamp: 'nk 6/25/2003 12:54'!
isTTCFont
	^false! !

!AbstractFont methodsFor: 'kerning' stamp: 'tween 3/10/2007 13:08'!
kerningLeft: leftChar right: rightChar
	^0! !

!AbstractFont methodsFor: 'measuring' stamp: 'tween 3/31/2007 20:17'!
linearWidthOf: aCharacter
	"This is the scaled, unrounded advance width."
	^self widthOf: aCharacter! !

!AbstractFont methodsFor: 'accessing' stamp: 'nk 8/31/2004 09:14'!
lineGrid
	"Answer the relative space between lines"

	^self subclassResponsibility! !

!AbstractFont methodsFor: 'accessing' stamp: 'nk 4/2/2004 11:33'!
pixelSize
	"Make sure that we don't return a Fraction"
	^ TextStyle pointsToPixels: self pointSize! !

!AbstractFont methodsFor: 'notifications' stamp: 'nk 4/2/2004 11:25'!
pixelsPerInchChanged
	"The definition of TextStyle class>>pixelsPerInch has changed. Do whatever is necessary."! !

!AbstractFont methodsFor: 'accessing' stamp: 'nk 4/1/2004 10:48'!
pointSize
	self subclassResponsibility.! !

!AbstractFont methodsFor: 'printing' stamp: 'nice 10/12/2013 02:08'!
printShortDescriptionOn: aStream
	aStream space; nextPutAll: self familyName! !

!AbstractFont methodsFor: 'caching' stamp: 'nk 3/15/2004 18:47'!
releaseCachedState
	! !

!AbstractFont methodsFor: 'example' stamp: 'topa 6/1/2016 11:31'!
sampleText

	| text |
	text := (self isSymbolFont or: [(self basicHasGlyphOf: $a) not])
		ifTrue: [Text symbolSample]
		ifFalse: [Text textSample].
	text addAttribute: (TextFontReference toFont: self).
	^ text! !

!AbstractFont methodsFor: 'character scanning' stamp: 'tpr 10/3/2013 12:42'!
scanByteCharactersFrom: startIndex to: stopIndex in: aByteString with: aCharacterScanner rightX: rightX
	"scan a single byte character string"
	^aCharacterScanner scanByteCharactersFrom: startIndex to: stopIndex in: aByteString rightX: rightX! !

!AbstractFont methodsFor: 'character scanning' stamp: 'tpr 10/3/2013 12:42'!
scanMultibyteCharactersFrom: startIndex to: stopIndex in: aWideString with: aCharacterScanner rightX: rightX
	"scan a multibyte character string"
	^aCharacterScanner scanMultibyteCharactersFrom: startIndex to: stopIndex in: aWideString rightX: rightX ! !

!AbstractFont methodsFor: 'character scanning' stamp: 'tpr 10/3/2013 12:57'!
scanMultibyteJapaneseCharactersFrom: startIndex to: stopIndex in: aWideString with: aCharacterScanner rightX: rightX
	"scan a multibyte Japanese character string"
	^aCharacterScanner scanJapaneseCharactersFrom: startIndex to: stopIndex in: aWideString rightX: rightX 
! !

!AbstractFont methodsFor: 'accessing' stamp: 'nk 7/11/2004 21:15'!
textStyle
	^ TextStyle actualTextStyles detect:
		[:aStyle | aStyle fontArray includes: self] ifNone: [ TextStyle fontArray: { self } ]! !

!AbstractFont methodsFor: 'accessing' stamp: 'nk 3/22/2004 15:15'!
textStyleName
	"Answer the name to be used as a key in the TextConstants dictionary."
	^self familyName! !

!AbstractFont methodsFor: 'kerning' stamp: 'tpr 9/3/2013 18:19'!
widthAndKernedWidthOfLeft: leftCharacter right: rightCharacterOrNil into: aTwoElementArray
	"Set the first element of aTwoElementArray to the width of leftCharacter and 
	the second element to the width of left character when kerned with
	rightCharacterOrNil. Answer aTwoElementArray"
	"Actually, nearly all users of this actually want just the widthOf the leftCharacter, so we will default to that for speed. See other implementations for more complex cases"

	| w |
	w := self widthOf: leftCharacter.
	aTwoElementArray at: 1 put: w.
	aTwoElementArray at: 2 put: w

"	The old code, and what fonts which have pair-kerning would use - 
	w := self widthOf: leftCharacter.
	rightCharacterOrNil isNil
		ifTrue:[
			aTwoElementArray 
				at: 1 put: w; 
				at: 2 put: w]
		ifFalse:[
			k := self kerningLeft: leftCharacter right: rightCharacterOrNil.
			aTwoElementArray 
				at: 1 put: w; 
				at: 2 put: w+k].
	^aTwoElementArray
"	! !

!AbstractFont methodsFor: 'measuring' stamp: 'sps 3/23/2004 15:50'!
widthOfStringOrText: aStringOrText
    aStringOrText ifNil:[^0].
    ^aStringOrText isText
        ifTrue:[self approxWidthOfText: aStringOrText ]
        ifFalse:[self widthOfString: aStringOrText ] ! !

!AbstractFont methodsFor: 'measuring' stamp: 'ar 12/31/2001 14:25'!
widthOfString: aString
	aString ifNil:[^0].
	^self widthOfString: aString from: 1 to: aString size.
"
	TextStyle default defaultFont widthOfString: 'zort' 21
"! !

!AbstractFont methodsFor: 'measuring' stamp: 'nice 12/26/2009 00:50'!
widthOfString: aString from: startIndex to: stopIndex
	"Measure the length of the given string between start and stop index"
	| resultX |
	resultX := 0.
	startIndex to: stopIndex do: [:i | 
		resultX := resultX + (self widthOf: (aString at: i))].
	^resultX! !

!AbstractFont methodsFor: 'measuring' stamp: 'ar 5/19/2000 14:58'!
widthOf: aCharacter
	"Return the width of the given character"
	^self subclassResponsibility! !

!AbstractFont methodsFor: 'accessing' stamp: 'ar 5/19/2000 14:57'!
xTable
	"Return the xTable for the font. The xTable defines the left x-value for each individual glyph in the receiver. If such a table is not provided, the character scanner will ask the font directly for the appropriate width of each individual character."
	^nil! !

AbstractFont subclass: #FixedFaceFont
	instanceVariableNames: 'baseFont substitutionCharacter displaySelector'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Fonts'!

!FixedFaceFont commentStamp: 'tak 12/22/2004 01:45' prior: 0!
I am a font for special purpose like password or fallback.
I can show same form whenever someone requests any character.

Variable displaySelector is future use to show a form dynamically.
(Although it would be unnecessary...)!

!FixedFaceFont methodsFor: 'accessing' stamp: 'ar 1/5/2003 16:58'!
ascent
	^baseFont ascent! !

!FixedFaceFont methodsFor: 'accessing' stamp: 'tak 12/20/2004 10:51'!
ascentOf: aCharacter
	^ self ascent! !

!FixedFaceFont methodsFor: 'accessing' stamp: 'ar 1/5/2003 16:57'!
baseFont
	^baseFont! !

!FixedFaceFont methodsFor: 'accessing' stamp: 'ar 1/5/2003 16:57'!
baseFont: aFont
	baseFont := aFont! !

!FixedFaceFont methodsFor: 'accessing' stamp: 'ar 1/5/2003 16:59'!
baseKern
	^baseFont baseKern! !

!FixedFaceFont methodsFor: 'private' stamp: 'topa 6/1/2016 11:50'!
basicHasGlyphOf: aCharacter

	" We present the same for any character, so, yes"
	^ true! !

!FixedFaceFont methodsFor: 'accessing' stamp: 'tak 12/22/2004 02:01'!
characterFormAt: character 
	^ baseFont characterFormAt: substitutionCharacter! !

!FixedFaceFont methodsFor: 'accessing' stamp: 'mt 5/9/2016 16:58'!
depth

	^ self baseFont depth! !

!FixedFaceFont methodsFor: 'accessing' stamp: 'ar 1/5/2003 17:00'!
descent
	^baseFont descent! !

!FixedFaceFont methodsFor: 'accessing' stamp: 'ar 1/5/2003 16:58'!
descentKern
	^baseFont descentKern! !

!FixedFaceFont methodsFor: 'accessing' stamp: 'tak 12/20/2004 10:51'!
descentOf: aCharacter
	^ self descent! !

!FixedFaceFont methodsFor: 'displaying' stamp: 'tak 12/20/2004 18:06'!
displayErrorOn: aCanvas length: length at: aPoint kern: kernDelta 
	| maskedString |
	maskedString := String new: length.
	maskedString atAllPut: substitutionCharacter.
	^ baseFont
		displayString: maskedString
		on: aCanvas
		from: 1
		to: length
		at: aPoint
		kern: kernDelta! !

!FixedFaceFont methodsFor: 'displaying' stamp: 'yo 1/7/2005 11:49'!
displayErrorOn: aCanvas length: length at: aPoint kern: kernDelta baselineY: baselineY
	| maskedString |
	maskedString := String new: length.
	maskedString atAllPut: substitutionCharacter.
	^ baseFont
		displayString: maskedString
		on: aCanvas
		from: 1
		to: length
		at: aPoint
		kern: kernDelta
		baselineY: baselineY! !

!FixedFaceFont methodsFor: 'displaying' stamp: 'tak 12/20/2004 18:06'!
displayPasswordOn: aCanvas length: length at: aPoint kern: kernDelta 
	| maskedString |
	maskedString := String new: length.
	maskedString atAllPut: substitutionCharacter.
	^ baseFont
		displayString: maskedString
		on: aCanvas
		from: 1
		to: length
		at: aPoint
		kern: kernDelta! !

!FixedFaceFont methodsFor: 'displaying' stamp: 'yo 1/7/2005 11:50'!
displayPasswordOn: aCanvas length: length at: aPoint kern: kernDelta baselineY: baselineY
	| maskedString |
	maskedString := String new: length.
	maskedString atAllPut: substitutionCharacter.
	^ baseFont
		displayString: maskedString
		on: aCanvas
		from: 1
		to: length
		at: aPoint
		kern: kernDelta
		baselineY: baselineY! !

!FixedFaceFont methodsFor: 'displaying' stamp: 'yo 1/7/2005 12:00'!
displayString: aString on: aDisplayContext from: startIndex to: stopIndex at: aPoint kern: kernDelta 
	| size |
	size := stopIndex - startIndex + 1.
	^ self perform: displaySelector withArguments: (Array with: aDisplayContext with: size with: aPoint with: kernDelta with: aPoint y + self ascent).! !

!FixedFaceFont methodsFor: 'displaying' stamp: 'yo 1/7/2005 12:19'!
displayString: aString on: aDisplayContext from: startIndex to: stopIndex at: aPoint kern: kernDelta baselineY: baselineY
	| size |
	size := stopIndex - startIndex + 1.
	^ self perform: displaySelector withArguments: (Array with: aDisplayContext with: size with: aPoint with: kernDelta with: baselineY).! !

!FixedFaceFont methodsFor: 'displaying' stamp: 'tak 12/20/2004 11:10'!
displayString: aString on: aBitBlt from: startIndex to: stopIndex at: aPoint kern: kernDelta from: fromFont 
	| destPoint |
	destPoint := self
				displayString: aString
				on: aBitBlt
				from: startIndex
				to: stopIndex
				at: aPoint
				kern: kernDelta.
	^ Array with: stopIndex + 1 with: destPoint! !

!FixedFaceFont methodsFor: 'displaying' stamp: 'ar 8/15/2009 10:45'!
displayString: aString on: aBitBlt from: startIndex to: stopIndex at: aPoint kern: kernDelta from: fromFont baselineY: baselineY
	| destPoint |
	destPoint := self
				displayString: aString
				on: aBitBlt
				from: startIndex
				to: stopIndex
				at: aPoint
				kern: kernDelta
				baselineY: baselineY.
	^destPoint! !

!FixedFaceFont methodsFor: 'accessing' stamp: 'tak 12/20/2004 10:10'!
emphasized: emph
	^self class new baseFont: (baseFont emphasized: emph)! !

!FixedFaceFont methodsFor: 'initialize-release' stamp: 'yo 1/7/2005 11:59'!
errorFont
	displaySelector := #displayErrorOn:length:at:kern:baselineY:.
	substitutionCharacter := $?.! !

!FixedFaceFont methodsFor: 'accessing' stamp: 'nk 8/31/2004 09:25'!
familyName
	^baseFont familyName, '-pw'! !

!FixedFaceFont methodsFor: 'accessing' stamp: 'tak 12/20/2004 10:19'!
fontSize: aNumber 
	self baseFont: (StrikeFont familyName: baseFont familyName size: aNumber) copy! !

!FixedFaceFont methodsFor: 'private' stamp: 'tpr 9/3/2013 13:50'!
glyphInfoOf: aCharacter into: glyphInfoArray
"since we replace every character with substitutionCharacter, get my baseFont's glyphInfo for that"
	^ baseFont glyphInfoOf: substitutionCharacter into: glyphInfoArray.
! !

!FixedFaceFont methodsFor: 'accessing' stamp: 'ar 1/5/2003 16:57'!
height
	^baseFont height! !

!FixedFaceFont methodsFor: 'initialize-release' stamp: 'rej 9/29/2007 09:04'!
initialize
	"This used to be the default textstyle, but it needs to be a StrikeFont and not a TTCFont and sometimes the default textstyle is a TTCFont.  So, we use a typical StrikeFont as the default fallback font."
	baseFont := StrikeFont defaultSized: 12.
	self passwordFont! !

!FixedFaceFont methodsFor: 'displaying' stamp: 'ar 1/5/2003 17:00'!
installOn: aDisplayContext foregroundColor: foregroundColor backgroundColor: backgroundColor
	^baseFont installOn: aDisplayContext foregroundColor: foregroundColor backgroundColor: backgroundColor! !

!FixedFaceFont methodsFor: 'accessing' stamp: 'nk 8/31/2004 09:26'!
lineGrid
	^baseFont lineGrid! !

!FixedFaceFont methodsFor: 'accessing' stamp: 'tak 12/20/2004 10:51'!
maxAscii
	^ SmallInteger maxVal! !

!FixedFaceFont methodsFor: 'accessing' stamp: 'ar 1/5/2003 16:59'!
passwordCharacter
	^$*! !

!FixedFaceFont methodsFor: 'initialize-release' stamp: 'yo 1/7/2005 11:59'!
passwordFont
	displaySelector := #displayPasswordOn:length:at:kern:baselineY:.
	substitutionCharacter := $*! !

!FixedFaceFont methodsFor: 'accessing' stamp: 'nk 8/31/2004 09:28'!
pointSize
	^baseFont pointSize! !

!FixedFaceFont methodsFor: 'caching' stamp: 'nk 3/15/2004 18:48'!
releaseCachedState
	baseFont releaseCachedState.! !

!FixedFaceFont methodsFor: 'measuring' stamp: 'tak 12/20/2004 18:05'!
widthOf: aCharacter 
	^ baseFont widthOf: substitutionCharacter! !

Object subclass: #BDFFontReader
	instanceVariableNames: 'file properties'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Fonts'!

!BDFFontReader commentStamp: '<historical>' prior: 0!
I am a conversion utility for reading X11 Bitmap Distribution Format fonts.  My code is derived from the multilingual Squeak changeset written by OHSHIMA Yoshiki (ohshima@is.titech.ac.jp), although all support for fonts with more than 256 glyphs has been ripped out.  See http://www.is.titech.ac.jp/~ohshima/squeak/squeak-multilingual-e.html .

My class methods contain tools for fetching BDF source files from a well-known archive site, batch conversion to Squeak's .sf2 format, and installation of these fonts as TextStyles.  Also, the legal notices for the standard 75dpi fonts I process this way are included as "x11FontLegalNotices'.!

!BDFFontReader class methodsFor: 'file creation' stamp: 'fbs 6/3/2013 23:05'!
convertFilesNamed: fileName toFamilyNamed: familyName inDirectoryNamed: dirName
		"BDFFontReader convertFilesNamed: 'helvR' toFamilyNamed: 'Helvetica' inDirectoryNamed: '' "

	"This utility converts X11 BDF font files to Squeak .sf2 StrikeFont files."

	"For this utility to work as is, the BDF files must be named 'familyNN.bdf',
	and must reside in the directory named by dirName (use '' for the current directory).
	The output StrikeFont files will be named familyNN.sf2, and will be placed in the
	current directory."

	| allFontNames dir |
	"Check for matching file names."
	dir := dirName isEmpty
		ifTrue: [FileDirectory default]
		ifFalse: [FileDirectory default directoryNamed: dirName].
	allFontNames := dir fileNamesMatching: fileName , '##.bdf'.
	allFontNames isEmpty ifTrue: [^ self error: 'No files found like ' , fileName , 'NN.bdf'].
	
	UIManager default informUserDuring: [:info |
		allFontNames do: [:fname | | f sizeChars | 
			info value: 'Converting ', familyName, ' BDF file ', fname, ' to SF2 format'.
			sizeChars := (fname copyFrom: fileName size + 1 to: fname size) copyUpTo: $. .

			f := StrikeFont new readBDFFromFile: (dir fullNameFor: fname) name: familyName, sizeChars.
			f writeAsStrike2named: familyName, sizeChars, '.sf2'.
		].
	]! !

!BDFFontReader class methodsFor: 'resource download' stamp: 'nop 1/23/2000 18:43'!
convertX11FontsToStrike2  "BDFFontReader convertX11FontsToStrike2"
	"Given a set of standard X11 BDF font files (probably downloaded via BDFFontReader downloadFonts), produce .sf2 format fonts.  The source and destination directory is the current directory."

	"Charter currently tickles a bug in the BDF parser.  Skip it for now."
	"self convertFilesNamed: 'charR' toFamilyNamed: 'Charter' inDirectoryNamed: ''."

	self convertFilesNamed: 'courR' toFamilyNamed: 'Courier' inDirectoryNamed: ''.
	self convertFilesNamed: 'helvR' toFamilyNamed: 'Helvetica' inDirectoryNamed: ''.

	self convertFilesNamed: 'lubR' toFamilyNamed: 'LucidaBright' inDirectoryNamed: ''.
	self convertFilesNamed: 'luRS' toFamilyNamed: 'Lucida' inDirectoryNamed: ''.
	self convertFilesNamed: 'lutRS' toFamilyNamed: 'LucidaTypewriter' inDirectoryNamed: ''.

	self convertFilesNamed: 'ncenR' toFamilyNamed: 'NewCenturySchoolbook' inDirectoryNamed: ''.
	self convertFilesNamed: 'timR' toFamilyNamed: 'TimesRoman' inDirectoryNamed: ''.! !

!BDFFontReader class methodsFor: 'resource download' stamp: 'fbs 7/12/2013 20:50'!
downloadFonts  "BDFFontReader downloadFonts"
	"Download a standard set of BDF sources from x.org.  
	The combined size of these source files is around 1.2M; after conversion 
	to .sf2 format they may be deleted."

	| heads tails filenames baseUrl basePath |
	heads := #( 'charR' 'courR' 'helvR' 'lubR' 'luRS' 'lutRS' 'ncenR' 'timR' ).
	tails := #( '08' '10' '12' '14' '18' '24').

	filenames := OrderedCollection new.
	heads do: [:head |
		filenames addAll: (tails collect: [:tail | head , tail , '.bdf'])
	].
	baseUrl := 'http://cvsweb.xfree86.org/cvsweb/*checkout*/xc/fonts/bdf/75dpi/' asUrl.
	basePath := baseUrl path.

	filenames do: [:filename |
		| document newPath newUrl |
		newUrl := baseUrl clone.
		newPath := OrderedCollection newFrom: basePath.

		newPath addLast: filename.
		newUrl path: newPath.

		UIManager default informUser: 'Fetching ' , filename during: 
			[document := newUrl retrieveContents].

		MultiByteFileStream newFileNamed: filename do: [ :f |
			f 
				wantsLineEndConversion: true;
				nextPutAll: document content ]
	].
! !

!BDFFontReader class methodsFor: 'documentation' stamp: 'nop 2/11/2001 00:22'!
gettingAndInstallingTheFonts

	"Download the 1.3M of BDF font source files from x.org:

		BDFFontReader downloadFonts.

	Convert them to .sf2 StrikeFont files:

		BDFFontReader convertX11FontsToStrike2.

	Install them into the system as TextStyles:

		BDFFontReader installX11Fonts.

	Read the legal notices in 'BDFFontReader x11FontLegalNotices' before
	redistributing images containing these fonts."! !

!BDFFontReader class methodsFor: 'resource download' stamp: 'nice 12/27/2009 03:12'!
installX11Fonts "BDFFontReader installX11Fonts"
	"Installs previously-converted .sf2 fonts into the TextConstants dictionary.  This makes them available as TextStyles everywhere in the image."

	| families |
	families := #( 'Courier' 'Helvetica' 'LucidaBright' 'Lucida' 'LucidaTypewriter' 'NewCenturySchoolbook' 'TimesRoman' ).

	families do: [:family | | fontArray textStyle |
		fontArray := StrikeFont readStrikeFont2Family: family.
		textStyle := TextStyle fontArray: fontArray.
		TextConstants at: family asSymbol put: textStyle.
	].
! !

!BDFFontReader class methodsFor: 'file creation' stamp: 'ar 10/25/2005 00:21'!
openFileNamed: fileName
	^self new openFileNamed: fileName! !

!BDFFontReader methodsFor: 'reading' stamp: 'nop 1/18/2000 19:45'!
errorFileFormat
	self error: 'malformed bdf format'! !

!BDFFontReader methodsFor: 'reading' stamp: 'nop 1/18/2000 19:46'!
errorUnsupported
	self error: 'unsupported bdf'! !

!BDFFontReader methodsFor: 'reading' stamp: 'nice 6/11/2010 21:32'!
getLine
	^file nextLine! !

!BDFFontReader methodsFor: 'initialize' stamp: 'nop 1/18/2000 19:44'!
initialize
	properties := Dictionary new.! !

!BDFFontReader methodsFor: 'initialize' stamp: 'ul 11/3/2010 06:21'!
openFileNamed: fileName
	file := MultiByteFileStream readOnlyFileNamed: fileName.
	file wantsLineEndConversion: true! !

!BDFFontReader methodsFor: 'reading' stamp: 'nice 9/4/2013 20:00'!
read
	| xTable strikeWidth glyphs ascent descent minAscii maxAscii maxWidth chars charsNum height form encoding bbx array width blt lastAscii pointSize ret stream |
	form := encoding := bbx := nil.
	self readAttributes.
	height := Integer readFromString: ((properties at: #FONTBOUNDINGBOX) at: 2).
	ascent := Integer readFromString: (properties at: #'FONT_ASCENT') first.
	descent := Integer readFromString: (properties at: #'FONT_DESCENT') first.
	pointSize := (Integer readFromString: (properties at: #'POINT_SIZE') first) // 10.
	
	maxWidth := 0.
	minAscii := 9999.
	strikeWidth := 0.
	maxAscii := 0.

	charsNum := Integer readFromString: (properties at: #CHARS) first.
	chars := Set new: charsNum.

	1 to: charsNum do: [:i |
		array := self readOneCharacter.
		stream := ReadStream on: array.
		form := stream next.
		encoding := stream next.
		bbx := stream next.
		form ifNotNil: [
			width := bbx at: 1.
			maxWidth := maxWidth max: width.
			minAscii := minAscii min: encoding.
			maxAscii := maxAscii max: encoding.
			strikeWidth := strikeWidth + width.
			chars add: array.
		].
	].

	chars := chars asSortedCollection: [:x :y | (x at: 2) <= (y at: 2)].
	charsNum := chars size. "undefined encodings make this different"

	charsNum > 256 ifTrue: [
		"it should be 94x94 charset, and should be fixed width font"
		strikeWidth := 94*94*maxWidth.
		maxAscii := 94*94.
		minAscii := 0.
		xTable := XTableForFixedFont new.
		xTable maxAscii: 94*94.
		xTable width: maxWidth.
	] ifFalse: [
		xTable := (Array new: 258) atAllPut: 0.
	].

	glyphs := Form extent: strikeWidth@height.
	blt := BitBlt toForm: glyphs.
	lastAscii := 0.
	
	charsNum > 256 ifTrue: [
		1 to: charsNum do: [:i |
			stream := ReadStream on: (chars at: i).
			form := stream next.
			encoding := stream next.
			bbx := stream next.
			encoding := ((encoding // 256) - 33) * 94 + ((encoding \\ 256) - 33).
			blt copy: ((encoding * maxWidth)@0 extent: maxWidth@height)
				from: 0@0 in: form.
		].
	] ifFalse: [
		1 to: charsNum do: [:i |
			stream := ReadStream on: (chars at: i).
			form := stream next.
			encoding := stream next.
			bbx := stream next.
			lastAscii+1 to: encoding-1 do: [:a | xTable at: a+2 put: (xTable at: a+1)].
			blt copy: (((xTable at: encoding+1)@(ascent - (bbx at: 2) - (bbx at: 4)))
					extent: (bbx at: 1)@(bbx at: 2))
				from: 0@0 in: form.
			xTable at: encoding+2 put: (xTable at: encoding+1)+(bbx at: 1).
			lastAscii := encoding.
		]
	].

	ret := Array new: 8.
	ret at: 1 put: xTable.
	ret at: 2 put: glyphs.
	ret at: 3 put: minAscii.
	ret at: 4 put: maxAscii.
	ret at: 5 put: maxWidth.
	ret at: 6 put: ascent.
	ret at: 7 put: descent.
	ret at: 8 put: pointSize.
	^ret.
" ^{xTable. glyphs. minAscii. maxAscii. maxWidth. ascent. descent. pointSize}"
! !

!BDFFontReader methodsFor: 'reading' stamp: 'ar 10/25/2005 00:35'!
readAttributes
	| str a |
	"I don't handle double-quotes correctly, but it works"
	file reset.
	[file atEnd] whileFalse: [
		str := self getLine.
		(str beginsWith: 'STARTCHAR') ifTrue: [file skip: (0 - str size - 1). ^self].
		a := str substrings.
		properties at: a first asSymbol put: a allButFirst.
	].
	self error: 'file seems corrupted'.! !

!BDFFontReader methodsFor: 'reading' stamp: 'nice 9/4/2013 20:00'!
readChars
	| strikeWidth ascent descent minAscii maxAscii maxWidth chars charsNum height form encoding bbx array width pointSize stream |
	form := encoding := bbx := nil.
	self readAttributes.
	height := Integer readFromString: ((properties at: #FONTBOUNDINGBOX) at: 2).
	ascent := Integer readFromString: (properties at: #'FONT_ASCENT') first.
	descent := Integer readFromString: (properties at: #'FONT_DESCENT') first.
	pointSize := (Integer readFromString: (properties at: #'POINT_SIZE') first) // 10.
	
	maxWidth := 0.
	minAscii := 9999.
	strikeWidth := 0.
	maxAscii := 0.

	charsNum := Integer readFromString: (properties at: #CHARS) first.
	chars := Set new: charsNum.

	1 to: charsNum do: [:i |
		array := self readOneCharacter.
		stream := ReadStream on: array.
		form := stream next.
		encoding := stream next.
		bbx := stream next.
		form ifNotNil: [
			width := bbx at: 1.
			maxWidth := maxWidth max: width.
			minAscii := minAscii min: encoding.
			maxAscii := maxAscii max: encoding.
			strikeWidth := strikeWidth + width.
			chars add: array.
		].
	].

	chars := chars asSortedCollection: [:x :y | (x at: 2) <= (y at: 2)].

	^ chars.
! !

!BDFFontReader methodsFor: 'reading' stamp: 'ar 10/25/2005 00:35'!
readOneCharacter
	| str a encoding bbx form bits hi low pos |
	((str := self getLine) beginsWith: 'ENDFONT') ifTrue: [^ {nil. nil. nil}].
	(str beginsWith: 'STARTCHAR') ifFalse: [self errorFileFormat].
	((str := self getLine) beginsWith: 'ENCODING') ifFalse: [self errorFileFormat].
	encoding := Integer readFromString: str substrings second.
	(self getLine beginsWith: 'SWIDTH') ifFalse: [self errorFileFormat].
	(self getLine beginsWith: 'DWIDTH') ifFalse: [self errorFileFormat].
	
	((str := self getLine) beginsWith: 'BBX') ifFalse: [self errorFileFormat].
	a := str substrings.
	bbx := (2 to: 5) collect: [:i | Integer readFromString: (a at: i)].
	((str := self getLine) beginsWith: 'ATTRIBUTES') ifTrue: [str := self getLine].
	(str beginsWith: 'BITMAP') ifFalse: [self errorFileFormat].

	form := Form extent: (bbx at: 1)@(bbx at: 2).
	bits := form bits.
	pos := 0.
	1 to: (bbx at: 2) do: [:t |
		1 to: (((bbx at: 1) - 1) // 8 + 1) do: [:i |
			hi := (('0123456789ABCDEF' indexOf: (file next asUppercase)) - 1) bitShift: 4.
			low := ('0123456789ABCDEF' indexOf: (file next asUppercase)) - 1.
			
			bits byteAt: (pos+i) put: (hi+low).
		].
		file next ~= Character cr ifTrue: [self errorFileFormat].
		pos := pos + ((((bbx at: 1) // 32) + 1) * 4).
	].

	(self getLine beginsWith: 'ENDCHAR') ifFalse: [self errorFileFormat].

	encoding < 0 ifTrue: [^{nil. nil. nil}].
	^{form. encoding. bbx}.
	
	
	! !

Object subclass: #BitBlt
	instanceVariableNames: 'destForm sourceForm halftoneForm combinationRule destX destY width height sourceX sourceY clipX clipY clipWidth clipHeight colorMap'
	classVariableNames: 'CachedFontColorMaps ColorConvertingMaps SubPixelRenderColorFonts SubPixelRenderFonts'
	poolDictionaries: ''
	category: 'Graphics-Primitives'!

!BitBlt commentStamp: 'tpr 9/17/2013 15:42' prior: 0!
WARNING: BitBlt's shape cannot be modified since WarpBlt relies on the exact layout. Important primitives will break if you fail to heed this warning.

I represent a block transfer (BLT) of pixels from one Form ( the sourceForm) into a rectangle (destX, destY, width, height) of the destinationForm, as modified by a combination rule, a possible halftoneForm and a possible color map.

The source of pixels may be a similar rectangle (at sourceX, sourceY) in the sourceForm, or the halftoneForm, or both.  If both are specified, their pixel values are combined by a logical AND function prior to any further combination rule processing. The halftoneForm may be an actual Form or a simple WordArray of 32 bit values usually intended to represent Color values. In either case the 'top' of the form is effectively aligned with the top of the destinationForm and for each scanline the destination y modulo the size of the halftoneForm gives the index of the word to use. This makes it easy to make horizontal stripes, for example.

In any case, the pixels from the source (AND'd with the halftone, remember) are combined with those of the destination by as specified by the combinationRules below- 
	name	rule		result 

					0	always 0
	and				1	src AND dst
					2	src AND not(dst)
	over			3	src only
	erase			4	not(src) AND& dst
					5 	dst only
	reverse		6	src XOR dst
	under			7	src OR dst
					8	not(src) AND not(dst)
					9	not(src) XOR dst
					10	not(dst)
					11	src OR not(dst)
					12	not(src)
					13	not(src) OR dst
					14	not(src) OR not(dst)
					15	always 1
(You can find an interesting explanation of how this comes to be in http://dev-docs.atariforge.org/files/BLiTTER_1-25-1990.pdf - which interestingly fails to mention any connection to Smalltalk and PARC.)
 Forms may be of different depths, see the comment in class Form.

In addition to the original 16 combination rules invented for monochrome Forms, this BitBlt supports
					16	fails (to simulate paint bits)
					17	fails (to simulate erase bits)
					18	sourceWord + destinationWord
					19	sourceWord - destinationWord
					20	rgbAdd: sourceWord with: destinationWord.  Sum of color components
					21	rgbSub: sourceWord with: destinationWord.  Difference of color components
					22	OLDrgbDiff: sourceWord with: destinationWord.  Sum of abs of differences in components
					23	OLDtallyIntoMap: destinationWord.  Tallies pixValues into a colorMap
							these old versions don't do bitwise dest clipping.  Use 32 and 33 now.
	blend			24	alphaBlend: sourceWord with: destinationWord.  32-bit source and dest only. Blend sourceWord 
							with destinationWord, assuming both are 32-bit pixels. The source is assumed to have 255*alpha
							in the high 8 bits of each pixel, while the high 8 bits of the destinationWord will be ignored.
							The blend produced is alpha*source + (1-alpha)*dest, with the computation being performed
							independently on each color component.  The high byte of the result will be 0.
	paint			25	pixPaint: sourceWord with: destinationWord.  Wherever the sourceForm is non-zero, it replaces
							the destination.  Can be used with a 1-bit source color mapped to (0, FFFFFFFF), and a fillColor 
							to fill the dest with that color wherever the source is 1.
	erase1BitShape	26	pixMask: sourceWord with: destinationWord.  Like pixPaint, but fills with 0.
					27	rgbMax: sourceWord with: destinationWord.  Max of each color component.
					28	rgbMin: sourceWord with: destinationWord.  Min of each color component.
					29	rgbMin: sourceWord bitInvert32 with: destinationWord.  Min with (max-source)
	blendAlpha		30	alphaBlendConst: sourceWord with: destinationWord.  alpha is an arg. works in 16 bits. Blend
							sourceWord with destinationWord using a constant alpha. Alpha is encoded as 0 meaning
							0.0, and 255 meaning 1.0. The blend produced is alpha*source + (1.0-alpha)*dest, with
							the computation being performed independently on each color component. 
	paintAlpha		31	alphaPaintConst: sourceWord with: destinationWord.  alpha is an arg. works in 16 bits.
					32	rgbDiff: sourceWord with: destinationWord.  Sum of abs of differences in components
					33	tallyIntoMap: destinationWord.  Tallies pixValues into a colorMap - Those tallied are exactly 
							those in the destination rectangle.  Note that the source should be specified == destination,
							in order for the proper color map checks  be performed at setup.
	blendAlphaScaled	34	alphaBlendScaled: srcWord with: dstWord. Alpha blend of scaled srcWord and destWord. In contrast
							to alphaBlend:with: the color produced is srcColor + (1-srcAlpha) * dstColor
					35	& 36 not used
	rgbMul			37	rgbMul: srcWord with: dstWord. 
					38	pixSwap: srcWord with: dstWord.
					39	pixClear: srcWord with: dstWord. Clear all pixels in destinationWord for which the pixels of 
							sourceWord have the same values. Used to clear areas of some constant color to zero.
					40	fixAlpha: srcWord with: dstWord. For any non-zero pixel value in destinationWord with zero alpha 
							channel take the alpha from sourceWord and fill it in. Intended for fixing alpha channels left at 
							zero during 16->32 bpp conversions.
					41	rgbComponentAlpha: srcWord with: dstWord.

Any transfer specified is further clipped by the specified clipping rectangle (clipX, clipY, clipWidth, clipHeight), and also by the bounds of the source and destination forms.
	To make a small Form repeat and fill a big form, use an InfiniteForm as the source.

Pixels copied from a source to a destination whose pixels have a different depth are converted based on the optional colorMap.  If colorMap is nil, then conversion to more bits is done by filling the new high-order bits with zero, and conversion to fewer bits is done by truncating the lost high-order bits.  

The colorMap, if specified, must be a either word array (ie Bitmap) with 2^n elements, where n is the pixel depth of the source, or a fully specified ColorMap which may contain a lookup table (ie Bitmap) and/or four separate masks and shifts which are applied to the pixels. For every source pixel, BitBlt will first perform masking and shifting and then index the lookup table, and select the corresponding pixelValue and mask it to the destination pixel size before storing.
	When blitting from a 32 or 16 bit deep Form to one 8 bits or less, the default is truncation.  This will produce very strange colors, since truncation of the high bits does not produce the nearest encoded color.  Supply a 512 long colorMap, and red, green, and blue will be shifted down to 3 bits each, and mapped.  The message copybits...stdColors will use the best map to the standard colors for destinations of depths 8, 4, 2 and 1.  Two other sized of colorMaps are allowed, 4096 (4 bits per color) and 32786 (five bits per color).
	Normal blits between 16 and 32 bit forms truncates or pads the colors automatically to provide the best preservation of colors.
	Colors can be remapped at the same depth.  Sometimes a Form is in terms of colors that are not the standard colors for this depth, for example in a GIF file.  Convert the Form to a MaskedForm and send colorMap: the list of colors that the picture is in terms of. (Note also that a Form can be copied to itself, and transformed in the process, if a non-nil colorMap is supplied.)!

!BitBlt class methodsFor: 'examples' stamp: 'di 12/1/97 12:08'!
alphaBlendDemo
	"To run this demo, use...
		Display restoreAfter: [BitBlt alphaBlendDemo]	
	Displays 10 alphas, then lets you paint.  Option-Click to stop painting."

	"This code exhibits alpha blending in any display depth by performing
	the blend in an off-screen buffer with 32-bit pixels, and then copying
	the result back onto the screen with an appropriate color map. - tk 3/10/97"
	
	"This version uses a sliding buffer for painting that keeps pixels in 32 bits
	as long as they are in the buffer, so as not to lose info by converting down
	to display resolution and back up to 32 bits at each operation. - di 3/15/97"

	| brush buff dispToBuff buffToDisplay mapDto32 map32toD prevP p brushToBuff theta buffRect buffSize buffToBuff brushRect delta newBuffRect updateRect |  

	"compute color maps if needed"
	Display depth <= 8 ifTrue: [
		mapDto32 := Color cachedColormapFrom: Display depth to: 32.
		map32toD := Color cachedColormapFrom: 32 to: Display depth].

	"display 10 different alphas, across top of screen"
	buff := Form extent: 500@50 depth: 32.
	dispToBuff := BitBlt toForm: buff.
	dispToBuff colorMap: mapDto32.
	dispToBuff copyFrom: (50@10 extent: 500@50) in: Display to: 0@0.
	1 to: 10 do: [:i | dispToBuff fill: (50*(i-1)@0 extent: 50@50)
						fillColor: (Color red alpha: i/10)
						rule: Form blend].
	buffToDisplay := BitBlt toForm: Display.
	buffToDisplay colorMap: map32toD.
	buffToDisplay copyFrom: buff boundingBox in: buff to: 50@10.

	"Create a brush with radially varying alpha"
	brush := Form extent: 30@30 depth: 32.
	1 to: 5 do: 
		[:i | brush fillShape: (Form dotOfSize: brush width*(6-i)//5)
				fillColor: (Color red alpha: 0.02 * i - 0.01)
				at: brush extent // 2].

	"Now paint with the brush using alpha blending."
	buffSize := 100.
	buff := Form extent: brush extent + buffSize depth: 32.  "Travelling 32-bit buffer"
	dispToBuff := BitBlt toForm: buff.  "This is from Display to buff"
	dispToBuff colorMap: mapDto32.
	brushToBuff := BitBlt toForm: buff.  "This is from brush to buff"
	brushToBuff sourceForm: brush; sourceOrigin: 0@0.
	brushToBuff combinationRule: Form blend.
	buffToBuff := BitBlt toForm: buff.  "This is for slewing the buffer"

	[Sensor yellowButtonPressed] whileFalse:
		[prevP := nil.
		buffRect := Sensor cursorPoint - (buffSize // 2) extent: buff extent.
		dispToBuff copyFrom: buffRect in: Display to: 0@0.
		[Sensor redButtonPressed] whileTrue:
			["Here is the painting loop"
			p := Sensor cursorPoint - (brush extent // 2).
			(prevP == nil or: [prevP ~= p]) ifTrue:
				[prevP == nil ifTrue: [prevP := p].
				(p dist: prevP) > buffSize ifTrue:
					["Stroke too long to fit in buffer -- clip to buffer,
						and next time through will do more of it"
					theta := (p-prevP) theta.
					p := ((theta cos@theta sin) * buffSize asFloat + prevP) truncated].
				brushRect := p extent: brush extent.
				(buffRect containsRect: brushRect) ifFalse:
					["Brush is out of buffer region.  Scroll the buffer,
						and fill vacated regions from the display"
					delta := brushRect amountToTranslateWithin: buffRect.
					buffToBuff copyFrom: buff boundingBox in: buff to: delta.
					newBuffRect := buffRect translateBy: delta negated.
					(newBuffRect areasOutside: buffRect) do:
						[:r | dispToBuff copyFrom: r in: Display to: r origin - newBuffRect origin].
					buffRect := newBuffRect].

				"Interpolate from prevP to p..."
				brushToBuff drawFrom: prevP - buffRect origin
									to: p - buffRect origin
									withFirstPoint: false.

				"Update (only) the altered pixels of the destination"
				updateRect := (p min: prevP) corner: (p max: prevP) + brush extent.
				buffToDisplay copy: updateRect from: updateRect origin - buffRect origin in: buff.
				prevP := p]]]! !

!BitBlt class methodsFor: 'examples' stamp: 'di 12/1/97 12:09'!
antiAliasDemo 
	"To run this demo, use...
		Display restoreAfter: [BitBlt antiAliasDemo]
	Goes immediately into on-screen paint mode.  Option-Click to stop painting."

	"This code exhibits alpha blending in any display depth by performing
	the blend in an off-screen buffer with 32-bit pixels, and then copying
	the result back onto the screen with an appropriate color map. - tk 3/10/97"
	
	"This version uses a sliding buffer for painting that keeps pixels in 32 bits
	as long as they are in the buffer, so as not to lose info by converting down
	to display resolution and back up to 32 bits at each operation. - di 3/15/97"
	
	"This version also uses WarpBlt to paint into twice as large a buffer,
	and then use smoothing when reducing back down to the display.
	In fact this same routine will now work for 3x3 soothing as well.
	Remove the statements 'buff displayAt: 0@0' to hide the buffer. - di 3/19/97"

	| brush buff dispToBuff buffToDisplay mapDto32 map32toD prevP p brushToBuff theta buffRect buffSize buffToBuff brushRect delta newBuffRect updateRect scale p0 |  
	"compute color maps if needed"
	Display depth <= 8 ifTrue: [
		mapDto32 := Color cachedColormapFrom: Display depth to: 32.
		map32toD := Color cachedColormapFrom: 32 to: Display depth].

	"Create a brush with radially varying alpha"
	brush := Form extent: 3@3 depth: 32.
	brush fill: brush boundingBox fillColor: (Color red alpha: 0.05).
	brush fill: (1@1 extent: 1@1) fillColor: (Color red alpha: 0.2).

	scale := 2.  "Actual drawing happens at this magnification"
	"Scale brush up for painting in magnified buffer"
	brush := brush magnify: brush boundingBox by: scale.

	"Now paint with the brush using alpha blending."
	buffSize := 100.
	buff := Form extent: (brush extent + buffSize) * scale depth: 32.  "Travelling 32-bit buffer"
	dispToBuff := (WarpBlt toForm: buff)  "From Display to buff - magnify by 2"
		sourceForm: Display;
		colorMap: mapDto32;
		combinationRule: Form over.
	brushToBuff := (BitBlt toForm: buff)  "From brush to buff"
		sourceForm: brush;
		sourceOrigin: 0@0;
		combinationRule: Form blend.
	buffToDisplay := (WarpBlt toForm: Display)  "From buff to Display - shrink by 2"
		sourceForm: buff;
		colorMap: map32toD;
		cellSize: scale;  "...and use smoothing"
		combinationRule: Form over.
	buffToBuff := BitBlt toForm: buff.  "This is for slewing the buffer"

	[Sensor yellowButtonPressed] whileFalse:
		[prevP := nil.
		buffRect := Sensor cursorPoint - (buff extent // scale // 2) extent: buff extent // scale.
		p0 := (buff extent // 2) - (buffRect extent // 2).
		dispToBuff copyQuad: buffRect innerCorners toRect: buff boundingBox.
buff displayAt: 0@0.  "** remove to hide sliding buffer **"
		[Sensor redButtonPressed] whileTrue:
			["Here is the painting loop"
			p := Sensor cursorPoint - buffRect origin + p0.  "p, prevP are rel to buff origin"
			(prevP == nil or: [prevP ~= p]) ifTrue:
				[prevP == nil ifTrue: [prevP := p].
				(p dist: prevP) > (buffSize-1) ifTrue:
					["Stroke too long to fit in buffer -- clip to buffer,
						and next time through will do more of it"
					theta := (p-prevP) theta.
					p := ((theta cos@theta sin) * (buffSize-2) asFloat + prevP) truncated].
				brushRect := p extent: brush extent.
				((buff boundingBox insetBy: scale) containsRect: brushRect) ifFalse:
					["Brush is out of buffer region.  Scroll the buffer,
						and fill vacated regions from the display"
					delta := (brushRect amountToTranslateWithin: (buff boundingBox insetBy: scale)) // scale.
					buffToBuff copyFrom: buff boundingBox in: buff to: delta*scale.
					newBuffRect := buffRect translateBy: delta negated.
					p := p translateBy: delta*scale.
					prevP := prevP translateBy: delta*scale.
					(newBuffRect areasOutside: buffRect) do:
						[:r | dispToBuff copyQuad: r innerCorners toRect: (r origin - newBuffRect origin*scale extent: r extent*scale)].
					buffRect := newBuffRect].

				"Interpolate from prevP to p..."
				brushToBuff drawFrom: prevP to: p withFirstPoint: false.
buff displayAt: 0@0.  "** remove to hide sliding buffer **"

				"Update (only) the altered pixels of the destination"
				updateRect := (p min: prevP) corner: (p max: prevP) + brush extent.
				updateRect := updateRect origin // scale * scale
						corner: updateRect corner + scale // scale * scale.
				buffToDisplay copyQuad: updateRect innerCorners
							toRect: (updateRect origin // scale + buffRect origin
										extent: updateRect extent // scale).
				prevP := p]]]! !

!BitBlt class methodsFor: 'benchmarks' stamp: 'nice 6/11/2010 21:32'!
benchDiffsFrom: before to: afterwards
	"Given two outputs of BitBlt>>benchmark show the relative improvements."
	| old new log oldLine newLine oldVal newVal improvement |
	log := WriteStream on: String new.
	old := ReadStream on: before.
	new := ReadStream on: afterwards.
	[old atEnd or:[new atEnd]] whileFalse:[
		oldLine := old nextLine.
		newLine := new nextLine.
		(oldLine includes: Character tab) ifTrue:[
			oldLine := ReadStream on: oldLine.
			newLine := ReadStream on: newLine.
			Transcript cr; show: (oldLine upTo: Character tab); tab.
			log cr; nextPutAll: (newLine upTo: Character tab); tab.

			[oldLine skipSeparators. newLine skipSeparators.
			oldLine atEnd] whileFalse:[
				oldVal := Integer readFrom: oldLine.
				newVal := Integer readFrom: newLine.
				improvement := oldVal asFloat / newVal asFloat roundTo: 0.01.
				Transcript show: improvement printString; tab; tab.
				log print: improvement; tab; tab].
		] ifFalse:[
			Transcript cr; show: oldLine.
			log cr; nextPutAll: oldLine.
		].
	].
	^log contents! !

!BitBlt class methodsFor: 'benchmarks' stamp: 'nice 12/27/2009 03:11'!
benchmark		"BitBlt benchmark"
	"Run a benchmark on different combinations rules, source/destination depths and BitBlt modes. Note: This benchmark doesn't give you any 'absolute' value - it is intended only for benchmarking improvements in the bitblt code and nothing else.
	Attention: *this*may*take*a*while*"
	| destRect log |
	log := WriteStream on: String new.
	destRect := 0@0 extent: 600@600.
	"Form paint/Form over - the most common rules"
	#( 25 3 ) do:[:rule|
		Transcript cr; show:'---- Combination rule: ', rule printString,' ----'.
		log cr; nextPutAll:'---- Combination rule: ', rule printString,' ----'.
		#(1 2 4 8 16 32) do:[:destDepth| | dest |
			dest := nil.
			dest := Form extent: destRect extent depth: destDepth.
			Transcript cr.
			log cr.
			#(1 2 4 8 16 32) do:[:sourceDepth| | t source bb |
				Transcript cr; show: sourceDepth printString, ' => ', destDepth printString.
				log cr; nextPutAll: sourceDepth printString, ' => ', destDepth printString.
				source := nil. bb := nil.
				source := Form extent: destRect extent depth: sourceDepth.
				(source getCanvas) fillOval: dest boundingBox color: Color yellow borderWidth: 30 borderColor: Color black.
				bb := WarpBlt toForm: dest.
				bb sourceForm: source.
				bb sourceRect: source boundingBox.
				bb destRect: dest boundingBox.
				bb colorMap: (source colormapIfNeededFor: dest).
				bb combinationRule: rule.

				"Measure speed of copyBits"
				t := Time millisecondsToRun:[bb copyBits].
				Transcript tab; show: t printString.
				log tab; nextPutAll: t printString.

				bb sourceForm: source destRect: source boundingBox.

				"Measure speed of 1x1 warpBits"
				bb cellSize: 1.
				t := Time millisecondsToRun:[bb warpBits].
				Transcript tab; show: t printString.
				log tab; nextPutAll: t printString.

				"Measure speed of 2x2 warpBits"
				bb cellSize: 2.
				t := Time millisecondsToRun:[bb warpBits].
				Transcript tab; show: t printString.
				log tab; nextPutAll: t printString.

				"Measure speed of 3x3 warpBits"
				bb cellSize: 3.
				t := Time millisecondsToRun:[bb warpBits].
				Transcript tab; show: t printString.
				log tab; nextPutAll: t printString.
			].
		].
	].
	^log contents! !

!BitBlt class methodsFor: 'benchmarks' stamp: 'nice 12/27/2009 03:11'!
benchmark2		"BitBlt benchmark"
	"Run a benchmark on different combinations rules, source/destination depths and BitBlt modes. Note: This benchmark doesn't give you any 'absolute' value - it is intended only for benchmarking improvements in the bitblt code and nothing else.
	Attention: *this*may*take*a*while*"
	| destRect log |
	log := WriteStream on: String new.
	destRect := 0@0 extent: 600@600.
	"Form paint/Form over - the most common rules"
	#( 25 3 ) do:[:rule|
		Transcript cr; show:'---- Combination rule: ', rule printString,' ----'.
		log cr; nextPutAll:'---- Combination rule: ', rule printString,' ----'.
		#(1 2 4 8 16 32) do:[:destDepth| | dest |
			dest := nil.
			dest := Form extent: destRect extent depth: destDepth.
			Transcript cr.
			log cr.
			#(1 2 4 8 16 32) do:[:sourceDepth| | t bb source |
				Transcript cr; show: sourceDepth printString, ' => ', destDepth printString.
				log cr; nextPutAll: sourceDepth printString, ' => ', destDepth printString.
				source := nil. bb := nil.
				source := Form extent: destRect extent depth: sourceDepth.
				(source getCanvas) fillOval: dest boundingBox color: Color yellow borderWidth: 30 borderColor: Color black.
				bb := WarpBlt toForm: dest.
				bb sourceForm: source.
				bb sourceRect: source boundingBox.
				bb destRect: dest boundingBox.
				bb colorMap: (source colormapIfNeededFor: dest).
				bb combinationRule: rule.

				"Measure speed of copyBits"
				t := Time millisecondsToRun:[1 to: 10 do:[:i| bb copyBits]].
				Transcript tab; show: t printString.
				log tab; nextPutAll: t printString.

				bb sourceForm: source destRect: source boundingBox.

				"Measure speed of 1x1 warpBits"
				bb cellSize: 1.
				t := Time millisecondsToRun:[1 to: 4 do:[:i| bb warpBits]].
				Transcript tab; show: t printString.
				log tab; nextPutAll: t printString.

				"Measure speed of 2x2 warpBits"
				bb cellSize: 2.
				t := Time millisecondsToRun:[bb warpBits].
				Transcript tab; show: t printString.
				log tab; nextPutAll: t printString.

				"Measure speed of 3x3 warpBits"
				bb cellSize: 3.
				t := Time millisecondsToRun:[bb warpBits].
				Transcript tab; show: t printString.
				log tab; nextPutAll: t printString.
			].
		].
	].
	^log contents! !

!BitBlt class methodsFor: 'benchmarks' stamp: 'nice 12/27/2009 03:11'!
benchmark3		"BitBlt benchmark"
	"Run a benchmark on different combinations rules, source/destination depths and BitBlt modes. Note: This benchmark doesn't give you any 'absolute' value - it is intended only for benchmarking improvements in the bitblt code and nothing else.
	Attention: *this*may*take*a*while*"
	| destRect log |
	log := WriteStream on: String new.
	destRect := 0@0 extent: 600@600.
	"Form paint/Form over - the most common rules"
	#( 25 3 ) do:[:rule|
		Transcript cr; show:'---- Combination rule: ', rule printString,' ----'.
		log cr; nextPutAll:'---- Combination rule: ', rule printString,' ----'.
		#(1 2 4 8 16 32) do:[:destDepth| | dest |
			dest := nil.
			dest := Form extent: destRect extent depth: destDepth.
			Transcript cr.
			log cr.
			#(1 2 4 8 16 32) do:[:sourceDepth| | t source bb |
				Transcript cr; show: sourceDepth printString, ' => ', destDepth printString.
				log cr; nextPutAll: sourceDepth printString, ' => ', destDepth printString.
				source := nil. bb := nil.
				source := Form extent: destRect extent depth: sourceDepth.
				(source getCanvas) fillOval: dest boundingBox color: Color yellow borderWidth: 30 borderColor: Color black.
				bb := WarpBlt toForm: dest.
				bb sourceForm: source.
				bb sourceRect: source boundingBox.
				bb destRect: dest boundingBox.
				bb colorMap: (source colormapIfNeededFor: dest).
				bb combinationRule: rule.

				"Measure speed of copyBits"
				t := Time millisecondsToRun:[1 to: 10 do:[:i| bb copyBits]].
				Transcript tab; show: t printString.
				log tab; nextPutAll: t printString.

				bb sourceForm: source destRect: source boundingBox.

				"Measure speed of 1x1 warpBits"
				bb cellSize: 1.
				t := Time millisecondsToRun:[1 to: 4 do:[:i| bb warpBits]].
				Transcript tab; show: t printString.
				log tab; nextPutAll: t printString.

				"Measure speed of 2x2 warpBits"
				bb cellSize: 2.
				t := Time millisecondsToRun:[bb warpBits].
				Transcript tab; show: t printString.
				log tab; nextPutAll: t printString.

				"Measure speed of 3x3 warpBits"
				bb cellSize: 3.
				t := Time millisecondsToRun:[bb warpBits].
				Transcript tab; show: t printString.
				log tab; nextPutAll: t printString.
			].
		].
	].
	^log contents! !

!BitBlt class methodsFor: 'instance creation' stamp: 'di 3/2/98 12:53'!
bitPeekerFromForm: sourceForm
	"Answer an instance to be used extract individual pixels from the given Form. The destination for a 1x1 copyBits will be the low order bits of (bits at: 1)."
	| pixPerWord |
	pixPerWord := 32 // sourceForm depth.
	sourceForm unhibernate.
	^ self destForm: (Form extent: pixPerWord@1 depth: sourceForm depth)
	 	sourceForm: sourceForm
		halftoneForm: nil
		combinationRule: Form over
		destOrigin: (pixPerWord - 1)@0
		sourceOrigin: 0@0
		extent: 1@1
		clipRect: (0@0 extent: pixPerWord@1)
! !

!BitBlt class methodsFor: 'instance creation' stamp: 'di 3/2/98 12:53'!
bitPokerToForm: destForm
	"Answer an instance to be used for valueAt: aPoint put: pixValue.
	The source for a 1x1 copyBits will be the low order of (bits at: 1)"
	| pixPerWord |
	pixPerWord := 32//destForm depth.
	destForm unhibernate.
	^ self destForm: destForm
	 	sourceForm: (Form extent: pixPerWord@1 depth: destForm depth)
		halftoneForm: nil combinationRule: Form over
		destOrigin: 0@0 sourceOrigin: (pixPerWord-1)@0
		extent: 1@1 clipRect: (0@0 extent: destForm extent)
! !

!BitBlt class methodsFor: 'class initialization' stamp: 'ar 2/26/2010 23:02'!
cleanUp
	"Flush caches"

	self recreateColorMaps.! !

!BitBlt class methodsFor: 'instance creation' stamp: 'tpr 3/15/2013 18:43'!
current
	"Return the class currently to be used for BitBlt"
	^self! !

!BitBlt class methodsFor: 'instance creation' stamp: ''!
destForm: df sourceForm: sf fillColor: hf combinationRule: cr destOrigin: destOrigin sourceOrigin: sourceOrigin extent: extent clipRect: clipRect 
	"Answer an instance of me with values set according to the arguments."

	^ self new
		setDestForm: df
		sourceForm: sf
		fillColor: hf
		combinationRule: cr
		destOrigin: destOrigin
		sourceOrigin: sourceOrigin
		extent: extent
		clipRect: clipRect! !

!BitBlt class methodsFor: 'instance creation' stamp: ''!
destForm: df sourceForm: sf halftoneForm: hf combinationRule: cr destOrigin: destOrigin sourceOrigin: sourceOrigin extent: extent clipRect: clipRect 
	"Answer an instance of me with values set according to the arguments."

	^ self new
		setDestForm: df
		sourceForm: sf
		fillColor: hf
		combinationRule: cr
		destOrigin: destOrigin
		sourceOrigin: sourceOrigin
		extent: extent
		clipRect: clipRect! !

!BitBlt class methodsFor: 'private' stamp: 'jrm 2/21/2001 23:45'!
exampleAt: originPoint rule: rule fillColor: mask 
	"This builds a source and destination form and copies the source to the
	destination using the specifed rule and mask. It is called from the method
	named exampleOne. Only works with Display depth of 1"

	| s d border aBitBlt | 
	border:=Form extent: 32@32.
	border fillBlack.
	border fill: (1@1 extent: 30@30) fillColor: Color white.
	s := Form extent: 32@32.
	s fillWhite.
	s fillBlack: (7@7 corner: 25@25).
	d := Form extent: 32@32.
	d fillWhite.
	d fillBlack: (0@0 corner: 32@16).

	s displayOn: Display at: originPoint.
	border displayOn: Display at: originPoint rule: Form under.
	d displayOn: Display at: originPoint + (s width @0).
	border displayOn: Display at: originPoint + (s width @0) rule: Form under.

	d displayOn: Display at: originPoint + (s extent // (2 @ 1)). 
	aBitBlt := BitBlt
		destForm: Display
		sourceForm: s
		fillColor: mask
		combinationRule: rule
		destOrigin: originPoint + (s extent // (2 @ 1))
		sourceOrigin: 0 @ 0
		extent: s extent
		clipRect: Display computeBoundingBox.
	aBitBlt copyBits.
	border 
		displayOn: Display at: originPoint + (s extent // (2 @ 1))
		rule: Form under.

	"BitBlt exampleAt: 100@100 rule: 0 fillColor: nil"  ! !

!BitBlt class methodsFor: 'examples' stamp: 'ar 5/4/2001 16:02'!
exampleColorMap	"BitBlt exampleColorMap"
	"This example shows what one can do with the fixed part of a color map. The color map, as setup below, rotates the bits of a pixel all the way around. Thus you'll get a (sometime strange looking ;-) animation of colors which will end up exactly the way it looked at the beginning. The example is given to make you understand that the masks and shifts can be used for a lot more than simply color converting pixels. In this example, for instance, we use only two of the four independent shifters."
	| cc bb |
	cc := ColorMap masks: {
		1 << (Display depth-1). "mask out high bit of color component"
		1 << (Display depth-1) - 1. "mask all other bits"
		0.
		0}
		shifts: {
			1 - Display depth. "shift right to bottom most position"
			1. "shift all other pixels one bit left"
			0.
			0}.
	bb := BitBlt toForm: Display.
	bb 
		sourceForm: Display;
		combinationRule: 3;
		colorMap: cc.
	1 to: Display depth do:[:i|
		bb copyBits.
		Display forceDisplayUpdate.
	].
! !

!BitBlt class methodsFor: 'examples' stamp: 'dtl 2/11/2010 23:38'!
exampleOne
	"This tests BitBlt by displaying the result of all sixteen combination rules that BitBlt is capable of using. (Please see the comment in BitBlt for the meaning of the combination rules). This only works at Display depth of 1. (Rule 15 does not work?)"
	| pathClass path displayDepth |

	displayDepth := Display depth.
	Display newDepth: 1.

	(Smalltalk hasClassNamed: #Path)
		ifTrue: [pathClass := Smalltalk at: #Path]
		ifFalse: [^self inform: 'MVC class Path not present in this image'].
	path := pathClass new.
	0 to: 3 do: [:i | 0 to: 3 do: [:j | path add: j * 100 @ (i * 75)]].
	Display fillWhite.
	path := path translateBy: 60 @ 40.
	1 to: 16 do: [:index | BitBlt
			exampleAt: (path at: index)
			rule: index - 1
			fillColor: nil].

	[Sensor anyButtonPressed] whileFalse: [].
	Display newDepth: displayDepth.

	"BitBlt exampleOne"! !

!BitBlt class methodsFor: 'examples' stamp: 'jrm 2/21/2001 23:43'!
exampleTwo
	"This is to test painting with a gray tone. It also tests that the seaming with gray patterns is correct in the microcode. Lets you paint for a while and then automatically stops. This only works at Depth of 1."
	| f aBitBlt displayDepth |
	"create a small black Form source as a brush. "
	displayDepth := Display depth.
	Display newDepth: 1.
	f := Form extent: 20 @ 20.
	f fillBlack.
	"create a BitBlt which will OR gray into the display. "
	aBitBlt := BitBlt
		destForm: Display
		sourceForm: f
		fillColor: Color gray
		combinationRule: Form over
		destOrigin: Sensor cursorPoint
		sourceOrigin: 0 @ 0
		extent: f extent
		clipRect: Display computeBoundingBox.
	"paint the gray Form on the screen for a while. "
	[Sensor anyButtonPressed] whileFalse: 
		[aBitBlt destOrigin: Sensor cursorPoint.
		aBitBlt copyBits].
	Display newDepth: displayDepth.
	"BitBlt exampleTwo"! !

!BitBlt class methodsFor: 'class initialization' stamp: 'jmv 9/7/2009 09:32'!
initialize
	self recreateColorMaps! !

!BitBlt class methodsFor: 'private' stamp: 'jmv 8/2/2009 21:37'!
recreateColorMaps
	CachedFontColorMaps := ColorConvertingMaps := nil! !

!BitBlt class methodsFor: 'preferences' stamp: 'ul 3/30/2011 01:03'!
subPixelRenderColorFonts

	<preference: 'Subpixel font rendering for color fonts'
	category: 'Graphics'
	description: 'If true, non-black opaque fonts are rendered using subpixel combination rules by BitBlt. Subpixel font rendering has to be enabled to take effect.'
	type: #Boolean>
	^SubPixelRenderColorFonts ifNil: [ true ]

	! !

!BitBlt class methodsFor: 'preferences' stamp: 'ul 3/30/2011 01:03'!
subPixelRenderColorFonts: aBoolean

	SubPixelRenderColorFonts := aBoolean

	! !

!BitBlt class methodsFor: 'preferences' stamp: 'ul 3/30/2011 01:01'!
subPixelRenderFonts

	<preference: 'Subpixel font rendering'
	category: 'Graphics'
	description: 'If true, black fonts are rendered using subpixel combination rules by BitBlt.'
	type: #Boolean>
	^SubPixelRenderFonts ifNil: [ true ]

	! !

!BitBlt class methodsFor: 'preferences' stamp: 'ul 3/30/2011 00:58'!
subPixelRenderFonts: aBoolean

	SubPixelRenderFonts := aBoolean

	! !

!BitBlt class methodsFor: 'instance creation' stamp: ''!
toForm: aForm
	^ self new setDestForm: aForm! !

!BitBlt methodsFor: 'copying' stamp: 'jmv 8/5/2009 22:09'!
basicDisplayString: aString from: startIndex to: stopIndex at: aPoint strikeFont: font kern: kernDelta

	destY := aPoint y.
	destX := aPoint x.

	"the following are not really needed, but theBitBlt primitive will fail if not set"
	sourceX ifNil: [sourceX := 100].
	width ifNil: [width := 100].

	self primDisplayString: aString from: startIndex to: stopIndex
			map: font characterToGlyphMap xTable: font xTable
			kern: kernDelta.
	^ destX@destY.
! !

!BitBlt methodsFor: 'private' stamp: 'hg 6/27/2000 12:27'!
cachedFontColormapFrom: sourceDepth to: destDepth

	| srcIndex map |
	CachedFontColorMaps class == Array 
		ifFalse: [CachedFontColorMaps := (1 to: 9) collect: [:i | Array new: 32]].
	srcIndex := sourceDepth.
	sourceDepth > 8 ifTrue: [srcIndex := 9].
	(map := (CachedFontColorMaps at: srcIndex) at: destDepth) ~~ nil ifTrue: [^ map].

	map := (Color cachedColormapFrom: sourceDepth to: destDepth) copy.
	(CachedFontColorMaps at: srcIndex) at: destDepth put: map.
	^ map
! !

!BitBlt methodsFor: 'accessing' stamp: 'ar 12/30/2001 20:33'!
clipByX1: x1 y1: y1 x2: x2 y2: y2
	| right bottom |
	right := clipX + clipWidth.
	bottom := clipY + clipHeight.
	x1 > clipX ifTrue:[clipX := x1].
	y1 > clipY ifTrue:[clipY := y1].
	x2 < right ifTrue:[right := x2].
	y2 < bottom ifTrue:[bottom := y2].
	clipWidth := right - clipX.
	clipHeight := bottom - clipY.
	clipWidth < 0 ifTrue:[clipWidth := 0].
	clipHeight < 0 ifTrue:[clipHeight := 0].! !

!BitBlt methodsFor: 'accessing' stamp: 'ar 12/30/2001 20:31'!
clipBy: aRectangle
	| aPoint right bottom |
	right := clipX + clipWidth.
	bottom := clipY + clipHeight.
	aPoint := aRectangle origin.
	aPoint x > clipX ifTrue:[clipX := aPoint x].
	aPoint y > clipY ifTrue:[clipY := aPoint y].
	aPoint := aRectangle corner.
	aPoint x < right ifTrue:[right := aPoint x].
	aPoint y < bottom ifTrue:[bottom := aPoint y].
	clipWidth := right - clipX.
	clipHeight := bottom - clipY.
	clipWidth < 0 ifTrue:[clipWidth := 0].
	clipHeight < 0 ifTrue:[clipHeight := 0].! !

!BitBlt methodsFor: 'accessing' stamp: 'ar 5/17/2000 18:58'!
clipHeight
	^clipHeight! !

!BitBlt methodsFor: 'accessing' stamp: ''!
clipHeight: anInteger 
	"Set the receiver's clipping area height to be the argument, anInteger."

	clipHeight := anInteger! !

!BitBlt methodsFor: 'private' stamp: 'ar 3/8/2003 00:34'!
clipRange
	"clip and adjust source origin and extent appropriately"
	"first in x"
	| sx sy dx dy bbW bbH |
	"fill in the lazy state if needed"
	destX ifNil:[destX := 0].
	destY ifNil:[destY := 0].
	width ifNil:[width := destForm width].
	height ifNil:[height := destForm height].
	sourceX ifNil:[sourceX := 0].
	sourceY ifNil:[sourceY := 0].
	clipX ifNil:[clipX := 0].
	clipY ifNil:[clipY := 0].
	clipWidth ifNil:[clipWidth := destForm width].
	clipHeight ifNil:[clipHeight := destForm height].

	destX >= clipX
		ifTrue: [sx := sourceX.
				dx := destX.
				bbW := width]
		ifFalse: [sx := sourceX + (clipX - destX).
				bbW := width - (clipX - destX).
				dx := clipX].
	(dx + bbW) > (clipX + clipWidth)
		ifTrue: [bbW := bbW - ((dx + bbW) - (clipX + clipWidth))].
	"then in y"
	destY >= clipY
		ifTrue: [sy := sourceY.
				dy := destY.
				bbH := height]
		ifFalse: [sy := sourceY + clipY - destY.
				bbH := height - (clipY - destY).
				dy := clipY].
	(dy + bbH) > (clipY + clipHeight)
		ifTrue: [bbH := bbH - ((dy + bbH) - (clipY + clipHeight))].
	sourceForm ifNotNil:[
		sx < 0
			ifTrue: [dx := dx - sx.
					bbW := bbW + sx.
					sx := 0].
		sx + bbW > sourceForm width
			ifTrue: [bbW := bbW - (sx + bbW - sourceForm width)].
		sy < 0
			ifTrue: [dy := dy - sy.
					bbH := bbH + sy.
					sy := 0].
		sy + bbH > sourceForm height
			ifTrue: [bbH := bbH - (sy + bbH - sourceForm height)].
	].
	(bbW <= 0 or:[bbH <= 0]) ifTrue:[
		sourceX := sourceY := destX := destY := clipX := clipY := width := height := 0.
		^true].
	(sx = sourceX 
		and:[sy = sourceY 
		and:[dx = destX 
		and:[dy = destY 
		and:[bbW = width 
		and:[bbH = height]]]]]) ifTrue:[^false].
	sourceX := sx.
	sourceY := sy.
	destX := dx.
	destY := dy.
	width := bbW.
	height := bbH.
	^true! !

!BitBlt methodsFor: 'accessing' stamp: ''!
clipRect
	"Answer the receiver's clipping area rectangle."

	^clipX @ clipY extent: clipWidth @ clipHeight! !

!BitBlt methodsFor: 'accessing' stamp: 'ar 10/4/2000 16:37'!
clipRect: aRectangle 
	"Set the receiver's clipping area rectangle to be the argument, aRectangle."

	clipX := aRectangle left truncated.
	clipY := aRectangle top truncated.
	clipWidth := aRectangle right truncated - clipX.
	clipHeight := aRectangle bottom truncated - clipY.! !

!BitBlt methodsFor: 'accessing' stamp: 'ar 5/17/2000 18:58'!
clipWidth
	^clipWidth! !

!BitBlt methodsFor: 'accessing' stamp: ''!
clipWidth: anInteger 
	"Set the receiver's clipping area width to be the argument, anInteger."

	clipWidth := anInteger! !

!BitBlt methodsFor: 'accessing' stamp: 'ar 5/17/2000 18:58'!
clipX
	^clipX! !

!BitBlt methodsFor: 'accessing' stamp: ''!
clipX: anInteger 
	"Set the receiver's clipping area top left x coordinate to be the argument, 
	anInteger."

	clipX := anInteger! !

!BitBlt methodsFor: 'accessing' stamp: 'ar 5/17/2000 18:58'!
clipY
	^clipY! !

!BitBlt methodsFor: 'accessing' stamp: ''!
clipY: anInteger 
	"Set the receiver's clipping area top left y coordinate to be the argument, 
	anInteger."

	clipY := anInteger! !

!BitBlt methodsFor: 'accessing' stamp: 'tk 8/15/2001 10:56'!
color
	"Return the current fill color as a Color.  
	 Gives the wrong answer if the halftoneForm is a complex pattern of more than one word."

	halftoneForm ifNil: [^ Color black].
	^ Color colorFromPixelValue: halftoneForm first depth: destForm depth! !

!BitBlt methodsFor: 'private' stamp: 'nice 8/27/2010 19:41'!
colorConvertingMap: targetColor from: sourceDepth to: destDepth keepSubPixelAA: keepSubPix

	| srcIndex map mapsForSource mapsForSourceAndDest |
	ColorConvertingMaps class == Array 
		ifFalse: [ColorConvertingMaps := (1 to: 10) collect: [:i | Array new: 32]].
		
	srcIndex := sourceDepth.
	sourceDepth > 8 ifTrue: [ srcIndex := keepSubPix ifTrue: [9] ifFalse: [10] ].
	mapsForSource := ColorConvertingMaps at: srcIndex.
	mapsForSourceAndDest := (mapsForSource at: destDepth) ifNil: [ mapsForSource at: destDepth put: Dictionary new ].
	
	map := mapsForSourceAndDest at: targetColor ifAbsentPut: [
		Color computeColorConvertingMap: targetColor from: sourceDepth to: destDepth keepSubPixelAA: keepSubPix ].

	^ map! !

!BitBlt methodsFor: 'accessing' stamp: ''!
colorMap
	^ colorMap! !

!BitBlt methodsFor: 'accessing' stamp: 'ar 5/4/2001 15:45'!
colorMap: map
	"See last part of BitBlt comment. 6/18/96 tk"
	colorMap := map.! !

!BitBlt methodsFor: 'accessing' stamp: 'tween 8/1/2006 17:52'!
combinationRule
	"Answer the receiver's combinationRule"
	
	^combinationRule! !

!BitBlt methodsFor: 'accessing' stamp: ''!
combinationRule: anInteger 
	"Set the receiver's combination rule to be the argument, anInteger, a 
	number in the range 0-15."

	combinationRule := anInteger! !

!BitBlt methodsFor: 'copying' stamp: 'tfel 2/12/2015 16:27'!
copyBits
	"Primitive. Perform the movement of bits from the source form to the 
	destination form. Fail if any variables are not of the right type (Integer, 
	Float, or Form) or if the combination rule is not implemented. 
	In addition to the original 16 combination rules, this BitBlt supports
	16	fail (to simulate paint)
	17	fail (to simulate mask)
	18	sourceWord + destinationWord
	19	sourceWord - destinationWord
	20	rgbAdd: sourceWord with: destinationWord
	21	rgbSub: sourceWord with: destinationWord
	22	rgbDiff: sourceWord with: destinationWord
	23	tallyIntoMap: destinationWord
	24	alphaBlend: sourceWord with: destinationWord
	25	pixPaint: sourceWord with: destinationWord
	26	pixMask: sourceWord with: destinationWord
	27	rgbMax: sourceWord with: destinationWord
	28	rgbMin: sourceWord with: destinationWord
	29	rgbMin: sourceWord bitInvert32 with: destinationWord
"
	<primitive: 'primitiveCopyBits' module: 'BitBltPlugin'>

	"Check for compressed source, destination or halftone forms"
	(combinationRule >= 30 and: [combinationRule <= 31]) ifTrue:
		["No alpha specified -- re-run with alpha = 1.0"
		^ self copyBitsTranslucent: 255].
	((sourceForm isForm) and: [sourceForm unhibernate])
		ifTrue: [^ self copyBits].
	((destForm isForm) and: [destForm unhibernate])
		ifTrue: [^ self copyBits].
	((halftoneForm isForm) and: [halftoneForm unhibernate])
		ifTrue: [^ self copyBits].

	"Check for unimplmented rules"
	combinationRule = Form oldPaint ifTrue: [^ self paintBits].
	combinationRule = Form oldErase1bitShape ifTrue: [^ self eraseBits].

	"Check if BitBlt doesn't support full color maps"
	(colorMap notNil and:[colorMap isColormap]) ifTrue:[
		colorMap := colorMap colors.
		^self copyBits].
	"Check if clipping gots us way out of range"
	self clipRange ifTrue:[self roundVariables. ^self copyBitsAgain].

	"Convert all numeric parameters to integers and try again."
	self roundVariables.
	^ self copyBitsAgain! !

!BitBlt methodsFor: 'private' stamp: 'ar 2/2/2001 15:09'!
copyBitsAgain
	"Primitive. See BitBlt|copyBits, also a Primitive. Essential. See Object
	documentation whatIsAPrimitive."

	<primitive: 'primitiveCopyBits' module: 'BitBltPlugin'>
	self primitiveFailed! !

!BitBlt methodsFor: 'private' stamp: 'ar 10/25/1998 17:30'!
copyBitsFrom: x0 to: x1 at: y
	destX := x0.
	destY := y.
	sourceX := x0.
	width := (x1 - x0).
	self copyBits.! !

!BitBlt methodsFor: 'copying' stamp: 'nk 4/17/2004 19:42'!
copyBitsTranslucent: factor
	"This entry point to BitBlt supplies an extra argument to specify translucency
	for operations 30 and 31.  The argument must be an integer between 0 and 255."

	<primitive: 'primitiveCopyBits' module: 'BitBltPlugin'>

	"Check for compressed source, destination or halftone forms"
	((sourceForm isForm) and: [sourceForm unhibernate])
		ifTrue: [^ self copyBitsTranslucent: factor].
	((destForm isForm) and: [destForm unhibernate])
		ifTrue: [^ self copyBitsTranslucent: factor].
	((halftoneForm isForm) and: [halftoneForm unhibernate])
		ifTrue: [^ self copyBitsTranslucent: factor].

	self primitiveFailed  "Later do nicer error recovery -- share copyBits recovery"! !

!BitBlt methodsFor: 'copying' stamp: 'ar 5/14/2001 23:32'!
copyForm: srcForm to: destPt rule: rule
	^ self copyForm: srcForm to: destPt rule: rule
		colorMap: (srcForm colormapIfNeededFor: destForm)! !

!BitBlt methodsFor: 'copying' stamp: 'di 7/17/97 10:04'!
copyForm: srcForm to: destPt rule: rule colorMap: map
	sourceForm := srcForm.
	halftoneForm := nil.
	combinationRule := rule.
	destX := destPt x + sourceForm offset x.
	destY := destPt y + sourceForm offset y.
	sourceX := 0.
	sourceY := 0.
	width := sourceForm width.
	height := sourceForm height.
	colorMap := map.
	self copyBits! !

!BitBlt methodsFor: 'copying' stamp: ''!
copyForm: srcForm to: destPt rule: rule color: color
	sourceForm := srcForm.
	halftoneForm := color.
	combinationRule := rule.
	destX := destPt x + sourceForm offset x.
	destY := destPt y + sourceForm offset y.
	sourceX := 0.
	sourceY := 0.
	width := sourceForm width.
	height := sourceForm height.
	self copyBits! !

!BitBlt methodsFor: 'copying' stamp: ''!
copyForm: srcForm to: destPt rule: rule fillColor: color
	sourceForm := srcForm.
	self fillColor: color.	"sets halftoneForm"
	combinationRule := rule.
	destX := destPt x + sourceForm offset x.
	destY := destPt y + sourceForm offset y.
	sourceX := 0.
	sourceY := 0.
	width := sourceForm width.
	height := sourceForm height.
	self copyBits! !

!BitBlt methodsFor: 'copying' stamp: 'ar 5/14/2001 23:32'!
copyFrom: sourceRectangle in: srcForm to: destPt
	| sourceOrigin |
	sourceForm := srcForm.
	halftoneForm := nil.
	combinationRule := 3.  "store"
	destX := destPt x.
	destY := destPt y.
	sourceOrigin := sourceRectangle origin.
	sourceX := sourceOrigin x.
	sourceY := sourceOrigin y.
	width := sourceRectangle width.
	height := sourceRectangle height.
	colorMap := srcForm colormapIfNeededFor: destForm.
	self copyBits! !

!BitBlt methodsFor: 'copying' stamp: ''!
copy: destRectangle from: sourcePt in: srcForm
	| destOrigin |
	sourceForm := srcForm.
	halftoneForm := nil.
	combinationRule := 3.  "store"
	destOrigin := destRectangle origin.
	destX := destOrigin x.
	destY := destOrigin y.
	sourceX := sourcePt x.
	sourceY := sourcePt y.
	width := destRectangle width.
	height := destRectangle height.
	self copyBits! !

!BitBlt methodsFor: 'copying' stamp: 'ar 5/14/2001 23:32'!
copy: destRectangle from: sourcePt in: srcForm fillColor: hf rule: rule
	"Specify a Color to fill, not a Form. 6/18/96 tk"  
	| destOrigin |
	sourceForm := srcForm.
	self fillColor: hf.	"sets halftoneForm"
	combinationRule := rule.
	destOrigin := destRectangle origin.
	destX := destOrigin x.
	destY := destOrigin y.
	sourceX := sourcePt x.
	sourceY := sourcePt y.
	width := destRectangle width.
	height := destRectangle height.
	srcForm == nil ifFalse:
		[colorMap := srcForm colormapIfNeededFor: destForm].
	^ self copyBits! !

!BitBlt methodsFor: 'copying' stamp: ''!
copy: destRectangle from: sourcePt in: srcForm halftoneForm: hf rule: rule 
	| destOrigin |
	sourceForm := srcForm.
	self fillColor: hf.		"sets halftoneForm"
	combinationRule := rule.
	destOrigin := destRectangle origin.
	destX := destOrigin x.
	destY := destOrigin y.
	sourceX := sourcePt x.
	sourceY := sourcePt y.
	width := destRectangle width.
	height := destRectangle height.
	self copyBits! !

!BitBlt methodsFor: 'accessing' stamp: ''!
destForm
	^ destForm! !

!BitBlt methodsFor: 'accessing' stamp: ''!
destOrigin: aPoint 
	"Set the receiver's destination top left coordinates to be those of the 
	argument, aPoint."

	destX := aPoint x.
	destY := aPoint y! !

!BitBlt methodsFor: 'accessing' stamp: 'tk 3/19/97'!
destRect
	"The rectangle we are about to blit to or just blitted to.  "

	^ destX @ destY extent: width @ height! !

!BitBlt methodsFor: 'accessing' stamp: ''!
destRect: aRectangle 
	"Set the receiver's destination form top left coordinates to be the origin of 
	the argument, aRectangle, and set the width and height of the receiver's 
	destination form to be the width and height of aRectangle."

	destX := aRectangle left.
	destY := aRectangle top.
	width := aRectangle width.
	height := aRectangle height! !

!BitBlt methodsFor: 'accessing' stamp: ''!
destX: anInteger 
	"Set the top left x coordinate of the receiver's destination form to be the 
	argument, anInteger."

	destX := anInteger! !

!BitBlt methodsFor: 'accessing' stamp: ''!
destX: x destY: y width: w height: h
	"Combined init message saves 3 sends from DisplayScanner"
	destX := x.
	destY := y.
	width := w.
	height := h.! !

!BitBlt methodsFor: 'accessing' stamp: ''!
destY: anInteger 
	"Set the top left y coordinate of the receiver's destination form to be the 
	argument, anInteger."

	destY := anInteger! !

!BitBlt methodsFor: 'copying' stamp: 'ar 8/14/2009 20:26'!
displayGlyph: aForm at: aPoint left: leftX right: rightX font: aFont
	"Display a glyph in a multi-lingual font. Do 2 pass rendering if necessary.
	This happens when #installStrikeFont:foregroundColor:backgroundColor: sets rule 37 (rgbMul).
	the desired effect is to do two bitblt calls. The first one is with rule 37 and special colormap.
	The second one is rule 34, with a colormap for applying the requested foreground color.
	This two together do component alpha blending, i.e. alpha blend red, green and blue separatedly.
	This is needed for arbitrary color over abitrary background text with subpixel AA."

	| prevRule secondPassMap |
	self sourceForm: aForm.
	destX := aPoint x.
	destY := aPoint y.
	sourceX := leftX.
	sourceY := 0.
	width := rightX - leftX.
	height := aFont height.
	combinationRule = 37 ifTrue:[
		"We need to do a second pass. The colormap set is for use in the second pass."
		secondPassMap := colorMap.
		colorMap := sourceForm depth = destForm depth
			ifFalse: [ self cachedFontColormapFrom: sourceForm depth to: destForm depth ].
		self copyBits.
		prevRule := combinationRule.
		combinationRule := 20. "rgbAdd"
		colorMap := secondPassMap.
		self copyBits.
		combinationRule := prevRule.
	] ifFalse:[self copyBits].! !

!BitBlt methodsFor: 'copying' stamp: 'jmv 8/22/2009 23:56'!
displayString: aString from: startIndex to: stopIndex at: aPoint strikeFont: font kern: kernDelta
	"If required, do a second pass with new rule and colorMap.
	This happens when #installStrikeFont:foregroundColor:backgroundColor: sets rule 37 (rgbMul).
	the desired effect is to do two bitblt calls. The first one is with rule 37 and special colormap.
	The second one is rule 34, with a colormap for applying the requested foreground color.
	This two together do component alpha blending, i.e. alpha blend red, green and blue separatedly.
	This is needed for arbitrary color over abitrary background text with subpixel AA."

	| answer prevRule secondPassMap |
	"If combinationRule is rgbMul, we might need the special two-pass technique for component alpha blending.
	If not, do it simply"
	combinationRule = 37 "rgbMul" ifFalse: [
		^self basicDisplayString: aString from: startIndex to: stopIndex at: aPoint strikeFont: font kern: kernDelta ].
	
	"We need to do a second pass. The colormap set is for use in the second pass."
	secondPassMap := colorMap.
	colorMap := sourceForm depth ~= destForm depth
		ifTrue: [ self cachedFontColormapFrom: sourceForm depth to: destForm depth ].
	answer := self basicDisplayString: aString from: startIndex to: stopIndex at: aPoint strikeFont: font kern: kernDelta.
	colorMap := secondPassMap.
	secondPassMap ifNotNil: [
		prevRule := combinationRule.
		combinationRule := 20. "rgbAdd"
		self basicDisplayString: aString from: startIndex to: stopIndex at: aPoint strikeFont: font kern: kernDelta.
		combinationRule := prevRule ].
	^answer! !

!BitBlt methodsFor: 'line drawing' stamp: ''!
drawFrom: startPoint to: stopPoint 
	
	 ^ self drawFrom: startPoint to: stopPoint withFirstPoint: true! !

!BitBlt methodsFor: 'line drawing' stamp: '6/8/97 15:41 di'!
drawFrom: startPoint to: stopPoint withFirstPoint: drawFirstPoint
	"Draw a line whose end points are startPoint and stopPoint.
	The line is formed by repeatedly calling copyBits at every
	point along the line.  If drawFirstPoint is false, then omit
	the first point so as not to overstrike at line junctions."
	| offset point1 point2 forwards |
	"Always draw down, or at least left-to-right"
	forwards := (startPoint y = stopPoint y and: [startPoint x < stopPoint x])
				or: [startPoint y < stopPoint y].
	forwards
		ifTrue: [point1 := startPoint. point2 := stopPoint]
		ifFalse: [point1 := stopPoint. point2 := startPoint].
	sourceForm == nil ifTrue:
		[destX := point1 x.
		destY := point1 y]
		ifFalse:
		[width := sourceForm width.
		height := sourceForm height.
		offset := sourceForm offset.
		destX := (point1 x + offset x) rounded.
		destY := (point1 y + offset y) rounded].

	"Note that if not forwards, then the first point is the last and vice versa.
	We agree to always paint stopPoint, and to optionally paint startPoint."
	(drawFirstPoint or: [forwards == false  "ie this is stopPoint"])
		ifTrue: [self copyBits].
	self drawLoopX: (point2 x - point1 x) rounded 
				  Y: (point2 y - point1 y) rounded.
	(drawFirstPoint or: [forwards  "ie this is stopPoint"])
		ifTrue: [self copyBits].
! !

!BitBlt methodsFor: 'line drawing' stamp: 'ar 2/2/2001 15:09'!
drawLoopX: xDelta Y: yDelta 
	"Primitive. Implements the Bresenham plotting algorithm (IBM Systems
	Journal, Vol. 4 No. 1, 1965). It chooses a principal direction, and
	maintains a potential, P. When P's sign changes, it is time to move in
	the minor direction as well. This particular version does not write the
	first and last points, so that these can be called for as needed in client code.
	Optional. See Object documentation whatIsAPrimitive."
	| dx dy px py P |
	<primitive: 'primitiveDrawLoop' module: 'BitBltPlugin'>
	dx := xDelta sign.
	dy := yDelta sign.
	px := yDelta abs.
	py := xDelta abs.
	"self copyBits."
	py > px
		ifTrue: 
			["more horizontal"
			P := py // 2.
			1 to: py do: 
				[:i |
				destX := destX + dx.
				(P := P - px) < 0 ifTrue: 
						[destY := destY + dy.
						P := P + py].
				i < py ifTrue: [self copyBits]]]
		ifFalse: 
			["more vertical"
			P := px // 2.
			1 to: px do:
				[:i |
				destY := destY + dy.
				(P := P - py) < 0 ifTrue: 
						[destX := destX + dx.
						P := P + px].
				i < px ifTrue: [self copyBits]]]! !

!BitBlt methodsFor: 'private' stamp: ''!
eraseBits
	"Perform the erase operation, which puts 0's in the destination
	wherever the source (which is assumed to be just 1 bit deep)
	has a 1.  This requires the colorMap to be set in order to AND
	all 1's into the destFrom pixels regardless of their size."
	| oldMask oldMap |
	oldMask := halftoneForm.
	halftoneForm := nil.
	oldMap := colorMap.
	self colorMap: (Bitmap with: 0 with: 16rFFFFFFFF).
	combinationRule := Form erase.
	self copyBits. 		"Erase the dest wherever the source is 1"
	halftoneForm := oldMask.	"already converted to a Bitmap"
	colorMap := oldMap! !

!BitBlt methodsFor: 'accessing' stamp: ''!
fillColor
	^ halftoneForm! !

!BitBlt methodsFor: 'accessing' stamp: 'ar 5/14/2001 23:25'!
fillColor: aColorOrPattern 
	"The destForm will be filled with this color or pattern of colors.  May be an old Color, a new type Color, a Bitmap (see BitBlt comment), a Pattern, or a Form.  6/18/96 tk"

	aColorOrPattern == nil ifTrue: [halftoneForm := nil. ^ self].
	destForm == nil ifTrue: [self error: 'Must set destForm first'].
	halftoneForm := destForm bitPatternFor: aColorOrPattern ! !

!BitBlt methodsFor: 'copying' stamp: ''!
fill: destRect fillColor: grayForm rule: rule
	"Fill with a Color, not a Form. 6/18/96 tk"
	sourceForm := nil.
	self fillColor: grayForm.		"sets halftoneForm"
	combinationRule := rule.
	destX := destRect left.
	destY := destRect top.
	sourceX := 0.
	sourceY := 0.
	width := destRect width.
	height := destRect height.
	self copyBits! !

!BitBlt methodsFor: 'private' stamp: 'ar 5/26/2000 16:38'!
getPluginName
	"Private. Return the name of the plugin representing BitBlt.
	Used for dynamically switching between different BB representations only."
	^'BitBltPlugin'! !

!BitBlt methodsFor: 'accessing' stamp: 'tbn 9/14/2004 20:38'!
halftoneForm
	"Returns the receivers half tone form. See class commment."
	
	^halftoneForm! !

!BitBlt methodsFor: 'accessing' stamp: 'tbn 9/14/2004 20:39'!
halftoneForm: aBitmap
	"Sets the receivers half tone form. See class commment."
	
	halftoneForm := aBitmap
	
 ! !

!BitBlt methodsFor: 'accessing' stamp: ''!
height: anInteger 
	"Set the receiver's destination form height to be the argument, anInteger."

	height := anInteger! !

!BitBlt methodsFor: 'private' stamp: 'ul 3/30/2011 01:04'!
installStrikeFont: aStrikeFont foregroundColor: foregroundColor backgroundColor: backgroundColor
	| lastSourceDepth targetColor |
	sourceForm ifNotNil:[lastSourceDepth := sourceForm depth].
	sourceForm := aStrikeFont glyphs.

	"Ignore any halftone pattern since we use a color map approach here"
	halftoneForm := nil.
	sourceY := 0.
	height := aStrikeFont height.

	sourceForm depth = 1 ifTrue: [
		self combinationRule: Form paint.
		(colorMap notNil and:[lastSourceDepth = sourceForm depth]) ifFalse: [
			"Set up color map for a different source depth (color font)"
			"Uses caching for reasonable efficiency"
			colorMap := self cachedFontColormapFrom: sourceForm depth to: destForm depth.
			colorMap at: 1 put: (destForm pixelValueFor: backgroundColor)].
		colorMap at: 2 put: (destForm pixelValueFor: foregroundColor).
	]
	ifFalse: [
		(self class subPixelRenderFonts and: [ foregroundColor = Color black
			"Only use rgbMul with opaque colors as alpha values get lost for translucent colors."
			or: [ self class subPixelRenderColorFonts and: [foregroundColor isOpaque] ]]) ifTrue: [
			destForm depth > 8 ifTrue: [
				"rgbMul is equivalent to component alpha blend if text is black (only faster, hehe)"
				self combinationRule: Form rgbMul.
				colorMap := (destForm depth = 32 or: [ (foregroundColor = Color black) not ]) ifTrue: [
					"rgbMul / rgbAdd IS component alpha blend for any color of text (neat trick, eh!!)"
					"This colorMap is to be used on the second pass with rule 20 (rgbAdd)
					See #displayString:from:to:at:strikeFont:kern:"
					"Note: In 32bpp we always need the second pass, as the source could have transparent pixels, and we need to add to the alpha channel"
					self colorConvertingMap: foregroundColor from: sourceForm depth to: destForm depth keepSubPixelAA: true]]
			ifFalse: [
				self combinationRule: Form paint.
				targetColor := foregroundColor = Color black ifFalse: [ foregroundColor ].
				colorMap := self colorConvertingMap: targetColor from: sourceForm depth to: destForm depth keepSubPixelAA: true]
		]
		ifFalse: [
			"Do not use rule 34 for 16bpp display. TTCFont uses it, but it builds a glyphs cache for each color used!!"
			self combinationRule: (destForm depth = 32 ifTrue: [Form blendAlphaScaled] ifFalse: [Form paint]).
			colorMap := self colorConvertingMap: foregroundColor from: sourceForm depth to: destForm depth keepSubPixelAA: false
		]
	].! !

!BitBlt methodsFor: 'private' stamp: 'yo 1/8/2005 09:12'!
installTTCFont: aTTCFont foregroundColor: foregroundColor backgroundColor: backgroundColor
	"Set up the parameters.  Since the glyphs in a TTCFont is 32bit depth form, it tries to use rule=34 to get better AA result if possible."

	((aTTCFont depth = 32)) ifTrue: [
		destForm depth <= 8 ifTrue: [
			self colorMap: (self cachedFontColormapFrom: aTTCFont depth to: destForm depth).
			self combinationRule: Form paint.
		] ifFalse: [
			self colorMap: nil.
			self combinationRule: 34.
		].
		halftoneForm := nil.
		sourceY := 0.
		height := aTTCFont height.
	].
! !

!BitBlt methodsFor: 'private' stamp: ''!
paintBits
	"Perform the paint operation, which requires two calls to BitBlt."
	| color oldMap saveRule |
	sourceForm depth = 1 ifFalse: 
		[^ self halt: 'paint operation is only defined for 1-bit deep sourceForms'].
	saveRule := combinationRule.
	color := halftoneForm.  halftoneForm := nil.
	oldMap := colorMap.
	"Map 1's to ALL ones, not just one"
	self colorMap: (Bitmap with: 0 with: 16rFFFFFFFF).
	combinationRule := Form erase.
	self copyBits. 		"Erase the dest wherever the source is 1"
	halftoneForm := color.
	combinationRule := Form under.
	self copyBits.	"then OR, with whatever color, into the hole"
	colorMap := oldMap.
	combinationRule := saveRule

" | dot |
dot := Form dotOfSize: 32.
((BitBlt destForm: Display
		sourceForm: dot
		fillColor: Color lightGray
		combinationRule: Form paint
		destOrigin: Sensor cursorPoint
		sourceOrigin: 0@0
		extent: dot extent
		clipRect: Display boundingBox)
		colorMap: (Bitmap with: 0 with: 16rFFFFFFFF)) copyBits"! !

!BitBlt methodsFor: 'copying' stamp: 'ar 3/1/2004 13:49'!
pixelAt: aPoint
	"Assumes this BitBlt has been set up specially (see the init message,
	BitBlt bitPeekerFromForm:.  Returns the pixel at aPoint."
	sourceX := aPoint x.
	sourceY := aPoint y.
	destForm unhibernate. "before poking"
	destForm bits at: 1 put: 0.  "Just to be sure"
	self copyBits.
	^ destForm bits at: 1! !

!BitBlt methodsFor: 'copying' stamp: 'ar 3/1/2004 13:49'!
pixelAt: aPoint put: pixelValue
	"Assumes this BitBlt has been set up specially (see the init message,
	BitBlt bitPokerToForm:.  Overwrites the pixel at aPoint."
	destX := aPoint x.
	destY := aPoint y.
	sourceForm unhibernate. "before poking"
	sourceForm bits at: 1 put: pixelValue.
	self copyBits
"
| bb |
bb := (BitBlt bitPokerToForm: Display).
[Sensor anyButtonPressed] whileFalse:
	[bb pixelAt: Sensor cursorPoint put: 55]
"! !

!BitBlt methodsFor: 'private' stamp: 'tpr 11/13/2015 15:35'!
primCompareColor: colorValueA to: colorValueB test: testID
	"Call the prim that compares pixel color values and can tell if two Forms that overlap in some manner when composited are touching colors as defined by the testID.
"
	<primitive: 'primitiveCompareColors' module: 'BitBltPlugin'>
	"to signal failure without an error we'll return -1"
	^-1! !

!BitBlt methodsFor: 'private' stamp: 'ar 8/15/2009 11:16'!
primDisplayString: aString from: startIndex to: stopIndex map: glyphMap xTable: xTable kern: kernDelta
	| ascii |
	<primitive:'primitiveDisplayString' module:'BitBltPlugin'>
	startIndex to: stopIndex do:[:charIndex|
		ascii := (aString at: charIndex) asciiValue.
		glyphMap ifNotNil:[ascii := glyphMap at: ascii+1].
		sourceX := xTable at: ascii + 1.
		width := (xTable at: ascii + 2) - sourceX.
		self copyBits.
		destX := destX + width + kernDelta.
	].! !

!BitBlt methodsFor: 'private' stamp: 'yo 3/15/2005 09:47'!
roundVariables

	| maxVal minVal |
	maxVal := SmallInteger maxVal.
	minVal := SmallInteger minVal.
	destX := destX asInteger min: maxVal max: minVal.
	destY := destY asInteger min: maxVal max: minVal.
	width := width asInteger min: maxVal max: minVal.
	height := height asInteger min: maxVal max: minVal.
	sourceX := sourceX asInteger min: maxVal max: minVal.
	sourceY := sourceY asInteger min: maxVal max: minVal.
	clipX := clipX asInteger min: maxVal max: minVal.
	clipY := clipY asInteger min: maxVal max: minVal.
	clipWidth := clipWidth asInteger min: maxVal max: minVal.
	clipHeight := clipHeight asInteger min: maxVal max: minVal.
! !

!BitBlt methodsFor: 'private' stamp: ''!
setDestForm: df
	| bb |
	bb := df boundingBox.
	destForm := df.
	clipX := bb left.
	clipY := bb top.
	clipWidth := bb width.
	clipHeight := bb height! !

!BitBlt methodsFor: 'private' stamp: 'ar 5/14/2001 23:32'!
setDestForm: df sourceForm: sf fillColor: hf combinationRule: cr destOrigin: destOrigin sourceOrigin: sourceOrigin extent: extent clipRect: clipRect

	| aPoint |
	destForm := df.
	sourceForm := sf.
	self fillColor: hf.	"sets halftoneForm"
	combinationRule := cr.
	destX := destOrigin x.
	destY := destOrigin y.
	sourceX := sourceOrigin x.
	sourceY := sourceOrigin y.
	width := extent x.
	height := extent y.
	aPoint := clipRect origin.
	clipX := aPoint x.
	clipY := aPoint y.
	aPoint := clipRect corner.
	clipWidth := aPoint x - clipX.
	clipHeight := aPoint y - clipY.
	sourceForm == nil ifFalse:
		[colorMap := sourceForm colormapIfNeededFor: destForm]! !

!BitBlt methodsFor: 'accessing' stamp: ''!
sourceForm

	^ sourceForm! !

!BitBlt methodsFor: 'accessing' stamp: ''!
sourceForm: aForm 
	"Set the receiver's source form to be the argument, aForm."

	sourceForm := aForm! !

!BitBlt methodsFor: 'accessing' stamp: ''!
sourceOrigin: aPoint 
	"Set the receiver's source form coordinates to be those of the argument, 
	aPoint."

	sourceX := aPoint x.
	sourceY := aPoint y! !

!BitBlt methodsFor: 'accessing' stamp: ''!
sourceRect: aRectangle 
	"Set the receiver's source form top left x and y, width and height to be 
	the top left coordinate and extent of the argument, aRectangle."

	sourceX := aRectangle left.
	sourceY := aRectangle top.
	width := aRectangle width.
	height := aRectangle height! !

!BitBlt methodsFor: 'accessing' stamp: ''!
sourceX: anInteger 
	"Set the receiver's source form top left x to be the argument, anInteger."

	sourceX := anInteger! !

!BitBlt methodsFor: 'accessing' stamp: ''!
sourceY: anInteger 
	"Set the receiver's source form top left y to be the argument, anInteger."

	sourceY := anInteger! !

!BitBlt methodsFor: 'accessing' stamp: 'ar 5/25/2000 19:39'!
tallyMap
	"Return the map used for tallying pixels"
	^colorMap! !

!BitBlt methodsFor: 'accessing' stamp: 'ar 5/25/2000 19:39'!
tallyMap: aBitmap
	"Install the map used for tallying pixels"
	colorMap := aBitmap! !

!BitBlt methodsFor: 'accessing' stamp: ''!
width: anInteger 
	"Set the receiver's destination form width to be the argument, anInteger."

	width := anInteger! !

BitBlt subclass: #Pen
	instanceVariableNames: 'location direction penDown'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Primitives'!

!Pen commentStamp: '<historical>' prior: 0!
My instances can scribble on the screen or some other Form, drawing and printing at any angle. Since I am a BitBlt, the drawing can be done with an arbitary source Form.
!

Pen subclass: #PenPointRecorder
	instanceVariableNames: 'points'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Primitives'!

!PenPointRecorder commentStamp: 'nice 3/24/2010 07:38' prior: 0!
This class is a special kind of Pen that instead of actually drawing lines records the destination points for those lines. These points can later be accessed through my accessing method #points.

This can be useful when determining the boundaries of a drawing session.

Example:

| pen |
pen := PenPointRecorder new.
pen up; goto: 100@100; down; goto: 120@120.
Transcript cr;
	show: 'Bounding box for drawing: ';
	show: (Rectangle encompassing: pen points)

Implementation note: Shouldn't we override #drawFrom:to:withFirstPoint: instead, and what about #drawLoopX:Y:? Aren't we missing those calls?!

!PenPointRecorder methodsFor: 'line drawing' stamp: 'md 11/14/2003 16:56'!
drawFrom: p1 to: p2
	"Overridden to skip drawing but track bounds of the region traversed."

	points ifNil: [points := OrderedCollection with: p1].
	points addLast: p2! !

!PenPointRecorder methodsFor: 'accessing' stamp: 'di 6/21/1998 09:35'!
points
	^ points! !

!Pen class methodsFor: 'examples' stamp: 'jm 5/6/1998 22:28'!
example
	"Draw a spiral with a pen that is 2 pixels wide."
	"Display restoreAfter: [Pen example]"

	| bic |
	bic := self new.
	bic defaultNib: 2.
	bic color: Color blue.
	bic combinationRule: Form over.
	1 to: 100 do: [:i | bic go: i*4. bic turn: 89].
! !

!Pen class methodsFor: 'tablet drawing examples' stamp: 'tpr 3/15/2013 12:42'!
feltTip: width cellSize: cellSize
	"Warning: This example potentially uses a large amount of memory--it creates a Form with cellSize squared bits for every Display pixel."
	"In this example, all drawing is done into a large, monochrome Form and then scaled down onto the Display using smoothing. The larger the cell size, the more possible shades of gray can be generated, and the smoother the resulting line appears. A cell size of 8 yields 64 possible grays, while a cell size of 16 gives 256 levels, which is about the maximum number of grays that the human visual system can distinguish. The width parameter determines the maximum line thickness. Requires the optional tablet support primitives which may not be supported on all platforms. Works best in full screen mode. Shift-mouse to exit." 
	"Pen feltTip: 2.7 cellSize: 8"

	| tabletScale bitForm pen warp |
	tabletScale := self tabletScaleFactor.
	bitForm := Form extent: Display extent * cellSize depth: 1.
	pen := Pen newOnForm: bitForm.
	pen color: Color black.
	warp := (WarpBlt toForm: Display)
		sourceForm: bitForm;
		colorMap: (bitForm colormapIfNeededFor: Display);
		cellSize: cellSize;
		combinationRule: Form over.
	Display fillColor: Color white.
	Display restoreAfter: [ | p r nibSize srcR startP dstR |
		[Sensor shiftPressed and: [Sensor anyButtonPressed]] whileFalse: [
			p := (Sensor tabletPoint * cellSize * tabletScale) rounded.
			nibSize := (Sensor tabletPressure * (cellSize * width)) rounded.
		     nibSize > 0
				ifTrue: [
					pen squareNib: nibSize.
					startP := pen location.
					pen goto: p.
					r := startP rect: pen location.
					dstR := (r origin // cellSize) corner: ((r corner + nibSize + (cellSize - 1)) // cellSize).
					srcR := (dstR origin * cellSize) corner: (dstR corner * cellSize).
					warp copyQuad: srcR innerCorners toRect: dstR]
				ifFalse: [
					pen place: p]]].
! !

!Pen class methodsFor: 'tablet drawing examples' stamp: 'nice 12/27/2009 03:11'!
inkBrush
	"Similar to simplePressurePen, but this example uses the average of the recent pen pressure values. The effect is that of a Japanese ink brush that comes up gradually off the paper as the brush is lifted, causing end (and beginning) of each stroke to taper. Requires the optional tablet support primitives which may not be supported on all platforms. Works best in full screen mode. Shift-mouse to exit." 
	"Pen inkBrush"

	| tabletScale historyMSecs pressureHistory pen |
	tabletScale := self tabletScaleFactor.
	historyMSecs := 120.
	pressureHistory := OrderedCollection new.
	pen := Pen newOnForm: Display.
	pen color: Color black.
	Display fillColor: Color white.
	Display restoreAfter: [ | sum p averagePressure now currentPressure |
		[Sensor shiftPressed and: [Sensor anyButtonPressed]] whileFalse: [
			"compute the average pressure over last historyMSecs milliseconds"
			now := Time millisecondClockValue.
			currentPressure := (20.0 * Sensor tabletPressure) rounded.
			pressureHistory addLast: (Array with: now with: currentPressure).
			[pressureHistory size > 0 and:
			 [(pressureHistory first first + historyMSecs) < now]]
				whileTrue: [pressureHistory removeFirst].  "prune old entries"
			sum := pressureHistory inject: 0 into: [:t :e | t + e last].
			averagePressure := sum // pressureHistory size.

			p := (Sensor tabletPoint * tabletScale) rounded.
		     averagePressure > 0
				ifTrue: [
					pen roundNib: averagePressure.
					pen goto: p]
				ifFalse: [
					pen place: p]]].
! !

!Pen class methodsFor: 'instance creation' stamp: ''!
new
	^ self newOnForm: Display! !

!Pen class methodsFor: 'instance creation' stamp: ''!
newOnForm: aForm
	| pen |
	pen := super new.
	pen setDestForm: aForm.
	pen sourceOrigin: 0@0.
	pen home.
	pen defaultNib: 1.
	pen north.
	pen down.
	^ pen! !

!Pen class methodsFor: 'tablet drawing examples' stamp: 'nice 12/27/2009 03:11'!
simplePressurePen
	"An example of using a pressure sensitive pen to control the thickness of the pen. This requires the optional tablet support primitives which may not be supported on all platforms. Works best in full screen mode. Shift-mouse to exit." 
	"Pen simplePressurePen"

	| tabletScale pen |
	tabletScale := self tabletScaleFactor.
	pen := Pen newOnForm: Display.
	pen color: Color black.
	Display fillColor: Color white.
	Display restoreAfter: [ | p pressure |
		[Sensor shiftPressed and: [Sensor anyButtonPressed]] whileFalse: [
			p := (Sensor tabletPoint * tabletScale) rounded.
			pressure := (15.0 * Sensor tabletPressure) rounded.
		     pressure > 0
				ifTrue: [
					pen roundNib: pressure.
					pen goto: p]
				ifFalse: [
					pen place: p]]].
! !

!Pen class methodsFor: 'tablet drawing examples' stamp: 'jm 4/13/1999 11:12'!
tabletScaleFactor
	"Answer a Point that scales tablet coordinates to Display coordinates, where the full extent of the tablet maps to the extent of the entire Display."

	| tabletExtent |
	tabletExtent := Sensor tabletExtent.
	^ (Display width asFloat / tabletExtent x) @ (Display height asFloat / tabletExtent y)
! !

!Pen class methodsFor: 'tablet drawing examples' stamp: 'nice 12/27/2009 03:11'!
testMouseTracking
	"A very simple example of drawing using the mouse. Compare the tracking speed of this example with that of testTabletTracking. Mouse down to draw a stroke, shift-mouse to exit." 
	"Pen testMouseTracking"

	| pen |
	pen := Pen newOnForm: Display.
	pen roundNib: 8.
	pen color: Color black.
	Display fillColor: Color white.
	Display restoreAfter: [ | p |
		[Sensor shiftPressed and: [Sensor anyButtonPressed]] whileFalse: [
			p := Sensor cursorPoint.
		     Sensor anyButtonPressed
				ifTrue: [pen goto: p]
				ifFalse: [
					pen color: Color random.
					pen place: p]]].
! !

!Pen class methodsFor: 'tablet drawing examples' stamp: 'nice 12/27/2009 03:11'!
testTabletTracking
	"A very simple example of drawing using the pen of a digitizing tablet such as a Wacom ArtZ tablet. This requires the optional tablet support primitives which may not be supported on all platforms. Compare the tracking speed of this example with that of testMouseTracking. On a Macintosh, the tablet primitives provide roughly 120 samples/second versus only 60 mouse samples/second, and the difference is noticable. Works best in full screen mode. Mouse down to draw a stroke, shift-mouse to exit." 
	"Pen testTabletTracking"

	| tabletScale pen |
	tabletScale := self tabletScaleFactor.
	pen := Pen newOnForm: Display.
	pen roundNib: 8.
	pen color: Color black.
	Display fillColor: Color white.
	Display restoreAfter: [ | p |
		[Sensor shiftPressed and: [Sensor anyButtonPressed]] whileFalse: [
			p := (Sensor tabletPoint * tabletScale) rounded.
		     Sensor tabletPressure > 0
				ifTrue: [pen goto: p]
				ifFalse: [
					pen color: Color random.
					pen place: p]]].
! !

!Pen methodsFor: 'operations' stamp: 'jm 4/28/1998 03:40'!
color: aColorOrInteger
	"Set the pen to the given color or to a color chosen from a fixed set of colors."

	| count c |
	aColorOrInteger isInteger
		ifTrue: [
			destForm depth = 1 ifTrue: [^ self fillColor: Color black].
			count := 19.  "number of colors in color wheel"
			c := (Color red wheel: count) at: ((aColorOrInteger * 7) \\ count) + 1]
		ifFalse: [c := aColorOrInteger].  "assume aColorOrInteger is a Color"
	self fillColor: c.
! !

!Pen methodsFor: 'initialize-release' stamp: 'jm 4/28/1998 04:02'!
defaultNib: widthInteger 
	"Nib is the tip of a pen. This sets up the pen, with a nib of width widthInteger. You can also set the shape of the pen nib using:
		roundNib: widthInteger, or
		squareNib: widthInteger, or
		sourceForm: aForm"
"Example:
	| bic |
	bic := Pen new sourceForm: Cursor normal.
	bic combinationRule: Form paint; turn: 90.
	10 timesRepeat: [bic down; go: 3; up; go: 10]."

	self color: Color black.
	self squareNib: widthInteger.
! !

!Pen methodsFor: 'accessing' stamp: ''!
direction
	"Answer the receiver's current direction. 0 is towards the top of the
	screen."

	^direction! !

!Pen methodsFor: 'operations' stamp: ''!
down
	"Set the state of the receiver's pen to down (drawing)."

	penDown := true! !

!Pen methodsFor: 'geometric designs' stamp: 'di 6/11/1998 22:01'!
dragon: n  "Display restoreAfter: [Display fillWhite. Pen new dragon: 10]."
	"Display restoreAfter: [Display fillWhite. 1 to: 4 do:
				[:i | Pen new color: i; turn: 90*i; dragon: 10]]"
	"Draw a dragon curve of order n in the center of the screen."
	n = 0
		ifTrue: [self go: 5]
		ifFalse: [n > 0
				ifTrue: [self dragon: n - 1; turn: 90; dragon: 1 - n]
				ifFalse: [self dragon: -1 - n; turn: -90; dragon: 1 + n]]
! !

!Pen methodsFor: 'geometric designs' stamp: 'di 6/14/1998 13:42'!
filberts: n side: s   "Display restoreAfter: [Pen new filberts: 4 side: 5]"
	"Two Hilbert curve fragments form a Hilbert tile. Draw four interlocking 
	tiles of order n and sides length s."
	| n2 |
	Display fillWhite.
	n2 := 1 bitShift: n - 1.
	self up; go: 0 - n2 * s; down.
	1 to: 4 do: 
		[:i | 
		self fill: [:p |
				p hilbert: n side: s.
				p go: s.
				p hilbert: n side: s.
				p go: s.
				p up.
				p go: n2 - 1 * s.
				p turn: -90.
				p go: n2 * s.
				p turn: 180.
				p down]
			color: (Color perform: (#(yellow red green blue) at: i))]! !

!Pen methodsFor: 'operations' stamp: 'di 6/21/1998 09:37'!
fill: drawBlock color: color
	| region tileForm tilePen shape saveColor recorder |
	drawBlock value: (recorder := self as: PenPointRecorder).
	region := Rectangle encompassing: recorder points.
	tileForm := Form extent: region extent+6.
	tilePen := Pen newOnForm: tileForm.
	tilePen location: location-(region origin-3)
		direction: direction
		penDown: penDown.
	drawBlock value: tilePen.  "Draw the shape in B/W"
	saveColor := halftoneForm.
	drawBlock value: self.
	halftoneForm := saveColor.
	shape := (tileForm findShapeAroundSeedBlock: [:f | f borderWidth: 1]) reverse.
	shape copy: shape boundingBox from: tileForm to: 0@0 rule: Form erase.
	destForm fillShape: shape fillColor: color at: region origin-3! !

!Pen methodsFor: 'operations' stamp: 'di 11/4/97 20:11'!
goto: aPoint 
	"Move the receiver to position aPoint. If the pen is down, a line will be 
	drawn from the current position to the new one using the receiver's 
	form source as the shape of the drawing brush. The receiver's set 
	direction does not change."
	| old |
	old := location.
	location := aPoint.
	penDown ifTrue: [self drawFrom: old rounded
								to: location rounded]

	"NOTE:  This should be changed so it does NOT draw the first point, so as
	not to overstrike at line junctions.  At the same time, place should draw
	a single dot if the pen is down, as should down (put-pen-down) if it
	was not down before."! !

!Pen methodsFor: 'operations' stamp: ''!
go: distance 
	"Move the pen in its current direction a number of bits equal to the 
	argument, distance. If the pen is down, a line will be drawn using the 
	receiver's form source as the shape of the drawing brush."

	self goto: (direction degreeCos @ direction degreeSin) * distance + location! !

!Pen methodsFor: 'geometric designs' stamp: ''!
hilberts: n   "Display restoreAfter: [Display fillWhite.  Pen new hilberts: 5]"
	"Draws n levels of nested Hilbert curves"
	| s |
	self up; turn: 90; go: 128; down.
	1 to: n do: 
		[:i | 
		s := 256 bitShift: 0 - i.
		self defaultNib: n - i * 2 + 1.
		self color: i+1.
		self up; go: 0 - s / 2; turn: -90; go: s / 2; turn: 90; down.
		self hilbert: i side: s.
		self go: s.
		self hilbert: i side: s.
		self go: s]! !

!Pen methodsFor: 'geometric designs' stamp: ''!
hilbert: n side: s 
	"Draw an nth level Hilbert curve with side length s in the center of the 
	screen. Write directly into the display's bitmap only. A Hilbert curve is 
	a space-filling curve."

	| a m |
	n = 0 ifTrue: [^self turn: 180].
	n > 0
		ifTrue: 
			[a := 90.
			m := n - 1]
		ifFalse: 
			[a := -90.
			m := n + 1].
	self turn: a.
	self hilbert: 0 - m side: s.
	self turn: a; go: s.
	self hilbert: m side: s.
	self turn: 0 - a; go: s; turn: 0 - a.
	self hilbert: m side: s.
	self go: s; turn: a.
	self hilbert: 0 - m side: s.
	self turn: a
	" 
	(Pen new) hilbert: 3 side: 8. 
	(Pen new sourceForm: Cursor wait) combinationRule: Form under; 
	hilbert: 3 side: 25.
	"! !

!Pen methodsFor: 'operations' stamp: ''!
home
	"Place the receiver at the center of its frame."
	location := destForm boundingBox center! !

!Pen methodsFor: 'accessing' stamp: ''!
location
	"Answer where the receiver is currently located."

	^location! !

!Pen methodsFor: 'private' stamp: 'di 6/11/1998 16:09'!
location: aPoint direction: aFloat penDown: aBoolean
	location := aPoint.
	direction := aFloat.
	penDown := aBoolean! !

!Pen methodsFor: 'geometric designs' stamp: ''!
mandala: npoints
	"Display restoreAfter: [Pen new mandala: 30]"
	"On a circle of diameter d, place npoints number of points. Draw all 	possible connecting lines between the circumferential points."
	| l points d |
	Display fillWhite.
	d := Display height-50.
	l := 3.14 * d / npoints.
	self home; up; turn: -90; go: d // 2; turn: 90; go: 0 - l / 2; down.
	points := Array new: npoints.
	1 to: npoints do: 
		[:i | 
		points at: i put: location rounded.
		self go: l; turn: 360.0 / npoints].
	npoints // 2
		to: 1
		by: -1
		do: 
			[:i | 
			self color: i.
			1 to: npoints do: 
				[:j | 
				self place: (points at: j).
				self goto: (points at: j + i - 1 \\ npoints + 1)]]
! !

!Pen methodsFor: 'operations' stamp: ''!
north
	"Set the receiver's direction to facing toward the top of the display screen."

	direction := 270! !

!Pen methodsFor: 'operations' stamp: ''!
place: aPoint 
	"Set the receiver at position aPoint. No lines are drawn."

	location := aPoint! !

!Pen methodsFor: 'operations' stamp: 'tpr 3/26/2013 11:12'!
print: str withFont: font
	"Print the given string in the given font at the current heading"
	| lineStart scale wasDown |
	scale := sourceForm width.
	wasDown := penDown.
	lineStart := location.
	str do:
		[:char |
		char = Character cr ifTrue:
			[self place: lineStart; up; turn: 90; go: font height*scale; turn: -90; down]
		ifFalse:
			[ | charStart pix rowStart form backgroundCode |
			form := font characterFormAt: char.
			backgroundCode := 1<< (form depth // 3 * 3) - 1.
			charStart := location.
wasDown ifTrue: [
			self up; turn: -90; go: font descent*scale; turn: 90; down.
			0 to: form height-1 do:
				[:y |
				rowStart := location.
				pix := RunArray newFrom:
					((0 to: form width-1) collect: [:x | form pixelValueAt: x@y]).
				pix runs with: pix values do:
					[:run :value |
					value = backgroundCode
						ifTrue: [self up; go: run*scale; down]
						ifFalse: [self go: run*scale]].
				self place: rowStart; up; turn: 90; go: scale; turn: -90; down].
].
			self place: charStart; up; go: form width*scale; down].
			].
	wasDown ifFalse: [self up]
"
Display restoreAfter:
[Pen new squareNib: 2; color: Color red; turn: 45;
	print: 'The owl and the pussycat went to sea
in a beautiful pea green boat.' withFont: TextStyle defaultFont]
"! !

!Pen methodsFor: 'initialize-release' stamp: 'jm 4/28/1998 04:03'!
roundNib: diameter
	"Makes this pen draw with a round dot of the given diameter."

	self sourceForm: (Form dotOfSize: diameter).
	combinationRule := Form paint.
! !

!Pen methodsFor: 'private' stamp: ''!
sourceForm: aForm
	(aForm depth = 1 and: [destForm depth > 1])
		ifTrue: ["Map 1-bit source to all ones for color mask"
				colorMap := Bitmap with: 0 with: 16rFFFFFFFF]
		ifFalse: [colorMap := nil].
	^ super sourceForm: aForm! !

!Pen methodsFor: 'geometric designs' stamp: 'jm 5/6/1998 22:26'!
spiral: n angle: a 
	"Draw a double squiral (see Papert, MindStorms), where each design is made
	by moving the receiver a distance of n after turning the amount + or -a."

	1 to: n do: 
		[:i | 
		self color: i * 2.
		self go: i; turn: a]
"
	Display restoreAfter: [
		Display fillWhite. Pen new spiral: 200 angle: 89; home; spiral: 200 angle: -89].
"! !

!Pen methodsFor: 'initialize-release' stamp: 'jm 4/28/1998 04:03'!
squareNib: widthInteger 
	"Makes this pen draw with a square nib of the given width."

	self sourceForm: (Form extent: widthInteger @widthInteger) fillBlack.
	self combinationRule: Form over.  "a bit faster than paint mode"
! !

!Pen methodsFor: 'operations' stamp: ''!
turn: degrees 
	"Change the direction that the receiver faces by an amount equal to the 
	argument, degrees."

	direction := direction + degrees! !

!Pen methodsFor: 'operations' stamp: ''!
up
	"Set the state of the receiver's pen to up (no drawing)."

	penDown := false! !

!Pen methodsFor: 'geometric designs' stamp: 'mt 2/16/2016 10:10'!
web   "Display restoreAfter: [Pen new web]"
	"Draw pretty web-like patterns from the mouse movement on the screen.
	Press the mouse button to draw, option-click to exit.
	By Dan Ingalls and Mark Lentczner. "
	| history newPoint ancientPoint lastPoint filter color |
	"self erase."
	color := 1.
	[ history := OrderedCollection new.
	Sensor waitButton.
	Sensor yellowButtonPressed ifTrue: [^ self].
	filter := lastPoint := Sensor cursorPoint.
	20 timesRepeat: [ history addLast: lastPoint ].
	self color: (color := color + 1).
	[ Sensor redButtonPressed ] whileTrue: 
		[ newPoint := Sensor cursorPoint.
		(newPoint = lastPoint) ifFalse:
			[ ancientPoint := history removeFirst.
			filter := filter * 4 + newPoint // 5.
			self place: filter.
			self goto: ancientPoint.
			lastPoint := newPoint.
			history addLast: filter ] ] ] repeat! !

BitBlt subclass: #WarpBlt
	instanceVariableNames: 'p1x p1y p1z p2x p2y p2z p3x p3y p3z p4x p4y p4z cellSize sourceRGBmap'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Primitives'!

!WarpBlt commentStamp: '<historical>' prior: 0!
WarpBlt is a little warp-drive added on to BitBlt.  It takes a quadrilateral as its source specification, while its destination is traversed and combined just like any other call to copyBits.

The source quadrilateral is specified as an array of points starting with the corner that wants to end up in the topLeft, and proceding to the successive points that want to follow CCW around the destination rectangle.  Note that in specifying a plain old rectangle source, its non topLeft points must be actual pixels, not outside by 1, as with rectangle bottmRight, eg.  See the method Rectangle asQuad.

WarpBlt does a fast job of rotation, reflection and scaling, and it can even produce a semblance of perspective.  Depth parameters are included for future improvements in this direction. but the primitve does not support this yet.!

!WarpBlt class methodsFor: 'instance creation' stamp: 'tpr 3/15/2013 18:44'!
current
	"Return the class currently to be used for WarpBlt"
	^self! !

!WarpBlt class methodsFor: 'form rotation' stamp: 'tpr 6/7/2016 14:59'!
rotate: srcForm degrees: angleInDegrees center: rotationCenter scaleBy: scalePoint smoothing: cellSize 
	"Rotate the given Form angleInDegrees about the given rotationCenter and scale its width and height by x and y of the given scale
	point. Smooth using the given cell size, an integer between 1 and 3, where 1 means no smoothing. 
	Return a pair where the first element is the rotated Form and the second is the position offset required to align the center of the rotated Form with that of the original. 
	Note that the dimensions of the resulting Form generally differ from those of the original."
	| srcRect srcCenter radians dstOrigin dstCorner p dstRect inverseScale quad dstForm warpSrc newRotationPoint oldOffset |
	srcRect := srcForm boundingBox.
	srcCenter := srcRect center.
	radians := angleInDegrees degreesToRadians.
	dstOrigin := dstCorner := srcCenter.
	srcRect corners
		do: [:corner | 
			"find the limits of a rectangle that just encloses the rotated
			original; in general, this rectangle will be larger than the
			original (e.g., consider a square rotated by 45 degrees)"
			p := (corner - srcCenter scaleBy: scalePoint) + srcCenter.
			p := (p rotateBy: radians about: srcCenter) rounded.
			dstOrigin := dstOrigin min: p.
			dstCorner := dstCorner max: p].
	"rotate the enclosing rectangle back to get the source quadrilateral"
	dstRect := dstOrigin corner: dstCorner.
	inverseScale := 1.0 / scalePoint x @ (1.0 / scalePoint y).
	quad := dstRect innerCorners
				collect: [:corner | 
					p := corner rotateBy: radians negated about: srcCenter.
					(p - srcCenter scaleBy: inverseScale) + srcCenter].

	"make a Form to hold the result and do the rotation"
	warpSrc := srcForm.
	srcForm isColorForm
		ifTrue: [warpSrc := Form extent: srcForm extent depth: 16.
			srcForm displayOn: warpSrc.
			dstForm := Form extent: dstRect extent depth: 16
			"use 16-bit depth to allow smoothing"]
		ifFalse: [dstForm := srcForm species extent: dstRect extent depth: srcForm depth].
	(WarpBlt toForm: dstForm)
		sourceForm: warpSrc;
		colorMap: (warpSrc colormapIfNeededFor: dstForm);
		 cellSize: cellSize;
		 combinationRule: Form paint;
		 copyQuad: quad toRect: dstForm boundingBox.

	"installs a new colormap if cellSize > 1"
	dstForm isColorForm
		ifTrue: [dstForm colors: srcForm colors copy].

	oldOffset := rotationCenter - srcCenter truncated * scalePoint.
	newRotationPoint := dstForm extent / 2.0 + (oldOffset rotateBy: radians about: 0 @ 0).

	^ Array with: dstForm with: newRotationPoint - rotationCenter! !

!WarpBlt class methodsFor: 'examples' stamp: 'fbs 7/12/2013 20:51'!
test1   "Display restoreAfter: [WarpBlt test1]"
	"Demonstrates variable scale and rotate"
	| warp pts r1 p0 p ext |
	UIManager default informUser: 'Choose a rectangle with interesting stuff'
		during: [r1 := Rectangle originFromUser: 50@50.
				Sensor waitNoButton].
	UIManager default informUser: 'Now click down and up
and move the mouse around the dot'
		during: [p0 := Sensor waitClickButton.
				(Form dotOfSize: 8) displayAt: p0].
	warp := (self toForm: Display)
		clipRect: (0@0 extent: r1 extent*5);
		sourceForm: Display;
		combinationRule: Form over.
	[Sensor anyButtonPressed] whileFalse:
		[p := Sensor cursorPoint.
		pts := {r1 topLeft. r1 bottomLeft. r1 bottomRight. r1 topRight}
			collect: [:pt | pt rotateBy: (p-p0) theta about: r1 center].
		ext := (r1 extent*((p-p0) r / 20.0 max: 0.1)) asIntegerPoint.
		warp copyQuad: pts toRect: (r1 extent*5-ext//2 extent: ext)]! !

!WarpBlt class methodsFor: 'examples' stamp: 'fbs 7/12/2013 20:51'!
test12   "Display restoreAfter: [WarpBlt test12]"
	"Just like test1, but comparing smooth to non-smooth warps"
	| warp pts r1 p0 p ext warp2 |
	UIManager default informUser: 'Choose a rectangle with interesting stuff'
		during: [r1 := Rectangle originFromUser: 50@50.
				Sensor waitNoButton].
	UIManager default informUser: 'Now click down and up
and move the mouse around the dot'
		during: [p0 := Sensor waitClickButton.
				(Form dotOfSize: 8) displayAt: p0].
	warp := (self toForm: Display)
		cellSize: 2;  "installs a colormap"
		clipRect: (0@0 extent: r1 extent*5);
		sourceForm: Display;
		combinationRule: Form over.
	warp2 := (self toForm: Display)
		clipRect: ((0@0 extent: r1 extent*5) translateBy: 250@0);
		sourceForm: Display;
		combinationRule: Form over.
	[Sensor anyButtonPressed] whileFalse:
		[p := Sensor cursorPoint.
		pts := {r1 topLeft. r1 bottomLeft. r1 bottomRight. r1 topRight}
			collect: [:pt | pt rotateBy: (p-p0) theta about: r1 center].
		ext := (r1 extent*((p-p0) r / 20.0 max: 0.1)) asIntegerPoint.
		warp copyQuad: pts toRect: (r1 extent*5-ext//2 extent: ext).
		warp2 copyQuad: pts toRect: ((r1 extent*5-ext//2 extent: ext) translateBy: 250@0).
		]! !

!WarpBlt class methodsFor: 'examples' stamp: 'nice 12/27/2009 05:17'!
test3   "Display restoreAfter: [WarpBlt test3]"

	"The Squeak Release Mandala - 9/23/96 di"

	"Move the mouse near the center of the square.
	Up and down affects shrink/grow
	Left and right affect rotation angle"
	| warp pts p0 box map d p |
	box := 100@100 extent: 300@300.
	Display border: (box expandBy: 2) width: 2.

	"Make a color map that steps through the color space"
	map := (Display depth > 8
		ifTrue: ["RGB is a bit messy..."
				d := Display depth = 16 ifTrue: [5] ifFalse: [8].
				(1 to: 512) collect: [:i | | t |
					t := i bitAnd: 511.
					((t bitAnd: 16r7) bitShift: d-3)
					+ ((t bitAnd: 16r38) bitShift: d-3*2)
					+ ((t bitAnd: 16r1C0) bitShift: d-3*3)]]
		ifFalse: ["otherwise simple"
				1 to: (1 bitShift: Display depth)])
			as: Bitmap.
	warp := (WarpBlt toForm: Display)
		clipRect: box;
		sourceForm: Display;
		colorMap: map;
		combinationRule: Form over.
	p0 := box center.
	[Sensor anyButtonPressed] whileFalse:
		[p := Sensor cursorPoint.
		pts := (box insetBy: p y - p0 y) innerCorners
			collect: [:pt | pt rotateBy: p x - p0 x / 50.0 about: p0].
		warp copyQuad: pts toRect: box]! !

!WarpBlt class methodsFor: 'examples' stamp: ''!
test4   "Display restoreAfter: [WarpBlt test4]"

	"The Squeak Release Mandala - 9/23/96 di
	This version does smoothing"

	"Move the mouse near the center ofhe square.
	Up and dn affects shrink/grow
	Left and right affect rotation angle"
	| warp pts p0 p box |
	box := 100@100 extent: 300@300.
	Display border: (box expandBy: 2) width: 2.

	warp := (WarpBlt toForm: Display)
		clipRect: box;
		sourceForm: Display;
		cellSize: 2;  "installs a colormap"
		combinationRule: Form over.
	p0 := box center.
	[Sensor anyButtonPressed] whileFalse:
		[p := Sensor cursorPoint.
		pts := (box insetBy: p y - p0 y) innerCorners
			collect: [:pt | pt rotateBy: p x - p0 x / 50.0 about: p0].
		warp copyQuad: pts toRect: box]! !

!WarpBlt class methodsFor: 'examples' stamp: 'fbs 7/12/2013 20:51'!
test5   "Display restoreAfter: [WarpBlt test5]"
	"Demonstrates variable scale and rotate"
	| warp pts r1 p0 p |
	UIManager default informUser: 'Choose a rectangle with interesting stuff'
		during: [r1 := Rectangle fromUser.
				Sensor waitNoButton].
	UIManager default informUser: 'Now click down and up
and move the mouse around the dot'
		during: [p0 := Sensor waitClickButton.
				(Form dotOfSize: 8) displayAt: p0].
	warp := (self toForm: Display)
		cellSize: 1;
		sourceForm: Display;
		cellSize: 2;  "installs a colormap"
		combinationRule: Form over.
	[Sensor anyButtonPressed] whileFalse:
		[p := Sensor cursorPoint.
		pts := {r1 topLeft. r1 bottomLeft. r1 bottomRight. r1 topRight}
			collect: [:pt | pt rotateBy: (p-p0) theta about: r1 center].
		warp copyQuad: pts toRect: (r1 translateBy: r1 width@0)]! !

!WarpBlt class methodsFor: 'initialization' stamp: ''!
toForm: destinationForm
	"Default cell size is 1 (no pixel smoothing)"
	^ (super toForm: destinationForm) cellSize: 1! !

!WarpBlt methodsFor: 'setup' stamp: ''!
cellSize
	^ cellSize! !

!WarpBlt methodsFor: 'setup' stamp: 'nice 2/1/2011 02:38'!
cellSize: s
	"Set the number of samples used for averaging"
	cellSize := s.
	cellSize = 1 ifTrue: [^ self].
	"Install the colorMap to used for mapping the averaged RGBA 32bit pixels to the
	destination depth. Note that we need to install the 32->32 color map explicitly because
	the VM will substitute a colorMap derived from sourceForm->destForm mapping which
	is just plain wrong for <32 source and 32bit dest depth"
	(destForm depth = 32 and: [sourceForm notNil and: [sourceForm depth < 32]])
		ifTrue:[colorMap := ColorMap shifts: #(0 0 0 0) masks:#(16rFF0000 16rFF00 16rFF 16rFF000000) colors: nil]
		ifFalse:[colorMap := Color colorMapIfNeededFrom: 32 to: destForm depth].
! !

!WarpBlt methodsFor: 'primitives' stamp: ''!
copyQuad: pts toRect: destRect
	self sourceQuad: pts destRect: destRect.
	self warpBits! !

!WarpBlt methodsFor: 'primitives' stamp: ''!
deltaFrom: x1 to: x2 nSteps: n
	"Utility routine for computing Warp increments.
	x1 is starting pixel, x2 is ending pixel;  assumes n >= 1"
	| fixedPtOne |
	fixedPtOne := 16384.  "1.0 in fixed-pt representation"
	x2 > x1
		ifTrue: [^ x2 - x1 + fixedPtOne // (n+1) + 1]
		ifFalse: [x2 = x1 ifTrue: [^ 0].
				^ 0 - (x1 - x2 + fixedPtOne // (n+1) + 1)]! !

!WarpBlt methodsFor: 'smoothing' stamp: 'di 6/24/97 00:09'!
mixPix: pix sourceMap: sourceMap destMap: destMap
	"Average the pixels in array pix to produce a destination pixel.
	First average the RGB values either from the pixels directly,
	or as supplied in the sourceMap.  Then return either the resulting
	RGB value directly, or use it to index the destination color map." 
	| r g b rgb nPix bitsPerColor d |
	nPix := pix size.
	r := 0. g := 0. b := 0.
	1 to: nPix do:
		[:i |   "Sum R, G, B values for each pixel"
		rgb := sourceForm depth <= 8
				ifTrue: [sourceMap at: (pix at: i) + 1]
				ifFalse: [sourceForm depth = 32
						ifTrue: [pix at: i]
						ifFalse: [self rgbMap: (pix at: i) from: 5 to: 8]].
		r := r + ((rgb bitShift: -16) bitAnd: 16rFF).
		g := g + ((rgb bitShift: -8) bitAnd: 16rFF).
		b := b + ((rgb bitShift: 0) bitAnd: 16rFF)].
	destMap == nil
		ifTrue: [bitsPerColor := 3.  "just in case eg depth <= 8 and no map"
				destForm depth = 16 ifTrue: [bitsPerColor := 5].
				destForm depth = 32 ifTrue: [bitsPerColor := 8]]
		ifFalse: [destMap size = 512 ifTrue: [bitsPerColor := 3].
				destMap size = 4096 ifTrue: [bitsPerColor := 4].
				destMap size = 32768 ifTrue: [bitsPerColor := 5]].
	d := bitsPerColor - 8.
	rgb := ((r // nPix bitShift: d) bitShift: bitsPerColor*2)
		+ ((g // nPix bitShift: d) bitShift: bitsPerColor)
		+ ((b // nPix bitShift: d) bitShift: 0).
	destMap == nil
		ifTrue: [^ rgb]
		ifFalse: [^ destMap at: rgb+1]! !

!WarpBlt methodsFor: 'smoothing' stamp: 'ul 11/2/2010 03:04'!
rgbMap: sourcePixel from: nBitsIn to: nBitsOut
	"NOTE: This code is copied verbatim from BitBltSimulation so that it
	may be removed from the system"
	"Convert the given pixel value with nBitsIn bits for each color component to a pixel value with nBitsOut bits for each color component. Typical values for nBitsIn/nBitsOut are 3, 5, or 8."
	| mask d srcPix destPix |
	<inline: true>
	(d := nBitsOut - nBitsIn) > 0
		ifTrue:
			["Expand to more bits by zero-fill"
			mask := (1 << nBitsIn) - 1.  "Transfer mask"
			srcPix := sourcePixel << d.
			mask := mask << d.
			destPix := srcPix bitAnd: mask.
			mask := mask << nBitsOut.
			srcPix := srcPix << d.
			^ destPix + (srcPix bitAnd: mask)
				 	+ (srcPix << d bitAnd: mask << nBitsOut)]
		ifFalse:
			["Compress to fewer bits by truncation"
			d = 0 ifTrue: [^ sourcePixel].  "no compression"
			sourcePixel = 0 ifTrue: [^ sourcePixel].  "always map 0 (transparent) to 0"
			d := nBitsIn - nBitsOut.
			mask := (1 << nBitsOut) - 1.  "Transfer mask"
			srcPix := sourcePixel >> d.
			destPix := srcPix bitAnd: mask.
			mask := mask << nBitsOut.
			srcPix := srcPix >> d.
			destPix := destPix + (srcPix bitAnd: mask)
					+ (srcPix >> d bitAnd: mask << nBitsOut).
			destPix = 0 ifTrue: [^ 1].  "Dont fall into transparent by truncation"
			^ destPix]! !

!WarpBlt methodsFor: 'primitives' stamp: 'jm 5/2/1999 07:09'!
sourceForm: srcForm destRect: dstRectangle
	"Set up a WarpBlt from the entire source Form to the given destination rectangle."

	| w h |
	sourceForm := srcForm.
	sourceX := sourceY := 0.
	destX := dstRectangle left.
	destY := dstRectangle top.
	width := dstRectangle width.
	height := dstRectangle height.
	w := 16384 * (srcForm width - 1).
	h := 16384 * (srcForm height - 1).
	p1x := 0.
	p2x := 0.
	p3x := w.
	p4x := w.
	p1y := 0.
	p2y := h.
	p3y := h.
	p4y := 0.
	p1z := p2z := p3z := p4z := 16384.  "z-warp ignored for now"
! !

!WarpBlt methodsFor: 'primitives' stamp: ''!
sourceQuad: pts destRect: aRectangle
	| fixedPt1 |
	sourceX := sourceY := 0.
	self destRect: aRectangle.
	fixedPt1 := (pts at: 1) x isInteger ifTrue: [16384] ifFalse: [16384.0].
	p1x := (pts at: 1) x * fixedPt1.
	p2x := (pts at: 2) x * fixedPt1.
	p3x := (pts at: 3) x * fixedPt1.
	p4x := (pts at: 4) x * fixedPt1.
	p1y := (pts at: 1) y * fixedPt1.
	p2y := (pts at: 2) y * fixedPt1.
	p3y := (pts at: 3) y * fixedPt1.
	p4y := (pts at: 4) y * fixedPt1.
	p1z := p2z := p3z := p4z := 16384.  "z-warp ignored for now"
! !

!WarpBlt methodsFor: 'primitives' stamp: ''!
startFrom: x1 to: x2 offset: sumOfDeltas
	"Utility routine for computing Warp increments."
	x2 >= x1
		ifTrue: [^ x1]
		ifFalse: [^ x2 - sumOfDeltas]! !

!WarpBlt methodsFor: 'primitives' stamp: 'nk 11/3/2004 09:26'!
warpBits
	"Move those pixels!!"

	cellSize < 1 ifTrue: [ ^self error: 'cellSize must be >= 1' ].

	self warpBitsSmoothing: cellSize
		sourceMap: (sourceForm colormapIfNeededForDepth: 32).
! !

!WarpBlt methodsFor: 'primitives' stamp: 'tpr 3/26/2013 11:13'!
warpBitsSmoothing: n sourceMap: sourceMap
	| deltaP12 deltaP43 pA pB deltaPAB sp fixedPtOne poker pix nSteps |
	<primitive: 'primitiveWarpBits' module: 'BitBltPlugin'>

	"Check for compressed source, destination or halftone forms"
	((sourceForm isForm) and: [sourceForm unhibernate])
		ifTrue: [^ self warpBitsSmoothing: n sourceMap: sourceMap].
	((destForm isForm) and: [destForm unhibernate])
		ifTrue: [^ self warpBitsSmoothing: n sourceMap: sourceMap].
	((halftoneForm isForm) and: [halftoneForm unhibernate])
		ifTrue: [^ self warpBitsSmoothing: n sourceMap: sourceMap].

	(width < 1) | (height < 1) ifTrue: [^ self].
	fixedPtOne := 16384.  "1.0 in fixed-pt representation"
	n > 1 ifTrue:
		[(destForm depth < 16 and: [colorMap == nil])
			ifTrue: ["color map is required to smooth non-RGB dest"
					^ self primitiveFail].
		pix := Array new: n*n].

	nSteps := height-1 max: 1.
	deltaP12 := (self deltaFrom: p1x to: p2x nSteps: nSteps)
			@ (self deltaFrom: p1y to: p2y nSteps: nSteps).
	pA := (self startFrom: p1x to: p2x offset: nSteps*deltaP12 x)
		@ (self startFrom: p1y to: p2y offset: nSteps*deltaP12 y).
	deltaP43 := (self deltaFrom: p4x to: p3x nSteps: nSteps)
			@ (self deltaFrom: p4y to: p3y nSteps: nSteps).
	pB := (self startFrom: p4x to: p3x offset: nSteps*deltaP43 x)
		@ (self startFrom: p4y to: p3y offset: nSteps*deltaP43 y).

	poker := BitBlt bitPokerToForm: destForm.
	poker clipRect: self clipRect.
	nSteps := width-1 max: 1.
	destY to: destY+height-1 do:
		[:y |
		deltaPAB := (self deltaFrom: pA x to: pB x nSteps: nSteps)
				@ (self deltaFrom: pA y to: pB y nSteps: nSteps).
		sp := (self startFrom: pA x to: pB x offset: nSteps*deltaPAB x)
			@ (self startFrom: pA y to: pB y offset: nSteps*deltaPAB x).
		destX to: destX+width-1 do:
			[:x | 
			n = 1
			ifTrue:
				[poker pixelAt: x@y
						put: (sourceForm pixelValueAt: sp // fixedPtOne asPoint)]
			ifFalse:
				[0 to: n-1 do:
					[:dx | 0 to: n-1 do:
						[:dy |
						pix at: dx*n+dy+1 put:
								(sourceForm pixelValueAt: sp
									+ (deltaPAB*dx//n)
									+ (deltaP12*dy//n)
										// fixedPtOne asPoint)]].
				poker pixelAt: x@y put: (self mixPix: pix
										sourceMap: sourceMap
										destMap: colorMap)].
			sp := sp + deltaPAB].
		pA := pA + deltaP12.
		pB := pB + deltaP43]! !

Object subclass: #Color
	instanceVariableNames: 'rgb cachedDepth cachedBitPattern'
	classVariableNames: 'Black Blue BlueShift Brown CachedColormaps ColorChart ColorNames ComponentMask ComponentMax Cyan DarkGray Gray GrayToIndexMap Green GreenShift HalfComponentMask HighLightBitmaps IndexedColors LightBlue LightBrown LightCyan LightGray LightGreen LightMagenta LightOrange LightRed LightYellow Magenta MaskingMap Orange PaleBlue PaleBuff PaleGreen PaleMagenta PaleOrange PalePeach PaleRed PaleTan PaleYellow PantonePurpleU PureBlue PureCyan PureGreen PureMagenta PureRed PureYellow RandomStream Red RedShift TranslucentPatterns Transparent VeryDarkGray VeryLightGray VeryPaleRed VeryVeryDarkGray VeryVeryLightGray White Yellow'
	poolDictionaries: ''
	category: 'Graphics-Primitives'!

!Color commentStamp: '<historical>' prior: 0!
This class represents abstract color, regardless of the depth of bitmap it will be shown in.  At the very last moment a Color is converted to a pixelValue that depends on the depth of the actual Bitmap inside the Form it will be used with.  The supported depths (in bits) are 1, 2, 4, 8, 16, and 32.  The number of actual colors at these depths are: 2, 4, 16, 256, 32768, and 16 million.  (See comment in BitBlt.)  To change the depth of the Display and set how many colors you can see, execute: (Display newDepth: 8).  (See comment in DisplayMedium)
	Color is represented as the amount of light in red, green, and blue.  White is (1.0, 1.0, 1.0) and black is (0, 0, 0).  Pure red is (1.0, 0, 0).  These colors are "additive".  Think of Color's instance variables as:
	r	amount of red, a Float between 0.0 and 1.0.
	g	amount of green, a Float between 0.0 and 1.0.
	b	amount of blue, a Float between 0.0 and 1.0.
(But, in fact, the three are encoded as values from 0 to 1023 and combined in a single integer, rgb.  The user does not need to know this.)
	Many colors are named.  You find a color by name by sending a message to class Color, for example (Color lightBlue).  Also, (Color red: 0.2 green: 0.6 blue: 1.0) or (Color r: 0.2 g: 0.6 b: 1.0) creates a color. (see below)
	A color is essentially immutable.  Once you set red, green, and blue, you cannot change them.  Instead, create a new Color and use it.
	Applications such as contour maps and bar graphs will want to display one of a set of shades based on a number.  Convert the range of this number to an integer from 1 to N.  Then call (Color green lightShades: N) to get an Array of colors from white to green.  Use the Array messages at:, atPin:, or atWrap: to pull out the correct color from the array.  atPin: gives the first (or last) color if the index is out of range.  atWrap: wraps around to the other end if the index is out of range.
	Here are some fun things to run in when your screen has color:
		Pen new mandala: 30 diameter: Display height-100.
		Pen new web  "Draw with the mouse, opt-click to end"
		Display fillWhite.  Pen new hilberts: 5.
		Form toothpaste: 30  "Draw with mouse, opt-click to end"
You might also want to try the comment in
	Form>class>examples>tinyText...


Messages:
	mixed: proportion with: aColor	Answer this color mixed with the given color additively. The proportion, a number between 0.0 and 1.0, determines what what fraction of the receiver to use in the mix.

	+ 	add two colors
	- 	subtract two colors
	*	multiply the values of r, g, b by a number or an Array of factors.  ((Color named: #white) * 0.3) gives a darkish gray.  (aColor * #(0 0 0.9)) gives a color with slightly less blue.
	/	divide a color by a factor or an array of three factors.

	errorForDepth: d     How close the nearest color at this depth is to this abstract color.  Sum of the squares of the RGB differences, square rooted and normalized to 1.0.  Multiply by 100 to get percent.

	hue			Returns the hue of the color. On a wheel from 0 to 360 with pure red at 0 and again at 360.
	saturation	Returns the saturation of the color.  0.0 to 1.0
	brightness	Returns the brightness of the color.  0.0 to 1.0

	name    Look to see if this Color has a name.
	display	Show a swatch of this color tracking the cursor.

	lightShades: thisMany		An array of thisMany colors from white to the receiver. 
	darkShades: thisMany		An array of thisMany colors from black to the receiver.  Array is of length num.
	mix: color2 shades: thisMany		An array of thisMany colors from the receiver to color2.
	wheel: thisMany			An array of thisMany colors around the color wheel starting and ending at the receiver.

	pixelValueForDepth: d    Returns the bits that appear be in a Bitmap of this depth for this color.  Represents the nearest available color at this depth.  Normal users do not need to know which pixelValue is used for which color. 

Messages to Class Color.
	red: r green: g blue: b		Return a color with the given r, g, and b components.
	r: g: b:		Same as above, for fast typing.

 	hue: h saturation: s brightness: b		Create a color with the given hue, saturation, and brightness.

	pink
 	blue
	red ...	Many colors have messages that return an instance of Color.
	canUnderstand: #brown	  Returns true if #brown is a defined color.
	names		An OrderedCollection of the names of the colors.
	named: #notAllThatGray put: aColor    Add a new color to the list and create an access message and a class variable for it.
	fromUser	Shows the palette of colors available at this display depth.  Click anywhere to return the color you clicked on.

	hotColdShades: thisMany	An array of thisMany colors showing temperature from blue to red to white hot.

    stdColorsForDepth: d        An Array of colors available at this depth.  For 16 bit and 32 bits, returns a ColorGenerator.  It responds to at: with a Color for that index, simulating a very big Array. 

   colorFromPixelValue: value depth: d    Returns a Color whose bit pattern (inside a Bitmap) at this depth is the number specified.  Normal users do not need to use this.

(See also comments in these classes: Form, Bitmap, BitBlt, Pattern, MaskedForm.)!

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
aluminum

	^ Color r: 153/255 g: 153/255 b: 153/255! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
aqua

	^ Color r: 0.0 g: 128/255 b: 1.0! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
asparagus

	^ Color r: 128/255 g: 128/255 b: 0.0! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
banana

	^ Color r: 1.0 g: 1.0 b: 102/255! !

!Color class methodsFor: 'named colors' stamp: ''!
black
	^Black! !

!Color class methodsFor: 'named colors' stamp: ''!
blue
	^Blue! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
blueberry

	^ Color r: 0.0 g: 0.0 b: 1.0! !

!Color class methodsFor: 'named colors' stamp: ''!
brown
	^Brown! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
bubblegum

	^ Color r: 1.0 g: 102/255 b: 1.0! !

!Color class methodsFor: 'colormaps' stamp: 'jm 5/2/1999 07:24'!
cachedColormapFrom: sourceDepth to: destDepth
	"Return a cached colormap for mapping between the given depths. Always return a real colormap, not nil; this allows the client to get an identity colormap that can then be copied and modified to do color transformations."
	"Note: This method returns a shared, cached colormap to save time and space. Clients that need to modify a colormap returned by this method should make a copy and modify that!!"
	"Note: The colormap cache may be cleared by evaluating 'Color shutDown'."

	| srcIndex map |
	CachedColormaps class == Array ifFalse: [CachedColormaps := (1 to: 9) collect: [:i | Array new: 32]].
	srcIndex := sourceDepth.
	sourceDepth > 8 ifTrue: [srcIndex := 9].
	(map := (CachedColormaps at: srcIndex) at: destDepth) ~~ nil ifTrue: [^ map].

	map := self computeColormapFrom: sourceDepth to: destDepth.
	(CachedColormaps at: srcIndex) at: destDepth put: map.
	^ map
! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
cantaloupe

	^ Color r: 1.0 g: 204/255 b: 102/255! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
carnation

	^ Color r: 1.0 g: 111/255 b: 207/255! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
cayenne

	^ Color r: 128/255 g: 0.0 b: 0.0! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
clover

	^ Color r: 0.0 g: 128/255 b: 0.0! !

!Color class methodsFor: 'instance creation' stamp: 'tk 8/15/2001 11:03'!
colorFromPixelValue: p depth: d
	"Convert a pixel value for the given display depth into a color."
	"Details: For depths of 8 or less, the pixel value is simply looked up in a table. For greater depths, the color components are extracted and converted into a color."

	| r g b alpha |
	d = 8 ifTrue: [^ IndexedColors at: (p bitAnd: 16rFF) + 1].
	d = 4 ifTrue: [^ IndexedColors at: (p bitAnd: 16r0F) + 1].
	d = 2 ifTrue: [^ IndexedColors at: (p bitAnd: 16r03) + 1].
	d = 1 ifTrue: [^ IndexedColors at: (p bitAnd: 16r01) + 1].

	(d = 16) | (d = 15) ifTrue: [
		"five bits per component"
		r := (p bitShift: -10) bitAnd: 16r1F.
		g := (p bitShift: -5) bitAnd: 16r1F.
		b := p bitAnd: 16r1F.
		(r = 0 and: [g = 0]) ifTrue: [
			b = 0 ifTrue: [^Color transparent].
			b = 1 ifTrue: [^Color black]].
		^ Color r: r g: g b: b range: 31].

	d = 32 ifTrue: [
		"eight bits per component; 8 bits of alpha"
		r := (p bitShift: -16) bitAnd: 16rFF.
		g := (p bitShift: -8) bitAnd: 16rFF.
		b := p bitAnd: 16rFF.
		alpha := p bitShift: -24.
		alpha = 0 ifTrue: [^Color transparent].
		(r = 0 and: [g = 0 and: [b = 0]])  ifTrue: [^Color transparent].
		alpha < 255
			ifTrue: [^ (Color r: r g: g b: b range: 255) alpha: (alpha asFloat / 255.0)]
			ifFalse: [^ (Color r: r g: g b: b range: 255)]].

	d = 12 ifTrue: [
		"four bits per component"
		r := (p bitShift: -8) bitAnd: 16rF.
		g := (p bitShift: -4) bitAnd: 16rF.
		b := p bitAnd: 16rF.
		^ Color r: r g: g b: b range: 15].

	d = 9 ifTrue: [
		"three bits per component"
		r := (p bitShift: -6) bitAnd: 16r7.
		g := (p bitShift: -3) bitAnd: 16r7.
		b := p bitAnd: 16r7.
		^ Color r: r g: g b: b range: 7].

	self error: 'unknown pixel depth: ', d printString
! !

!Color class methodsFor: 'instance creation' stamp: 'ar 4/10/2005 18:45'!
colorFrom: parm
	"Return an instantiated color from parm.  If parm is already a color, return it, else return the result of my performing it if it's a symbol or, if it is a list, it can either be an array of three numbers, which will be interpreted as RGB values, or a list of symbols, the first of which is sent to me and then the others of which are in turn sent to the prior result, thus allowing entries of the form #(blue darker).  Else just return the thing"

	| aColor firstParm |
	(parm isKindOf: Color) ifTrue: [^ parm].
	(parm isSymbol) ifTrue: [^ self perform: parm].
	(parm isString) ifTrue: [^ self fromString: parm].
	((parm isKindOf: SequenceableCollection) and: [parm size > 0])
		ifTrue:
			[firstParm := parm first.
			(firstParm isKindOf: Number) ifTrue:
				[^ self fromRgbTriplet: parm].
			aColor := self colorFrom: firstParm.
			parm doWithIndex:
				[:sym :ind | ind > 1 ifTrue:
					[aColor := aColor perform: sym]].
			^ aColor].
	^ parm

"
Color colorFrom: #(blue darker)
Color colorFrom: Color blue darker
Color colorFrom: #blue
Color colorFrom: #(0.0 0.0 1.0)
"! !

!Color class methodsFor: 'colormaps' stamp: ''!
colorMapIfNeededFrom: sourceDepth to: destDepth
	"Return a colormap for mapping between the given depths, or nil if no colormap is needed."
	"Note: This method returns a shared, cached colormap to save time and space. Clients that need to modify a colormap returned by this method should make a copy and modify that!!"

	sourceDepth = destDepth ifTrue: [^ nil].  "not needed if depths are the same"

	(sourceDepth >= 16) & (destDepth >= 16) ifTrue: [
		"mapping is done in BitBlt by zero-filling or truncating each color component"
		^ nil].

	^ Color cachedColormapFrom: sourceDepth to: destDepth
! !

!Color class methodsFor: 'other' stamp: ''!
colorNames
	"Return a collection of color names."

	^ ColorNames! !

!Color class methodsFor: 'examples' stamp: ''!
colorRampForDepth: depth extent: aPoint
	"Returns a form of the given size showing R, G, B, and gray ramps for the given depth. Useful for testing color conversions between different depths."
	"(Color colorRampForDepth: Display depth extent: 256@80) display"
	"(Color colorRampForDepth: 32 extent: 256@80) displayOn: Display at: 0@0 rule: Form paint"

	| f dx dy r |
	f := Form extent: aPoint depth: depth.
	dx := aPoint x // 256.
	dy := aPoint y // 4.
	0 to: 255 do: [:i |
		r := (dx * i)@0 extent: dx@dy.
		f fill: r fillColor: (Color r: i g: 0 b: 0 range: 255).
		r := r translateBy: 0@dy.
		f fill: r fillColor: (Color r: 0 g: i b: 0 range: 255).
		r := r translateBy: 0@dy.
		f fill: r fillColor: (Color r: 0 g: 0 b: i range: 255).
		r := r translateBy: 0@dy.
		f fill: r fillColor: (Color r: i g: i b: i range: 255)].
	^ f
! !

!Color class methodsFor: 'color from user' stamp: 'nice 12/27/2009 03:11'!
colorTest: depth extent: chartExtent colorMapper: colorMapper
	"Create a palette of colors sorted horizontally by hue and vertically by lightness. Useful for eyeballing the color gamut of the display, or for choosing a color interactively."
	"Note: It is slow to build this palette, so it should be cached for quick access."
	"(Color colorTest: 32 extent: 570@180 colorMapper: [:c | c]) display"
	"(Color colorTest: 32 extent: 570@180 colorMapper:
		[:c | Color
			r: (c red * 7) asInteger / 7
			g: (c green * 7) asInteger / 7
			b: (c blue * 3) asInteger / 3]) display"
	"(Color colorTest: 32 extent: 570@180 colorMapper:
		[:c | Color
			r: (c red * 5) asInteger / 5
			g: (c green * 5) asInteger / 5
			b: (c blue * 5) asInteger / 5]) display"
	"(Color colorTest: 32 extent: 570@180 colorMapper:
		[:c | Color
			r: (c red * 15) asInteger / 15
			g: (c green * 15) asInteger / 15
			b: (c blue * 15) asInteger / 15]) display"
	"(Color colorTest: 32 extent: 570@180 colorMapper:
		[:c | Color
			r: (c red * 31) asInteger / 31
			g: (c green * 31) asInteger / 31
			b: (c blue * 31) asInteger / 31]) display"

	| startHue palette transHt vSteps transCaption grayWidth hSteps y c x |
	palette := Form extent: chartExtent depth: depth.
	transCaption := "(DisplayText text: 'no color' asText textStyle: (TextConstants at: #ComicPlain)) form storeString"
		(Form extent: 34@9 depth: 1
			fromArray: #(0 0 256 0 256 0 3808663859 2147483648 2491688266 2147483648 2491688266 0 2491688266 0 2466486578 0 0 0)
			offset: 0@0).
	transHt := transCaption height.
	palette fillWhite: (0@0 extent: palette width@transHt).
	palette fillBlack: (0@transHt extent: palette width@1).
	transCaption displayOn: palette at: palette boundingBox topCenter - ((transCaption width // 2)@0).
	grayWidth := 10.
	startHue := 338.0.
	vSteps := palette height - transHt // 2.
	hSteps := palette width - grayWidth.
	x := 0.
	startHue to: startHue + 360.0 by: 360.0/hSteps do: [:h | | basicHue |
		basicHue := Color h: h asFloat s: 1.0 v: 1.0.
		y := transHt+1.
		0 to: vSteps do: [:n |
 			c := basicHue mixed: (n asFloat / vSteps asFloat) with: Color white.
			c := colorMapper value: c.
			palette fill: (x@y extent: 1@1) fillColor: c.
			y := y + 1].
		1 to: vSteps do: [:n |
 			c := Color black mixed: (n asFloat / vSteps asFloat) with: basicHue.
			c := colorMapper value: c.
			palette fill: (x@y extent: 1@1) fillColor: c.
			y := y + 1].
		x := x + 1].
	y := transHt + 1.
	1 to: vSteps * 2 do: [:n |
 		c := Color black mixed: (n asFloat / (vSteps*2) asFloat) with: Color white.
		c := colorMapper value: c.
		palette fill: (x@y extent: 10@1) fillColor: c.
		y := y + 1].
	^ palette
! !

!Color class methodsFor: 'colormaps' stamp: 'jmv 8/2/2009 21:32'!
computeColorConvertingMap: targetColor from: sourceDepth to: destDepth keepSubPixelAA: keepSubPix

	sourceDepth < 16 ifTrue: [
		"source is 1-, 2-, 4-, or 8-bit indexed color.
		Assumed not to include subpixelAA"
		^ self computeIndexedColorConvertingMap: targetColor from: sourceDepth to: destDepth
	] ifFalse: [
		"source is 16-bit or 32-bit RGB.
		Might include subpixelAA"
		^ self computeRGBColorConvertingMap: targetColor to: destDepth keepSubPixelAA: keepSubPix
	]! !

!Color class methodsFor: 'colormaps' stamp: 'jm 3/25/1999 19:48'!
computeColormapFrom: sourceDepth to: destDepth
	"Compute a colorMap for translating between the given depths. A colormap is a Bitmap whose entries contain the pixel values for the destination depth. Typical clients use cachedColormapFrom:to: instead."

	| map bitsPerColor |
	sourceDepth < 16 ifTrue: [
		"source is 1-, 2-, 4-, or 8-bit indexed color"
		map := (IndexedColors copyFrom: 1 to: (1 bitShift: sourceDepth))
					collect: [:c | c pixelValueForDepth: destDepth].
		map := map as: Bitmap.
	] ifFalse: [
		"source is 16-bit or 32-bit RGB"
		destDepth > 8
			ifTrue: [bitsPerColor := 5]  "retain maximum color resolution"
			ifFalse: [bitsPerColor := 4].
		map := self computeRGBColormapFor: destDepth bitsPerColor: bitsPerColor].

	"Note: zero is transparent except when source depth is one-bit deep"
	sourceDepth > 1 ifTrue: [map at: 1 put: 0].
	^ map
! !

!Color class methodsFor: 'colormaps' stamp: 'nice 12/27/2009 03:11'!
computeIndexedColorConvertingMap: targetColor from: sourceDepth to: destDepth
	| map |
	
	map := (IndexedColors copyFrom: 1 to: (1 bitShift: sourceDepth)) collect: [ :cc | | f c | 
		f := 1.0 - (cc red + cc green + cc blue / 3.0 ).
		c := targetColor notNil
			ifTrue: [
				destDepth = 32
					ifTrue: [ targetColor * f alpha: f]
					ifFalse: [ targetColor alphaMixed: f*1.5 with: Color white ]]
			ifFalse: [ cc ].
		destDepth = 32
			ifTrue: [ c pixelValueForDepth: destDepth]
			ifFalse: [
				f = 0.0
					ifTrue: [ 0 ]
					ifFalse: [ c pixelValueForDepth: destDepth ]]].
	map := map as: Bitmap.
	^map! !

!Color class methodsFor: 'colormaps' stamp: 'jmv 9/7/2009 09:30'!
computeRGBColorConvertingMap: targetColor to: destDepth keepSubPixelAA: keepSubPix
	"Builds a colormap intended to convert from subpixelAA black values to targetColor values.
	keepSubPix
		ifTrue: [ Answer colors that also include subpixelAA ]
		ifFalse: [ 
			Take fullpixel luminance level. Apply it to targetColor.
			I.e. answer colors with NO subpixelAA ]"

	| mask map c bitsPerColor r g b f v |

	destDepth > 8
		ifTrue: [bitsPerColor := 5]  "retain maximum color resolution"
		ifFalse: [bitsPerColor := 4].
	"Usually a bit less is enough, but make it configurable"
	bitsPerColor := bitsPerColor min: Preferences aaFontsColormapDepth.
	mask := (1 bitShift: bitsPerColor) - 1.
	map := Bitmap new: (1 bitShift: (3 * bitsPerColor)).
	0 to: map size - 1 do: [:i |
		r := (i bitShift: 0 - (2 * bitsPerColor)) bitAnd: mask.
		g := (i bitShift: 0 - bitsPerColor) bitAnd: mask.
		b := (i bitShift: 0) bitAnd: mask.
		f := 1.0 - (r + g + b / 3.0 / mask).
		c := targetColor notNil
			ifTrue: [
				(keepSubPix and: [destDepth > 8]) ifTrue: [
						Color
							r: 1.0 - (r/mask) * targetColor red
							g: 1.0 - (g/mask) * targetColor green
							b: 1.0 - (b/mask) * targetColor blue
							alpha: f	* targetColor alpha "alpha will be ignored below, in #pixelValueForDepth: if destDepth ~= 32" ]
				ifFalse: [
					destDepth = 32
						ifTrue: [ targetColor * f alpha: f * targetColor alpha ]
						ifFalse: [ targetColor alphaMixed: f*1.5 with: Color white ]]]
			ifFalse: [ Color r: r g: g b: b range: mask].	"This is currently used only to keep some SubPixelAA on destDepth = 8, using a single pass of rule 25"
		v := destDepth = 32
			ifTrue: [ c pixelValueForDepth: destDepth]
			ifFalse: [
				f < 0.1
					ifTrue: [ 0 ]
					ifFalse: [ c pixelValueForDepth: destDepth ]].
		map at: i + 1 put: v ].
	^ map! !

!Color class methodsFor: 'colormaps' stamp: 'jm 12/4/97 15:25'!
computeRGBColormapFor: destDepth bitsPerColor: bitsPerColor
	"Compute a colorMap for translating from 16-bit or 32-bit RGB color to the given depth, using the given number of of bits per color component."

	| mask map c |
	(#(3 4 5) includes: bitsPerColor)
		ifFalse: [self error: 'BitBlt only supports 3, 4, or 5 bits per color component'].
	mask := (1 bitShift: bitsPerColor) - 1.
	map := Bitmap new: (1 bitShift: (3 * bitsPerColor)).
	0 to: map size - 1 do: [:i |
		c := Color
			r: ((i bitShift: 0 - (2 * bitsPerColor)) bitAnd: mask)
			g: ((i bitShift: 0 - bitsPerColor) bitAnd: mask)
			b: ((i bitShift: 0) bitAnd: mask)
			range: mask.
		map at: i + 1 put: (c pixelValueForDepth: destDepth)].

	map at: 1 put: (Color transparent pixelWordForDepth: destDepth).  "zero always transparent"
	^ map
! !

!Color class methodsFor: 'named colors' stamp: ''!
cyan
	^Cyan! !

!Color class methodsFor: 'named colors' stamp: ''!
darkGray
	^DarkGray! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
eggplant

	^ Color r: 64/255 g: 0.0 b: 128/255! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
fern

	^ Color r: 64/255 g: 128/255 b: 0.0! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
flora

	^ Color r: 102/255 g: 1.0 b: 102/255! !

!Color class methodsFor: 'instance creation' stamp: 'ul 11/15/2010 11:35'!
fromArray: colorDef
	colorDef size = 3
			ifTrue: [^self r: (colorDef at: 1) g: (colorDef at: 2) b: (colorDef at: 3)].
	colorDef size = 0
			ifTrue: [^Color transparent].
	colorDef size = 4
			ifTrue: [^(TranslucentColor r: (colorDef at: 1) g: (colorDef at: 2) b: (colorDef at: 3)) alpha: (colorDef at: 4)].
	self error: 'Undefined color definition'! !

!Color class methodsFor: 'instance creation' stamp: 'nice 1/10/2014 01:59'!
fromColorref: aColorref 
	| red green blue |
	red := aColorref bitAnd: 16rFF.
	green := (aColorref bitAnd: 16rFF00)
				>> 8.
	blue := (aColorref bitAnd: 16rFF0000)
				>> 16.
	^ self r: red g: green b: blue range: 255.! !

!Color class methodsFor: 'instance creation' stamp: 'sw 8/8/97 22:03'!
fromRgbTriplet: list
	^ self r: list first g: list second b: list last! !

!Color class methodsFor: 'instance creation' stamp: 'tpr 7/19/2016 12:50'!
fromString: aString
	"for HTML color spec: #FFCCAA or white/black/red/other name, or an r,g,b triplet string"
	"Color fromString: '#FFCCAA'.
	 Color fromString: 'white'.
	 Color fromString: 'orange'
	 Color fromString: '126,42,33' "
	
	| aColorHex rgb|
	aString isEmptyOrNil ifTrue: [ ^self white ].
	aString first = $#
		ifTrue: [ aColorHex := aString allButFirst ]
		ifFalse: [ aColorHex := aString ].
	"is the string a 6 digit hex number?"
	(aColorHex size = 6 and: [ 
		aColorHex allSatisfy: [ :each | '0123456789ABCDEFabcdef' includes: each ] ])
			ifTrue: [
				| green red blue |
				red := (Integer readFrom: (aColorHex first: 2) base: 16).
				green := (Integer readFrom: (aColorHex copyFrom: 3 to: 4) base: 16).
				blue := (Integer readFrom: (aColorHex last: 2) base: 16).
				^self r: red g: green b: blue range: 255].	
	"is the string in the form a,b,c ?"
	rgb := aColorHex findTokens: $, .
	rgb size = 3 ifTrue: [
				| green red blue |
				red := (Integer readFrom:(rgb at: 1)) min: 255 max: 0.
				green := (Integer readFrom:(rgb at: 2)) min: 255 max: 0.
				blue := (Integer readFrom:(rgb at: 3)) min: 255 max: 0.
				^self r: red g: green b: blue range: 255].
	"try to match aColorHex with known named colors, case insensitive"
	^self perform: (ColorNames detect: [:colorSymbol | aColorHex sameAs: colorSymbol] ifNone: [ #white ])! !

!Color class methodsFor: 'color from user' stamp: 'di 4/13/1999 14:30'!
fromUser
	"Displays a color palette of colors, waits for a mouse click, and returns the selected color. Any pixel on the Display can be chosen, not just those in the color palette."
	"Note: Since the color chart is cached, you may need to do 'ColorChart := nil' after changing the oldColorPaletteForDepth:extent: method."
	"Color fromUser"

	| d startPt save tr oldColor c here s |
	d := Display depth.
	((ColorChart == nil) or: [ColorChart depth ~= Display depth]) 
		ifTrue: [ColorChart := self oldColorPaletteForDepth: d extent: (2 * 144)@80].
	Sensor cursorPoint y < Display center y 
		ifTrue: [startPt := 0@(Display boundingBox bottom - ColorChart height)]
		ifFalse: [startPt := 0@0].

	save := Form fromDisplay: (startPt extent: ColorChart extent).
	ColorChart displayAt: startPt.
	tr := ColorChart extent - (50@19) corner: ColorChart extent.
	tr := tr translateBy: startPt.

	oldColor := nil.
	[Sensor anyButtonPressed] whileFalse: [
		c := Display colorAt: (here := Sensor cursorPoint).
		(tr containsPoint: here)
			ifFalse: [Display fill: (0@61+startPt extent: 20@19) fillColor: c]
			ifTrue: [
				c := Color transparent.
				Display fill: (0@61+startPt extent: 20@19) fillColor: Color white].
		c = oldColor ifFalse: [
			Display fillWhite: (20@61 + startPt extent: 135@19).
			c isTransparent
				ifTrue: [s := 'transparent']
				ifFalse: [s := c shortPrintString.
						s := s copyFrom: 7 to: s size - 1].
			s displayAt: 20@61 + startPt.
			oldColor := c]].
	save displayAt: startPt.
	Sensor waitNoButton.
	^ c
! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
grape

	^ Color r: 128/255 g: 0.0 b: 1.0! !

!Color class methodsFor: 'named colors' stamp: ''!
gray
	^Gray! !

!Color class methodsFor: 'instance creation' stamp: 'jm 12/4/97 13:05'!
gray: brightness
	"Return a gray shade with the given brightness in the range [0.0..1.0]."

	^ self basicNew setRed: brightness green: brightness blue: brightness
! !

!Color class methodsFor: 'named colors' stamp: ''!
green
	^Green! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
honeydew

	^ Color r: 204/255 g: 1.0 b: 102/255! !

!Color class methodsFor: 'examples' stamp: 'tk 6/19/96'!
hotColdShades: thisMany
	"An array of thisMany colors showing temperature from blue to red to white hot.  (Later improve this by swinging in hue.)  "
	"Color showColors: (Color hotColdShades: 25)"

	| n s1 s2 s3 s4 s5 |
	thisMany < 5 ifTrue: [^ self error: 'must be at least 5 shades'].
	n := thisMany // 5.
	s1 := self white mix: self yellow shades: (thisMany - (n*4)).
	s2 := self yellow mix: self red shades: n+1.
	s2 := s2 copyFrom: 2 to: n+1.
	s3 := self red mix: self green darker shades: n+1.
	s3 := s3 copyFrom: 2 to: n+1.
	s4 := self green darker mix: self blue shades: n+1.
	s4 := s4 copyFrom: 2 to: n+1.
	s5 := self blue mix: self black shades: n+1.
	s5 := s5 copyFrom: 2 to: n+1.
	^ s1, s2, s3, s4, s5
! !

!Color class methodsFor: 'instance creation' stamp: ''!
h: hue s: saturation v: brightness
	"Create a color with the given hue, saturation, and brightness. Hue is given as the angle in degrees of the color on the color circle where red is zero degrees. Saturation and brightness are numbers in [0.0..1.0] where larger values are more saturated or brighter colors. For example, (Color h: 0 s: 1 v: 1) is pure red."
	"Note: By convention, brightness is abbreviated 'v' to to avoid confusion with blue."

	^ self basicNew setHue: hue saturation: saturation brightness: brightness! !

!Color class methodsFor: 'instance creation' stamp: 'dew 3/19/2002 23:49'!
h: h s: s v: v alpha: alpha

	^ (self h: h s: s v: v) alpha: alpha! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
ice

	^ Color r: 102/255 g: 1.0 b: 1.0! !

!Color class methodsFor: 'other' stamp: ''!
indexedColors

	^ IndexedColors! !

!Color class methodsFor: 'class initialization' stamp: ''!
initialize
	"Color initialize"

	"Details: Externally, the red, green, and blue components of color
	are floats in the range [0.0..1.0]. Internally, they are represented
	as integers in the range [0..ComponentMask] packing into a
	small integer to save space and to allow fast hashing and
	equality testing.

	For a general description of color representations for computer
	graphics, including the relationship between the RGB and HSV
	color models used here, see Chapter 17 of Foley and van Dam,
	Fundamentals of Interactive Computer Graphics, Addison-Wesley,
	1982."

	ComponentMask := 1023.
	HalfComponentMask := 512.  "used to round up in integer calculations"
	ComponentMax := 1023.0.  "a Float used to normalize components"
	RedShift := 20.
	GreenShift := 10.
	BlueShift := 0.

	PureRed		 := self r: 1 g: 0 b: 0.
	PureGreen	 := self r: 0 g: 1 b: 0.
	PureBlue	 := self r: 0 g: 0 b: 1.
	PureYellow	 := self r: 1 g: 1 b: 0.
	PureCyan	 := self r: 0 g: 1 b: 1.
	PureMagenta := self r: 1 g: 0 b: 1.

	RandomStream := Random new.

	self initializeIndexedColors.
	self initializeGrayToIndexMap.
	self initializeNames.
	self initializeHighLights.
! !

!Color class methodsFor: 'class initialization' stamp: ''!
initializeGrayToIndexMap
	"Build an array of gray values available in the 8-bit colormap. This array is indexed by a gray level between black (1) and white (256) and returns the pixel value for the corresponding gray level."
	"Note: This method must be called after initializeIndexedColors, since it uses IndexedColors."
	"Color initializeGrayToIndexMap"

	| grayLevels grayIndices c distToClosest dist indexOfClosest |
	"record the level and index of each gray in the 8-bit color table"
	grayLevels := OrderedCollection new.
	grayIndices := OrderedCollection new.
	"Note: skip the first entry, which is reserved for transparent"
	2 to: IndexedColors size do: [:i |
		c := IndexedColors at: i.
		c saturation = 0.0 ifTrue: [  "c is a gray"
			grayLevels add: (c privateBlue) >> 2.  "top 8 bits; R, G, and B are the same"
			grayIndices add: i - 1]].  "pixel values are zero-based"
	grayLevels := grayLevels asArray.
	grayIndices := grayIndices asArray.

	"for each gray level in [0..255], select the closest match"
	GrayToIndexMap := ByteArray new: 256.
	0 to: 255 do: [:level |
		distToClosest := 10000.  "greater than distance to any real gray"
		1 to: grayLevels size do: [:i |
			dist := (level - (grayLevels at: i)) abs.
			dist < distToClosest ifTrue: [
				distToClosest := dist.
				indexOfClosest := grayIndices at: i]].
		GrayToIndexMap at: (level + 1) put: indexOfClosest].
! !

!Color class methodsFor: 'class initialization' stamp: 'tk 6/22/96'!
initializeHighLights
	"Create a set of Bitmaps for quickly reversing areas of the screen without converting colors. "
	"Color initializeHighLights"

	| t |
	t := Array new: 32.
	t at: 1 put: (Bitmap with: 16rFFFFFFFF).
	t at: 2 put: (Bitmap with: 16rFFFFFFFF).
	t at: 4 put: (Bitmap with: 16r55555555).
	t at: 8 put: (Bitmap with: 16r7070707).
	t at: 16 put: (Bitmap with: 16rFFFFFFFF).
	t at: 32 put: (Bitmap with: 16rFFFFFFFF).
	HighLightBitmaps := t.
! !

!Color class methodsFor: 'class initialization' stamp: ''!
initializeIndexedColors
	"Build an array of colors corresponding to the fixed colormap used
	 for display depths of 1, 2, 4, or 8 bits."
	"Color initializeIndexedColors"

	| a index grayVal |
	a := Array new: 256.

	"1-bit colors (monochrome)"
	a at: 1 put: (Color r: 1.0 g: 1.0 b: 1.0).		"white or transparent"
	a at: 2 put: (Color r: 0.0 g: 0.0 b: 0.0).	"black"

	"additional colors for 2-bit color"
	a at: 3 put: (Color r: 1.0 g: 1.0 b: 1.0).	"opaque white"
	a at: 4 put: (Color r: 0.5 g: 0.5 b: 0.5).	"1/2 gray"

	"additional colors for 4-bit color"
	a at:  5 put: (Color r: 1.0 g: 0.0 b: 0.0).	"red"
	a at:  6 put: (Color r: 0.0 g: 1.0 b: 0.0).	"green"
	a at:  7 put: (Color r: 0.0 g: 0.0 b: 1.0).	"blue"
	a at:  8 put: (Color r: 0.0 g: 1.0 b: 1.0).	"cyan"
	a at:  9 put: (Color r: 1.0 g: 1.0 b: 0.0).	"yellow"
	a at: 10 put: (Color r: 1.0 g: 0.0 b: 1.0).	"magenta"

	a at: 11 put: (Color r: 0.125 g: 0.125 b: 0.125).		"1/8 gray"
	a at: 12 put: (Color r: 0.25 g: 0.25 b: 0.25).		"2/8 gray"
	a at: 13 put: (Color r: 0.375 g: 0.375 b: 0.375).		"3/8 gray"
	a at: 14 put: (Color r: 0.625 g: 0.625 b: 0.625).		"5/8 gray"
	a at: 15 put: (Color r: 0.75 g: 0.75 b: 0.75).		"6/8 gray"
	a at: 16 put: (Color r: 0.875 g: 0.875 b: 0.875).		"7/8 gray"

	"additional colors for 8-bit color"
	"24 more shades of gray (1/32 increments but not repeating 1/8 increments)"
	index := 17.
	1 to: 31 do: [:v |
		(v \\ 4) = 0 ifFalse: [
			grayVal := v / 32.0.
			a at: index put: (Color r: grayVal g: grayVal b: grayVal).
			index := index + 1]].

	"The remainder of color table defines a color cube with six steps
	 for each primary color. Note that the corners of this cube repeat
	 previous colors, but this simplifies the mapping between RGB colors
	 and color map indices. This color cube spans indices 40 through 255
	 (indices 41-256 in this 1-based array)."
	0 to: 5 do: [:r |
		0 to: 5 do: [:g |
			0 to: 5 do: [:b |
				index := 41 + ((36 * r) + (6 * b) + g).
				index > 256 ifTrue: [
					self error: 'index out of range in color table compuation'].
				a at: index put: (Color r: r g: g b: b range: 5)]]].

	IndexedColors := a.
! !

!Color class methodsFor: 'class initialization' stamp: 'mtf 12/28/2010 23:45'!
initializeNames
	"Name some colors."
	"Color initializeNames"

	ColorNames := Set new.
	self named: #black put: (Color r: 0 g: 0 b: 0).
	self named: #veryVeryDarkGray put: (Color r: 0.125 g: 0.125 b: 0.125).
	self named: #veryDarkGray put: (Color r: 0.25 g: 0.25 b: 0.25).
	self named: #darkGray put: (Color r: 0.375 g: 0.375 b: 0.375).
	self named: #gray put: (Color r: 0.5 g: 0.5 b: 0.5).
	self named: #lightGray put: (Color r: 0.625 g: 0.625 b: 0.625).
	self named: #veryLightGray put: (Color r: 0.75 g: 0.75 b: 0.75).
	self named: #veryVeryLightGray put: (Color r: 0.875 g: 0.875 b: 0.875).
	self named: #white put: (Color r: 1.0 g: 1.0 b: 1.0).
	self named: #red put: (Color r: 1.0 g: 0 b: 0).
	self named: #yellow put: (Color r: 1.0 g: 1.0 b: 0).
	self named: #green put: (Color r: 0 g: 1.0 b: 0).
	self named: #cyan put: (Color r: 0 g: 1.0 b: 1.0).
	self named: #blue put: (Color r: 0 g: 0 b: 1.0).
	self named: #magenta put: (Color r: 1.0 g: 0 b: 1.0).
	self named: #brown put: (Color r: 0.6 g: 0.2 b: 0).
	self named: #orange put: (Color r: 1.0 g: 0.6 b: 0).
	self named: #lightRed put: (Color r: 1.0 g: 0.8 b: 0.8).
	self named: #lightYellow put: (Color r: 1.0 g: 1.0 b: 0.8).
	self named: #lightGreen put: (Color r: 0.8 g: 1.0 b: 0.6).
	self named: #lightCyan put: (Color r: 0.4 g: 1.0 b: 1.0).
	self named: #lightBlue put: (Color r: 0.8 g: 1.0 b: 1.0).
	self named: #lightMagenta put: (Color r: 1.0 g: 0.8 b: 1.0).
	self named: #lightBrown put: (Color r: 1.0 g: 0.6 b: 0.2).
	self named: #lightOrange put: (Color r: 1.0 g: 0.8 b: 0.4).
	self named: #transparent put: (TranslucentColor new alpha: 0.0).
	self named: #paleBuff put: (Color r: 254 g: 250 b: 235 range: 255).
	self named: #paleBlue put: (Color r: 222 g: 249 b: 254 range: 255).
	self named: #paleYellow put: (Color r: 255 g: 255 b: 217 range: 255).
	self named: #paleGreen put: (Color r: 223 g: 255 b: 213 range: 255).
	self named: #paleRed put: (Color r: 255 g: 230 b: 230 range: 255).
	self named: #veryPaleRed put: (Color r: 255 g: 242 b: 242 range: 255).
	self named: #paleTan put: (Color r: 235 g: 224 b: 199 range: 255).
	self named: #paleMagenta put: (Color r: 255 g: 230 b: 255 range: 255).
	self named: #paleOrange put: (Color r: 253 g: 237 b: 215 range: 255).
	self named: #palePeach put: (Color r: 255 g: 237 b: 213 range: 255).
	self named: #pantonePurpleU put: (Color r: 193 g: 81 b: 184 range: 255).

! !

!Color class methodsFor: 'class initialization' stamp: 'nice 12/27/2009 03:11'!
initializeTranslucentPatterns
	"Color initializeTranslucentPatterns"
	
	TranslucentPatterns := Array new: 8.
	#(1 2 4 8) do:[:d| | pattern patternList mask bits |
		patternList := Array new: 5.
		mask := (1 bitShift: d) - 1.
		bits := 2 * d.
		[bits >= 32] whileFalse: [
			mask := mask bitOr: (mask bitShift: bits).  "double the length of mask"
			bits := bits + bits].
		"0% pattern"
		pattern := Bitmap with: 0 with: 0.
		patternList at: 1 put: pattern.
		"25% pattern"
		pattern := Bitmap with: mask with: 0.
		patternList at: 2 put: pattern.
		"50% pattern"
		pattern := Bitmap with: mask with: mask bitInvert32.
		patternList at: 3 put: pattern.
		"75% pattern"
		pattern := Bitmap with: mask with: 16rFFFFFFFF.
		patternList at: 4 put: pattern.
		"100% pattern"
		pattern := Bitmap with: 16rFFFFFFFF with: 16rFFFFFFFF.
		patternList at: 5 put: pattern.
		TranslucentPatterns at: d put: patternList.
	].! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
iron

	^ Color r: 76/255 g: 76/255 b: 76/255! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
lavender

	^ Color r: 204/255 g: 102/255 b: 1.0! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
lead

	^ Color r: 25/255 g: 25/255 b: 25/255! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
lemon

	^ Color r: 1.0 g: 1.0 b: 0.0! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
licorice

	^ Color r: 0.0 g: 0.0 b: 0.0! !

!Color class methodsFor: 'named colors' stamp: ''!
lightBlue
	^LightBlue! !

!Color class methodsFor: 'named colors' stamp: ''!
lightBrown
	^LightBrown! !

!Color class methodsFor: 'named colors' stamp: ''!
lightCyan
	^LightCyan! !

!Color class methodsFor: 'named colors' stamp: ''!
lightGray
	^LightGray! !

!Color class methodsFor: 'named colors' stamp: ''!
lightGreen
	^LightGreen! !

!Color class methodsFor: 'named colors' stamp: ''!
lightMagenta
	^LightMagenta! !

!Color class methodsFor: 'named colors' stamp: ''!
lightOrange
	^LightOrange! !

!Color class methodsFor: 'named colors' stamp: ''!
lightRed
	^LightRed! !

!Color class methodsFor: 'named colors' stamp: ''!
lightYellow
	^LightYellow! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
lime

	^ Color r: 128/255 g: 1.0 b: 0.0! !

!Color class methodsFor: 'named colors' stamp: ''!
magenta
	^Magenta! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
magnesium

	^ Color r: 179/255 g: 179/255 b: 179/255! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
maraschino

	^ Color r: 1.0 g: 0.0 b: 0.0! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
maroon

	^ Color r: 128/255 g: 0.0 b: 64/255! !

!Color class methodsFor: 'other' stamp: 'di 3/29/1999 13:33'!
maskingMap: depth
	"Return a color map that maps all colors except transparent to words of all ones. Used to create a mask for a Form whose transparent pixel value is zero. Cache the most recently used map."

	| sizeNeeded |
	depth <= 8
		ifTrue: [sizeNeeded := 1 bitShift: depth]
		ifFalse: [sizeNeeded := 4096].

	(MaskingMap == nil or: [MaskingMap size ~= sizeNeeded]) ifTrue:
		[MaskingMap := Bitmap new: sizeNeeded withAll: 16rFFFFFFFF.
		MaskingMap at: 1 put: 0.  "transparent"].

	^ MaskingMap
! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
mercury

	^ Color r: 230.0 g: 230.0 b: 230.0! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
midnight

	^ Color r: 0.0 g: 0.0 b: 128/255! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
mocha

	^ Color r: 128/255 g: 64/255 b: 0.0! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
moss

	^ Color r: 0.0 g: 128/255 b: 64/255! !

!Color class methodsFor: 'class initialization' stamp: 'ul 12/9/2010 02:57'!
named: newName put: aColor
	"Add a new color to the list and create an access message and a class variable for it.  The name should start with a lowercase letter.  (The class variable will start with an uppercase letter.)  (Color colorNames) returns a list of all color names.  "
	| str cap sym accessor csym |
	(aColor isKindOf: self) ifFalse: [^ self error: 'not a Color'].
	str := newName asString.
	sym := str asSymbol.
	cap := str capitalized.
	csym := cap asSymbol.
	(self class canUnderstand: sym) ifFalse: [
		"define access message"
		accessor := str, (String with: Character cr with: Character tab), 			'^', cap.
		self class compile: accessor
			classified: 'named colors'].
	(self classPool includesKey: csym) ifFalse: [
		self addClassVarName: cap].
	ColorNames add: sym.
	^ self classPool at: csym put: aColor! !

!Color class methodsFor: 'instance creation' stamp: ''!
new

	^ self r: 0.0 g: 0.0 b: 0.0! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
nickel

	^ Color r: 128/255 g: 128/255 b: 128/255! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
ocean

	^ Color r: 0.0 g: 64/255 b: 128/255! !

!Color class methodsFor: 'color from user' stamp: 'di 4/13/1999 14:28'!
oldColorPaletteForDepth: depth extent: paletteExtent
	"Returns a form of the given size showing a color palette for the given depth."
	"(Color oldColorPaletteForDepth: Display depth extent: 720@100) display"

	| c p f nSteps rect w h q |
	f := Form extent: paletteExtent depth: depth.
	f fill: f boundingBox fillColor: Color white.
	nSteps := depth > 8 ifTrue: [12] ifFalse: [6].
	w := paletteExtent x // (nSteps * nSteps).
	h := paletteExtent y - 20 // nSteps.
	0 to: nSteps-1 do: [:r |
		0 to: nSteps-1 do: [:g |
			0 to: nSteps-1 do: [:b |
				c := Color r: r g: g b: b range: nSteps - 1.
				rect := ((r * nSteps * w) + (b * w)) @ (g * h) extent: w@(h + 1).
				f fill: rect fillColor: c]]].
	q := Quadrangle origin: paletteExtent - (50@19) corner: paletteExtent.
	q displayOn: f.
	'Trans.' displayOn: f at: q origin + (9@1).

	w := ((paletteExtent x - q width - 130) // 64) max: 1.
	p := paletteExtent x - q width - (64 * w) - 1 @ (paletteExtent y - 19).
	0 to: 63 do:
		[:v | c := Color r: v g: v b: v range: 63.
		f fill: ((v * w)@0 + p extent: (w + 1)@19) fillColor: c].
	^ f
! !

!Color class methodsFor: 'named colors' stamp: ''!
orange
	^Orange! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
orchid

	^ Color r: 102/255 g: 102/255 b: 1.0! !

!Color class methodsFor: 'other' stamp: 'mt 8/10/2016 18:02'!
orderedCrayonColors
	"self orderedCrayonColors explore."
	
	^ OrderedDictionary newFrom: (#(cantaloupe honeydew spindrift sky lavender carnation licorice snow salmon banana flora ice orchid bubblegum lead mercury tangerine lime seaFoam aqua grape strawberry tungsten silver maraschino lemon spring turquoise blueberry magenta iron magnesium mocha fern moss ocean eggplant maroon steel aluminum cayenne asparagus clover teal midnight plum tin nickel) collect: [:ea |
		ea -> (self perform: ea)])! !

!Color class methodsFor: 'named colors' stamp: 'dwh 7/7/1999 23:56'!
paleBlue
	^PaleBlue! !

!Color class methodsFor: 'named colors' stamp: 'dwh 7/7/1999 23:56'!
paleBuff
	^PaleBuff! !

!Color class methodsFor: 'named colors' stamp: 'dwh 7/7/1999 23:56'!
paleGreen
	^PaleGreen! !

!Color class methodsFor: 'named colors' stamp: 'dwh 7/7/1999 23:56'!
paleMagenta
	^PaleMagenta! !

!Color class methodsFor: 'named colors' stamp: 'dwh 7/7/1999 23:56'!
paleOrange
	^PaleOrange! !

!Color class methodsFor: 'named colors' stamp: 'dwh 7/7/1999 23:56'!
palePeach
	^PalePeach! !

!Color class methodsFor: 'named colors' stamp: 'dwh 7/7/1999 23:56'!
paleRed
	^PaleRed! !

!Color class methodsFor: 'named colors' stamp: 'dwh 7/7/1999 23:56'!
paleTan
	^PaleTan! !

!Color class methodsFor: 'named colors' stamp: 'dwh 7/7/1999 23:56'!
paleYellow
	^PaleYellow! !

!Color class methodsFor: 'named colors' stamp: 'jrd 10/16/2010 19:59'!
pantonePurpleU
	^PantonePurpleU! !

!Color class methodsFor: 'other' stamp: ''!
pixelScreenForDepth: depth
	"Return a 50% stipple containing alternating pixels of all-zeros and all-ones to be used as a mask at the given depth."

	| mask bits |
	mask := (1 bitShift: depth) - 1.
	bits := 2 * depth.
	[bits >= 32] whileFalse: [
		mask := mask bitOr: (mask bitShift: bits).  "double the length of mask"
		bits := bits + bits].
	^ Bitmap with: mask with: mask bitInvert32
! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
plum

	^ Color r: 128/255 g: 0.0 b: 128/255! !

!Color class methodsFor: 'other' stamp: ''!
quickHighLight: depth
	"Quickly return a Bitblt-ready raw colorValue for highlighting areas.  6/22/96 tk"

	^ HighLightBitmaps at: depth! !

!Color class methodsFor: 'instance creation' stamp: ''!
random
	"Return a random color that isn't too dark or under-saturated."

	^ self basicNew
		setHue: (360.0 * RandomStream next)
		saturation: (0.3 + (RandomStream next * 0.7))
		brightness: (0.4 + (RandomStream next * 0.6))! !

!Color class methodsFor: 'named colors' stamp: ''!
red
	^Red! !

!Color class methodsFor: 'instance creation' stamp: 'jm 12/4/97 13:04'!
r: r g: g b: b
	"Return a color with the given r, g, and b components in the range [0.0..1.0]."

	^ self basicNew setRed: r green: g blue: b
! !

!Color class methodsFor: 'instance creation' stamp: ''!
r: r g: g b: b alpha: alpha

	^ (self r: r g: g b: b) alpha: alpha! !

!Color class methodsFor: 'instance creation' stamp: ''!
r: r g: g b: b range: range
	"Return a color with the given r, g, and b components specified as integers in the range [0..r]. This avoids the floating point arithmetic in the red:green:blue: message and is thus a bit faster for certain applications (such as computing a sequence of colors for a palette)."

	^ self basicNew setRed: r green: g blue: b range: range! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
salmon

	^ Color r: 1.0 g: 102/255 b: 102/255! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
seaFoam

	^ Color r: 0.0 g: 1.0 b: 128/255! !

!Color class methodsFor: 'examples' stamp: ''!
showColorCube
	"Show a 12x12x12 color cube."
	"Color showColorCube"

	0 to: 11 do: [:r |
		0 to: 11 do: [:g |
			0 to: 11 do: [:b |	
				Display fill: (((r*60) + (b*5)) @ (g*5) extent: 5@5)
					fillColor: (Color r: r g: g b: b range: 11)]]].
! !

!Color class methodsFor: 'examples' stamp: ''!
showColors: colorList
	"Display the given collection of colors across the top of the Display."

	| w r |
	w := Display width // colorList size.
	r := 0@0 extent: w@((w min: 30) max: 10).
	colorList do: [:c |
		Display fill: r fillColor: c.
		r := r translateBy: w@0].
! !

!Color class methodsFor: 'examples' stamp: ''!
showHSVPalettes
	"Shows a palette of hues, varying the saturation and brightness for each one. Best results are with depths 16 and 32."
	"Color showHSVPalettes"

	| left top c |
	left := top := 0.
	0 to: 179 by: 15 do: [:h |
		0 to: 10 do: [:s |
			left := (h * 4) + (s * 4).
			0 to: 10 do: [:v |
				c := Color h: h s: s asFloat / 10.0 v: v asFloat / 10.0.
				top := (v * 4).
				Display fill: (left@top extent: 4@4) fillColor: c.

				c := Color h: h + 180 s: s asFloat / 10.0 v: v asFloat / 10.0.
				top := (v * 4) + 50.
				Display fill: (left@top extent: 4@4) fillColor: c]]].
! !

!Color class methodsFor: 'examples' stamp: ''!
showHuesInteractively
	"Shows a palette of hues at a (saturation, brightness) point determined by the mouse position. Click the mouse button to exit and return the selected (saturation, brightness) point."
	"Color showHuesInteractively"

	| p s v |
	[Sensor anyButtonPressed] whileFalse: [
		p := Sensor cursorPoint.
		s := p x asFloat / 300.0.
		v := p y asFloat / 300.0.
		self showColors: (self wheel: 12 saturation: s brightness: v)].
	^ (s min: 1.0) @ (v min: 1.0)! !

!Color class methodsFor: 'other' stamp: ''!
shutDown
	"Color shutDown"

	ColorChart := nil.		"Palette of colors for the user to pick from"
	CachedColormaps := nil.	"Maps to translate between color depths"
	MaskingMap := nil.		"Maps all colors except transparent to black for creating a mask"
! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
silver

	^ Color r: 204/255 g: 204/255 b: 204/255! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
sky

	^ Color r: 102/255 g: 204/255 b: 1.0! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
snow

	^ Color r: 1.0 g: 1.0 b: 1.0! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
spindrift

	^ Color r: 102/255 g: 1.0 b: 204/255! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
spring

	^ Color r: 0.0 g: 1.0 b: 0.0! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
steel

	^ Color r: 102/255 g: 102/255 b: 102/255! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
strawberry

	^ Color r: 1.0 g: 0.0 b: 128/255! !

!Color class methodsFor: 'named colors' stamp: 'wod 5/24/1998 01:56'!
tan
	^  Color r: 0.8 g: 0.8 b: 0.5! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
tangerine

	^ Color r: 1.0 g: 128/255 b: 0.0! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
teal

	^ Color r: 0.0 g: 128/255 b: 128/255! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
tin

	^ Color r: 127/255 g: 127/255 b: 127/255! !

!Color class methodsFor: 'other' stamp: 'ar 2/16/2000 21:56'!
translucentMaskFor: alphaValue depth: d
	"Return a pattern representing a mask usable for stipple transparency"
	^(TranslucentPatterns at: d) at: ((alphaValue min: 1.0 max: 0.0) * 4) rounded + 1! !

!Color class methodsFor: 'named colors' stamp: ''!
transparent
	^Transparent! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
tungsten

	^ Color r: 51/255 g: 51/255 b: 51/255! !

!Color class methodsFor: 'named colors - crayons' stamp: 'mt 8/10/2016 17:57'!
turquoise

	^ Color r: 0.0 g: 1.0 b: 1.0! !

!Color class methodsFor: 'named colors' stamp: ''!
veryDarkGray
	^VeryDarkGray! !

!Color class methodsFor: 'named colors' stamp: ''!
veryLightGray
	^VeryLightGray! !

!Color class methodsFor: 'named colors' stamp: 'dwh 7/7/1999 23:56'!
veryPaleRed
	^VeryPaleRed! !

!Color class methodsFor: 'named colors' stamp: ''!
veryVeryDarkGray
	^VeryVeryDarkGray! !

!Color class methodsFor: 'named colors' stamp: ''!
veryVeryLightGray
	^VeryVeryLightGray! !

!Color class methodsFor: 'examples' stamp: ''!
wheel: thisMany
	"Return a collection of thisMany colors evenly spaced around the color wheel."
	"Color showColors: (Color wheel: 12)"

	^ Color wheel: thisMany saturation: 0.9 brightness: 0.7
! !

!Color class methodsFor: 'examples' stamp: ''!
wheel: thisMany saturation: s brightness: v
	"Return a collection of thisMany colors evenly spaced around the color wheel, all of the given saturation and brightness."
	"Color showColors: (Color wheel: 12 saturation: 0.4 brightness: 1.0)"
	"Color showColors: (Color wheel: 12 saturation: 0.8 brightness: 0.5)"

	^ (Color h: 0.0 s: s v: v) wheel: thisMany
! !

!Color class methodsFor: 'named colors' stamp: ''!
white
	^White! !

!Color class methodsFor: 'named colors' stamp: ''!
yellow
	^Yellow! !

!Color methodsFor: 'Morphic menu' stamp: 'dgd 10/17/2003 12:10'!
addFillStyleMenuItems: aMenu hand: aHand from: aMorph
	"Add the items for changing the current fill style of the receiver"
	aMenu add: 'change color...' translated target: self selector: #changeColorIn:event: argument: aMorph! !

!Color methodsFor: 'transformations' stamp: 'dew 3/19/2002 23:50'!
adjustBrightness: brightness
	"Adjust the relative brightness of this color. (lowest value is 0.005 so that hue information is not lost)"

	^ Color
		h: self hue
		s: self saturation
		v: (self brightness + brightness min: 1.0 max: 0.005)
		alpha: self alpha! !

!Color methodsFor: 'transformations' stamp: 'dew 3/19/2002 23:51'!
adjustSaturation: saturation brightness: brightness
	"Adjust the relative saturation and brightness of this color. (lowest value is 0.005 so that hue information is not lost)"

	^ Color
		h: self hue
		s: (self saturation + saturation min: 1.0 max: 0.005)
		v: (self brightness + brightness min: 1.0 max: 0.005)
		alpha: self alpha! !

!Color methodsFor: 'access' stamp: ''!
alpha
	"Return the opacity ('alpha') value of opaque so that normal colors can be compared to TransparentColors."

	^ 1.0
! !

!Color methodsFor: 'transformations' stamp: 'tk 7/4/2000 11:55'!
alphaMixed: proportion with: aColor 
	"Answer this color mixed with the given color. The proportion, a number 
	between 0.0 and 1.0, determines what what fraction of the receiver to  
	use in the mix. For example, 0.9 would yield a color close to the  
	receiver. This method uses RGB interpolation; HSV interpolation can lead 
	to surprises.  Mixes the alphas (for transparency) also."

	| frac1 frac2 |
	frac1 := proportion asFloat min: 1.0 max: 0.0.
	frac2 := 1.0 - frac1.
	^ Color
		r: self red * frac1 + (aColor red * frac2)
		g: self green * frac1 + (aColor green * frac2)
		b: self blue * frac1 + (aColor blue * frac2)
		alpha: self alpha * frac1 + (aColor alpha * frac2)! !

!Color methodsFor: 'transformations' stamp: 'sma 6/25/2000 15:36'!
alpha: alphaValue 
	"Answer a new Color with the given amount of opacity ('alpha')."

	alphaValue = 1.0
		ifFalse: [^ TranslucentColor basicNew setRgb: rgb alpha: alphaValue]! !

!Color methodsFor: 'conversions' stamp: 'ar 11/2/1998 12:19'!
asColor
	"Convert the receiver into a color"
	^self! !

!Color methodsFor: 'conversions' stamp: 'jmg 1/6/2012 14:31'!
asColorref
	"Convert the receiver into a colorref"
	^ (self red * 255) rounded + ((self green * 255) rounded << 8) + ((self blue * 255) rounded << 16)! !

!Color methodsFor: 'conversions' stamp: 'bf 2/19/2008 12:10'!
asHTMLColor
	| s |
	s := '#000000' copy.
	s at: 2 put: (Character digitValue: ((rgb bitShift: -6 - RedShift) bitAnd: 15)).
	s at: 3 put: (Character digitValue: ((rgb bitShift: -2 - RedShift) bitAnd: 15)).
	s at: 4 put: (Character digitValue: ((rgb bitShift: -6 - GreenShift) bitAnd: 15)).
	s at: 5 put: (Character digitValue: ((rgb bitShift: -2 - GreenShift) bitAnd: 15)).
	s at: 6 put: (Character digitValue: ((rgb bitShift: -6 - BlueShift) bitAnd: 15)).
	s at: 7 put: (Character digitValue: ((rgb bitShift: -2 - BlueShift) bitAnd: 15)).
	^ s! !

!Color methodsFor: 'conversions' stamp: 'sw 10/27/1999 10:51'!
asNontranslucentColor
	^ self! !

!Color methodsFor: 'transformations' stamp: 'RAA 6/2/2000 08:47'!
atLeastAsLuminentAs: aFloat

	| revisedColor |
	revisedColor := self.
	[revisedColor luminance < aFloat] whileTrue: [revisedColor := revisedColor slightlyLighter].
	^revisedColor
! !

!Color methodsFor: 'transformations' stamp: 'nk 3/8/2004 09:43'!
atMostAsLuminentAs: aFloat

	| revisedColor |
	revisedColor := self.
	[revisedColor luminance > aFloat] whileTrue: [revisedColor := revisedColor slightlyDarker].
	^revisedColor
! !

!Color methodsFor: 'private' stamp: ''!
attemptToMutateError
	"A color is immutable. Once a color's red, green, and blue have been initialized, you cannot change them. Instead, create a new Color and use it."

	self error: 'Color objects are immutable once created'
! !

!Color methodsFor: 'conversions' stamp: 'di 3/25/2000 10:13'!
balancedPatternForDepth: depth
	"A generalization of bitPatternForDepth: as it exists.  Generates a 2x2 stipple of color.
	The topLeft and bottomRight pixel are closest approx to this color"
	| pv1 pv2 mask1 mask2 pv3 c |
	(depth == cachedDepth and:[cachedBitPattern size = 2]) ifTrue: [^ cachedBitPattern].
	(depth between: 4 and: 16) ifFalse: [^ self bitPatternForDepth: depth].
	cachedDepth := depth.
	pv1 := self pixelValueForDepth: depth.
"
	Subtract error due to pv1 to get pv2.
	pv2 := (self - (err1 := (Color colorFromPixelValue: pv1 depth: depth) - self))
						pixelValueForDepth: depth.
	Subtract error due to 2 pv1's and pv2 to get pv3.
	pv3 := (self - err1 - err1 - ((Color colorFromPixelValue: pv2 depth: depth) - self))
						pixelValueForDepth: depth.
"
	"Above two statements computed faster by the following..."
	pv2 := (c := self - ((Color colorFromPixelValue: pv1 depth: depth) - self))
						pixelValueForDepth: depth.
	pv3 := (c + (c - (Color colorFromPixelValue: pv2 depth: depth)))
						pixelValueForDepth: depth.

	"Return to a 2-word bitmap that encodes a 2x2 stipple of the given pixelValues."
	mask1 := (#(- - -	
			16r01010101 - - -			"replicates every other 4 bits"
			16r00010001 - - - - - - -	"replicates every other 8 bits"
			16r00000001) at: depth).	"replicates every other 16 bits"
	mask2 := (#(- - -	
			16r10101010 - - -			"replicates the other 4 bits"
			16r01000100 - - - - - - -	"replicates the other 8 bits"
			16r00010000) at: depth).	"replicates the other 16 bits"
	^ cachedBitPattern := Bitmap with: (mask1*pv1) + (mask2*pv2) with: (mask1*pv3) + (mask2*pv1)! !

!Color methodsFor: 'conversions' stamp: 'hmm 4/25/2000 09:40'!
bitPatternForDepth: depth
	"Return a Bitmap, possibly containing a stipple pattern, that best represents this color at the given depth. BitBlt calls this method to convert colors into Bitmaps. The resulting Bitmap may be multiple words to represent a stipple pattern of several lines.  "
	"See also:	pixelValueAtDepth:	-- value for single pixel
				pixelWordAtDepth:	-- a 32-bit word filled with the pixel value"
	"Details: The pattern for the most recently requested depth is cached."
	"Note for depths > 2, there are stippled and non-stippled versions (generated with #balancedPatternForDepth: and #bitPatternForDepth:, respectively). The stippled versions don't work with the window bit caching of StandardSystemView, so we make sure that for these depths, only unstippled patterns are returned"

	(depth == cachedDepth and: [depth <= 2 or: [cachedBitPattern size = 1]]) ifTrue: [^ cachedBitPattern].
	cachedDepth := depth.

	depth > 2 ifTrue: [^ cachedBitPattern := Bitmap with: (self pixelWordForDepth: depth)].
	depth = 1 ifTrue: [^ cachedBitPattern := self halfTonePattern1].
	depth = 2 ifTrue: [^ cachedBitPattern := self halfTonePattern2].
! !

!Color methodsFor: 'transformations' stamp: 'dew 3/23/2002 01:38'!
blacker

	^ self alphaMixed: 0.8333 with: Color black
! !

!Color methodsFor: 'access' stamp: ''!
blue
	"Return the blue component of this color, a float in the range [0.0..1.0]."

	^ self privateBlue asFloat / ComponentMax! !

!Color methodsFor: 'access' stamp: ''!
brightness
	"Return the brightness of this color, a float in the range [0.0..1.0]."

	^ ((self privateRed max:
	    self privateGreen) max:
	    self privateBlue) asFloat / ComponentMax! !

!Color methodsFor: 'printing' stamp: 'cmm 1/19/2012 20:29'!
byteEncode: aStream

	aStream
		print: '(';
		print: self species name;
		print: ' r: ';
		write: (self red roundTo: 0.001);
		print: ' g: ';
		write: (self green roundTo: 0.001);
		print: ' b: ';
		write: (self blue roundTo: 0.001) ;
		print: ')'.
! !

!Color methodsFor: 'Morphic menu' stamp: 'ar 10/5/2000 18:50'!
changeColorIn: aMorph event: evt
	"Note: This is just a workaround to make sure we don't use the old color inst var"
	aMorph changeColorTarget: aMorph selector: #fillStyle: originalColor: self hand: evt hand! !

!Color methodsFor: 'conversions' stamp: ''!
closestPixelValue1
	"Return the nearest approximation to this color for a monochrome Form."

	"fast special cases"
	rgb = 0 ifTrue: [^ 1].  "black"
	rgb = 16r3FFFFFFF ifTrue: [^ 0].  "white"

	self luminance > 0.5
		ifTrue: [^ 0]  "white"
		ifFalse: [^ 1].  "black"
! !

!Color methodsFor: 'conversions' stamp: ''!
closestPixelValue2
	"Return the nearest approximation to this color for a 2-bit deep Form."

	| lum |
	"fast special cases"
	rgb = 0 ifTrue: [^ 1].  "black"
	rgb = 16r3FFFFFFF ifTrue: [^ 2].  "opaque white"

	lum := self luminance.
	lum < 0.2 ifTrue: [^ 1].  "black"
	lum > 0.6 ifTrue: [^ 2].  "opaque white"
	^ 3  "50% gray"
! !

!Color methodsFor: 'conversions' stamp: ''!
closestPixelValue4
	"Return the nearest approximation to this color for a 4-bit deep Form."

	| bIndex |
	"fast special cases"
	rgb = 0 ifTrue: [^ 1].  "black"
	rgb = 16r3FFFFFFF ifTrue: [^ 2].  "opaque white"

	rgb = PureRed privateRGB ifTrue: [^ 4].
	rgb = PureGreen privateRGB ifTrue: [^ 5].
	rgb = PureBlue privateRGB ifTrue: [^ 6].
	rgb = PureCyan privateRGB ifTrue: [^ 7].
	rgb = PureYellow privateRGB ifTrue: [^ 8].
	rgb = PureMagenta privateRGB ifTrue: [^ 9].

	bIndex := (self luminance * 8.0) rounded.  "bIndex in [0..8]"
	^ #(
		1	"black"
		10	"1/8 gray"
		11	"2/8 gray"
		12	"3/8 gray"
		3	"4/8 gray"
		13	"5/8 gray"
		14	"6/8 gray"
		15	"7/8 gray"
		2	"opaque white"
	) at: bIndex + 1.
! !

!Color methodsFor: 'conversions' stamp: ''!
closestPixelValue8
	"Return the nearest approximation to this color for an 8-bit deep Form."

	"fast special cases"
	rgb = 0 ifTrue: [^ 1].  "black"
	rgb = 16r3FFFFFFF ifTrue: [^ 255].  "white"

	self saturation < 0.2 ifTrue: [
		^ GrayToIndexMap at: (self privateGreen >> 2) + 1.  "nearest gray"
	] ifFalse: [
		"compute nearest entry in the color cube"
		^ 40 +
		  ((((self privateRed * 5) + HalfComponentMask) // ComponentMask) * 36) +
		  ((((self privateBlue * 5) + HalfComponentMask) // ComponentMask) * 6) +
		  (((self privateGreen * 5) + HalfComponentMask) // ComponentMask)].
! !

!Color methodsFor: 'other' stamp: 'sw 2/16/98 03:42'!
colorForInsets
	^ self! !

!Color methodsFor: 'transformations' stamp: 'dew 3/19/2002 23:54'!
dansDarker
	"Return a darker shade of the same color.
	An attempt to do better than the current darker method.
	(now obsolete, since darker has been changed to do this. -dew)"
	^ Color h: self hue s: self saturation
		v: (self brightness - 0.16 max: 0.0)! !

!Color methodsFor: 'transformations' stamp: 'dew 3/4/2002 01:40'!
darker
	"Answer a darker shade of this color."

	^ self adjustBrightness: -0.08! !

!Color methodsFor: 'groups of shades' stamp: 'tk 6/18/96'!
darkShades: thisMany
	"An array of thisMany colors from black to the receiver.  Array is of length num. Very useful for displaying color based on a variable in your program.  "
	"Color showColors: (Color red darkShades: 12)"

	^ self class black mix: self shades: thisMany
! !

!Color methodsFor: 'equality' stamp: 'di 9/27/2000 08:07'!
diff: theOther
	"Returns a number between 0.0 and 1.0"

	^ ((self privateRed - theOther privateRed) abs
		+ (self privateGreen - theOther privateGreen) abs
		+ (self privateBlue - theOther privateBlue) abs)
		/ 3.0 / ComponentMax! !

!Color methodsFor: 'other' stamp: 'tk 6/14/96'!
display
	"Show a swatch of this color tracking the cursor until the next mouseClick. "
	"Color red display"
	| f |
	f := Form extent: 40@20 depth: Display depth.
	f fillColor: self.
	Cursor blank showWhile:
		[f follow: [Sensor cursorPoint] while: [Sensor noButtonPressed]]! !

!Color methodsFor: 'conversions' stamp: 'di 9/2/97 20:21'!
dominantColor
	^ self! !

!Color methodsFor: 'transformations' stamp: 'topa 10/17/2014 19:49'!
duller
	"Answer a darker, desaturated color.  If the original color isn't very saturated, desaturate it by less (otherwise will just end up with grey). If the original color is a grey, don't try to be smart."
	| sat adjust |
	(sat := self saturation) > 0.3
		ifTrue: [adjust := -0.1]
		ifFalse: [adjust := 0.1 - sat max: 0.0].
	^ sat isZero 
		ifTrue: [self adjustBrightness: -0.1]
		ifFalse: [self adjustSaturation: adjust brightness: -0.1]! !

!Color methodsFor: 'private' stamp: ''!
flushCache
	"Flush my cached bit pattern."

	cachedDepth := nil.
	cachedBitPattern := nil.
! !

!Color methodsFor: 'access' stamp: ''!
green
	"Return the green component of this color, a float in the range [0.0..1.0]."

	^ self privateGreen asFloat / ComponentMax! !

!Color methodsFor: 'conversions' stamp: 'di 6/23/97 23:27'!
halfTonePattern1
	"Return a halftone-pattern to approximate luminance levels on 1-bit deep Forms."

	| lum |
	lum := self luminance.
	lum < 0.1 ifTrue: [^ Bitmap with: 16rFFFFFFFF]. "black"
	lum < 0.4 ifTrue: [^ Bitmap with: 16rBBBBBBBB with: 16rEEEEEEEE]. "dark gray"
	lum < 0.6 ifTrue: [^ Bitmap with: 16r55555555 with: 16rAAAAAAAA]. "medium gray"
	lum < 0.9 ifTrue: [^ Bitmap with: 16r44444444 with: 16r11111111]. "light gray"
	^ Bitmap with: 0  "1-bit white"
! !

!Color methodsFor: 'conversions' stamp: ''!
halfTonePattern2
	"Return a halftone-pattern to approximate luminance levels on 2-bit deep Forms."

	| lum |
	lum := self luminance.
	lum < 0.125 ifTrue: [^ Bitmap with: 16r55555555].  "black"
	lum < 0.25 ifTrue: [^ Bitmap with: 16r55555555 with: 16rDDDDDDDD].  "1/8 gray"
	lum < 0.375 ifTrue: [^ Bitmap with: 16rDDDDDDDD with: 16r77777777].  "2/8 gray"
	lum < 0.5 ifTrue: [^ Bitmap with: 16rFFFFFFFF with: 16r77777777].  "3/8 gray"
	lum < 0.625 ifTrue: [^ Bitmap with: 16rFFFFFFFF].  "4/8 gray"
	lum < 0.75 ifTrue: [^ Bitmap with: 16rFFFFFFFF with: 16rBBBBBBBB].  "5/8 gray"
	lum < 0.875 ifTrue: [^ Bitmap with: 16rEEEEEEEE with: 16rBBBBBBBB].  "6/8 gray"
	lum < 1.0 ifTrue: [^ Bitmap with: 16rAAAAAAAA with: 16rBBBBBBBB].  "7/8 gray"
	^ Bitmap with: 16rAAAAAAAA  "opaque white"

"handy expression for computing patterns for 2x2 tiles;
 set p to a string of 4 letters (e.g., 'wggw' for a gray-and-
 white checkerboard) and print the result of evaluating:
| p d w1 w2 |
p := 'wggw'.
d := Dictionary new.
d at: $b put: '01'.
d at: $w put: '10'.
d at: $g put: '11'.
w1 := (d at: (p at: 1)), (d at: (p at: 2)).
w1 := '2r', w1, w1, w1, w1, w1, w1, w1, w1, ' hex'.
w2 := (d at: (p at: 3)), (d at: (p at: 4)).
w2 := '2r', w2, w2, w2, w2, w2, w2, w2, w2, ' hex'.
Array with: (Compiler evaluate: w1) with: (Compiler evaluate: w2) 
"! !

!Color methodsFor: 'equality' stamp: ''!
hash

	^ rgb! !

!Color methodsFor: 'access' stamp: ''!
hue
	"Return the hue of this color, an angle in the range [0.0..360.0]."

	| r g b max min span h |
	r := self privateRed.
	g := self privateGreen.
	b := self privateBlue. 

	max := ((r max: g) max: b).
	min := ((r min: g) min: b).
	span := (max - min) asFloat.
	span = 0.0 ifTrue: [ ^ 0.0 ].

	r = max ifTrue: [
		h := ((g - b) asFloat / span) * 60.0.
	] ifFalse: [
		g = max
			ifTrue: [ h := 120.0 + (((b - r) asFloat / span) * 60.0). ]
			ifFalse: [ h := 240.0 + (((r - g) asFloat / span) * 60.0). ].
	].

	h < 0.0 ifTrue: [ h := 360.0 + h ].
	^ h! !

!Color methodsFor: 'conversions' stamp: 'tk 4/24/97'!
indexInMap: aColorMap
	"Return the index corresponding to this color in the given color map. RGB colors are truncated to 3-, 4-, or 5-bits per color component when indexing into such a colorMap.  "

	aColorMap size = 2 ifTrue: [^ (self pixelValueForDepth: 1) + 1].
	aColorMap size = 4 ifTrue: [^ (self pixelValueForDepth: 2) + 1].
	aColorMap size = 16 ifTrue: [^ (self pixelValueForDepth: 4) + 1].
	aColorMap size = 256 ifTrue: [^ (self pixelValueForDepth: 8) + 1].
	aColorMap size = 512 ifTrue: [^ (self pixelValueForDepth: 9) + 1].
	aColorMap size = 4096 ifTrue: [^ (self pixelValueForDepth: 12) + 1].
	aColorMap size = 32768 ifTrue: [^ (self pixelValueForDepth: 16) + 1].
	self error: 'unknown pixel depth'.
! !

!Color methodsFor: 'queries' stamp: 'ar 1/14/1999 15:27'!
isBitmapFill
	^false! !

!Color methodsFor: 'queries' stamp: 'ar 11/12/1998 19:43'!
isBlack
	"Return true if the receiver represents black"
	^rgb = 0! !

!Color methodsFor: 'queries' stamp: ''!
isColor

	^ true
! !

!Color methodsFor: 'queries' stamp: 'ar 6/18/1999 06:58'!
isGradientFill
	^false! !

!Color methodsFor: 'queries' stamp: 'ar 11/12/1998 19:44'!
isGray
	"Return true if the receiver represents a shade of gray"
	^(self privateRed = self privateGreen) and:[self privateRed = self privateBlue]! !

!Color methodsFor: 'queries' stamp: 'ar 4/20/2001 04:33'!
isOpaque
	^true! !

!Color methodsFor: 'queries' stamp: 'ar 6/18/1999 07:57'!
isOrientedFill
	"Return true if the receiver keeps an orientation (e.g., origin, direction, and normal)"
	^false! !

!Color methodsFor: 'queries' stamp: 'ar 11/7/1998 20:20'!
isSolidFill
	^true! !

!Color methodsFor: 'queries' stamp: 'di 12/30/1998 14:33'!
isTranslucent

	^ false
! !

!Color methodsFor: 'queries' stamp: 'di 1/3/1999 12:23'!
isTranslucentColor
	"This means: self isTranslucent, but isTransparent not"
	^ false! !

!Color methodsFor: 'queries' stamp: ''!
isTransparent

	^ false
! !

!Color methodsFor: 'transformations' stamp: 'dew 1/23/2002 20:19'!
lighter
	"Answer a lighter shade of this color."

	^ self adjustSaturation: -0.03 brightness: 0.08! !

!Color methodsFor: 'groups of shades' stamp: 'tk 6/18/96'!
lightShades: thisMany
	"An array of thisMany colors from white to self. Very useful for displaying color based on a variable in your program.  "
	"Color showColors: (Color red lightShades: 12)"

	^ self class white mix: self shades: thisMany
! !

!Color methodsFor: 'access' stamp: ''!
luminance
	"Return the luminance of this color, a brightness value weighted by the human eye's color sensitivity."

	^ ((299 * self privateRed) +
	   (587 * self privateGreen) +
	   (114 * self privateBlue)) / (1000 * ComponentMax)
! !

!Color methodsFor: 'conversions' stamp: 'bf 4/18/2001 16:25'!
makeForegroundColor
        "Make a foreground color contrasting with me"
        ^self luminance >= 0.5
                ifTrue: [Color black]
                ifFalse: [Color white]! !

!Color methodsFor: 'transformations' stamp: 'tk 7/4/2000 12:00'!
mixed: proportion with: aColor 
	"Mix with another color and do not preserve transpareny.  Only use this for extracting the RGB value and mixing it.  All other callers should use instead: 
	aColor alphaMixed: proportion with: anotherColor
	"

	| frac1 frac2 |
	frac1 := proportion asFloat min: 1.0 max: 0.0.
	frac2 := 1.0 - frac1.
	^ Color
		r: self red * frac1 + (aColor red * frac2)
		g: self green * frac1 + (aColor green * frac2)
		b: self blue * frac1 + (aColor blue * frac2)! !

!Color methodsFor: 'groups of shades' stamp: 'nice 12/27/2009 03:10'!
mix: color2 shades: thisMany
	"Return an array of thisMany colors from self to color2. Very useful for displaying color based on a variable in your program.  "
	"Color showColors: (Color red mix: Color green shades: 12)"

	| redInc greenInc blueInc out rr gg bb |
	thisMany = 1 ifTrue: [^ Array with: color2].
	redInc := color2 red - self red / (thisMany-1).
	greenInc := color2 green - self green / (thisMany-1).
	blueInc := color2 blue - self blue / (thisMany-1).
	rr := self red.  gg := self green.  bb := self blue.
	out := (1 to: thisMany) collect: [:num | | c |
		c := Color r: rr g: gg b: bb.
		rr := rr + redInc.
		gg := gg + greenInc.
		bb := bb + blueInc.
		c].
	out at: out size put: color2.	"hide roundoff errors"
	^ out
! !

!Color methodsFor: 'transformations' stamp: 'dew 1/19/2002 01:29'!
muchDarker

	^ self alphaMixed: 0.5 with: Color black
! !

!Color methodsFor: 'transformations' stamp: 'tk 7/4/2000 12:07'!
muchLighter

	^ self alphaMixed: 0.233 with: Color white
! !

!Color methodsFor: 'other' stamp: 'ul 12/9/2010 02:56'!
name
	"Return this color's name, or nil if it has no name. Only returns a name if it exactly matches the named color."

	^ColorNames detect: [ :name | (Color perform: name) = self ] ifNone: [ nil ]! !

!Color methodsFor: 'transformations' stamp: 'ar 6/19/1999 00:36'!
negated
	"Return an RGB inverted color"
	^Color
		r: 1.0 - self red
		g: 1.0 - self green
		b: 1.0 - self blue! !

!Color methodsFor: 'transformations' stamp: 'di 9/27/2000 08:14'!
orColorUnlike: theOther
	"If this color is a lot like theOther, then return its complement, otherwide, return self"

	(self diff: theOther) < 0.3
		ifTrue: [^ theOther negated]
		ifFalse: [^ self]! !

!Color methodsFor: 'transformations' stamp: 'dew 3/4/2002 01:42'!
paler
	"Answer a paler shade of this color."

	^ self adjustSaturation: -0.09 brightness: 0.09
! !

!Color methodsFor: 'conversions' stamp: 'ar 5/15/2001 16:12'!
pixelValue32
	"Note: pixelWord not pixelValue so we include translucency"
	^self pixelWordForDepth: 32! !

!Color methodsFor: 'conversions' stamp: 'eem 1/16/2016 09:40'!
pixelValueForDepth: d
	"Answers an integer representing the bits that appear in a single pixel of this color in a Form of the given depth.
	 The depth must be one of 1, 2, 4, 8, 16, or 32. Contrast with pixelWordForDepth: and bitPatternForDepth:, which
	 answer either a 32-bit word packed with the given pixel value or a multiple-word Bitmap containing a pattern.
	 The inverse is the class message colorFromPixelValue:depth:"
	"Details:
		For depths of 8 or less, the result is a colorMap index.
		For depths of 16 and 32, it is a direct color value with 5 or 8 bits per color component."
	"Transparency:
		The pixel value zero is reserved for transparent.
		For depths greater than 8, black maps to the darkest possible blue."

	| val |
	d > 8 ifTrue: "most common case"
		[d = 32 ifTrue: "eight bits per component; top 8 bits set to all ones (opaque alpha)"
			["this subexpression is a SmallInteger in both 32- and 64-bits."
			 val :=	((rgb bitShift: -6) bitAnd: 16rFF0000) bitOr:
					(((rgb bitShift: -4) bitAnd: 16rFF00) bitOr:
					((rgb bitShift: -2) bitAnd: 16rFF)).
			"16rFF000000 & 16rFF000001 are LargeIntegers in 32-bits, SmallIntegers in 64-bits."
			^val = 0 ifTrue: [16rFF000001] ifFalse: [16rFF000000 + val]].
			
		d = 16 ifTrue: "five bits per component; top bits ignored"
			[val := (((rgb bitShift: -15) bitAnd: 16r7C00) bitOr:
					 ((rgb bitShift: -10) bitAnd: 16r03E0)) bitOr:
					 ((rgb bitShift: -5) bitAnd: 16r001F).
			^val = 0 ifTrue: [1] ifFalse: [val]].

		d = 12 ifTrue: "for indexing a color map with 4 bits per color component"
			[val := (((rgb bitShift: -18) bitAnd: 16r0F00) bitOr:
					 ((rgb bitShift: -12) bitAnd: 16r00F0)) bitOr:
					 ((rgb bitShift: -6) bitAnd: 16r000F).
			^val = 0 ifTrue: [1] ifFalse: [val]].

		d = 9 ifTrue: "for indexing a color map with 3 bits per color component"
			[val := (((rgb bitShift: -21) bitAnd: 16r01C0) bitOr:
				 ((rgb bitShift: -14) bitAnd: 16r0038)) bitOr:
				 ((rgb bitShift: -7) bitAnd: 16r0007).
			^val = 0 ifTrue: [1] ifFalse: [val]]].
	d = 8 ifTrue: [^ self closestPixelValue8].
	d = 4 ifTrue: [^ self closestPixelValue4].
	d = 2 ifTrue: [^ self closestPixelValue2]..
	d = 1 ifTrue: [^ self closestPixelValue1].

	self error: 'unknown pixel depth: ', d printString
! !

!Color methodsFor: 'conversions' stamp: ''!
pixelWordForDepth: depth
	"Return to a 32-bit word that concatenates enough copies of the receiver's pixel value to fill the word (i.e., 32/depth copies). Depth should be one of 1, 2, 4, 8, 16, or 32. The pixel value should be an integer in 0..2^depth-1."

	| pixelValue |
	pixelValue := self pixelValueForDepth: depth.
	^ self pixelWordFor: depth filledWith: pixelValue
! !

!Color methodsFor: 'conversions' stamp: 'di 11/30/1998 09:03'!
pixelWordFor: depth filledWith: pixelValue
	"Return to a 32-bit word that concatenates enough copies of the given pixel value to fill the word (i.e., 32/depth copies). Depth should be one of 1, 2, 4, 8, 16, or 32. The pixel value should be an integer in 0..2^depth-1."
	| halfword |
	depth = 32 ifTrue: [^ pixelValue].
	depth = 16
		ifTrue: [halfword := pixelValue]
		ifFalse: [halfword := pixelValue * 
					(#(16rFFFF				"replicates at every bit"
						16r5555 -			"replicates every 2 bits"
						16r1111 - - -			"replicates every 4 bits"
						16r0101) at: depth)	"replicates every 8 bits"].
	^ halfword bitOr: (halfword bitShift: 16)! !

!Color methodsFor: 'html' stamp: 'hmm 11/1/2006 23:28'!
printHtmlString
	"answer a string whose characters are the html representation  
	of the receiver"
	^ ((self red * 255) asInteger printStringBase: 16 length: 2 padded: true)
	, ((self green * 255) asInteger printStringBase: 16 length: 2 padded: true)
	, ((self blue * 255) asInteger printStringBase: 16 length: 2 padded: true)! !

!Color methodsFor: 'printing' stamp: 'bf 5/25/2000 16:52'!
printOn: aStream
	| name |
	(name := self name) ifNotNil:
		[^ aStream
			nextPutAll: 'Color ';
			nextPutAll: name].
	self storeOn: aStream.
! !

!Color methodsFor: 'private' stamp: ''!
privateAlpha
	"Private!! Return the raw alpha value for opaque. Used only for equality testing."

	^ 255! !

!Color methodsFor: 'private' stamp: ''!
privateBlue
	"Private!! Return the internal representation of my blue component."

	^ rgb bitAnd: ComponentMask! !

!Color methodsFor: 'private' stamp: ''!
privateGreen
	"Private!! Return the internal representation of my green component.
	Replaced >> by bitShift: 0 -. SqR!! 2/25/1999 23:08"

	^ (rgb bitShift: 0 - GreenShift) bitAnd: ComponentMask! !

!Color methodsFor: 'private' stamp: ''!
privateRed
	"Private!! Return the internal representation of my red component."

	^ (rgb bitShift: 0 - RedShift) bitAnd: ComponentMask! !

!Color methodsFor: 'private' stamp: ''!
privateRGB
	"Private!! Return the internal representation of my RGB components."

	^ rgb
! !

!Color methodsFor: 'other' stamp: 'ar 8/16/2001 12:47'!
raisedColor
	^ self! !

!Color methodsFor: 'access' stamp: ''!
red
	"Return the red component of this color, a float in the range [0.0..1.0]."

	^ self privateRed asFloat / ComponentMax! !

!Color methodsFor: 'other' stamp: 'jm 12/4/97 10:27'!
rgbTriplet
	"Color fromUser rgbTriplet"

	^ Array
		with: (self red roundTo: 0.01)
		with: (self green roundTo: 0.01)
		with: (self blue roundTo: 0.01)
! !

!Color methodsFor: 'access' stamp: ''!
saturation
	"Return the saturation of this color, a value between 0.0 and 1.0."

	| r g b max min |
	r := self privateRed.
	g := self privateGreen.
	b := self privateBlue. 

	max := min := r.
	g > max ifTrue: [max := g].
	b > max ifTrue: [max := b].
	g < min ifTrue: [min := g].
	b < min ifTrue: [min := b].

	max = 0
		ifTrue: [ ^ 0.0 ]
		ifFalse: [ ^ (max - min) asFloat / max asFloat ].
! !

!Color methodsFor: 'conversions' stamp: 'ar 1/14/1999 15:28'!
scaledPixelValue32
	"Return the alpha scaled pixel value for depth 32"
	^self pixelWordForDepth: 32! !

!Color methodsFor: 'private' stamp: 'nice 10/30/2009 21:03'!
setHue: hue saturation: saturation brightness: brightness
	"Initialize this color to the given hue, saturation, and brightness. See the comment in the instance creation method for details."

	| s v hf i f p q t | 
	s := (saturation asFloat max: 0.0) min: 1.0.
	v := (brightness asFloat max: 0.0) min: 1.0.

	"zero saturation yields gray with the given brightness"
	s = 0.0 ifTrue: [ ^ self setRed: v green: v blue: v ].

	hf := hue asFloat.
	(hf < 0.0 or: [hf >= 360.0])
		ifTrue: [hf := hf \\ 360].
	hf := hf / 60.0.
	i := hf asInteger.  "integer part of hue"
	f := hf fractionPart.         "fractional part of hue"
	p := (1.0 - s) * v.
	q := (1.0 - (s * f)) * v.
	t := (1.0 - (s * (1.0 - f))) * v.

	0 = i ifTrue: [ ^ self setRed: v green: t blue: p ].
	1 = i ifTrue: [ ^ self setRed: q green: v blue: p ].
	2 = i ifTrue: [ ^ self setRed: p green: v blue: t ].
	3 = i ifTrue: [ ^ self setRed: p green: q blue: v ].
	4 = i ifTrue: [ ^ self setRed: t green: p blue: v ].
	5 = i ifTrue: [ ^ self setRed: v green: p blue: q ].

	self error: 'implementation error'.
! !

!Color methodsFor: 'private' stamp: 'di 11/2/97 12:19'!
setPrivateRed: r green: g blue: b
	"Initialize this color's r, g, and b components to the given values in the range [0..ComponentMax].  Encoded in a single variable as 3 integers in [0..1023]."

	rgb == nil ifFalse: [self attemptToMutateError].
	rgb := ((r min: ComponentMask max: 0) bitShift: RedShift) +
		((g min: ComponentMask max: 0) bitShift: GreenShift) +
		 (b min: ComponentMask max: 0).
	cachedDepth := nil.
	cachedBitPattern := nil.
! !

!Color methodsFor: 'private' stamp: ''!
setRed: r green: g blue: b
	"Initialize this color's r, g, and b components to the given values in the range [0.0..1.0].  Encoded in a single variable as 3 integers in [0..1023]."

	rgb == nil ifFalse: [self attemptToMutateError].
	rgb :=
		(((r * ComponentMax) rounded bitAnd: ComponentMask) bitShift: RedShift) +
		(((g * ComponentMax) rounded bitAnd: ComponentMask) bitShift: GreenShift) +
		 ((b * ComponentMax) rounded bitAnd: ComponentMask).
	cachedDepth := nil.
	cachedBitPattern := nil.
! !

!Color methodsFor: 'private' stamp: ''!
setRed: r green: g blue: b range: range
	"Initialize this color's r, g, and b components to the given values in the range [0..r]."

	rgb == nil ifFalse: [self attemptToMutateError].
	rgb :=
		((((r * ComponentMask) // range) bitAnd: ComponentMask) bitShift: RedShift) +
		((((g * ComponentMask) // range) bitAnd: ComponentMask) bitShift: GreenShift) +
		 (((b * ComponentMask) // range) bitAnd: ComponentMask).
	cachedDepth := nil.
	cachedBitPattern := nil.
! !

!Color methodsFor: 'private' stamp: 'ls 9/24/1999 20:04'!
setRGB: rgb0
	rgb == nil ifFalse: [self attemptToMutateError].
	rgb := rgb0! !

!Color methodsFor: 'printing' stamp: 'bf 5/16/2012 18:46'!
shortPrintString
	"Return a short (but less precise) print string for use where space is tight."

	^String streamContents: [:s | s
		nextPutAll: '(';
		print: self class;
		nextPutAll: ' r: '; print: self red maxDecimalPlaces: 2;
		nextPutAll: ' g: '; print: self green maxDecimalPlaces: 2;
		nextPutAll: ' b: '; print: self blue maxDecimalPlaces: 2;
		nextPutAll: ')']! !

!Color methodsFor: 'transformations' stamp: 'dew 3/4/2002 01:43'!
slightlyDarker

	^ self adjustBrightness: -0.03
! !

!Color methodsFor: 'transformations' stamp: 'dew 3/4/2002 01:43'!
slightlyLighter

	^ self adjustSaturation: -0.01 brightness: 0.03! !

!Color methodsFor: 'transformations' stamp: 'dew 1/19/2002 01:25'!
slightlyWhiter

	^ self alphaMixed: 0.85 with: Color white
! !

!Color methodsFor: 'printing' stamp: 'mir 7/21/1999 11:41'!
storeArrayOn: aStream

	aStream nextPutAll: '#('.
	self storeArrayValuesOn: aStream.
	aStream nextPutAll: ') '
! !

!Color methodsFor: 'printing' stamp: 'bf 5/16/2012 18:45'!
storeArrayValuesOn: aStream

	aStream
		print: self red maxDecimalPlaces: 3;
		space;
		print: self green maxDecimalPlaces: 3;
		space;
		print: self blue maxDecimalPlaces: 3.
! !

!Color methodsFor: 'printing' stamp: 'bf 5/16/2012 18:46'!
storeOn: aStream

	aStream
		nextPutAll: '(' , self species name;
		nextPutAll: ' r: '; print: self red maxDecimalPlaces: 3;
		nextPutAll: ' g: '; print: self green maxDecimalPlaces: 3;
		nextPutAll: ' b: '; print: self blue maxDecimalPlaces: 3;
		nextPutAll: ')'.
! !

!Color methodsFor: 'transformations' stamp: 'bgf 7/22/2006 00:37'!
twiceDarker
	"Answer a significantly darker shade of this color."

	^ self adjustSaturation: 0.075 brightness: -0.15! !

!Color methodsFor: 'transformations' stamp: 'dew 3/4/2002 01:45'!
twiceLighter
	"Answer a significantly lighter shade of this color."

	^ self adjustSaturation: -0.06 brightness: 0.15! !

!Color methodsFor: 'copying' stamp: 'tk 8/19/1998 16:12'!
veryDeepCopyWith: deepCopier
	"Return self.  I am immutable in the Morphic world.  Do not record me."! !

!Color methodsFor: 'transformations' stamp: 'tk 7/4/2000 12:07'!
veryMuchLighter

	^ self alphaMixed: 0.1165 with: Color white
! !

!Color methodsFor: 'groups of shades' stamp: 'nice 12/27/2009 03:10'!
wheel: thisMany
	"An array of thisMany colors around the color wheel starting at self and ending all the way around the hue space just before self.  Array is of length thisMany.  Very useful for displaying color based on a variable in your program.  "

	| sat bri step hue |
	sat := self saturation.
	bri := self brightness.
	hue := self hue.
	step := 360.0 / (thisMany max: 1).
	^ (1 to: thisMany) collect: [:num | | c |
		c := Color h: hue s: sat v: bri.  "hue is taken mod 360"
		hue := hue + step.
		c].
"
(Color wheel: 8) withIndexDo: [:c :i | Display fill: (i*10@20 extent: 10@20) fillColor: c]
"! !

!Color methodsFor: 'transformations' stamp: 'dew 3/23/2002 01:38'!
whiter

	^ self alphaMixed: 0.8333 with: Color white
! !

!Color methodsFor: 'transformations' stamp: 'fbs 2/3/2005 13:09'!
* aNumberOrArray
	"Answer this color with its RGB multiplied by the given number, or
	 multiply this color's RGB values by the corresponding entries in the
	given array."
	"(Color brown * 2) display"
	"(Color brown * #(1 0 1)) display"
	| multipliers |
	multipliers := aNumberOrArray isCollection
		ifTrue: [aNumberOrArray]
		ifFalse:
			[Array
				with: aNumberOrArray
				with: aNumberOrArray
				with: aNumberOrArray].

	^ Color basicNew
		setPrivateRed: (self privateRed * multipliers first) asInteger
		green: (self privateGreen * multipliers second) asInteger
		blue: (self privateBlue * multipliers third) asInteger.! !

!Color methodsFor: 'transformations' stamp: 'di 11/2/97 14:05'!
+ aColor
	"Answer this color mixed with the given color in an additive color space.  "
	"(Color blue + Color green) display"

	^ Color basicNew
		setPrivateRed: self privateRed + aColor privateRed
		green: self privateGreen + aColor privateGreen
		blue: self privateBlue + aColor  privateBlue
! !

!Color methodsFor: 'transformations' stamp: 'di 11/2/97 14:05'!
- aColor
	"Answer aColor is subtracted from the given color in an additive color space.  "
	"(Color white - Color red) display"

	^ Color basicNew
		setPrivateRed: self privateRed - aColor privateRed
		green: self privateGreen - aColor privateGreen
		blue: self privateBlue - aColor  privateBlue
! !

!Color methodsFor: 'transformations' stamp: 'di 11/2/97 14:07'!
/ aNumber
	"Answer this color with its RGB divided by the given number. "
	"(Color red / 2) display"

	^ Color basicNew
		setPrivateRed: (self privateRed / aNumber) asInteger
		green: (self privateGreen / aNumber) asInteger
		blue: (self privateBlue / aNumber) asInteger
! !

!Color methodsFor: 'equality' stamp: 'di 1/6/1999 20:26'!
= aColor
	"Return true if the receiver equals the given color. This method handles TranslucentColors, too."

	aColor isColor ifFalse: [^ false].
	^ aColor privateRGB = rgb and:
		[aColor privateAlpha = self privateAlpha]
! !

Color subclass: #TranslucentColor
	instanceVariableNames: 'alpha'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Primitives'!

!TranslucentColor commentStamp: '<historical>' prior: 0!
A TranslucentColor behaves just like a normal color, except that it will pack its alpha value into the high byte of a 32-bit pixelValue.  This allows creating forms with translucency for use with the alpha blend function of BitBlt.  An alpha of zero is transparent, and 1.0 is opaque.!

!TranslucentColor methodsFor: 'accessing' stamp: ''!
alpha
	"Return my alpha value, a number between 0.0 and 1.0 where 0.0 is completely transparent and 1.0 is completely opaque."

	^ alpha asFloat / 255.0
! !

!TranslucentColor methodsFor: 'conversions' stamp: 'di 1/15/1999 11:44'!
alpha: alphaValue
	alphaValue = 1.0 ifTrue:
		[^ Color basicNew
			setPrivateRed: self privateRed
			green: self privateGreen
			blue: self privateBlue].
	^ super alpha: alphaValue! !

!TranslucentColor methodsFor: 'conversions' stamp: 'sw 10/27/1999 10:51'!
asNontranslucentColor
	^ self alpha: 1.0! !

!TranslucentColor methodsFor: 'conversions' stamp: 'di 3/25/2000 17:56'!
balancedPatternForDepth: depth
	"Return an appropriate bit pattern or stipple.  This will almost never be meaningful for tranlucentColors, except for the degenerate case of tranparency."

	alpha = 0 ifTrue: [^ Bitmap with: 0].
	^ super balancedPatternForDepth: depth! !

!TranslucentColor methodsFor: 'conversions' stamp: 'di 1/14/1999 20:05'!
bitPatternForDepth: depth
	"Return an appropriate bit pattern or stipple.  This will almost never be meaningful for tranlucentColors, except for the degenerate case of tranparency."

	alpha = 0 ifTrue: [^ Bitmap with: 0].
	^ super bitPatternForDepth: depth! !

!TranslucentColor methodsFor: 'object fileIn' stamp: 'RAA 12/20/2000 17:50'!
convertToCurrentVersion: varDict refStream: smartRefStrm
	
	"1/13/1999 -- old versions did not have alpha??"
	varDict at: 'alpha' ifAbsent: [^ Color transparent].

	^super convertToCurrentVersion: varDict refStream: smartRefStrm.
	! !

!TranslucentColor methodsFor: 'equality' stamp: ''!
hash

	^ rgb bitXor: alpha
! !

!TranslucentColor methodsFor: 'queries' stamp: 'ar 4/20/2001 04:33'!
isOpaque
	^alpha = 255! !

!TranslucentColor methodsFor: 'queries' stamp: 'di 12/30/1998 14:33'!
isTranslucent
	^ alpha < 255! !

!TranslucentColor methodsFor: 'queries' stamp: 'di 1/3/1999 12:22'!
isTranslucentColor
	"This means: self isTranslucent, but isTransparent not"
	^ alpha > 0! !

!TranslucentColor methodsFor: 'queries' stamp: 'di 12/30/1998 14:33'!
isTransparent
	^ alpha = 0! !

!TranslucentColor methodsFor: 'conversions' stamp: 'ar 5/27/2001 16:30'!
pixelValueForDepth: d
	"Return the pixel value for this color at the given depth. Translucency only works in RGB; this color will appear either opaque or transparent at all other depths."
	| basicPixelWord |
	alpha = 0 ifTrue: [^ 0].
	basicPixelWord := super pixelValueForDepth: d.
	d < 32
		ifTrue: [^ basicPixelWord]
		ifFalse: [^ (basicPixelWord bitAnd: 16rFFFFFF) bitOr: (alpha bitShift: 24)].
! !

!TranslucentColor methodsFor: 'conversions' stamp: 'di 1/6/1999 16:14'!
pixelWordForDepth: depth
	"Return the pixel value for this color at the given depth. Translucency only works in RGB; this color will appear either opaque or transparent at all other depths."

	| basicPixelWord |
	alpha = 0 ifTrue: [^ 0].
	basicPixelWord := super pixelWordForDepth: depth.
	depth < 32
		ifTrue: [^ basicPixelWord]
		ifFalse: [^ (basicPixelWord bitAnd: 16rFFFFFF) bitOr: (alpha bitShift: 24)].
! !

!TranslucentColor methodsFor: 'private' stamp: ''!
privateAlpha
	"Return my raw alpha value, an integer in the range 0..255. Used for fast equality testing."

	^ alpha
! !

!TranslucentColor methodsFor: 'conversions' stamp: 'ar 1/14/1999 15:30'!
scaledPixelValue32
	"Return the alpha scaled pixel value for depth 32"
	| pv32 a b g r |
	pv32 := super scaledPixelValue32.
	a := (self alpha * 255.0) rounded.
	b := (pv32 bitAnd: 255) * a // 256.
	g := ((pv32 bitShift: -8) bitAnd: 255) * a // 256.
	r := ((pv32 bitShift: -16) bitAnd: 255) * a // 256.
	^b + (g bitShift: 8) + (r bitShift: 16) + (a bitShift: 24)! !

!TranslucentColor methodsFor: 'private' stamp: ''!
setRgb: rgbValue alpha: alphaValue
	"Set the state of this translucent color. Alpha is represented internally by an integer in the range 0..255."

	rgb == nil ifFalse: [self attemptToMutateError].
	rgb := rgbValue.
	alpha := (255.0 * alphaValue) asInteger min: 255 max: 0.
! !

!TranslucentColor methodsFor: 'printing' stamp: 'nice 12/25/2013 23:43'!
storeArrayValuesOn: aStream

	self isTransparent ifTrue: [
		^ aStream space].
	super storeArrayValuesOn: aStream.
	aStream
		space;
		print: self alpha maxDecimalPlaces: 3.! !

!TranslucentColor methodsFor: 'printing' stamp: 'bf 5/16/2012 18:47'!
storeOn: aStream

	self isTransparent ifTrue: [^ aStream nextPutAll: '(Color transparent)'].
	super storeOn: aStream.
	aStream
		skip: -1;	  "get rid of trailing )"
		nextPutAll: ' alpha: ';
		print: self alpha maxDecimalPlaces: 3;
		nextPutAll: ')'.
! !

Object subclass: #ColorMap
	instanceVariableNames: 'shifts masks colors'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Primitives'!

!ColorMap class methodsFor: 'instance creation' stamp: 'ar 2/22/2000 14:08'!
colors: colorArray
	^self new setShifts: nil masks: nil colors: colorArray! !

!ColorMap class methodsFor: 'instance creation' stamp: 'ar 5/27/2000 20:09'!
mapBitsFrom: srcBitMask to: dstBitMask
	"Return an array consisting of the shift and the mask for
	mapping component values out of srcBitMask and into dstBitMask.
	While this computation is somewhat complicated it eases the batch
	conversion of all the pixels in BitBlt."
	| srcBits dstBits srcLow srcHigh dstLow dstHigh bits mask shift |
	(srcBitMask = 0 or:[dstBitMask = 0]) ifTrue:[^#(0 0)]. "Zero mask and shift"
	"Compute low and high bit position for source and dest bit mask"
	srcLow := srcBitMask lowBit - 1.	srcHigh := srcBitMask highBit.
	dstLow := dstBitMask lowBit - 1.	dstHigh := dstBitMask highBit.
	"Compute the number of bits in source and dest bit mask"
	srcBits := srcHigh - srcLow.		dstBits := dstHigh - dstLow.
	"Compute the maximum number of bits we can transfer inbetween"
	bits := srcBits min: dstBits.
	"Compute the (unshifted) transfer mask"
	mask := (1 bitShift: bits) - 1.
	"Shift the transfer mask to the mask the highest n bits of srcBitMask"
	mask := mask bitShift: (srcHigh - bits).
	"Compute the delta shift so that the most significant bit of the
	source bit mask falls on the most significant bit of the dest bit mask.
	Note that delta is used for #bitShift: so
		shift > 0 : shift right
		shift < 0 : shift left
	e.g., if dstHigh > srcHigh we need to shift left and if dstHigh < srcHigh
	we need to shift right. This leads to:"
	shift := dstHigh - srcHigh.
	"And that's all we need"
	^Array with: shift with: mask! !

!ColorMap class methodsFor: 'instance creation' stamp: 'ar 5/27/2000 20:08'!
mappingFromARGB: dstBitMasks
	"Return a ColorMap mapping from canonical ARGB space into dstBitMasks"
	^self mappingFrom: #(16rFF0000 16rFF00 16rFF 16rFF000000) to: dstBitMasks! !

!ColorMap class methodsFor: 'instance creation' stamp: 'ar 5/27/2000 19:41'!
mappingFrom: srcBitMasks to: dstBitMasks
	"Return a color map mapping from the array of source bit masks
	to the array of dest bit masks."
	| shifts masks shiftAndMask |
	shifts := IntegerArray new: 4.
	masks := WordArray new: 4.
	1 to: 4 do:[:i|
		shiftAndMask := self mapBitsFrom: (srcBitMasks at: i) to: (dstBitMasks at: i).
		shifts at: i put: (shiftAndMask at: 1).
		masks at: i put: (shiftAndMask at: 2).
	].
	^self shifts: shifts masks: masks! !

!ColorMap class methodsFor: 'instance creation' stamp: 'ar 5/27/2000 20:08'!
mappingToARGB: srcBitMasks
	"Return a ColorMap mapping from srcBitMasks into canonical ARGB space"
	^self mappingFrom: srcBitMasks to: #(16rFF0000 16rFF00 16rFF 16rFF000000)! !

!ColorMap class methodsFor: 'instance creation' stamp: 'ar 5/4/2001 15:59'!
masks: maskArray shifts: shiftArray
	^self shifts: shiftArray masks: maskArray colors: nil.! !

!ColorMap class methodsFor: 'instance creation' stamp: 'ar 1/16/2000 16:02'!
shifts: shiftArray masks: maskArray
	^self shifts: shiftArray masks: maskArray colors: nil.! !

!ColorMap class methodsFor: 'instance creation' stamp: 'ar 1/16/2000 16:02'!
shifts: shiftArray masks: maskArray colors: colorArray
	^self new setShifts: shiftArray masks: maskArray colors: colorArray! !

!ColorMap methodsFor: 'accessing' stamp: 'ar 1/16/2000 15:54'!
alphaMask
	^masks at: 4! !

!ColorMap methodsFor: 'accessing' stamp: 'ar 1/16/2000 15:55'!
alphaMask: value
	masks at: 4 put: value! !

!ColorMap methodsFor: 'accessing' stamp: 'ar 1/16/2000 15:31'!
alphaShift
	^shifts at: 4! !

!ColorMap methodsFor: 'accessing' stamp: 'ar 1/16/2000 15:31'!
alphaShift: value
	shifts at: 4 put: value! !

!ColorMap methodsFor: 'accessing' stamp: 'ar 1/16/2000 15:39'!
at: index
	^colors at: index! !

!ColorMap methodsFor: 'accessing' stamp: 'ar 1/16/2000 15:39'!
at: index put: value
	^colors at: index put: value! !

!ColorMap methodsFor: 'accessing' stamp: 'ar 1/16/2000 15:31'!
blueMask
	^masks at: 3! !

!ColorMap methodsFor: 'accessing' stamp: 'ar 1/16/2000 15:31'!
blueMask: value
	masks at: 3 put: value! !

!ColorMap methodsFor: 'accessing' stamp: 'ar 1/16/2000 15:31'!
blueShift
	^shifts at: 3! !

!ColorMap methodsFor: 'accessing' stamp: 'ar 1/16/2000 15:32'!
blueShift: value
	shifts at: 3 put: value! !

!ColorMap methodsFor: 'accessing' stamp: 'ar 2/10/2000 17:12'!
colors
	^colors! !

!ColorMap methodsFor: 'accessing' stamp: 'ar 1/16/2000 15:32'!
greenMask
	^masks at: 2! !

!ColorMap methodsFor: 'accessing' stamp: 'ar 1/16/2000 15:32'!
greenMask: value
	masks at: 2 put: value! !

!ColorMap methodsFor: 'accessing' stamp: 'ar 1/16/2000 15:32'!
greenShift
	^shifts at: 2! !

!ColorMap methodsFor: 'accessing' stamp: 'ar 1/16/2000 15:36'!
greenShift: value
	shifts at: 2 put: value.! !

!ColorMap methodsFor: 'comparing' stamp: 'ar 5/27/2000 19:29'!
hash
	"Hash is re-implemented because #= is re-implemented"
	^colors hash bitXor: (shifts hash bitXor: masks hash)! !

!ColorMap methodsFor: 'accessing' stamp: 'ar 5/28/2000 22:08'!
inverseMap
	"Return the inverse map of the receiver"
	| newMasks newShifts |
	colors ifNotNil:[^self error:'Not yet implemented'].
	newMasks := WriteStream on: (Array new: 4).
	newShifts := WriteStream on: (Array new: 4).
	masks with: shifts do:[:mask :shift|
		newMasks nextPut: (mask bitShift: shift).
		newShifts nextPut: shift negated].
	^ColorMap
		shifts: newShifts contents
		masks: newMasks contents! !

!ColorMap methodsFor: 'testing' stamp: 'ar 5/25/2000 19:41'!
isColormap
	^true! !

!ColorMap methodsFor: 'testing' stamp: 'ar 5/27/2000 19:06'!
isFixed
	"Return true if the receiver does not use a lookup mechanism for pixel mapping"
	^self isIndexed not! !

!ColorMap methodsFor: 'testing' stamp: 'ar 5/27/2000 19:06'!
isIndexed
	"Return true if the receiver uses a lookup mechanism for pixel mapping"
	^colors notNil! !

!ColorMap methodsFor: 'pixel mapping' stamp: 'ar 5/15/2001 16:12'!
mapPixel: pixelValue
	"Perform a forward pixel mapping operation"
	| pv |
	(shifts == nil and:[masks == nil]) ifFalse:[
		pv := (((pixelValue bitAnd: self redMask) bitShift: self redShift) bitOr:
			((pixelValue bitAnd: self greenMask) bitShift: self greenShift)) bitOr:
			(((pixelValue bitAnd: self blueMask) bitShift: self blueShift) bitOr:
			((pixelValue bitAnd: self alphaMask) bitShift: self alphaShift)).
	] ifTrue:[pv := pixelValue].
	colors ifNotNil:[pv := colors at: pv].
	"Need to check for translucency else Form>>paint goes gaga"
	pv = 0 ifTrue:[pixelValue = 0 ifFalse:[pv := 1]].
	^pv! !

!ColorMap methodsFor: 'pixel mapping' stamp: 'cmm 1/19/2012 20:31'!
mappingTo: aColorMap
	"Compute a new color map through the receiver and aColorMap.
	Both maps are assumed to be mappings into canonical ARGB space"
	| fixedMap |
	self = aColorMap ifTrue:[^nil]. "No mapping needed"
	aColorMap isIndexed ifTrue:[^nil]. "We can't compute mappings to an indexed map yet"
	fixedMap := self species mappingFrom: self rgbaBitMasks to: aColorMap rgbaBitMasks.
	self isIndexed ifFalse:[^fixedMap].
	"If the receiver is indexed then we need to map the colors as well"
	self flag: #untested.
	^ColorMap
		shifts: fixedMap shifts
		masks: fixedMap masks
		colors: (colors collect:[:pv| aColorMap pixelMap: pv]).
! !

!ColorMap methodsFor: 'accessing' stamp: 'ar 5/27/2000 19:16'!
masks
	^masks! !

!ColorMap methodsFor: 'pixel mapping' stamp: 'ar 5/15/2001 16:12'!
pixelMap: pixelValue
	"Perform a reverse pixel mapping operation"
	| pv |
	colors == nil
		ifTrue:[pv := pixelValue]
		ifFalse:[pv := colors at: pixelValue].
	(shifts == nil and:[masks == nil]) 
		ifFalse:[pv := (((pv bitAnd: self redMask) bitShift: self redShift) bitOr: 
				((pv bitAnd: self greenMask) bitShift: self greenShift)) bitOr:
					(((pv bitAnd: self blueMask) bitShift: self blueShift) bitOr: 
						((pv bitAnd: self alphaMask) bitShift: self alphaShift))].
	"Need to check for translucency else Form>>paint goes gaga"
	pv = 0 ifTrue:[pixelValue = 0 ifFalse:[pv := 1]].
	^pv! !

!ColorMap methodsFor: 'accessing' stamp: 'ar 1/16/2000 15:36'!
redMask
	^masks at: 1! !

!ColorMap methodsFor: 'accessing' stamp: 'ar 1/16/2000 15:37'!
redMask: value
	masks at: 1 put: value! !

!ColorMap methodsFor: 'accessing' stamp: 'ar 1/16/2000 15:37'!
redShift
	^shifts at: 1! !

!ColorMap methodsFor: 'accessing' stamp: 'ar 1/16/2000 15:37'!
redShift: value
	shifts at: 1 put: value! !

!ColorMap methodsFor: 'accessing' stamp: 'ar 5/27/2000 20:48'!
rgbaBitMasks
	"Return the rgba bit masks for the receiver"
	^masks asArray with: shifts collect:[:m :s| m bitShift: s]! !

!ColorMap methodsFor: 'private' stamp: 'ar 2/22/2000 16:47'!
setShifts: shiftArray masks: maskArray colors: colorArray
	shiftArray ifNotNil:[shifts := shiftArray asIntegerArray].
	maskArray ifNotNil:[masks := maskArray asWordArray].
	colorArray ifNotNil:[colors := colorArray asWordArray].! !

!ColorMap methodsFor: 'accessing' stamp: 'ar 5/27/2000 19:16'!
shifts
	^shifts! !

!ColorMap methodsFor: 'comparing' stamp: 'tk 7/5/2001 21:59'!
= aColorMap
	"Return true if the receiver is equal to aColorMap"
	self species == aColorMap species ifFalse:[^false].
	self isIndexed == aColorMap isIndexed ifFalse:[^false].
	^self colors = aColorMap colors and:[
		self shifts = aColorMap shifts and:[
			self masks = aColorMap masks]]! !

Object subclass: #DisplayObject
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Display Objects'!

!DisplayObject commentStamp: '<historical>' prior: 0!
The abstract protocol for most display primitives that are used by Views for presenting information on the screen.!

DisplayObject subclass: #DisplayMedium
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Display Objects'!

!DisplayMedium commentStamp: '<historical>' prior: 0!
I am a display object which can both paint myself on a medium (displayOn: messages), and can act as a medium myself. My chief subclass is Form.!

!DisplayMedium methodsFor: 'bordering' stamp: ''!
border: aRectangle widthRectangle: insets rule: combinationRule fillColor: aHalfTone
	"Paint a border whose rectangular area is defined by aRectangle. The 
	width of each edge of the border is determined by the four coordinates 
	of insets. Uses aHalfTone and combinationRule for drawing the border."

	(aRectangle areasOutside: (aRectangle insetBy: insets)) do:
		[:edgeStrip | self fill: edgeStrip rule: combinationRule fillColor: aHalfTone]! !

!DisplayMedium methodsFor: 'bordering' stamp: ''!
border: aRectangle width: borderWidth 
	"Paint a border whose rectangular area is defined by aRectangle. The 
	width of the border of each side is borderWidth. Uses black for 
	drawing the border."

	self border: aRectangle width: borderWidth fillColor: Color black.
! !

!DisplayMedium methodsFor: 'bordering' stamp: ''!
border: aRectangle width: borderWidth fillColor: aHalfTone 
	"Paint a border whose rectangular area is defined by aRectangle. The 
	width of the border of each side is borderWidth. Uses aHalfTone for 
	drawing the border."

	self border: aRectangle
		widthRectangle: 
			(Rectangle
				left: borderWidth
				right: borderWidth
				top: borderWidth
				bottom: borderWidth)
		rule: Form over
		fillColor: aHalfTone! !

!DisplayMedium methodsFor: 'bordering' stamp: ''!
border: aRectangle width: borderWidth rule: combinationRule fillColor: aHalfTone 
	"Paint a border whose rectangular area is defined by aRectangle. The 
	width of the border of each side is borderWidth. Uses aHalfTone for 
	drawing the border."

	self border: aRectangle
		widthRectangle: 
			(Rectangle
				left: borderWidth
				right: borderWidth
				top: borderWidth
				bottom: borderWidth)
		rule: combinationRule
		fillColor: aHalfTone! !

!DisplayMedium methodsFor: 'displaying' stamp: ''!
copyBits: sourceRect from: sourceForm at: destOrigin clippingBox: clipRect rule: rule fillColor: aForm 
	"Make up a BitBlt table and copy the bits."

	self subclassResponsibility! !

!DisplayMedium methodsFor: 'displaying' stamp: 'hmm 9/16/2000 21:27'!
deferUpdatesIn: aRectangle while: aBlock
	"DisplayScreen overrides with something more involved..."
	^aBlock value! !

!DisplayMedium methodsFor: 'displaying' stamp: ''!
drawLine: sourceForm from: beginPoint to: endPoint clippingBox: clipRect rule: anInteger fillColor: aForm 
	"Draw line by copying the argument, sourceForm, starting at location 
	beginPoint and ending at endPoint, clipped by the rectangle, clipRect. 
	The rule and mask for copying are the arguments anInteger and aForm."

	self subclassResponsibility! !

!DisplayMedium methodsFor: 'coloring' stamp: ''!
fillBlack
	"Set all bits in the receiver to black (ones)."

	self fill: self boundingBox fillColor: Color black! !

!DisplayMedium methodsFor: 'coloring' stamp: ''!
fillBlack: aRectangle 
	"Set all bits in the receiver's area defined by aRectangle to black (ones)."

	self fill: aRectangle rule: Form over fillColor: Color black! !

!DisplayMedium methodsFor: 'coloring' stamp: ''!
fillColor: aColor
	"Set all pixels in the receiver to the color.  Must be a correct color for this depth of medium.  TK 1 Jun 96"

	self fill: self boundingBox fillColor: aColor! !

!DisplayMedium methodsFor: 'coloring' stamp: ''!
fillGray
	"Set all bits in the receiver to gray."

	self fill: self boundingBox fillColor: Color gray! !

!DisplayMedium methodsFor: 'coloring' stamp: ''!
fillGray: aRectangle
	"Set all bits in the receiver's area defined by aRectangle to the gray mask."

	self fill: aRectangle rule: Form over fillColor: Color gray! !

!DisplayMedium methodsFor: 'coloring' stamp: ''!
fillShape: aShapeForm fillColor: aColor
	"Fill a region corresponding to 1 bits in aShapeForm with aColor"

	^ self fillShape: aShapeForm fillColor: aColor at: 0@0! !

!DisplayMedium methodsFor: 'coloring' stamp: 'tpr 3/15/2013 12:20'!
fillShape: aShapeForm fillColor: aColor at: location
	"Fill a region corresponding to 1 bits in aShapeForm with aColor"

	((BitBlt destForm: self sourceForm: aShapeForm fillColor: aColor
		combinationRule: Form paint
		destOrigin: location + aShapeForm offset sourceOrigin: 0@0
		extent: self extent clipRect: self boundingBox)
		colorMap: (Bitmap with: 0 with: 16rFFFFFFFF))
		copyBits! !

!DisplayMedium methodsFor: 'coloring' stamp: ''!
fillWhite
	"Set all bits in the form to white."

	self fill: self boundingBox fillColor: Color white.
! !

!DisplayMedium methodsFor: 'coloring' stamp: ''!
fillWhite: aRectangle
	"Set all bits in the receiver's area defined by aRectangle to white."

	self fill: aRectangle rule: Form over fillColor: Color white.
! !

!DisplayMedium methodsFor: 'coloring' stamp: ''!
fillWithColor: aColor
	"Fill the receiver's bounding box with the given color."

	self fill: self boundingBox fillColor: aColor.
! !

!DisplayMedium methodsFor: 'coloring' stamp: ''!
fill: aRectangle fillColor: aForm 
	"Replace a rectangular area of the receiver with the pattern described by 
	aForm according to the rule over."

	self fill: aRectangle rule: Form over fillColor: aForm! !

!DisplayMedium methodsFor: 'coloring' stamp: ''!
fill: aRectangle rule: anInteger fillColor: aForm 
	"Replace a rectangular area of the receiver with the pattern described by 
	aForm according to the rule anInteger."

	self subclassResponsibility! !

!DisplayMedium methodsFor: 'coloring' stamp: 'jm 6/18/1999 19:01'!
reverse
	"Change all the bits in the receiver that are white to black, and the ones 
	that are black to white."

	self fill: self boundingBox rule: Form reverse fillColor: (Color quickHighLight: self depth)! !

!DisplayMedium methodsFor: 'coloring' stamp: 'jm 6/18/1999 19:00'!
reverse: aRectangle
	"Change all the bits in the receiver's area that intersects with aRectangle 
	that are white to black, and the ones that are black to white."

	self fill: aRectangle rule: Form reverse fillColor: (Color quickHighLight: self depth)! !

!DisplayMedium methodsFor: 'coloring' stamp: ''!
reverse: aRectangle fillColor: aMask	
	"Change all the bits in the receiver's area that intersects with aRectangle 
	according to the mask. Black does not necessarily turn to white, rather it 
	changes with respect to the rule and the bit in a corresponding mask 
	location. Bound to give a surprise."

	self fill: aRectangle rule: Form reverse fillColor: aMask! !

DisplayMedium subclass: #Form
	instanceVariableNames: 'bits width height depth offset'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Display Objects'!

!Form commentStamp: 'ls 1/4/2004 17:16' prior: 0!
A rectangular array of pixels, used for holding images.  All pictures, including character images are Forms.  The depth of a Form is how many bits are used to specify the color at each pixel.  The actual bits are held in a Bitmap, whose internal structure is different at each depth.  Class Color allows you to deal with colors without knowing how they are actually encoded inside a Bitmap.
	  The supported depths (in bits) are 1, 2, 4, 8, 16, and 32.  The number of actual colors at these depths are: 2, 4, 16, 256, 32768, and 16 million.
	Forms are indexed starting at 0 instead of 1; thus, the top-left pixel of a Form has coordinates 0@0.
	Forms are combined using BitBlt.  See the comment in class BitBlt.  Forms that repeat many times to fill a large destination are InfiniteForms.

	colorAt: x@y		Returns the abstract Color at this location
	displayAt: x@y		shows this form on the screen
	displayOn: aMedium at: x@y	shows this form in a Window, a Form, or other DisplayMedium
	fillColor: aColor		Set all the pixels to the color.
	edit		launch an editor to change the bits of this form.
	pixelValueAt: x@y	The encoded color.  The encoding depends on the depth.
!

Form subclass: #ColorForm
	instanceVariableNames: 'colors cachedDepth cachedColormap'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Display Objects'!

ColorForm class
	instanceVariableNames: 'grayScalePalette'!

!ColorForm commentStamp: '<historical>' prior: 0!
ColorForm is a normal Form plus a color map of up to 2^depth Colors. Typically, one reserves one entry in the color map for transparent. This allows 1, 3, 15, or 255 non-transparent colors in ColorForms of depths 1, 2, 4, and 8 bits per pixel. ColorForms don't support depths greater than 8 bits because that would require excessively large color maps with little real benefit, since 16-bit and 32-bit depths already support thousands and millions of colors.

ColorForms have several uses:
  1) Precise colors. You can have up to 256 true colors, instead being limited to the 8-bit color palette.
  2) Easy transparency. Just store (Color transparent) at the desired position in the color map.
  3) Cheap color remapping by changing the color map.

A color map is an Array of up to 2^depth Color objects. A Bitmap colorMap is automatically computed and cached for rapid display. Note that if you change the color map, you must resubmit it via the colors: method to flush this cache.

ColorForms can be a bit tricky. Note that:
  a) When you BitBlt from one ColorForm to another, you must remember to copy the color map of the source ColorForm to the destination ColorForm.
  b) A ColorForm's color map is an array of depth-independent Color objects. BitBlt requires a BitMap of actual pixel values, adjusted to the destination depth. These are different things!! ColorForms automatically maintain a cache of the BitBlt-style color map corresponding to the colors array for the last depth on which the ColorForm was displayed, so there should be little need for clients to work with BitBlt-style color maps.
  c) The default map for 8 bit depth has black in the first entry, not transparent.  Say (cform colors at: 1 put: Color transparent).
!

ColorForm class
	instanceVariableNames: 'grayScalePalette'!

!ColorForm class methodsFor: 'constants' stamp: 'lpc 5/19/2016 10:35'!
grayScalePalette
	grayScalePalette ifNil: [
		grayScalePalette := (0 to: 255) collect: [:brightness | Color gray: brightness asFloat / 255.0].
		grayScalePalette at: 1 put: Color transparent].
	^ grayScalePalette! !

!ColorForm class methodsFor: 'as yet unclassified' stamp: 'nk 4/17/2004 19:44'!
mappingWhiteToTransparentFrom: aFormOrCursor
	"Return a ColorForm copied from the given Form or Cursor with white mapped to transparent."

	| f map |
	aFormOrCursor depth <= 8 ifFalse: [
		^ self error: 'argument depth must be 8-bits per pixel or less'].
	(aFormOrCursor isColorForm) ifTrue: [
		f := aFormOrCursor deepCopy.
		map := aFormOrCursor colors.
	] ifFalse: [
		f := ColorForm extent: aFormOrCursor extent depth: aFormOrCursor depth.
		f copyBits: aFormOrCursor boundingBox
			from: aFormOrCursor
			at: 0@0
			clippingBox: aFormOrCursor boundingBox
			rule: Form over
			fillColor: nil.
		map := Color indexedColors copyFrom: 1 to: (1 bitShift: aFormOrCursor depth)].
	map := map collect: [:c |
		c = Color white ifTrue: [Color transparent] ifFalse: [c]].
	f colors: map.
	^ f
! !

!ColorForm class methodsFor: 'as yet unclassified' stamp: ''!
twoToneFromDisplay: aRectangle using: oldForm backgroundColor: bgColor
	"Return a 1-bit deep ColorForm copied from the given rectangle of the display. All colors except the background color will be mapped to black."

	| f |
	((oldForm ~~ nil) and: [oldForm extent = aRectangle extent]) ifTrue: [
		f := oldForm fromDisplay: aRectangle.
	] ifFalse: [
		f := ColorForm extent: aRectangle extent depth: 1.
		f twoToneFromDisplay: aRectangle backgroundColor: bgColor.
		f colors: (Array
			with: bgColor
			with: Color black)].
	^ f
! !

!ColorForm methodsFor: 'copying' stamp: 'RAA 8/14/2000 10:45'!
asCursorForm

	^ (self asFormOfDepth: 32) offset: offset; as: StaticForm! !

!ColorForm methodsFor: 'postscript generation' stamp: ''!
asFormWithSingleTransparentColors
	| transparentIndexes |
	transparentIndexes := self transparentColorIndexes.
	transparentIndexes size <= 1 ifTrue:[^self]
		ifFalse:[^self mapTransparencies:transparentIndexes].! !

!ColorForm methodsFor: 'color manipulation' stamp: 'di 11/11/1998 13:20'!
asGrayScale
	"Return a grayscale ColorForm computed by mapping each color into its grayscale equivalent"
	^ self copy colors:
		(colors collect:
			[:c | c isTransparent ifTrue: [c]
						ifFalse: [Color gray: c luminance]])! !

!ColorForm methodsFor: 'copying' stamp: 'ar 10/24/2005 22:25'!
blankCopyOf: aRectangle scaledBy: scale
	^Form extent: (aRectangle extent * scale) truncated depth: 32! !

!ColorForm methodsFor: 'private' stamp: 'jm 11/16/97 09:07'!
clearColormapCache

	cachedDepth := nil.
	cachedColormap := nil.
! !

!ColorForm methodsFor: 'pixel accessing' stamp: 'jm 11/14/97 17:25'!
colorAt: aPoint
	"Return the color of the pixel at aPoint."

	^ self colors at: (self pixelValueAt: aPoint) + 1
! !

!ColorForm methodsFor: 'pixel accessing' stamp: 'jm 11/14/97 17:25'!
colorAt: aPoint put: aColor
	"Store the given color into the pixel at aPoint. The given color must match one of the colors in the receiver's colormap."

	| i |
	i := self colors indexOf: aColor
		ifAbsent: [^ self error: 'trying to use a color that is not in my colormap'].
	self pixelValueAt: aPoint put: i - 1.
! !

!ColorForm methodsFor: 'color manipulation' stamp: 'ar 5/17/2001 15:44'!
colormapIfNeededForDepth: destDepth
	"Return a colormap for displaying the receiver at the given depth, or nil if no colormap is needed."

	| newMap |
	colors == nil ifTrue: [
		"use the standard colormap"
		^ Color colorMapIfNeededFrom: self depth to: destDepth].

	(destDepth = cachedDepth and:[cachedColormap isColormap not]) 
		ifTrue: [^ cachedColormap].
	newMap := Bitmap new: colors size.
	1 to: colors size do: [:i |
		newMap
			at: i
			put: ((colors at: i) pixelValueForDepth: destDepth)].

	cachedDepth := destDepth.
	^ cachedColormap := newMap.
! !

!ColorForm methodsFor: 'color mapping' stamp: 'ar 5/17/2001 15:44'!
colormapIfNeededFor: destForm
	| newMap color pv |
	(self hasNonStandardPalette or:[destForm hasNonStandardPalette]) ifFalse:[
		^self colormapIfNeededForDepth: destForm depth.
	].
	colors == nil ifTrue: [
		"use the standard colormap"
		^ super colormapIfNeededFor: destForm].

	(destForm depth = cachedDepth and:[cachedColormap isColormap]) 
		ifTrue: [^ cachedColormap].
	newMap := WordArray new: (1 bitShift: self depth).
	1 to: colors size do: [:i |
		color := colors at: i.
		pv := destForm pixelValueFor: color.
		(pv = 0 and:[color isTransparent not]) ifTrue:[pv := 1].
		newMap at: i put: pv].

	cachedDepth := destForm depth.
	^cachedColormap := ColorMap shifts: nil masks: nil colors: newMap.! !

!ColorForm methodsFor: 'accessing' stamp: 'jm 11/14/97 17:39'!
colors
	"Return my color palette."

	self ensureColorArrayExists.
	^ colors
! !

!ColorForm methodsFor: 'accessing' stamp: 'mir 7/21/1999 11:51'!
colorsFromArray: colorArray
	| colorList |
	colorList := colorArray collect: [:colorDef |
		Color fromArray: colorDef].
	self colors: colorList! !

!ColorForm methodsFor: 'color manipulation' stamp: 'jm 4/18/98 20:34'!
colorsUsed
	"Return a list of the colors actually used by this ColorForm."

	| myColor list |
	myColor := self colors.
	list := OrderedCollection new.
	self tallyPixelValues doWithIndex: [:count :i |
		count > 0 ifTrue: [list add: (myColor at: i)]].
	^ list asArray
! !

!ColorForm methodsFor: 'accessing' stamp: 'ar 5/17/2001 15:45'!
colors: colorList
	"Set my color palette to the given collection."

	| colorArray colorCount newColors |
	colorList ifNil: [
		colors := cachedDepth := cachedColormap := nil.
		^ self].

	colorArray := colorList asArray.
	colorCount := colorArray size.
	newColors := Array new: (1 bitShift: self depth).
	1 to: newColors size do: [:i |
		i <= colorCount
			ifTrue: [newColors at: i put: (colorArray at: i)]
			ifFalse: [newColors at: i put: Color transparent]].

	colors := newColors.
	cachedDepth := nil.
	cachedColormap := nil.
! !

!ColorForm methodsFor: 'copying' stamp: 'tpr 3/25/2013 13:57'!
copy: aRect
 	"Return a new ColorForm containing the portion of the receiver delineated by aRect."

	| newForm |
	newForm := self species extent: aRect extent depth: depth.
	((BitBlt
		destForm: newForm
		sourceForm: self
		fillColor: nil
		combinationRule: Form over
		destOrigin: 0@0
		sourceOrigin: aRect origin
		extent: aRect extent
		clipRect: newForm boundingBox)
		colorMap: nil) copyBits.
	colors ifNotNil: [newForm colors: colors copy].
	^ newForm
! !

!ColorForm methodsFor: 'postscript generation' stamp: ''!
decodeArray
	^self depth = 1 ifTrue:['[1 0]'] ifFalse:['[0 255]'].! !

!ColorForm methodsFor: 'private' stamp: 'jm 11/16/97 09:12'!
depth: bitsPerPixel

	bitsPerPixel > 8 ifTrue: [self error: 'ColorForms only support depths up to 8 bits'].
	super depth: bitsPerPixel.
! !

!ColorForm methodsFor: 'displaying' stamp: 'di 7/17/97 10:04'!
displayOnPort: port at: location

	port copyForm: self to: location rule: Form paint! !

!ColorForm methodsFor: 'displaying' stamp: 'ar 5/14/2001 23:32'!
displayOn: aDisplayMedium at: aDisplayPoint clippingBox: clipRectangle rule: rule fillColor: aForm

	aDisplayMedium copyBits: self boundingBox
		from: self
		at: aDisplayPoint + self offset
		clippingBox: clipRectangle
		rule: rule
		fillColor: aForm
		map: (self colormapIfNeededFor: aDisplayMedium).
! !

!ColorForm methodsFor: 'analyzing' stamp: 'mt 5/3/2016 13:30'!
dominantColor
	"Overridden to consider color table"
	
	| tally max maxi |
	tally := self tallyPixelValues.
	max := maxi := 0.
	tally withIndexDo: [:n :i | n > max ifTrue: [max := n. maxi := i]].
	^ self colors at: maxi! !

!ColorForm methodsFor: 'private' stamp: 'ar 5/17/2001 15:44'!
ensureColorArrayExists
	"Return my color palette."

	colors ifNil: [
		self depth > 8 ifTrue: [^ self error: 'ColorForms only support depths up to 8 bits'].
		self colors: (Color indexedColors copyFrom: 1 to: (1 bitShift: self depth))].
! !

!ColorForm methodsFor: 'color manipulation' stamp: 'jm 11/16/97 11:18'!
ensureTransparentColor
	"Ensure that the receiver (a) includes Color transparent in its color map and (b) that the entry for Color transparent is the first entry in its color map."

	| i |
self error: 'not yet implemented'.
	(colors includes: Color transparent)
		ifTrue: [
			(colors indexOf: Color transparent) = 1 ifTrue: [^ self].
			"shift the entry for color transparent"]
		ifFalse: [
			i := self unusedColormapEntry.
			i = 0 ifTrue: [self error: 'no color map entry is available'].
			colors at: i put: Color transparent.
			"shift the entry for color transparent"].
! !

!ColorForm methodsFor: 'scaling, rotation' stamp: 'ar 3/15/1999 14:28'!
flipBy: direction centerAt: aPoint
	| oldColors newForm |
	oldColors := colors.
	self colors: nil.
	newForm := super flipBy: direction centerAt: aPoint.
	self colors: oldColors.
	newForm colors: oldColors.
	^newForm ! !

!ColorForm methodsFor: 'postscript generation' stamp: ''!
getTransparencyUnificationLUT
	| lut transparentIndex |
	lut := Array new:colors size.
	transparentIndex := self indexOfColor:Color transparent.
	1 to: colors size do:
		[ :i | lut at:i put:(((colors at:i) = Color transparent) ifTrue:[transparentIndex] ifFalse:[i])].
 ! !

!ColorForm methodsFor: 'fileIn/Out' stamp: 'ar 3/3/2001 20:07'!
hibernate
	"Make myself take up less space. See comment in Form>hibernate."

	super hibernate.
	self clearColormapCache.
	colors ifNotNil:[colors := colors asColorArray].! !

!ColorForm methodsFor: 'color manipulation' stamp: 'di 8/28/1998 15:48'!
indexOfColor: aColor
	"Return the index of aColor in my color array"

	self ensureColorArrayExists.
	^ colors indexOf: aColor ifAbsent: [0]! !

!ColorForm methodsFor: 'testing' stamp: 'ar 5/27/2001 16:34'!
isColorForm
	^true! !

!ColorForm methodsFor: 'testing' stamp: 'lpc 6/8/2016 12:11'!
isGrayScale
	^ self colors = ColorForm grayScalePalette.! !

!ColorForm methodsFor: 'testing' stamp: 'ar 2/10/2004 17:18'!
isTranslucent
	"Answer whether this form may be translucent"
	^true! !

!ColorForm methodsFor: 'pixel accessing' stamp: 'tk 10/21/97 12:27'!
isTransparentAt: aPoint 
	"Return true if the receiver is transparent at the given point."

	^ (self colorAt: aPoint) isTransparent
! !

!ColorForm methodsFor: 'color manipulation' stamp: 'jm 10/19/1998 10:52'!
mapColor: oldColor to: newColor
	"Replace all occurances of the given color with the given new color in my color map."

	self ensureColorArrayExists.
	1 to: colors size do: [:i | 
		(colors at: i) = oldColor ifTrue: [colors at: i put: newColor]].
	self clearColormapCache.
! !

!ColorForm methodsFor: 'postscript generation' stamp: ''!
mapTransparencies:transparentIndexes
	^self deepCopy mapColors:transparentIndexes to:(transparentIndexes at:1).! !

!ColorForm methodsFor: 'displaying' stamp: 'ar 12/14/2001 18:14'!
maskingMap
	"Return a color map that maps all colors except transparent to words of all ones. Used to create a mask for a Form whose transparent pixel value is zero."
	| maskingMap |
	maskingMap := Bitmap new: (1 bitShift: depth) withAll: 16rFFFFFFFF.
	1 to: colors size do:[:i|
		(colors at: i) isTransparent ifTrue:[maskingMap at: i put: 0].
	].
	colors size+1 to: maskingMap size do:[:i| maskingMap at: i put: 0].
	^maskingMap! !

!ColorForm methodsFor: 'copying' stamp: 'nice 12/13/2013 21:24'!
postCopy
	super postCopy.
	colors := colors copy.
! !

!ColorForm methodsFor: 'fileIn/Out' stamp: 'mu 8/17/2003 00:46'!
readAttributesFrom: aBinaryStream
	super readAttributesFrom: aBinaryStream.
	colors := ColorArray new: (2 raisedTo: depth).
	1 to: colors size do: [:idx | 
		colors basicAt: idx put: (aBinaryStream nextLittleEndianNumber: 4).
	]. 
	! !

!ColorForm methodsFor: 'color manipulation' stamp: 'di 8/28/1998 15:49'!
replaceColorAtIndex: index with: newColor
	"Replace a color map entry with newColor."

	self ensureColorArrayExists.
	colors at: index put: newColor.
	cachedColormap == nil ifFalse:
		[cachedColormap at: index put: (newColor pixelValueForDepth: cachedDepth)]! !

!ColorForm methodsFor: 'color manipulation' stamp: 'tk 3/2/98 15:42'!
replaceColorAt: aPoint with: newColor
	"Replace a color map entry with newColor.  The entry replaced is the one used by aPoint.  If there are are two entries in the colorMap for the oldColor, just replace ONE!!!!  There are often two whites or two blacks, and this is what you want, when replacing one."

	| oldIndex |
	self ensureColorArrayExists.
	oldIndex := self pixelValueAt: aPoint.
	colors at: oldIndex+1 put: newColor.
	self clearColormapCache.
! !

!ColorForm methodsFor: 'color manipulation' stamp: 'jm 11/16/97 09:08'!
replaceColor: oldColor with: newColor
	"Replace all occurances of the given color with the given new color in my color map."

	self ensureColorArrayExists.
	1 to: colors size do: [:i | 
		(colors at: i) = oldColor ifTrue: [colors at: i put: newColor]].
	self clearColormapCache.
! !

!ColorForm methodsFor: 'scaling, rotation' stamp: 'RAA 8/5/2000 18:12'!
scaledToSize: newExtent

	"super method did not seem to work so well on ColorForms"

	^(self asFormOfDepth: 16) scaledToSize: newExtent! !

!ColorForm methodsFor: 'postscript generation' stamp: ''!
setColorspaceOn:aStream
	self depth = 1 ifTrue:[
		aStream print:'/DeviceRGB setcolorspace 0 setgray'; cr.
	]
	ifFalse:[
	aStream print:'[ /Indexed /DeviceRGB ';
	write:self colors size-1;
	print:' <'.
	(self colormapIfNeededForDepth: 32 ) storeBits:20 to:0 on:aStream.
	aStream print:'> ] setcolorspace'; cr.].
! !

!ColorForm methodsFor: 'private' stamp: 'jm 4/5/1999 10:11'!
setColors: colorArray cachedColormap: aBitmap depth: anInteger
	"Semi-private. Set the color array, cached colormap, and cached colormap depth to avoid having to recompute the colormap when switching color palettes in animations."

	colors := colorArray.
	cachedDepth := anInteger.
	cachedColormap := aBitmap.
! !

!ColorForm methodsFor: 'private' stamp: 'jm 11/16/97 08:37'!
setExtent: extent depth: bitsPerPixel
	"Create a virtual bit map with the given extent and bitsPerPixel."

	bitsPerPixel > 8 ifTrue: [self error: 'ColorForms only support depths up to 8 bits'].
	super setExtent: extent depth: bitsPerPixel.
! !

!ColorForm methodsFor: 'fileIn/Out' stamp: 'bf 5/25/2000 16:31'!
storeOn: aStream
	aStream nextPut: $(.
	super storeOn: aStream.
	aStream
		cr; tab;
		nextPutAll: 'colorsFromArray: #('.
	self colors do: [:color |
		color storeArrayOn: aStream].
	aStream nextPutAll: ' ))'.! !

!ColorForm methodsFor: 'color manipulation' stamp: 'tk 3/2/98 11:26'!
transparentAllPixelsLike: aPoint
	"Make all occurances of the given pixel value transparent.  Very useful when two entries in the colorMap have the same value.  This only changes ONE."

	self replaceColorAt: aPoint with: Color transparent.
! !

!ColorForm methodsFor: 'postscript generation' stamp: ''!
transparentColorIndexes
	^(1 to: colors size) select: [ :index | (colors at:index) isTransparent ].
! !

!ColorForm methodsFor: 'color manipulation' stamp: 'tk 3/2/98 11:27'!
transparentColor: aColor
	"Make all occurances of the given color transparent.  Note: for colors like black and white, which have two entries in the colorMap, this changes BOTH of them.  Not always what you want."

	self replaceColor: aColor with: Color transparent.
! !

!ColorForm methodsFor: 'color manipulation' stamp: 'tpr 3/15/2013 12:20'!
twoToneFromDisplay: aRectangle backgroundColor: bgColor
	"Copy one-bit deep ColorForm from the Display using a color map that maps all colors except the background color to black. Used for caching the contents of inactive MVC windows."

	| map |
	(width = aRectangle width and: [height = aRectangle height])
		ifFalse: [self setExtent: aRectangle extent depth: depth].

	"make a color map mapping the background color
	 to zero and all other colors to one"
	map := Bitmap new: (1 bitShift: (Display depth min: 9)).
	1 to: map size do: [:i | map at: i put: 16rFFFFFFFF].
	map at: (bgColor indexInMap: map) put: 0.

	(BitBlt toForm: self)
		destOrigin: 0@0;
		sourceForm: Display;
		sourceRect: aRectangle;
		combinationRule: Form over;
		colorMap: map;
		copyBits.
! !

!ColorForm methodsFor: 'fileIn/Out' stamp: 'ar 3/3/2001 20:07'!
unhibernate
	colors ifNotNil:[colors := colors asArray].
	^super unhibernate.
! !

!ColorForm methodsFor: 'private' stamp: 'jm 2/24/98 18:53'!
unusedColormapEntry
	"Return the index of an unused color map entry, or zero if there isn't one."

	| tallies |
	tallies := self tallyPixelValues.
	1 to: tallies size do: [:i |
		(tallies at: i) = 0 ifTrue: [^ i]].
	^ 0
! !

!ColorForm methodsFor: 'fileIn/Out' stamp: 'mu 8/17/2003 00:42'!
writeAttributesOn: file
	| colorArray |
	super writeAttributesOn: file.
	colorArray := self colors asColorArray.
	1 to: (2 raisedTo: depth) do: [:idx |
		file nextLittleEndianNumber: 4 put: (colorArray basicAt: idx).
	] ! !

Form subclass: #Cursor
	instanceVariableNames: ''
	classVariableNames: 'BlankCursor BottomLeftCursor BottomRightCursor CornerCursor CrossHairCursor CurrentCursor DownCursor MarkerCursor MenuCursor MoveCursor NormalCursor OriginCursor ReadCursor ResizeLeftCursor ResizeTopCursor ResizeTopLeftCursor ResizeTopRightCursor RightArrowCursor SquareCursor TargetCursor TopLeftCursor TopRightCursor UpCursor UseBiggerCursors WaitCursor WebLinkCursor WriteCursor XeqCursor'
	poolDictionaries: ''
	category: 'Graphics-Display Objects'!

!Cursor commentStamp: '<historical>' prior: 0!
I am a Form that is a possible appearance for a mouse cursor.  My size is always 16x16, ever since the original implementation on the Alto.

There are many examples available in the "current cursor" category of class methods.  For example, "Cursor normal" and "Cursor wait".  For example:

	Cursor wait show

!

Cursor subclass: #CursorWithAlpha
	instanceVariableNames: 'fallback'
	classVariableNames: 'Constants'
	poolDictionaries: ''
	category: 'Graphics-Display Objects'!

!CursorWithAlpha commentStamp: '<historical>' prior: 0!
A 32-bit ARGB Cursor of arbitrary extent (some platforms may limit the size). Compositing assumes alpha is pre-multiplied.!

!CursorWithAlpha class methodsFor: 'constants' stamp: 'ar 3/9/2010 22:39'!
biggerNormal
	"self biggerNormal showWhile:[Sensor waitButton]"
	"(Base64MimeConverter mimeEncode: ((FileStream readOnlyFileNamed: 'EtoysCursor.png') binary)) upToEnd"

	^self constants at: #biggerNormal ifAbsentPut: [
		| form cursor |
		form := (PNGReadWriter on: (Base64MimeConverter mimeDecodeToBytes:
			'iVBORw0KGgoAAAANSUhEUgAAABsAAAArCAYAAACJrvP4AAAACXBIWXMAAAsTAAALEwEAmpwY
			AAAEF0lEQVRYCb2XS0hcVxjHj2/G8ZWMQQbSGO2iRhERwRALBmJNoOOqwUXtYtxOTQJxI8SN
			CyXJqggVEghusrAuBB8IddUWF64CvnCj+AJrsYKio6JJOPn/j+dc5s6MztyZMR/857v3PL7f
			/c4595w7QmiTUvrN9ZV7wGhfB3jOunpgOoYtPQQm19fXn6DsulY2PJUSi4ARvLm5+SuiE5hS
			mAsBXSYzv99vLuXExMRL1H2jlRKoDYbAMhS4uLj4PJUwN4K5TTqEhQPHxsZeayCzTCrDqLC0
			tLQryTAqjNmFA1OR4YWwaMBk5/BSWDRgMhnGhEUDJpphXDACqdDXIpEMHcHCF43TDB3Bks0w
			IVj4kMabYcKwcGA8c+gIlp2drRaKGc5wYKwMHcFycnIiYOHACzLkhi9SAgsHRsnQOSzaMBJk
			FPoejo6OvkJ5iZY67R1lZoJe5kOBKysrzxzBCgoKrCcnpKysTO7v75sjMKafmZl5gX6uNPww
			M4EeQXrsEAJDJc7Ozngr8vPzRVVVldjZ2RGrq6uqrLi4WPT394u2tjZxeHj4P8C7qiLkJzMz
			8zNvc3NzT+jR/yl9xDBmZWWpTAoLC2V9fb3c29uTXV1dtuwaGxtVRgcHBzuI0QY91vLBUw+0
			voOnXPyyijBEUWWVlZViampKFBUVCcyDKC8vt9pitYnp6WlmfqO7u/uOVRHjIiKzjIwM2dDQ
			oDIKnZCWlhZbdoFAQFUvLCz8Bcb3WrfgqWItFR/XKrEIWG1trQWam5v7Z3Bw8C2jjoyMyNLS
			UgvIYeYQ05A5h5HA+GE1NTVWgPn5+b/RubWiosJ/enoaZNDq6moLhjrZ19fHYjk7O/sO9/eg
			G1oZ8JTNbJmZJ9Wgn9GyleJQMWhPT48NhnllsTw+Pv4X7WLCuI1YX8TsuLy8/CfKmrXuwt9t
			b2//iXX4LJder9cCut1uOT4+zio5PDz8G9pWaqm4uLaZDaZBXLY2GO4bdnd3PzAowDZYc3Mz
			i+X29vY82l0K4ypR/2JOTk7e49qsIuMLUEbdXFpaes6gk5OT0uPxWECeBGtra6ySvb29v6Bt
			ve7DfjZTsKOjo99RyvkzEOMtGOpuBoPBbQblQsK9Ejfnzs5OFsuNjY0JlF8IQ11clodWeVgo
			bxh0YGDABmOmNGxzh2j3EPJqRV2VqLvUFKyjo+NHBuWqxb4nS0pKVFZmGFG+gihJw8wTerHx
			/kEgXng6y7a2thYxnAHAHkHfavEcoxyZBcOh+AOHixS+7HwnfT4f/6nynSQoaZh5MjWcTU1N
			94aGhtrr6up8qLgPcVFQd7SuwVPmIdN5njk1wmi31a8QHu3VuYVrLhDaf+dOHGgvE4Gp3RsB
			cnUQMx+f9P1H7c9PXyHUIcoy01HXX637AibwgHAnFRPGAAAAAElFTkSuQmCC' 
				readStream) readStream) nextImage.
	cursor := CursorWithAlpha extent: form extent depth: 32.
	form displayOn: cursor.
	cursor offset: -2 @ -1.
	cursor preMultiplyAlpha.
	cursor]! !

!CursorWithAlpha class methodsFor: 'constants' stamp: 'bf 3/30/2007 18:47'!
constants
	^Constants ifNil: [Constants := Dictionary new]! !

!CursorWithAlpha class methodsFor: 'instance creation' stamp: 'bf 3/22/2007 11:08'!
fromDisplay: aRectangle 
	"Answer an ARGB cursor with bitmap initialized from the area of the 
	display screen defined by aRectangle."

	^ (self extent: aRectangle extent depth: 32)
		offset: aRectangle extent // -2;
		fromDisplay: aRectangle;
		fixAlpha! !

!CursorWithAlpha class methodsFor: 'constants' stamp: 'bf 8/17/2009 12:56'!
resetConstants
	Constants := nil.
! !

!CursorWithAlpha methodsFor: 'converting' stamp: 'bf 4/10/2007 18:16'!
asCursorForm

	^ self as: StaticForm! !

!CursorWithAlpha methodsFor: 'primitives' stamp: 'tfel 7/28/2016 17:05'!
beCursor
	<primitive: 101>
	self fallback beCursor! !

!CursorWithAlpha methodsFor: 'accessing' stamp: 'bf 3/30/2007 18:57'!
fallback
	^fallback ifNil: [NormalCursor]! !

!CursorWithAlpha methodsFor: 'accessing' stamp: 'bf 3/30/2007 18:58'!
fallback: aCursor
	fallback := aCursor! !

Cursor subclass: #CursorWithMask
	instanceVariableNames: 'maskForm'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Display Objects'!

!CursorWithMask commentStamp: '<historical>' prior: 0!
A Cursor which additionally has a 16x16 transparency bitmap called a "mask".  See the comment of beCursorWithMask: for details on how the mask is treated.!

!CursorWithMask class methodsFor: 'as yet unclassified' stamp: 'di 2/18/1999 08:56'!
derivedFrom: aForm      "Cursor initNormalWithMask.  Cursor normal show"
	"aForm is presumably a cursor"
	| cursor mask ext |
	ext := aForm extent.
	cursor := self extent: ext.
	cursor copy: (1@1 extent: ext) from: 0@0 in: aForm rule: Form over.
	mask := Form extent: ext.
	(1@1) eightNeighbors do:
		[:p | mask copy: (p extent: ext) from: 0@0 in: aForm rule: Form under].
	cursor setMaskForm: mask.
	cursor offset: ((aForm offset - (1@1)) max: ext negated).
	^ cursor! !

!CursorWithMask methodsFor: 'converting' stamp: 'RAA 8/14/2000 10:14'!
asCursorForm
	| form |
	form := StaticForm extent: self extent depth: 8.
	form fillShape: maskForm fillColor: Color white.
	form fillShape: self fillColor: Color black at: offset negated.
	^ form offset: offset! !

!CursorWithMask methodsFor: 'primitives' stamp: 'di 10/6/1998 15:16'!
beCursor
	maskForm unhibernate.
	^ self beCursorWithMask: maskForm! !

!CursorWithMask methodsFor: 'mask' stamp: 'bf 2/2/1999 19:34'!
hasMask
	^true! !

!CursorWithMask methodsFor: 'mask' stamp: 'di 10/8/1998 16:46'!
maskForm
	^ maskForm! !

!CursorWithMask methodsFor: 'copying' stamp: 'nice 12/18/2013 15:40'!
postCopy
	super postCopy.
	maskForm := maskForm copy! !

!CursorWithMask methodsFor: 'mask' stamp: 'di 10/8/1998 16:46'!
setMaskForm: aForm
	maskForm := aForm! !

!CursorWithMask methodsFor: 'mask' stamp: 'bf 2/2/1999 19:30'!
storeOn: aStream base: anInteger

	aStream nextPut: $(.
	super storeOn: aStream base: anInteger.
	aStream nextPutAll: ' setMaskForm: '.
	maskForm storeOn: aStream base: anInteger.
	aStream nextPut: $)! !

!CursorWithMask methodsFor: 'mask' stamp: 'bf 2/2/1999 19:31'!
withMask
	^self! !

!Cursor class methodsFor: 'constants' stamp: ''!
blank
	"Answer the instance of me that is all white."

	^BlankCursor! !

!Cursor class methodsFor: 'constants' stamp: 'JMM 10/21/2003 19:13'!
bottomLeft
	"Cursor bottomLeft showWhile: [Sensor waitButton]"
	^BottomLeftCursor
! !

!Cursor class methodsFor: 'constants' stamp: 'JMM 10/21/2003 19:13'!
bottomRight
	"Cursor bottomRight showWhile: [Sensor waitButton]"
	^BottomRightCursor
! !

!Cursor class methodsFor: 'constants' stamp: ''!
corner
	"Answer the instance of me that is the shape of the bottom right corner 
	of a rectangle."

	^CornerCursor! !

!Cursor class methodsFor: 'constants' stamp: ''!
crossHair
	"Answer the instance of me that is the shape of a cross."

	^CrossHairCursor! !

!Cursor class methodsFor: 'current cursor' stamp: ''!
currentCursor
	"Answer the instance of Cursor that is the one currently displayed."

	^CurrentCursor! !

!Cursor class methodsFor: 'current cursor' stamp: 'tfel 7/28/2016 17:00'!
currentCursor: aCursor 
	"Make the instance of cursor, aCursor, be the current cursor. Display it. 
	Create an error if the argument is not a Cursor."

	(aCursor isKindOf: self)
		ifTrue: [CurrentCursor := aCursor.
				self useBiggerCursors
					ifTrue: [[^ aCursor asBigCursor beCursor]
						on: Error do: ["fall through"]].
				aCursor beCursor]
		ifFalse: [self error: 'The new cursor must be an instance of class Cursor']! !

!Cursor class methodsFor: 'constants' stamp: ''!
down
	"Answer the instance of me that is the shape of an arrow facing 
	downward."

	^DownCursor! !

!Cursor class methodsFor: 'constants' stamp: ''!
execute
	"Answer the instance of me that is the shape of an arrow slanted left 
	with a star next to it."

	^XeqCursor! !

!Cursor class methodsFor: 'instance creation' stamp: ''!
extent: extentPoint fromArray: anArray offset: offsetPoint 
	"Answer a new instance of me with width and height specified by
	extentPoint, offset by offsetPoint, and bits from anArray.
	NOTE: This has been kluged to take an array of 16-bit constants,
	and shift them over so they are left-justified in a 32-bit bitmap"

	extentPoint = (16 @ 16)
		ifTrue: 
			[^ super
				extent: extentPoint
				fromArray: (anArray collect: [:bits | bits bitShift: 16])
				offset: offsetPoint]
		ifFalse: [self error: 'cursors must be 16@16']! !

!Cursor class methodsFor: 'class initialization' stamp: 'nice 12/29/2010 16:57'!
initBottomLeft

	BottomLeftCursor := 
		(Cursor extent: 16 @ 16
			fromArray: #(
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1111111111111111
		2r1111111111111111)
			offset: 0 @ -16).
! !

!Cursor class methodsFor: 'class initialization' stamp: 'nice 12/29/2010 16:57'!
initBottomRight

	BottomRightCursor := 
		(Cursor extent: 16 @ 16
			fromArray: #(
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r1111111111111111
		2r1111111111111111)
			offset: -16 @ -16).
! !

!Cursor class methodsFor: 'class initialization' stamp: 'nice 12/29/2010 16:57'!
initCorner

	CornerCursor := 
		(Cursor 
			extent: 16 @ 16
			fromArray: #(
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r1111111111111111
		2r1111111111111111)
			offset: -16 @ -16).
! !

!Cursor class methodsFor: 'class initialization' stamp: 'nice 12/29/2010 16:57'!
initCrossHair

	CrossHairCursor :=   
		(Cursor
			extent: 16 @ 16
			fromArray: #(
		2r0000000000000000
		2r0000000100000000
		2r0000000100000000
		2r0000000100000000
		2r0000000100000000
		2r0000000100000000
		2r0000000100000000
		2r0111111111111100
		2r0000000100000000
		2r0000000100000000
		2r0000000100000000
		2r0000000100000000
		2r0000000100000000
		2r0000000100000000
		2r0000000000000000
		2r0)
			offset: -7 @ -7).
	
	! !

!Cursor class methodsFor: 'class initialization' stamp: 'nice 12/29/2010 16:57'!
initDown

	DownCursor  :=
		     (Cursor
	extent: 16 @ 16
	fromArray: #(
		2r11000000000000
		2r11000000000000
		2r11000000000000
		2r11000000000000
		2r11000000000000
		2r11000000000000
		2r11000000000000
		2r1111110000000000
		2r111100000000000
		2r11000000000000
		2r0
		2r0
		2r0
		2r0
		2r0
		2r0)
	offset: 0 @ 0).
! !

!Cursor class methodsFor: 'class initialization' stamp: 'JMM 10/21/2003 19:04'!
initialize
	"Create all the standard cursors..."
		self initOrigin.
		self initRightArrow.
		self initMenu.
		self initCorner.
		self initRead.
		self initWrite.
		self initWait.
		BlankCursor := Cursor new.
		self initXeq.
		self initSquare.
		self initNormalWithMask.
		self initCrossHair.
		self initMarker.
		self initUp.
		self initDown.
		self initMove.
		self initBottomLeft.
		self initBottomRight.
		self initResizeLeft.
		self initResizeTop.
		self initResizeTopLeft.
		self initResizeTopRight.
		self initTopLeft.
		self initTopRight.
		self makeCursorsWithMask.

		"Cursor initialize"
! !

!Cursor class methodsFor: 'class initialization' stamp: 'nice 12/29/2010 16:57'!
initMarker

	MarkerCursor := 
		Cursor
			extent: 16 @ 16
			fromArray: #(
		2r0111000000000000
		2r1111100000000000
		2r1111100000000000
		2r0111000000000000
		2r0
		2r0
		2r0
		2r0
		2r0
		2r0
		2r0
		2r0
		2r0
		2r0
		2r0
		2r0)
			offset: 0 @ 0.
! !

!Cursor class methodsFor: 'class initialization' stamp: 'nice 12/29/2010 16:57'!
initMenu 

	MenuCursor  :=
		        (Cursor
	extent: 16 @ 16
	fromArray: #(
		2r1111111111100000
		2r1000000000100000
		2r1010011000100000
		2r1000000000100000
		2r1101001101100000
		2r1111111111100000
		2r1000000000100000
		2r1011001010100000
		2r1000000000100000
		2r1010110010100000
		2r1000000000100000
		2r1010010100100000
		2r1000000000100000
		2r1111111111100000
		0)
	offset: 0 @ 0).
! !

!Cursor class methodsFor: 'class initialization' stamp: 'nice 12/29/2010 16:58'!
initMove

	MoveCursor := 
		Cursor 
			extent: 16 @ 16
			fromArray: #(
		2r1111111111111100
		2r1111111111111100
		2r1100001100001100
		2r1100001100001100
		2r1100001100001100
		2r1100001100001100
		2r1111111111111100
		2r1111111111111100
		2r1100001100001100
		2r1100001100001100
		2r1100001100001100
		2r1100001100001100
		2r1111111111111100
		2r1111111111111100
          0)
			offset: 0 @ 0.
! !

!Cursor class methodsFor: 'class initialization' stamp: 'nice 12/29/2010 16:58'!
initNormal

	NormalCursor :=   
		(Cursor
			extent: 16 @ 16
			fromArray: #(
		2r1000000000000000
		2r1100000000000000
		2r1110000000000000
		2r1111000000000000
		2r1111100000000000
		2r1111110000000000
		2r1111111000000000
		2r1111100000000000
		2r1111100000000000
		2r1001100000000000
		2r0000110000000000
		2r0000110000000000
		2r0000011000000000
		2r0000011000000000
		2r0000001100000000
		2r0000001100000000)
	offset: 0 @ 0).

	
	! !

!Cursor class methodsFor: 'class initialization' stamp: 'nice 12/29/2010 16:58'!
initNormalWithMask    "Cursor initNormalWithMask.  Cursor normal show"
	"Next two lines work simply for any cursor..."
	self initNormal.
	NormalCursor := CursorWithMask derivedFrom: NormalCursor.

	"But for a good looking cursor, you have to tweak things..."
	NormalCursor := (CursorWithMask extent: 16 @ 16 depth: 1
			fromArray: #( 0 1073741824 1610612736 1879048192
				2013265920 2080374784 2113929216 2130706432
				2080374784 2080374784 1275068416 100663296
				100663296 50331648 50331648 0)
			offset: -1 @ -1)
		setMaskForm: (Form extent: 16 @ 16 depth: 1
			fromArray: #( 3221225472 3758096384 4026531840 4160749568
				4227858432 4261412864 4278190080 4286578688
				4278190080 4261412864 4261412864 3472883712
				251658240 125829120 125829120 50331648)
			offset: 0 @ 0).! !

!Cursor class methodsFor: 'class initialization' stamp: 'nice 12/29/2010 16:58'!
initOrigin

	OriginCursor :=   
		(Cursor
			extent: 16 @ 16
			fromArray: #(
		2r1111111111111111
		2r1111111111111111
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000)
			offset: 0 @ 0).
! !

!Cursor class methodsFor: 'class initialization' stamp: 'nice 12/29/2010 16:59'!
initRead

	ReadCursor :=  
		(Cursor
			extent: 16 @ 16
			fromArray: #(
		2r0000000000000000
		2r0000000000000000
		2r0001000000001000
		2r0010100000010100
		2r0100000000100000
		2r1111101111100000
		2r1000010000100000
		2r1000010000100000
		2r1011010110100000
		2r0111101111000000
		2r0
		2r0
		2r0
		2r0
		2r0
		2r0)
	offset: 0 @ 0).
! !

!Cursor class methodsFor: 'class initialization' stamp: 'nice 12/29/2010 16:59'!
initResizeLeft

       ResizeLeftCursor :=
               (Cursor extent: 16 @ 16 fromArray: #(
               2r0000000000000000
               2r0000000000000000
               2r0000000000000000
               2r0000000000000000
               2r0000100000010000
               2r0001100000011000
               2r0011100000011100
               2r0111111111111110
               2r0011100000011100
               2r0001100000011000
               2r0000100000010000
               2r0000000000000000
               2r0000000000000000
               2r0000000000000000
               2r0000000000000000
               2r0000000000000000 )
       offset: -7 @ -7 ) withMask! !

!Cursor class methodsFor: 'class initialization' stamp: 'nice 12/29/2010 16:59'!
initResizeTop
    "Cursor initResizeTop"
       ResizeTopCursor :=
               (Cursor extent: 16 @ 16 fromArray: #(
               2r000000100000000
               2r000001110000000
               2r000011111000000
               2r000111111100000
               2r000000100000000
               2r000000100000000
               2r000000100000000
               2r000000100000000
               2r000000100000000
               2r000000100000000
               2r000111111100000
               2r000011111000000
               2r000001110000000
               2r000000100000000
               2r000000000000000)
       offset: -7 @ -7) withMask! !

!Cursor class methodsFor: 'class initialization' stamp: 'nice 12/29/2010 16:59'!
initResizeTopLeft

       ResizeTopLeftCursor :=
               (Cursor extent: 16 @ 16 fromArray: #(
               2r0000000000000000
               2r0111110000000000
               2r0111100000000000
               2r0111000000000000
               2r0110100000000000
               2r0100010000000000
               2r0000001000000000
               2r0000000100000000
               2r0000000010000000
               2r0000000001000100
               2r0000000000101100
               2r0000000000011100
               2r0000000000111100
               2r0000000001111100
               2r0000000000000000
               2r0000000000000000)
       offset: -7 @ -7) withMask! !

!Cursor class methodsFor: 'class initialization' stamp: 'nice 12/29/2010 16:59'!
initResizeTopRight

       ResizeTopRightCursor :=
               (Cursor extent: 16 @ 16 fromArray: #(
               2r0000000000000000
               2r0000000001111100
               2r0000000000111100
               2r0000000000011100
               2r0000000000101100
               2r0000000001000100
               2r0000000010000000
               2r0000000100000000
               2r0000001000000000
               2r0100010000000000
               2r0110100000000000
               2r0111000000000000
               2r0111100000000000
               2r0111110000000000
               2r0000000000000000
               2r0000000000000000)
       offset: -7 @ -7) withMask! !

!Cursor class methodsFor: 'class initialization' stamp: 'nice 12/29/2010 16:59'!
initRightArrow 

	RightArrowCursor  :=
		      (Cursor
	extent: 16 @ 16
	fromArray: #(
		2r100000000000
		2r111000000000
		2r1111111110000000
		2r111000000000
		2r100000000000
		2r0
		2r0
		2r0
		2r0
		2r0
		2r0
		2r0
		2r0
		2r0
		2r0
		2r0)
	offset: 0 @ 0).
	
	"Cursor initRightArrow"! !

!Cursor class methodsFor: 'class initialization' stamp: 'nice 12/29/2010 16:59'!
initSquare

	SquareCursor := 
		(Cursor
			extent: 16 @ 16
			fromArray: #(
		2r0
		2r0
		2r0
		2r0
		2r0
		2r0000001111000000
		2r0000001111000000
		2r0000001111000000
		2r0000001111000000
		2r0
		2r0
		2r0
		2r0
		2r0
		2r0
		2r0)
	offset: -8 @ -8).

	! !

!Cursor class methodsFor: 'class initialization' stamp: 'ar 3/1/2006 22:42'!
initTarget
	^TargetCursor := Cursor
				extent: 16 @ 16
				fromArray:  #(1984 6448 8456 16644 17284 33026 35106 65278 35106 33026 17284 16644 8456 6448 1984 0)
				offset: -7 @ -7! !

!Cursor class methodsFor: 'class initialization' stamp: 'nice 12/29/2010 16:59'!
initTopLeft
	TopLeftCursor := 
		(Cursor extent: 16 @ 16
			fromArray: #(
		2r1111111111111111
		2r1111111111111111
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000
		2r1100000000000000)
			offset: 0 @ 0).
! !

!Cursor class methodsFor: 'class initialization' stamp: 'nice 12/29/2010 17:00'!
initTopRight
	TopRightCursor := 
		(Cursor extent: 16 @ 16
			fromArray: #(
		2r1111111111111111
		2r1111111111111111
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011
		2r0000000000000011)
			offset: -16 @ 0).
! !

!Cursor class methodsFor: 'class initialization' stamp: 'nice 12/29/2010 17:00'!
initUp

	UpCursor := 
		    (Cursor
	extent: 16 @ 16
	fromArray: #(
		2r11000000000000
		2r111100000000000
		2r1111110000000000
		2r11000000000000
		2r11000000000000
		2r11000000000000
		2r11000000000000
		2r11000000000000
		2r11000000000000
		2r11000000000000
		2r0
		2r0
		2r0
		2r0
		2r0
		2r0)
	offset: 0 @ 0).
! !

!Cursor class methodsFor: 'class initialization' stamp: 'nice 12/29/2010 17:00'!
initWait

	WaitCursor := 
		  (Cursor
			extent: 16 @ 16
			fromArray: #(
		2r1111111111111100
		2r1000000000000100
		2r0100000000001000
		2r0010000000010000
		2r0001110011100000
		2r0000111111000000
		2r0000011110000000
		2r0000011110000000
		2r0000100101000000
		2r0001000100100000
		2r0010000110010000
		2r0100001111001000
		2r1000111111110100
		2r1111111111111100
		0)
			offset: 0 @ 0).
! !

!Cursor class methodsFor: 'class initialization' stamp: 'nice 12/29/2010 17:00'!
initWrite

	WriteCursor := (Cursor
	extent: 16 @ 16
	fromArray: #(
		2r0000000000011000
		2r0000000000111100
		2r0000000001001000
		2r0000000010010000
		2r0000000100100000
		2r0000001001000100
		2r0000010010000100
		2r0000100100001100
		2r0001001000010000
		2r0010010000010000
		2r0111100000001000
		2r0101000011111000
		2r1110000110000000
		2r0111111100000000
		2r0
		2r0)
	offset: 0 @ 0).
! !

!Cursor class methodsFor: 'class initialization' stamp: 'nice 12/29/2010 17:00'!
initXeq

	XeqCursor := 
		(Cursor
			extent: 16 @ 16
			fromArray: #(
		2r1000000000010000
		2r1100000000010000
		2r1110000000111000
		2r1111000111111111
		2r1111100011000110
		2r1111110001000100
		2r1111111001111100
		2r1111000001101100
		2r1101100011000110
		2r1001100010000010
		2r0000110000000000
		2r0000110000000000
		2r0000011000000000
		2r0000011000000000
		2r0000001100000000
		2r0000001100000000)
	offset: 0 @ 0).
! !

!Cursor class methodsFor: 'class initialization' stamp: 'ar 7/18/2009 20:42'!
makeCursorsWithMask
	"Cursor initialize;makeCursorsWithMask"

	self classPool associationsDo: [:var |
		((var value isKindOf: Cursor) and:[var value hasMask not])
			ifTrue: [var value: var value withMask]]! !

!Cursor class methodsFor: 'constants' stamp: ''!
marker
	"Answer the instance of me that is the shape of a small ball."

	^MarkerCursor! !

!Cursor class methodsFor: 'constants' stamp: ''!
menu 
	"Answer the instance of me that is the shape of a menu."

	^MenuCursor! !

!Cursor class methodsFor: 'constants' stamp: ''!
move
	"Answer the instance of me that is the shape of a cross inside a square."

	^MoveCursor! !

!Cursor class methodsFor: 'instance creation' stamp: 'di 10/6/1998 13:53'!
new

	^ self extent: 16 @ 16
		fromArray: (Array new: 16 withAll: 0)
		offset: 0 @ 0

	"Cursor new bitEdit show"! !

!Cursor class methodsFor: 'constants' stamp: ''!
normal
	"Answer the instance of me that is the shape of an arrow slanted left."

	^NormalCursor! !

!Cursor class methodsFor: 'constants' stamp: ''!
origin
	"Answer the instance of me that is the shape of the top left corner of a 
	rectangle."

	^OriginCursor! !

!Cursor class methodsFor: 'constants' stamp: ''!
read
	"Answer the instance of me that is the shape of eyeglasses."

	^ReadCursor! !

!Cursor class methodsFor: 'constants' stamp: 'ar 8/16/2001 14:48'!
resizeBottom
	"Cursor resizeBottom showWhile: [Sensor waitButton]"
	^self resizeTop! !

!Cursor class methodsFor: 'constants' stamp: 'ar 8/16/2001 14:46'!
resizeBottomLeft
	"Cursor resizeBottomLeft showWhile: [Sensor waitButton]"
	^self resizeTopRight! !

!Cursor class methodsFor: 'constants' stamp: 'ar 8/16/2001 14:45'!
resizeBottomRight
	"Cursor resizeBottomRight showWhile: [Sensor waitButton]"
	^self resizeTopLeft! !

!Cursor class methodsFor: 'instance creation' stamp: 'ar 8/16/2001 15:52'!
resizeForEdge: aSymbol
	"Cursor resizeForEdge: #top"
	"Cursor resizeForEdge: #bottomLeft"
	^self perform: ('resize', aSymbol first asString asUppercase, (aSymbol copyFrom: 2 to: aSymbol size)) asSymbol.! !

!Cursor class methodsFor: 'constants' stamp: 'JMM 10/21/2003 18:58'!
resizeLeft
	"Cursor resizeLeft showWhile: [Sensor waitButton]"
	^ResizeLeftCursor! !

!Cursor class methodsFor: 'constants' stamp: 'ar 8/16/2001 14:45'!
resizeRight
	"Cursor resizeRight showWhile: [Sensor waitButton]"
	^self resizeLeft! !

!Cursor class methodsFor: 'constants' stamp: 'JMM 10/21/2003 19:19'!
resizeTop
	"Cursor resizeTop showWhile: [Sensor waitButton]"
	^ResizeTopCursor! !

!Cursor class methodsFor: 'constants' stamp: 'JMM 10/21/2003 19:00'!
resizeTopLeft
	"Cursor resizeTopLeft showWhile: [Sensor waitButton]"
	^ ResizeTopLeftCursor! !

!Cursor class methodsFor: 'constants' stamp: 'JMM 10/21/2003 19:00'!
resizeTopRight
	"Cursor resizeTopRight showWhile: [Sensor waitButton]"
	^ResizeTopRightCursor! !

!Cursor class methodsFor: 'constants' stamp: ''!
rightArrow 
	"Answer the instance of me that is the shape of an arrow pointing to the right."

	^RightArrowCursor! !

!Cursor class methodsFor: 'constants' stamp: ''!
square
	"Answer the instance of me that is the shape of a square."

	^SquareCursor! !

!Cursor class methodsFor: 'class initialization' stamp: ''!
startUp
	self currentCursor: self currentCursor! !

!Cursor class methodsFor: 'constants' stamp: 'ar 3/1/2006 22:42'!
target
	"Answer the instance of me that is the shape of a gunsight."
	"Cursor target show"
	^TargetCursor ifNil:[self initTarget]! !

!Cursor class methodsFor: 'constants' stamp: 'JMM 10/21/2003 19:01'!
topLeft
	"Cursor topLeft showWhile: [Sensor waitButton]"
	^ TopLeftCursor! !

!Cursor class methodsFor: 'constants' stamp: 'JMM 10/21/2003 19:02'!
topRight
	"Cursor topRight showWhile: [Sensor waitButton]"
	^ TopRightCursor! !

!Cursor class methodsFor: 'constants' stamp: ''!
up
	"Answer the instance of me that is the shape of an arrow facing upward."

	^UpCursor! !

!Cursor class methodsFor: 'preferences' stamp: 'tfel 7/28/2016 16:58'!
useBiggerCursors

	<preference: 'Use bigger mouse cursors'
		category: 'mouse'
		description: 'If true, mouse cursors are scaled up'
		type: #Boolean>
	^ UseBiggerCursors ifNil: [false]! !

!Cursor class methodsFor: 'preferences' stamp: 'tfel 7/28/2016 16:58'!
useBiggerCursors: aBool

	UseBiggerCursors := aBool! !

!Cursor class methodsFor: 'constants' stamp: 'sw 8/15/97 13:28'!
wait
	"Answer the instance of me that is the shape of an Hourglass (was in the 
	shape of three small balls)."

	^WaitCursor! !

!Cursor class methodsFor: 'constants' stamp: 'ar 9/26/2001 22:37'!
webLink
	"Return a cursor that can be used for emphasizing web links"
	"Cursor webLink showWhile: [Sensor waitButton]"
	^WebLinkCursor ifNil:[
		WebLinkCursor :=  (CursorWithMask extent: 16@16
			fromArray: #(3072 4608 4608 4608 4608 5046 4681 29257 37449 37449 32769 32769 49155 16386 24582 16380 )
			offset: -5@0) setMaskForm:
		(Form extent: 16@16 
			fromArray: (#(3072 7680 7680 7680 7680 8118 8191 32767 65535 65535 65535 65535 65535 32766 32766 16380 )  collect: [:bits | bits bitShift: 16])
			offset: 0@0)].! !

!Cursor class methodsFor: 'constants' stamp: ''!
write
	"Answer the instance of me that is the shape of a pen writing."

	^WriteCursor! !

!Cursor methodsFor: 'converting' stamp: 'bf 3/22/2007 11:08'!
asBigCursor
	"Big cursors are 32 bits deep (ARGB premultiplied)"
	depth = 32
		ifFalse: [^self enlargedBy: 2].
	^self! !

!Cursor methodsFor: 'converting' stamp: 'RAA 8/14/2000 10:14'!
asCursorForm
	| form |
	form := StaticForm extent: self extent depth: 8.
	form fillShape: self fillColor: Color black at: offset negated.
	^ form offset: offset! !

!Cursor methodsFor: 'primitives' stamp: ''!
beCursor
	"Primitive. Tell the interpreter to use the receiver as the current cursor 
	image. Fail if the receiver does not match the size expected by the 
	hardware. Essential. See Object documentation whatIsAPrimitive."

	<primitive: 101>
	self primitiveFailed! !

!Cursor methodsFor: 'primitives' stamp: 'jm 9/22/1998 23:33'!
beCursorWithMask: maskForm
	"Primitive. Tell the interpreter to use the receiver as the current cursor image with the given mask Form. Both the receiver and the mask should have extent 16@16 and a depth of one. The mask and cursor bits are combined as follow:
			mask	cursor	effect
			 0		  0		transparent (underlying pixel shows through)
			 1		  1		opaque black
			 1		  0		opaque white
			 0		  1		invert the underlying pixel"
"Essential. See Object documentation whatIsAPrimitive."

	<primitive: 101>
	self primitiveFailed
! !

!Cursor methodsFor: 'updating' stamp: 'ls 6/17/2002 12:00'!
changed: aParameter
	"overriden to reinstall the cursor if it is the active cursor, in case the appearance has changed.  (Is this used anywhere?  Do cursors really change in place these days?)"
	self == CurrentCursor ifTrue: [self beCursor].
	super changed: aParameter! !

!Cursor methodsFor: 'converting' stamp: 'bf 5/10/2007 18:22'!
enlargedBy: scale
	"Big cursors are 32 bits deep (ARGB premultiplied)"
	| big |
	scale = 1 ifTrue: [^self].
	big := CursorWithAlpha extent: self extent * scale depth: 32.
	(self asCursorForm magnifyBy: scale) displayOn: big.
	big offset: (self offset - 0.5 * scale min: 0@0 max: big extent negated) asIntegerPoint.
	big fallback: self.
	^big! !

!Cursor methodsFor: 'testing' stamp: 'bf 2/2/1999 19:34'!
hasMask
	^false! !

!Cursor methodsFor: 'printing' stamp: ''!
printOn: aStream

	self storeOn: aStream base: 2! !

!Cursor methodsFor: 'displaying' stamp: 'fbs 7/11/2013 20:41'!
show
	"Make the hardware's mouse cursor look like the receiver"

	Cursor currentCursor: self! !

!Cursor methodsFor: 'displaying' stamp: 'fbs 7/11/2013 20:43'!
showGridded: gridPoint 
	"Make the current cursor shape be the receiver, forcing the location of the cursor to the point nearest gridPoint."
	
	Sensor cursorPoint: (Sensor cursorPoint grid: gridPoint).
	Cursor currentCursor: self! !

!Cursor methodsFor: 'displaying' stamp: 'fbs 7/8/2013 22:48'!
showWhile: aBlock 
	"While evaluating the argument, aBlock, make the receiver be the cursor shape."
	"ar 2/2/2006: Only allow this if active process is ui process"
	| oldcursor |
	Processor activeProcess == Project uiProcess ifFalse:[^aBlock value].
	oldcursor := Cursor currentCursor.
	self show.
	^aBlock ensure: [oldcursor show]
! !

!Cursor methodsFor: 'converting' stamp: 'bf 2/2/1999 19:32'!
withMask
	^CursorWithMask derivedFrom: self! !

Form subclass: #DisplayScreen
	instanceVariableNames: 'clippingBox extraRegions'
	classVariableNames: 'DeferringUpdates DisplayChangeSignature DisplayIsFullScreen ScreenSave'
	poolDictionaries: ''
	category: 'Graphics-Display Objects'!

!DisplayScreen commentStamp: '<historical>' prior: 0!
There is only one instance of me, Display. It is a global and is used to handle general user requests to deal with the whole display screen. 
	Although I offer no protocol, my name provides a way to distinguish this special instance from all other Forms. This is useful, for example, in dealing with saving and restoring the system.
	To change the depth of your Display...
		Display newDepth: 16.
		Display newDepth: 8.
		Display newDepth: 1.
Valid display depths are 1, 2, 4, 8, 16 and 32.  It is suggested that you run with your monitors setting the same, for better speed and color fidelity.  Note that this can add up to 4Mb for the Display form.  Finally, note that newDepth: ends by executing a 'ControlManager restore' which currently terminates the active process, so nothing that follows in the doit will get executed.

Depths 1, 2, 4 and 8 bits go through a color map to put color on the screen, but 16 and 32-bit color use the pixel values directly for RGB color (5 and 8 bits per, respectivlely).  The color choice an be observed by executing Color fromUser in whatever depth you are using.
!

!DisplayScreen class methodsFor: 'snapshots' stamp: 'ar 2/5/2001 17:24'!
actualScreenDepth
	<primitive: 'primitiveScreenDepth'>
	^ Display depth! !

!DisplayScreen class methodsFor: 'snapshots' stamp: ''!
actualScreenSize
	<primitive: 106>
	^ 640@480! !

!DisplayScreen class methodsFor: 'display box access' stamp: ''!
boundingBox
	"Answer the bounding box for the form representing the current display 
	screen."

	^Display boundingBox! !

!DisplayScreen class methodsFor: 'display box access' stamp: 'mt 5/9/2016 10:47'!
checkForNewScreenSize
	"Check whether the screen size has changed and if so take appropriate actions"

	Display extent = DisplayScreen actualScreenSize
		ifFalse: [Display restore].! !

!DisplayScreen class methodsFor: 'screen modes' stamp: 'mt 5/6/2016 15:20'!
displayIsFullScreen

	^ DisplayIsFullScreen ifNil: [DisplayIsFullScreen := false]! !

!DisplayScreen class methodsFor: 'screen modes' stamp: 'mt 5/6/2016 15:17'!
fullScreenOff

	Display fullScreenMode: (DisplayIsFullScreen := false).
	self checkForNewScreenSize.
! !

!DisplayScreen class methodsFor: 'screen modes' stamp: 'mt 5/6/2016 15:17'!
fullScreenOn

	Display fullScreenMode: (DisplayIsFullScreen := true).
	self checkForNewScreenSize.! !

!DisplayScreen class methodsFor: 'host window access' stamp: 'mt 5/7/2016 09:37'!
hostWindowExtent: aPoint
	
	^ self
		primitiveWindow: self hostWindowIndex
		width: aPoint x
		height: aPoint y! !

!DisplayScreen class methodsFor: 'host window access' stamp: 'dtl 5/11/2016 22:33'!
hostWindowIndex
	"By convention, the reference to the primary Squeak display window is 1.
	The host window plugin may use different conventions for references to
	windows. In general, the handles for references to host windows should be
	considered as meaningful only to the VM plugin, with host window index 1
	being a special case of a well known handle value."

	^ 1! !

!DisplayScreen class methodsFor: 'host window access' stamp: 'mt 5/7/2016 09:33'!
hostWindowTitle: aString

	^ self
		primitiveWindow: self hostWindowIndex
		title: aString squeakToUtf8! !

!DisplayScreen class methodsFor: 'testing' stamp: 'tfel 3/3/2016 17:05'!
isDeferringUpdates

	^ DeferringUpdates == true! !

!DisplayScreen class methodsFor: 'primitives - host window access' stamp: 'mt 5/7/2016 09:30'!
primitiveWindow: id title: titleString

	<primitive: 'primitiveHostWindowTitle' module: 'HostWindowPlugin'>
	^self primitiveFailed! !

!DisplayScreen class methodsFor: 'primitives - host window access' stamp: 'mt 5/7/2016 09:30'!
primitiveWindow: id width: width height: height

	<primitive: 'primitiveHostWindowSizeSet' module: 'HostWindowPlugin'>
	^self primitiveFailed! !

!DisplayScreen class methodsFor: 'display box access' stamp: 'mt 5/12/2016 11:05'!
setNewScreenSize: aPoint
	"Ensure that the Display is set to the given extent."
	
	self hostWindowExtent: aPoint.
	self checkForNewScreenSize.
	
	"In the Windows version of the host window plugin, the extent currently includes window decorations. Therefore, we need two attempts to ensure that the Display extent is aPoint. Note that this is a bug in the plugin."
	Display extent < aPoint ifTrue: [
		self hostWindowExtent: 2*aPoint - Display extent.
		self checkForNewScreenSize].! !

!DisplayScreen class methodsFor: 'snapshots' stamp: 'ar 5/28/2000 11:26'!
shutDown 
	"Minimize Display memory saved in image"
	Display shutDown.! !

!DisplayScreen class methodsFor: 'snapshots' stamp: 'ar 5/17/2001 15:50'!
startUp  "DisplayScreen startUp"
	Display setExtent: self actualScreenSize depth: Display nativeDepth.
	Display beDisplay! !

!DisplayScreen class methodsFor: 'screen modes' stamp: 'mt 5/6/2016 15:20'!
toggleFullScreen
	"Toggle between full screen and windowed mode."
	
	self displayIsFullScreen
		ifTrue: [self fullScreenOff]
		ifFalse: [self fullScreenOn].! !

!DisplayScreen methodsFor: 'displaying' stamp: 'ar 4/19/2001 05:44'!
addExtraRegion: aRectangle for: regionDrawer
	"Register the given rectangle as a region which is drawn by the specified region drawer. The region will be excluded from any updates when #forceDamageToScreen: is called. Note that the rectangle is only valid for a single update cycle; once #forceDamageToScreen: has been called, the region drawer and its region are being removed from the list"
	extraRegions ifNil:[extraRegions := #()].
	extraRegions := extraRegions copyWith: (Array with: regionDrawer with: aRectangle).
! !

!DisplayScreen methodsFor: 'private' stamp: ''!
beDisplay
	"Primitive. Tell the interpreter to use the receiver as the current display 
	image. Fail if the form is too wide to fit on the physical display. 
	Essential. See Object documentation whatIsAPrimitive."

	<primitive: 102>
	self primitiveFailed! !

!DisplayScreen methodsFor: 'other' stamp: ''!
boundingBox
	clippingBox == nil
		ifTrue: [clippingBox := super boundingBox].
	^ clippingBox! !

!DisplayScreen methodsFor: 'other' stamp: ''!
clippingTo: aRect do: aBlock
	"Display clippingTo: Rectangle fromUser do:
	[ScheduledControllers restore: Display fullBoundingBox]"
	| saveClip |
	saveClip := clippingBox.
	clippingBox := aRect.
	aBlock value.
	clippingBox := saveClip! !

!DisplayScreen methodsFor: 'displaying' stamp: 'tpr 3/15/2013 12:20'!
copyBits: rect from: sf at: destOrigin clippingBox: clipRect rule: cr fillColor: hf 
	(BitBlt
		destForm: self
		sourceForm: sf
		fillColor: hf
		combinationRule: cr
		destOrigin: destOrigin
		sourceOrigin: rect origin
		extent: rect extent
		clipRect: (clipRect intersect: clippingBox)) copyBits! !

!DisplayScreen methodsFor: 'displaying' stamp: 'tpr 3/15/2013 12:21'!
copyBits: rect from: sf at: destOrigin clippingBox: clipRect rule: cr fillColor: hf map: map
	((BitBlt
		destForm: self
		sourceForm: sf
		fillColor: hf
		combinationRule: cr
		destOrigin: destOrigin
		sourceOrigin: rect origin
		extent: rect extent
		clipRect: (clipRect intersect: clippingBox)) colorMap: map) copyBits! !

!DisplayScreen methodsFor: 'private' stamp: 'di 3/3/1999 10:00'!
copyFrom: aForm
	"Take on all state of aForm, with complete sharing"

	super copyFrom: aForm.
	clippingBox := super boundingBox! !

!DisplayScreen methodsFor: 'blitter defaults' stamp: 'ar 5/28/2000 12:01'!
defaultBitBltClass
	"Return the BitBlt version to use when I am active"
	^BitBlt! !

!DisplayScreen methodsFor: 'blitter defaults' stamp: 'ar 5/28/2000 12:01'!
defaultWarpBltClass
	"Return the WarpBlt version to use when I am active"
	^WarpBlt! !

!DisplayScreen methodsFor: 'other' stamp: 'hmm 2/2/2001 10:14'!
deferUpdatesIn: aRectangle while: aBlock
	| result |
	(self deferUpdates: true) ifTrue: [^aBlock value].
	result := aBlock value.
	self deferUpdates: false.
	self forceToScreen: aRectangle.
	^result! !

!DisplayScreen methodsFor: 'other' stamp: 'hmm 6/18/2000 19:16'!
deferUpdates: aBoolean
	| wasDeferred |
	"Set the deferUpdates flag in the virtual machine. When this flag is true, BitBlt operations on the Display are not automatically propagated to the screen. If this underlying platform does not support deferred updates, this primitive will fail. Answer whether updates were deferred before if the primitive succeeds, nil if it fails."

	wasDeferred := DeferringUpdates == true.
	DeferringUpdates := aBoolean.
	^(self primitiveDeferUpdates: aBoolean) ifNotNil: [wasDeferred]! !

!DisplayScreen methodsFor: 'other' stamp: 'RAA 11/27/1999 15:48'!
displayChangeSignature

	^DisplayChangeSignature! !

!DisplayScreen methodsFor: 'private' stamp: 'jrd 5/23/2009 00:53'!
findAnyDisplayDepth
	"Return any display depth that is supported on this system."
	^self findAnyDisplayDepthIfNone:[
		"Ugh .... now this is a biggie - a system that does not support
		any of the Squeak display depths at all."
		Smalltalk
			logSqueakError:'Fatal error: This system has no support for any display depth at all.'
			inContext: thisContext .
		Smalltalk quitPrimitive. "There is no way to continue from here"
	].! !

!DisplayScreen methodsFor: 'private' stamp: 'ar 5/17/2001 21:03'!
findAnyDisplayDepthIfNone: aBlock
	"Return any display depth that is supported on this system.
	If there is none, evaluate aBlock."
	#(1 2 4 8 16 32 -1 -2 -4 -8 -16 -32) do:[:bpp|
		(self supportsDisplayDepth: bpp) ifTrue:[^bpp].
	].
	^aBlock value! !

!DisplayScreen methodsFor: 'displaying' stamp: 'sw 1/1/2005 01:31'!
flashAll: rectangleList andWait: msecs
	"Flash the areas of the screen defined by the given rectangles."

	rectangleList do: [:aRectangle | self reverse: aRectangle].
	self forceDisplayUpdate.
	(Delay forMilliseconds: msecs) wait.
	rectangleList do: [:aRectangle | self reverse: aRectangle].
	self forceDisplayUpdate.
	(Delay forMilliseconds: msecs) wait.
! !

!DisplayScreen methodsFor: 'displaying' stamp: 'jm 5/22/1998 01:23'!
flash: aRectangle 
	"Flash the area of the screen defined by the given rectangle."

	self reverse: aRectangle.
	self forceDisplayUpdate.
	(Delay forMilliseconds: 100) wait.
	self reverse: aRectangle.
	self forceDisplayUpdate.
! !

!DisplayScreen methodsFor: 'displaying' stamp: 'RAA 6/2/2000 12:09'!
flash: aRectangle andWait: msecs
	"Flash the area of the screen defined by the given rectangle."

	self reverse: aRectangle.
	self forceDisplayUpdate.
	(Delay forMilliseconds: msecs) wait.
	self reverse: aRectangle.
	self forceDisplayUpdate.
	(Delay forMilliseconds: msecs) wait.
! !

!DisplayScreen methodsFor: 'displaying' stamp: 'nice 12/27/2009 03:10'!
forceDamageToScreen: allDamage
	"Force all the damage rects to the screen."
	| regions rectList |
	rectList := allDamage.
	"Note: Reset extra regions at the beginning to prevent repeated errors"
	regions := extraRegions.
	extraRegions := nil.
	regions ifNotNil:[
		"exclude extra regions"
		regions do:[:drawerAndRect| | excluded remaining |
			excluded := drawerAndRect at: 2.
			remaining := WriteStream on: #().
			rectList do:[:r|
				remaining nextPutAll:(r areasOutside: excluded)].
			rectList := remaining contents].
	].
	rectList do:[:r| self forceToScreen: r].
	regions ifNotNil:[
		"Have the drawers paint what is needed"
		regions do:[:drawerAndRect| (drawerAndRect at: 1) forceToScreen].
	].! !

!DisplayScreen methodsFor: 'other' stamp: 'jm 5/21/1998 23:48'!
forceDisplayUpdate
	"On platforms that buffer screen updates, force the screen to be updated immediately. On other platforms, or if the primitive is not implemented, do nothing."

	<primitive: 231>
	"do nothing if primitive fails"! !

!DisplayScreen methodsFor: 'other' stamp: 'ar 2/11/1999 18:14'!
forceToScreen
	"Force the entire display area to the screen"
	^self forceToScreen: self boundingBox! !

!DisplayScreen methodsFor: 'other' stamp: 'jm 5/19/1998 17:50'!
forceToScreen: aRectangle
	"Force the given rectangular section of the Display to be copied to the screen. The primitive call does nothing if the primitive is not implemented. Typically used when the deferUpdates flag in the virtual machine is on; see deferUpdates:."

	self primShowRectLeft: aRectangle left
		right: aRectangle right
		top: aRectangle top
		bottom: aRectangle bottom.
! !

!DisplayScreen methodsFor: 'other' stamp: ''!
fullBoundingBox
	^ super boundingBox! !

!DisplayScreen methodsFor: 'other' stamp: ''!
fullScreen   "Display fullScreen"

	ScreenSave notNil ifTrue: [Display := ScreenSave].
	clippingBox := super boundingBox! !

!DisplayScreen methodsFor: 'other' stamp: 'sd 6/7/2003 19:46'!
fullScreenMode: aBoolean
	"On platforms that support it, set full-screen mode to the value of the argument. (Note: you'll need to restore the Display after calling this primitive."
	"Display fullScreenMode: true. Display newDepth: Display depth"

	<primitive: 233>
	self primitiveFailed
! !

!DisplayScreen methodsFor: 'other' stamp: ''!
height
	^ self boundingBox height! !

!DisplayScreen methodsFor: 'testing' stamp: 'ar 5/25/2000 23:34'!
isDisplayScreen
	^true! !

!DisplayScreen methodsFor: 'other' stamp: 'mt 5/9/2016 11:16'!
newDepth: pixelSize
"
	Display newDepth: 8.
	Display newDepth: 1.
"
	| area need |
	
	(self supportsDisplayDepth: pixelSize)
		ifFalse:[^self inform:'Display depth ', pixelSize printString, ' is not supported on this system'].

	pixelSize = self depth ifTrue: [^ self  "no change"].
	pixelSize abs < self depth ifFalse:
		["Make sure there is enough space"
		area := self boundingBox area. "pixels"

		need := (area * (pixelSize abs - self depth) // 8)  "new bytes needed"
				+ Smalltalk lowSpaceThreshold.
		(Smalltalk garbageCollectMost <= need
			and: [Smalltalk garbageCollect <= need])
			ifTrue: [self error: 'Insufficient free space']].

	Display setExtent: Display extent depth: pixelSize.
	Display beDisplay.

	Project current ifNotNil: [:p |
		p
			displayDepthChanged;
			displaySizeChanged].! !

!DisplayScreen methodsFor: 'disk I/O' stamp: 'tk 9/28/2000 15:41'!
objectForDataStream: refStrm
	| dp |
	"I am about to be written on an object file.  Write a reference to the Display in the other system instead.  "

	"A path to me"
	dp := DiskProxy global: #Display selector: #yourself args: #().
	refStrm replace: self with: dp.
	^ dp
! !

!DisplayScreen methodsFor: 'other' stamp: 'hmm 6/18/2000 19:14'!
primitiveDeferUpdates: aBoolean
	"Set the deferUpdates flag in the virtual machine. When this flag is true, BitBlt operations on the Display are not automatically propagated to the screen. If this underlying platform does not support deferred updates, this primitive will fail. Answer the receiver if the primitive succeeds, nil if it fails."

	<primitive: 126>
	^ nil  "answer nil if primitive fails"
! !

!DisplayScreen methodsFor: 'private' stamp: 'jm 6/3/1998 13:00'!
primRetryShowRectLeft: l right: r top: t bottom: b
	"Copy the given rectangular section of the Display to to the screen. This primitive is not implemented on all platforms. Do nothing if it fails. "

	<primitive: 127>
	"do nothing if primitive fails"
! !

!DisplayScreen methodsFor: 'private' stamp: 'jm 6/3/1998 13:02'!
primShowRectLeft: l right: r top: t bottom: b
	"Copy the given rectangular section of the Display to to the screen. This primitive is not implemented on all platforms. If this fails, retry integer coordinates."

	<primitive: 127>
	"if this fails, coerce coordinates to integers and try again"
	self primRetryShowRectLeft: l truncated
		right: r rounded
		top: t truncated
		bottom: b rounded.
! !

!DisplayScreen methodsFor: 'initialize-release' stamp: 'ar 5/26/2000 00:07'!
release
	"I am no longer Display. Release any resources if necessary"! !

!DisplayScreen methodsFor: 'other' stamp: ''!
replacedBy: aForm do: aBlock
	"Permits normal display to draw on aForm instead of the display."

	ScreenSave := self.
	Display := aForm.
	aBlock value.
	Display := self.
	ScreenSave := nil.! !

!DisplayScreen methodsFor: 'other' stamp: 'mt 5/9/2016 10:46'!
restore

	DisplayScreen startUp.
	Project current ifNotNil: [:p| p displaySizeChanged].! !

!DisplayScreen methodsFor: 'other' stamp: 'mt 5/9/2016 10:57'!
restoreAfter: aBlock
	"Evaluate the block, wait for a mouse click, and then restore the screen."

	aBlock ensure: [
		Sensor waitButton.
		self restore].! !

!DisplayScreen methodsFor: 'private' stamp: 'bf 5/16/2006 11:35'!
setExtent: aPoint depth: bitsPerPixel  "DisplayScreen startUp"
	"This method is critical.  If the setExtent fails, there will be no
	proper display on which to show the error condition..."
	"ar 5/1/1999: ... and that is exactly why we check for the available display depths first."

	"RAA 27 Nov 99 - if depth and extent are the same and acceptable, why go through this.
	also - record when we change so worlds can tell if it is time to repaint"

	(depth == bitsPerPixel and: [aPoint = self extent and: 
					[self supportsDisplayDepth: bitsPerPixel]]) ifFalse: [
		bits := nil.  "Free up old bitmap in case space is low"
		DisplayChangeSignature := (DisplayChangeSignature ifNil: [0]) + 1.
		(self supportsDisplayDepth: bitsPerPixel)
			ifTrue:[super setExtent: aPoint depth: bitsPerPixel]
			ifFalse:[(self supportsDisplayDepth: bitsPerPixel negated)
				ifTrue:[super setExtent: aPoint depth: bitsPerPixel negated]
				ifFalse:["Search for a suitable depth"
					super setExtent: aPoint depth: self findAnyDisplayDepth]].
	].
	clippingBox := super boundingBox! !

!DisplayScreen methodsFor: 'initialize-release' stamp: 'ar 5/28/2000 11:25'!
shutDown 
	"Minimize Display memory saved in image"
	self setExtent: 240@120 depth: depth! !

!DisplayScreen methodsFor: 'other' stamp: 'ar 5/17/2001 21:02'!
supportedDisplayDepths
	"Return all pixel depths supported on the current host platform."
	^#(1 2 4 8 16 32 -1 -2 -4 -8 -16 -32) select: [:d | self supportsDisplayDepth: d]! !

!DisplayScreen methodsFor: 'other' stamp: 'ar 5/5/1999 23:45'!
supportsDisplayDepth: pixelDepth
	"Return true if this pixel depth is supported on the current host platform.
	Primitive. Optional."
	<primitive: 91>
	^#(1 2 4 8 16 32) includes: pixelDepth! !

!DisplayScreen methodsFor: 'other' stamp: ''!
usableArea
	"Answer the usable area of the receiver.  5/22/96 sw."

	^ self boundingBox deepCopy! !

!DisplayScreen methodsFor: 'other' stamp: ''!
width
	^ self boundingBox width! !

Form subclass: #FormStub
	instanceVariableNames: 'locator'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Display Objects'!

!FormStub methodsFor: 'accessing' stamp: 'ar 2/24/2001 22:02'!
locator
	^locator! !

!FormStub methodsFor: 'accessing' stamp: 'ar 2/24/2001 22:02'!
locator: aString
	locator := aString! !

!FormStub methodsFor: 'fileIn/Out' stamp: 'ar 2/27/2001 21:36'!
objectForDataStream: refStream
	"Force me into outPointers so that I get notified about startup"
	refStream replace: self with: self.
	^self! !

!Form class methodsFor: 'mode constants' stamp: ''!
and
	"Answer the integer denoting the logical 'and' combination rule."

	^1! !

!Form class methodsFor: 'mode constants' stamp: ''!
blend
	"Answer the integer denoting BitBlt's alpha blend combination rule."
	^24! !

!Form class methodsFor: 'mode constants' stamp: 'di 12/31/1998 14:02'!
blendAlpha
	"Answer the integer denoting BitBlt's blend-with-constant-alpha rule."

	^ 30! !

!Form class methodsFor: 'mode constants' stamp: 'mt 11/16/2010 20:31'!
blendAlphaScaled
	"Answer the integer denoting BitBlt's blend-with-alpha-scaled rule."

	^ 34! !

!Form class methodsFor: 'mode constants' stamp: 'tpr 11/13/2015 15:35'!
compareMatchColor
	"The primCompare test id values are
	compareMatchColors -> 0
	compareNotColorANotColorB -> 1
	compareNotColorAMatchColorB -> 2"
	^0! !

!Form class methodsFor: 'mode constants' stamp: 'tpr 11/13/2015 15:35'!
compareNotColorAMatchColorB
	"The primCompare test id values are
	compareMatchColors -> 0
	compareNotColorANotColorB -> 1
	compareNotColorAMatchColorB -> 2"
	^2! !

!Form class methodsFor: 'mode constants' stamp: 'tpr 11/13/2015 15:35'!
compareNotColorANotColorB
	"The primCompare test id values are
	compareMatchColors -> 0
	compareNotColorANotColorB -> 1
	compareNotColorAMatchColorB -> 2"
	^1! !

!Form class methodsFor: 'mode constants' stamp: 'tpr 11/13/2015 15:36'!
compareTallyFlag
	"The primCompare test id values are ORR'd with 8 to indicate tallying rather than simply reporting the first hit"
	^8! !

!Form class methodsFor: 'instance creation' stamp: 'tpr 3/15/2013 12:30'!
dotOfSize: diameter
	"Create a form which contains a round black dot."
	| radius form bb rect centerX centerY centerYBias centerXBias radiusSquared xOverY maxy dx |
	radius := diameter//2.
	form := self extent: diameter@diameter offset: (0@0) - (radius@radius).	
	bb := (BitBlt toForm: form)
		sourceX: 0; sourceY: 0;
		combinationRule: Form over;
		fillColor: Color black.
	rect := form boundingBox.
	centerX := rect center x.
	centerY := rect center y.
	centerYBias := rect height odd ifTrue: [0] ifFalse: [1].
	centerXBias := rect width odd ifTrue: [0] ifFalse: [1].
	radiusSquared := (rect height asFloat / 2.0) squared - 0.01.
	xOverY := rect width asFloat / rect height asFloat.
	maxy := rect height - 1 // 2.

	"First do the inner fill, and collect x values"
	0 to: maxy do:
		[:dy |
		dx := ((radiusSquared - (dy * dy) asFloat) sqrt * xOverY) truncated.
		bb	destX: centerX - centerXBias - dx
			destY: centerY - centerYBias - dy
			width: dx + dx + centerXBias + 1
			height: 1;
			copyBits.
		bb	destY: centerY + dy;
			copyBits].
	^ form
"
Time millisecondsToRun:
	[1 to: 20 do: [:i | (Form dotOfSize: i) displayAt: (i*20)@(i*20)]]
"! !

!Form class methodsFor: 'mode constants' stamp: ''!
erase
	"Answer the integer denoting mode erase."

	^4! !

!Form class methodsFor: 'mode constants' stamp: ''!
erase1bitShape
	"Answer the integer denoting mode erase."

	^ 26! !

!Form class methodsFor: 'examples' stamp: 'nice 1/10/2010 17:41'!
exampleBorder    "Form exampleBorder"
	"This example demonstrates the border finding algorithm. Start
	by having the user sketch on the screen (end with option-click) and then select a rectangular
	area of the screen which includes all of the area to be filled. Finally,
	(with crosshair cursor), the user points at the interior of the region to be
	outlined, and the region begins with that place as its seed."
	| f r interiorPoint |
	Form exampleSketch.		"sketch a little area with an enclosed region"
	r := Rectangle fromUser.
	f := Form fromDisplay: r.
	interiorPoint := Cursor crossHair showWhile:
		[Sensor waitButton - r origin].
	Cursor execute showWhile:
		[f shapeBorder: Color blue width: 2 interiorPoint: interiorPoint
			sharpCorners: false internal: false].
	f displayOn: Display at: r origin	! !

!Form class methodsFor: 'examples' stamp: ''!
exampleEdits
	"In Form category editing are messages edit and bitEdit that make it possible to 
	create editors on instances of Form. 
	 
	This is the general form editor:
	| f | 
	f := Form fromUser. 
	f edit. 
	 
	This is the general bit editor:
	| f | 
	f := Form fromUser. 
	f bitEdit."! !

!Form class methodsFor: 'examples' stamp: ''!
exampleMagnify

	| f m |
	f := Form fromUser.
	m := f magnify: f boundingBox by: 5 @ 5.
	m displayOn: Display at: Sensor waitButton

	"Form exampleMagnify."! !

!Form class methodsFor: 'examples' stamp: ''!
exampleShrink

	| f s |
	f := Form fromUser.
	s := f shrink: f boundingBox by: 2 @ 5.
	s displayOn: Display at: Sensor waitButton	

	"Form exampleShrink."! !

!Form class methodsFor: 'examples' stamp: ''!
exampleSketch
	"This is a simple drawing algorithm to get a sketch on the display screen.
	Draws whenever mouse button down.  Ends with option-click."
	| aPen color |
	aPen := Pen new.
	color := 0.
	[Sensor yellowButtonPressed]
		whileFalse:
		[aPen place: Sensor cursorPoint; color: (color := color + 1).
		[Sensor redButtonPressed]
			whileTrue: [aPen goto: Sensor cursorPoint]].
	Sensor waitNoButton.

	"Form exampleSketch"! !

!Form class methodsFor: 'examples' stamp: 'nice 1/10/2010 17:41'!
exampleSpaceFill    "Form exampleSpaceFill"
	"This example demonstrates the area filling algorithm. Starts by having
	the user sketch on the screen (ended by option-click) and then select a rectangular
	area of the screen which includes all of the area to be filled. Finally,
	(with crosshair cursor), the user points at the interior of some region to be
	filled, and the filling begins with that place as its seed."
	| f r interiorPoint |
	Form exampleSketch.		"sketch a little area with an enclosed region"
	r := Rectangle fromUser.
	f := Form fromDisplay: r.
	interiorPoint := Cursor crossHair showWhile:
		[Sensor waitButton - r origin].
	Cursor execute showWhile:
		[f shapeFill: Color gray interiorPoint: interiorPoint].
	f displayOn: Display at: r origin	! !

!Form class methodsFor: 'instance creation' stamp: 'jm 3/27/98 16:27'!
extent: extentPoint
	"Answer an instance of me with a blank bitmap of depth 1."

	^ self extent: extentPoint depth: 1
! !

!Form class methodsFor: 'instance creation' stamp: 'jm 3/27/98 16:36'!
extent: extentPoint depth: bitsPerPixel
	"Answer an instance of me with blank bitmap of the given dimensions and depth."

	^ self basicNew setExtent: extentPoint depth: bitsPerPixel
! !

!Form class methodsFor: 'instance creation' stamp: 'ar 10/9/1998 23:44'!
extent: extentPoint depth: bitsPerPixel bits: aBitmap
	"Answer an instance of me with blank bitmap of the given dimensions and depth."

	^ self basicNew setExtent: extentPoint depth: bitsPerPixel bits: aBitmap! !

!Form class methodsFor: 'instance creation' stamp: 'jm 3/27/98 16:35'!
extent: extentPoint depth: bitsPerPixel fromArray: anArray offset: offsetPoint 
	"Answer an instance of me with a pixmap of the given depth initialized from anArray."

	^ (self extent: extentPoint depth: bitsPerPixel)
		offset: offsetPoint;
		initFromArray: anArray
! !

!Form class methodsFor: 'instance creation' stamp: 'jm 3/27/98 16:33'!
extent: extentPoint fromArray: anArray offset: offsetPoint 
	"Answer an instance of me of depth 1 with bitmap initialized from anArray."

	^ (self extent: extentPoint depth: 1)
		offset: offsetPoint;
		initFromArray: anArray
! !

!Form class methodsFor: 'instance creation' stamp: 'nice 12/27/2009 05:15'!
extent: extentPoint fromStipple: fourNibbles
	"Answer an instance of me with bitmap initialized from
	a repeating 4x4 bit stipple encoded in a 16-bit constant."
	
	^ (self extent: extentPoint depth: 1)
		initFromArray: ((1 to: 4) collect:
				[:i | | nibble |
				nibble := (fourNibbles bitShift: -4*(4-i)) bitAnd: 16rF.
				16r11111111 * nibble])  "fill 32 bits with each 4-bit nibble"
! !

!Form class methodsFor: 'instance creation' stamp: 'jm 3/27/98 16:26'!
extent: extentPoint offset: offsetPoint 
	"Answer an instance of me with a blank bitmap of depth 1."

	^ (self extent: extentPoint depth: 1) offset: offsetPoint
! !

!Form class methodsFor: 'file list services' stamp: 'nk 6/12/2004 12:56'!
fileReaderServicesForDirectory: aFileDirectory
	^{
		self serviceImageImportDirectory.
		self serviceImageImportDirectoryWithSubdirectories.
	}! !

!Form class methodsFor: 'file list services' stamp: 'nk 7/16/2003 18:01'!
fileReaderServicesForFile: fullName suffix: suffix

	^((ImageReadWriter allTypicalFileExtensions add: '*'; add: 'form'; yourself)
		includes: suffix)
		ifTrue: [ self services ]
		ifFalse: [#()]
! !

!Form class methodsFor: 'instance creation' stamp: 'nk 7/7/2003 18:19'!
fromBinaryStream: aBinaryStream
	"Read a Form or ColorForm from given file, using the first byte of the file to guess its format. Currently handles: GIF, uncompressed BMP, and both old and new DisplayObject writeOn: formats, JPEG, and PCX. Return nil if the file could not be read or was of an unrecognized format."

	| firstByte |
	aBinaryStream binary.
	firstByte := aBinaryStream next.
	firstByte = 1 ifTrue: [
		"old Squeakform format"
		^ self new readFromOldFormat: aBinaryStream].
	firstByte = 2 ifTrue: [
		"new Squeak form format"
		^ self new readFrom: aBinaryStream].

	"Try for JPG, GIF, or PCX..."
	"Note: The following call closes the stream."
	^ ImageReadWriter formFromStream: aBinaryStream
! !

!Form class methodsFor: 'BMP file reading' stamp: 'ar 6/16/2002 17:41'!
fromBMPFileNamed: fileName
	"Obsolete"
	^self fromFileNamed: fileName
! !

!Form class methodsFor: 'BMP file reading' stamp: 'ar 6/16/2002 17:41'!
fromBMPFile: aBinaryStream
	"Obsolete"
	^self fromBinaryStream: aBinaryStream.! !

!Form class methodsFor: 'instance creation' stamp: ''!
fromDisplay: aRectangle 
	"Answer an instance of me with bitmap initialized from the area of the 
	display screen defined by aRectangle."

	^ (self extent: aRectangle extent depth: Display depth)
		fromDisplay: aRectangle! !

!Form class methodsFor: 'instance creation' stamp: ''!
fromDisplay: aRectangle using: oldForm
	"Like fromDisplay: only if oldForm is the right size, copy into it and answer it instead."

	((oldForm ~~ nil) and: [oldForm extent = aRectangle extent])
		ifTrue:
			[oldForm fromDisplay: aRectangle.
			 ^ oldForm]
		ifFalse:
			[^ self fromDisplay: aRectangle]! !

!Form class methodsFor: 'instance creation' stamp: 'mir 11/19/2001 14:13'!
fromFileNamed: fileName
	"Read a Form or ColorForm from the given file."

	| file form |
	file := (FileStream readOnlyFileNamed: fileName) binary.
	form := self fromBinaryStream: file.
	Smalltalk isMorphic ifTrue:[
		Project current resourceManager
			addResource: form
			url: (FileDirectory urlForFileNamed: file name) asString].
	file close.
	^ form
! !

!Form class methodsFor: 'instance creation' stamp: ''!
fromUser
	"Answer an instance of me with bitmap initialized from the area of the 
	display screen designated by the user. The grid for selecting an area is 
	1@1."

	^self fromUser: 1 @ 1! !

!Form class methodsFor: 'instance creation' stamp: 'jm 12/5/97 19:32'!
fromUserWithExtent: anExtent
	"Answer an instance of me with bitmap initialized from the area of the 
	display screen whose origin is designated by the user and whose size is anExtent"

	^ self fromDisplay: (Rectangle originFromUser: anExtent)

"(Form fromUserWithExtent: 50@50) displayAt: 10@10"! !

!Form class methodsFor: 'instance creation' stamp: 'ar 3/1/2006 22:50'!
fromUser: gridPoint
	"Answer an instance of me with bitmap initialized from the area of the 
	display screen designated by the user. The grid for selecting an area is 
	aPoint. Ensures that the returned form has positive extent."
	| rect |
	rect := Rectangle fromUser: gridPoint.
	^ self fromDisplay: (rect origin extent: (rect extent max: gridPoint))! !

!Form class methodsFor: 'file list services' stamp: 'mt 7/13/2016 11:40'!
importImageAndShowImports: fullName

	self importImage: fullName.
	Imports default explore.! !

!Form class methodsFor: 'fileIn/Out' stamp: 'nk 6/12/2004 12:55'!
importImageDirectoryWithSubdirectories: dir
	"Import the given image file and store the resulting Form in the default Imports.
	The image is named with the short filename up to the first period, possibly with additions from the directory path to make it unique."

	Imports default importImageDirectoryWithSubdirectories: dir
! !

!Form class methodsFor: 'fileIn/Out' stamp: 'nk 6/12/2004 13:08'!
importImageDirectory: dir
	"Import the given image file and store the resulting Form in the default Imports.
	The image is named with the short filename up to the first period, possibly with additions from the directory path to make it unique."

	Imports default importImageDirectory: dir
! !

!Form class methodsFor: 'fileIn/Out' stamp: 'sw 9/28/2006 05:39'!
importImage: fullName
	"Import the given image file and store the resulting Form in the default Imports.
	The image is named with the short filename up to the first period, possibly with additions from the directory path to make it unique.  Does nothing if called with nil fullName."

	fullName ifNotNil:
		[Imports default importImageFromFileNamed: fullName]
! !

!Form class methodsFor: 'initialize-release' stamp: 'ar 9/5/2010 09:09'!
initialize

	FileServices registerFileReader: self! !

!Form class methodsFor: 'examples' stamp: ''!
makeStar  "See the similar example in OpaqueForm"
	| sampleForm pen |
	sampleForm := Form extent: 50@50.  "Make a form"
	pen := Pen newOnForm: sampleForm.
	pen place: 24@50; turn: 18.		"Draw a 5-pointed star on it."
	1 to: 5 do: [:i | pen go: 19; turn: 72; go: 19; turn: -144].
	^ sampleForm
"
Form makeStar follow: [Sensor cursorPoint]
				while: [Sensor noButtonPressed]
"! !

!Form class methodsFor: 'mode constants' stamp: ''!
oldErase1bitShape
	"Answer the integer denoting mode erase."

	^ 17! !

!Form class methodsFor: 'mode constants' stamp: ''!
oldPaint
	"Answer the integer denoting the 'paint' combination rule."

	^16! !

!Form class methodsFor: 'file list services' stamp: 'sw 9/28/2006 05:37'!
openAsBackground: fullName
	"Set an image as a background image.  Support Squeak's common file format 
	(GIF, JPG, PNG, 'Form stoteOn: (run coded)' and BMP).
	If name provided is nil, does nothing."

	fullName ifNotNil:
		[(self fromFileNamed: fullName) setAsBackground]! !

!Form class methodsFor: 'file list services' stamp: 'dtl 2/10/2010 15:30'!
openImageInWindow: fullName
	"Handle five file formats: GIF, JPG, PNG, Form storeOn: (run coded), and BMP.
	Fail if file format is not recognized."

	| image myStream |

	myStream := (FileStream readOnlyFileNamed: fullName) binary.
	[image := self fromBinaryStream: myStream.
	Project current openImage: image name: fullName saveResource: true]
		ensure: [myStream close]! !

!Form class methodsFor: 'mode constants' stamp: ''!
over
	"Answer the integer denoting mode over."

	^3! !

!Form class methodsFor: 'mode constants' stamp: ''!
paint
	"Answer the integer denoting the 'paint' combination rule."

	^25! !

!Form class methodsFor: 'mode constants' stamp: 'di 12/31/1998 14:02'!
paintAlpha
	"Answer the integer denoting BitBlt's paint-with-constant-alpha rule."

	^ 31! !

!Form class methodsFor: 'mode constants' stamp: ''!
reverse
	"Answer the integer denoting mode reverse."

	^6! !

!Form class methodsFor: 'mode constants' stamp: 'hg 1/29/2001 17:28'!
rgbMul
	"Answer the integer denoting 'Multiply each color component, 
	 their values regarded as fractions of 1' rule."

	^ 37! !

!Form class methodsFor: 'file list services' stamp: 'KR 3/21/2008 21:00'!
serviceImageAsBackground
	"Answer a service for setting the desktop background from a given graphical file's contents"

	^ SimpleServiceEntry 
		provider: self 
		label: 'use graphic as background' translatedNoop
		selector: #openAsBackground:
		description: 'use the graphic as the background for the desktop' translatedNoop
		buttonLabel: 'background' translatedNoop! !

!Form class methodsFor: 'file list services' stamp: 'mt 8/10/2016 10:02'!
serviceImageImportAndShowImports
	"Answer a service for reading a graphic into ImageImports"

	^	SimpleServiceEntry
			provider: self 
			label: 'read graphic into and show ImageImports'
			selector: #importImageAndShowImports:
			description: 'Load a graphic, placing it in the ImageImports repository and browse that repository.'
			buttonLabel: 'import'! !

!Form class methodsFor: 'file list services' stamp: 'KR 3/21/2008 20:59'!
serviceImageImportDirectory
	"Answer a service for reading a graphic into ImageImports"

	^(SimpleServiceEntry
			provider: self 
			label: 'import all images from this directory' translatedNoop
			selector: #importImageDirectory:
			description: 'Load all graphics found in this directory, adding them to the ImageImports repository.' translatedNoop
			buttonLabel: 'import dir' translatedNoop)
			argumentGetter: [ :fileList | fileList directory ];
			yourself
! !

!Form class methodsFor: 'file list services' stamp: 'KR 3/21/2008 20:59'!
serviceImageImportDirectoryWithSubdirectories
	"Answer a service for reading all graphics from a directory and its subdirectories into ImageImports"

	^(SimpleServiceEntry
			provider: self 
			label: 'import all images from here and subdirectories' translatedNoop
			selector: #importImageDirectoryWithSubdirectories:
			description: 'Load all graphics found in this directory and its subdirectories, adding them to the ImageImports repository.' translatedNoop
			buttonLabel: 'import subdirs' translatedNoop)
			argumentGetter: [ :fileList | fileList directory ];
			yourself
! !

!Form class methodsFor: 'file list services' stamp: 'sw 2/17/2002 01:39'!
serviceImageImports
	"Answer a service for reading a graphic into ImageImports"

	^	SimpleServiceEntry
			provider: self 
			label: 'read graphic into ImageImports'
			selector: #importImage:
			description: 'Load a graphic, placing it in the ImageImports repository.'
			buttonLabel: 'import'! !

!Form class methodsFor: 'file list services' stamp: 'KR 3/21/2008 20:54'!
serviceOpenImageInWindow
	"Answer a service for opening a graphic in a window"

	^ SimpleServiceEntry 
		provider: self 
		label: 'open graphic in a window' translatedNoop
		selector: #openImageInWindow:
		description: 'open a graphic file in a window' translatedNoop
		buttonLabel: 'open' translatedNoop! !

!Form class methodsFor: 'file list services' stamp: 'yo 10/15/2006 02:07'!
services

	| a |
	a _ Array with: self serviceOpenImageInWindow.

	Preferences eToyFriendly ifFalse: [
		a _ (Array with: self serviceImageAsBackground with: self serviceImageImports), a.
	].
	^ a.

! !

!Form class methodsFor: 'shut down' stamp: 'ar 5/28/2000 23:35'!
shutDown  "Form shutDown"
	"Compress all instances in the system.  Will decompress on demand..."
	Form allInstancesDo: [:f | f hibernate].
	ColorForm allInstancesDo: [:f | f hibernate].! !

!Form class methodsFor: 'examples' stamp: 'tpr 3/15/2013 12:30'!
toothpaste: diam		"Display restoreAfter: [Form toothpaste: 30]"
	"Draws wormlike lines by laying down images of spheres.
	See Ken Knowlton, Computer Graphics, vol. 15 no. 4 p352.
	Draw with mouse button down; terminate by option-click."
	| facade ball filter point queue port color q colors colr colr2 |
	colors := Display depth = 1
		ifTrue: [Array with: Color black]
		ifFalse: [Color red wheel: 12].
	facade := Form extent: diam@diam offset: (diam // -2) asPoint.
	(Form dotOfSize: diam) displayOn: facade
			at: (diam // 2) asPoint clippingBox: facade boundingBox
			rule: Form under fillColor: Color white.
	#(1 2 3) do:
		[:x |  "simulate facade by circles of gray"
		(Form dotOfSize: x * diam // 5) displayOn: facade
			at: (diam * 2 // 5) asPoint clippingBox: facade boundingBox
			rule: Form under
			fillColor: (Color perform: 
					(#(black gray lightGray) at: x)).
		"facade displayAt: 50*x@50"].
	ball := Form dotOfSize: diam.
	color := 8.
	[port := BitBlt toForm: Display.
	"Expand 1-bit forms to any pixel depth"
	port colorMap: (Bitmap with: 0 with: 16rFFFFFFFF).
	queue := OrderedCollection new: 32.
	16 timesRepeat: [queue addLast: -20 @ -20].
	Sensor waitButton.
	Sensor yellowButtonPressed ifTrue: [^ self].
	filter := Sensor cursorPoint.
	colr := colors atWrap: (color := color + 5).  "choose increment relatively prime to colors size"
	colr2 := colr alphaMixed: 0.3 with: Color white.
	[Sensor redButtonPressed or: [queue size > 0]] whileTrue:
		[filter := filter * 4 + Sensor cursorPoint  //  5.
		point := Sensor redButtonPressed
			ifTrue: [filter] ifFalse: [-20 @ -20].
		port copyForm: ball to: point rule: Form paint fillColor: colr.
		(q := queue removeFirst) == nil ifTrue: [^ self].	"exit"
		Display depth = 1
			ifTrue: [port copyForm: facade to: q rule: Form erase]
			ifFalse: [port copyForm: facade to: q rule: Form paint fillColor: colr2].
		Sensor redButtonPressed ifTrue: [queue addLast: point]]] repeat.
! !

!Form class methodsFor: 'mode constants' stamp: ''!
under
	"Answer the integer denoting mode under."

	^7! !

!Form class methodsFor: 'class initialization' stamp: 'ar 9/5/2010 09:09'!
unload

	FileServices unregisterFileReader: self ! !

!Form class methodsFor: 'examples' stamp: 'nice 12/29/2010 16:55'!
xorHack: size  "Display restoreAfter: [Form xorHack: 256]"
	"Draw a smiley face or stick figure, and end with option-click.
	Thereafter image gets 'processed' as long as you have button down.
	If you stop at just the right time, you'll see you figure upside down,
	and at the end of a full cycle, you'll see it perfectly restored.
	Dude -- this works in color too!!"
	| rect form i bb |
	rect := 5 @ 5 extent: size @ size.
	Display fillWhite: rect; border: (rect expandBy: 2) width: 2.
	Display border: (rect topRight - (0 @ 2) extent: rect extent * 2 + 4) width: 2.
	Form exampleSketch.
	form := Form fromDisplay: rect.
	bb := form boundingBox.
	i := 0.
	[Sensor yellowButtonPressed] whileFalse:
		[[Sensor redButtonPressed] whileTrue:
			[i := i + 1.
			(Array with: 0 @ 1 with: 0 @ -1 with: 1 @ 0 with: -1 @ 0) do:
				[:d | form copyBits: bb from: form at: d
					clippingBox: bb rule: Form reverse fillColor: nil].
			form displayAt: rect topLeft.
			i+2\\size < 4 ifTrue: [(Delay forMilliseconds: 300) wait]].
		(form magnify: form boundingBox by: 2 @ 2) displayAt: rect topRight + (2 @ 0).
		Sensor waitButton].! !

!Form methodsFor: 'converting' stamp: 'mt 5/10/2015 13:28'!
adjustBrightness: brightness

	^ self collectColors: [:color | color adjustSaturation: 0 brightness: brightness]! !

!Form methodsFor: 'converting' stamp: 'mt 5/10/2015 13:26'!
adjustSaturation: saturation

	^ self collectColors: [:color | color adjustSaturation: saturation brightness: 0]! !

!Form methodsFor: 'initialize-release' stamp: 'ar 5/17/2001 22:54'!
allocateForm: extentPoint
	"Allocate a new form which is similar to the receiver and can be used for accelerated blts"
	^Form extent: extentPoint depth: self nativeDepth! !

!Form methodsFor: 'filling' stamp: 'di 2/19/1999 07:07'!
anyShapeFill
	"Fill the interior of the outermost outlined region in the receiver, a 1-bit deep form.  Typically the resulting form is used with fillShape:fillColor: to paint a solid color.  See also convexShapeFill:"

	| shape |
	"Draw a seed line around the edge and fill inward from the outside."
	shape := self findShapeAroundSeedBlock: [:f | f borderWidth: 1].
	"Reverse so that this becomes solid in the middle"
	shape := shape reverse.
	"Finally erase any bits from the original so the fill is only elsewhere"
	shape copy: shape boundingBox from: self to: 0@0 rule: Form erase.
	^ shape! !

!Form methodsFor: 'processing' stamp: 'tfel 4/17/2015 14:12'!
approxGaussianBlur

	^ self processUsingKernel: (Matrix rows: 3 columns: 3 contents: #(
		 1 2 1
		 2 4 2
		 1 2 1
	) *  0.0625)! !

!Form methodsFor: 'converting' stamp: 'jm 11/12/97 19:28'!
as8BitColorForm
	"Simple conversion of zero pixels to transparent.  Force it to 8 bits."

	| f map |
	f := ColorForm extent: self extent depth: 8.
	self displayOn: f at: self offset negated.
	map := Color indexedColors copy.
	map at: 1 put: Color transparent.
	f colors: map.
	f offset: self offset.
	^ f
! !

!Form methodsFor: 'converting' stamp: 'RAA 8/14/2000 10:13'!
asCursorForm

	^ self as: StaticForm! !

!Form methodsFor: 'converting' stamp: 'tpr 11/13/2015 15:38'!
asFormOfDepth: d
	"Create a copy of me with depth 'd'. Includes a correction for some bitmaps that when imported have poorly set up transparency"
	| newForm |
	d = self depth ifTrue:[^self].
	newForm := Form extent: self extent depth: d.
	(BitBlt toForm: newForm)
		colorMap: (self colormapIfNeededFor: newForm);
		copy: (self boundingBox)
		from: 0@0 in: self
		fillColor: nil rule: Form over.
	"Special case: For a 16 -> 32 bit conversion fill the alpha channel because it gets lost in translation."
	d = 32 ifTrue:[newForm fixAlpha].
	^newForm! !

!Form methodsFor: 'converting' stamp: 'lpc 5/19/2016 10:35'!
asGrayScale
	"Assume the receiver is a grayscale image. Return a grayscale ColorForm computed by extracting the brightness levels of one color component. This technique allows a 32-bit Form to be converted to an 8-bit ColorForm to save space while retaining a full 255 levels of gray. (The usual colormapping technique quantizes to 8, 16, or 32 levels, which loses information.)"
	| f32 srcForm result map bb |
	self depth = 32 ifFalse: [
		f32 := Form extent: width@height depth: 32.
		self displayOn: f32.
		^ f32 asGrayScale].
	self unhibernate.
	srcForm := Form extent: (width * 4)@height depth: 8.
	srcForm bits: bits.
	result := ColorForm extent: width@height depth: 8.
	map := Bitmap new: 256.
	2 to: 256 do: [:i | map at: i put: i - 1].
	map at: 1 put: 1.  "map zero pixel values to near-black"
	bb := (BitBlt toForm: result)
		sourceForm: srcForm;
		combinationRule: Form over;
		colorMap: map.
	0 to: width - 1 do: [:dstX |
		bb  sourceRect: (((dstX * 4) + 2)@0 extent: 1@height);
			destOrigin: dstX@0;
			copyBits].

	"final BitBlt to zero-out pixels that were truely transparent in the original"
	map := Bitmap new: 512.
	map at: 1 put: 16rFF.
	(BitBlt toForm: result)
		sourceForm: self;
		sourceRect: self boundingBox;
		destOrigin: 0@0;
		combinationRule: Form erase;
		colorMap: map;
		copyBits.
	
	
	result colors: ColorForm grayScalePalette.
	^ result
! !

!Form methodsFor: 'converting' stamp: 'ar 2/7/2004 18:16'!
asSourceForm
	^self! !

!Form methodsFor: 'color mapping' stamp: 'ar 5/15/2001 16:16'!
balancedPatternFor: aColor
	"Return the pixel word for representing the given color on the receiver"
	self hasNonStandardPalette
		ifTrue:[^self bitPatternFor: aColor]
		ifFalse:[^aColor balancedPatternForDepth: self depth]! !

!Form methodsFor: 'editing' stamp: 'dtl 1/23/2010 18:28'!
bitEdit
	"Create and schedule a view located in an area designated by the user 
	that contains a view of the receiver magnified by 8@8 that can be 
	modified using the Bit Editor. It also contains a view of the original 
	form."

	Project current bitEdit: self
! !

!Form methodsFor: 'editing' stamp: 'dtl 1/23/2010 18:36'!
bitEditAt: magnifiedFormLocation scale: scaleFactor 
	"Create and schedule a view whose top left corner is magnifiedLocation 
	and that contains a view of the receiver magnified by scaleFactor that 
	can be modified using the Bit Editor. It also contains a view of the 
	original form."

	Project current bitEdit: self at: magnifiedFormLocation scale: scaleFactor 
! !

!Form methodsFor: 'filling' stamp: ''!
bitPatternForDepth: suspectedDepth
	"Only called when a Form is being used as a fillColor.  Use a Pattern or InfiniteForm instead for this purpose.
	Interpret me as an array of (32/depth) Color pixelValues.  BitBlt aligns the first element of this array with the top scanline of the destinationForm, the second with the second, and so on, cycling through the color array as necessary. 6/18/96 tk"

	^ self! !

!Form methodsFor: 'color mapping' stamp: 'ar 5/15/2001 16:16'!
bitPatternFor: aColor
	"Return the pixel word for representing the given color on the receiver"
	aColor isColor ifFalse:[^aColor bitPatternForDepth: self depth].
	self hasNonStandardPalette
		ifTrue:[^Bitmap with: (self pixelWordFor: aColor)]
		ifFalse:[^aColor bitPatternForDepth: self depth]! !

!Form methodsFor: 'accessing' stamp: ''!
bits
	"Answer the receiver's Bitmap containing its bits."

	^ bits! !

!Form methodsFor: 'postscript generation' stamp: 'ar 5/17/2001 15:36'!
bitsPerComponent
	^self depth <= 8 ifTrue:[self depth] ifFalse:[8].
! !

!Form methodsFor: 'accessing' stamp: 'ar 5/17/2001 15:41'!
bitsSize
	| pixPerWord |
	depth == nil ifTrue: [depth := 1].
	pixPerWord := 32 // self depth.
	^ width + pixPerWord - 1 // pixPerWord * height! !

!Form methodsFor: 'accessing' stamp: ''!
bits: aBitmap 
	"Reset the Bitmap containing the receiver's bits."

	bits := aBitmap! !

!Form methodsFor: 'copying' stamp: 'cmm 1/19/2012 20:24'!
blankCopyOf: aRectangle scaledBy: scale 
	^ self species
		extent: (aRectangle extent * scale) truncated
		depth: depth! !

!Form methodsFor: 'bordering' stamp: 'tpr 3/15/2013 12:22'!
borderFormOfWidth: borderWidth sharpCorners: sharpen
	"Smear this form around and then subtract the original to produce
	an outline.  If sharpen is true, then cause right angles to be outlined
	by right angles (takes an additional diagonal smears ANDed with both
	horizontal and vertical smears)."
	| smearForm bigForm smearPort all cornerForm cornerPort nbrs |
	self depth > 1 ifTrue: [self halt]. "Only meaningful for B/W forms."
	bigForm := self deepCopy.
	all := bigForm boundingBox.
	smearForm := Form extent: self extent.
	smearPort := BitBlt toForm: smearForm.
	sharpen ifTrue:
		[cornerForm := Form extent: self extent.
		cornerPort := BitBlt toForm: cornerForm].
	nbrs := (0@0) fourNeighbors.
	1 to: borderWidth do:
		[:i |  "Iterate to get several layers of 'skin'"
		nbrs do:
			[:d |  "Smear the self in 4 directions to grow each layer of skin"
			smearPort copyForm: bigForm to: d rule: Form under].
		sharpen ifTrue:
			["Special treatment to smear sharp corners"
			nbrs with: ((2 to: 5) collect: [:i2 | nbrs atWrap: i2]) do:
				[:d1 :d2 |
				"Copy corner points diagonally"
				cornerPort copyForm: bigForm to: d1+d2 rule: Form over.
				"But only preserve if there were dots on either side"
				cornerPort copyForm: bigForm to: d1+d1+d2 rule: Form and.
				cornerPort copyForm: bigForm to: d1+d2+d2 rule: Form and.
				smearPort copyForm: cornerForm to: 0@0 rule: Form under].
			].
		bigForm copy: all from: 0@0 in: smearForm rule: Form over.
		].
	"Now erase the original shape to obtain the outline"
	bigForm copy: all from: 0@0 in: self rule: Form erase.
	^ bigForm! !

!Form methodsFor: 'bordering' stamp: ''!
borderWidth: anInteger 
	"Set the width of the border for the receiver to be anInteger and paint it 
	using black as the border color."

	self border: self boundingBox width: anInteger fillColor: Color black! !

!Form methodsFor: 'bordering' stamp: ''!
borderWidth: anInteger color: aMask
	"Set the width of the border for the receiver to be anInteger and paint it 
	using aMask as the border color."

	self border: self boundingBox width: anInteger fillColor: aMask! !

!Form methodsFor: 'bordering' stamp: ''!
borderWidth: anInteger fillColor: aMask
	"Set the width of the border for the receiver to be anInteger and paint it 
	using aMask as the border color."

	self border: self boundingBox width: anInteger fillColor: aMask! !

!Form methodsFor: 'bordering' stamp: 'tpr 3/15/2013 12:22'!
border: rect width: borderWidth rule: rule fillColor: fillColor
        "Paint a border whose rectangular area is defined by rect. The
width of the border of each side is borderWidth. Uses fillColor for drawing
the border."
        | blt |
        blt := (BitBlt toForm: self) combinationRule: rule; fillColor: fillColor.
        blt sourceOrigin: 0@0.
        blt destOrigin: rect origin.
        blt width: rect width; height: borderWidth; copyBits.
        blt destY: rect corner y - borderWidth; copyBits.
        blt destY: rect origin y + borderWidth.
        blt height: rect height - borderWidth - borderWidth; width:
borderWidth; copyBits.
        blt destX: rect corner x - borderWidth; copyBits! !

!Form methodsFor: 'display box access' stamp: ''!
boundingBox
	^ Rectangle origin: 0 @ 0
			corner: width @ height! !

!Form methodsFor: 'postscript generation' stamp: 'mpw 11/14/1999 22:22'!
bytesPerRow
	^ self numComponents * self paddedWidth * self bitsPerComponent / 8.! !

!Form methodsFor: 'display box access' stamp: 'tk 3/9/97'!
center
	"Note that offset is ignored here.  Are we really going to embrace offset?  "
	^ (width @ height) // 2! !

!Form methodsFor: 'analyzing' stamp: 'nice 12/27/2009 03:10'!
cgForPixelValue: pv orNot: not
	"Return the center of gravity for all pixels of value pv.
	Note:  If orNot is true, then produce the center of gravity for all pixels
	that are DIFFERENT from the supplied (background) value"
	| xAndY |
	xAndY := (Array with: (self xTallyPixelValue: pv orNot: not)
					with: (self yTallyPixelValue: pv orNot: not)) collect:
		[:profile | | pixCount weighted |	"For both x and y profiles..."
		pixCount := 0.  weighted := 0.
		profile doWithIndex:
			[:t :i | pixCount := pixCount + t.
			weighted := weighted + (t*i)].
		pixCount = 0  "Produce average of nPixels weighted by coordinate"
			ifTrue: [0.0]
			ifFalse: [weighted asFloat / pixCount asFloat - 1.0]].

	^ xAndY first @ xAndY last
"
| f cg |
[Sensor anyButtonPressed] whileFalse:
	[f := Form fromDisplay: (Sensor cursorPoint extent: 50@50).
	cg := f cgForPixelValue: (Color black pixelValueForDepth: f depth) orNot: false.
	f displayAt: 0@0.
	Display fill: (cg extent: 2@2) fillColor: Color red].
	ScheduledControllers restore
"! !

!Form methodsFor: 'scaling, rotation' stamp: 'mt 4/19/2015 11:38'!
clippedToSize: aPoint
 	"Return a copy of this form that is clipped to the given size around the center."
	
	| newForm |
	newForm := self class extent: aPoint depth: depth.
	^ newForm copyBits: ((0@0 corner: aPoint) translateBy: (self extent - aPoint) // 2) from: self at: 0@0
		clippingBox: newForm boundingBox rule: Form over fillColor: nil! !

!Form methodsFor: 'converting' stamp: 'ar 3/28/2010 15:34'!
collectColors: aBlock
	"Create a new copy of the receiver with all the colors transformed by aBlock"
	^self collectPixels:[:pv|
		(aBlock value: (Color colorFromPixelValue: pv depth: self depth)) 
			pixelValueForDepth: self depth.
	].! !

!Form methodsFor: 'converting' stamp: 'ar 4/2/2010 22:35'!
collectPixels: aBlock
	"Create a new copy of the receiver with all the pixels transformed by aBlock"
	self depth = 32 ifFalse:[
		"Perform the operation in 32bpp"
		^((self asFormOfDepth: 32) collectPixels: aBlock) asFormOfDepth: self depth].
	self unhibernate. "ensure unhibernated before touching bits"
	^Form 
		extent: self extent 
		depth: self depth
		bits: (self bits collect: aBlock)! !

!Form methodsFor: 'pixel access' stamp: 'ar 5/17/2001 15:42'!
colorAt: aPoint
	"Return the color in the pixel at the given point.  "

	^ Color 
		colorFromPixelValue: (self pixelValueAt: aPoint)
		depth: self depth
! !

!Form methodsFor: 'pixel access' stamp: 'ar 5/14/2001 23:46'!
colorAt: aPoint put: aColor
	"Store a Color into the pixel at coordinate aPoint.  "

	self pixelValueAt: aPoint put: (self pixelValueFor: aColor).

"[Sensor anyButtonPressed] whileFalse:
	[Display colorAt: Sensor cursorPoint put: Color red]"
! !

!Form methodsFor: 'color mapping' stamp: 'ar 5/15/2001 16:16'!
colormapFromARGB
	"Return a ColorMap mapping from canonical ARGB space into the receiver.
	Note: This version is optimized for Squeak forms."
	| map nBits |
	self hasNonStandardPalette 
		ifTrue:[^ColorMap mappingFromARGB: self rgbaBitMasks].
	self depth <= 8 ifTrue:[
		map := Color colorMapIfNeededFrom: 32 to: self depth.
		map size = 512 ifTrue:[nBits := 3].
		map size = 4096 ifTrue:[nBits := 4].
		map size = 32768 ifTrue:[nBits := 5].
		^ColorMap
			shifts: (Array 
						with: 3 * nBits - 24
						with: 2 * nBits - 16
						with: 1 * nBits - 8
						with: 0)
			masks: (Array
						with: (1 << nBits) - 1 << (24 - nBits)
						with: (1 << nBits) - 1 << (16 - nBits)
						with: (1 << nBits) - 1 << (8 - nBits)
						with: 0)
			colors: map].
	self depth = 16 ifTrue:[
		^ColorMap
			shifts: #(-9 -6 -3 0)
			masks: #(16rF80000 16rF800 16rF8 0)].
	self depth = 32 ifTrue:[
		^ColorMap
			shifts: #(0 0 0 0)
			masks: #(16rFF0000 16rFF00 16rFF 16rFF000000)].
	self error:'Bad depth'! !

!Form methodsFor: 'color mapping' stamp: 'ar 5/17/2001 15:42'!
colormapIfNeededForDepth: destDepth
	"Return a colormap for displaying the receiver at the given depth, or nil if no colormap is needed."

	self depth = destDepth ifTrue: [^ nil].  "not needed if depths are the same"
	^ Color colorMapIfNeededFrom: self depth to: destDepth
! !

!Form methodsFor: 'color mapping' stamp: 'ar 5/16/2001 22:23'!
colormapIfNeededFor: destForm
	"Return a ColorMap mapping from the receiver to destForm."
	(self hasNonStandardPalette or:[destForm hasNonStandardPalette]) 
		ifTrue:[^self colormapFromARGB mappingTo: destForm colormapFromARGB]
		ifFalse:[^self colormapIfNeededForDepth: destForm depth]! !

!Form methodsFor: 'color mapping' stamp: 'ar 5/15/2001 16:16'!
colormapToARGB
	"Return a ColorMap mapping from the receiver into canonical ARGB space."
	self hasNonStandardPalette 
		ifTrue:[^self colormapFromARGB inverseMap].
	self depth <= 8 ifTrue:[
		^ColorMap
			shifts: #(0 0 0 0)
			masks: #(16rFF0000 16rFF00 16rFF 16rFF000000)
			colors: (Color colorMapIfNeededFrom: self depth to: 32)].
	self depth = 16 ifTrue:[
		^ColorMap 
			shifts: #( 9 6 3 0) 
			masks: #(16r7C00 16r3E0 16r1F 0)].
	self depth = 32 ifTrue:[
		^ColorMap
			shifts: #(0 0 0 0) 
			masks: #(16rFF0000 16rFF00 16rFF 16rFF000000)].
	self error:'Bad depth'! !

!Form methodsFor: 'converting' stamp: 'jm 4/5/1999 19:20'!
colorReduced
	"Return a color-reduced ColorForm version of the receiver, if possible, or the receiver itself if not."

	| tally tallyDepth colorCount newForm cm oldPixelValues newFormColors nextColorIndex c |
	tally := self tallyPixelValues asArray.
	tallyDepth := (tally size log: 2) asInteger.
	colorCount := 0.
	tally do: [:n | n > 0 ifTrue: [colorCount := colorCount + 1]].
	(tally at: 1) = 0 ifTrue: [colorCount := colorCount + 1].  "include transparent"
	colorCount > 256 ifTrue: [^ self].  "cannot reduce"
	newForm := self formForColorCount: colorCount.

	"build an array of just the colors used, and a color map to translate
	 old pixel values to their indices into this color array"
	cm := Bitmap new: tally size.
	oldPixelValues := self colormapIfNeededForDepth: 32.
	newFormColors := Array new: colorCount.
	newFormColors at: 1 put: Color transparent.
	nextColorIndex := 2.
	2 to: cm size do: [:i |
		(tally at: i) > 0 ifTrue: [
			oldPixelValues = nil
				ifTrue: [c := Color colorFromPixelValue: i - 1 depth: tallyDepth]
				ifFalse: [c := Color colorFromPixelValue: (oldPixelValues at: i) depth: 32].
			newFormColors at: nextColorIndex put: c.
			cm at: i put: nextColorIndex - 1.  "pixel values are zero-based indices"
			nextColorIndex := nextColorIndex + 1]].

	"copy pixels into new ColorForm, mapping to new pixel values"
	newForm copyBits: self boundingBox
		from: self
		at: 0@0
		clippingBox: self boundingBox
		rule: Form over
		fillColor: nil
		map: cm.
	newForm colors: newFormColors.
	newForm offset: offset.
	^ newForm
! !

!Form methodsFor: 'analyzing' stamp: 'jm 12/5/97 19:48'!
colorsUsed
	"Return a list of the Colors this form uses."

	| tallies tallyDepth usedColors |
	tallies := self tallyPixelValues.
	tallyDepth := (tallies size log: 2) asInteger.
	usedColors := OrderedCollection new.
	tallies doWithIndex: [:count :i |
		count > 0 ifTrue: [
			usedColors add: (Color colorFromPixelValue: i - 1 depth: tallyDepth)]].
	^ usedColors asArray
! !

!Form methodsFor: 'fileIn/Out' stamp: 'ar 2/24/2001 22:41'!
comeFullyUpOnReload: smartRefStream
	bits isForm ifFalse:[^self].
	"make sure the resource gets loaded afterwards"
	ResourceCollector current ifNil:[^self].
	ResourceCollector current noteResource: bits replacing: self.
! !

!Form methodsFor: 'display box access' stamp: ''!
computeBoundingBox
	^ Rectangle origin: 0 @ 0
			corner: width @ height! !

!Form methodsFor: 'copying' stamp: 'cmm 1/19/2012 20:31'!
contentsOfArea: aRect
 	"Return a new form which derives from the portion of the original form delineated by aRect."
	^self contentsOfArea: aRect 
		into: (self species extent: aRect extent depth: depth).! !

!Form methodsFor: 'copying' stamp: 'ar 6/9/2000 19:00'!
contentsOfArea: aRect into: newForm
 	"Return a new form which derives from the portion of the original form delineated by aRect."
	^ newForm copyBits: aRect from: self at: 0@0
		clippingBox: newForm boundingBox rule: Form over fillColor: nil! !

!Form methodsFor: 'filling' stamp: 'di 9/11/1998 16:25'!
convexShapeFill: aMask 
	"Fill the interior of the outtermost outlined region in the receiver.  The outlined region must not be concave by more than 90 degrees.  Typically aMask is Color black, to produce a solid fill. then the resulting form is used with fillShape: to paint a solid color.  See also anyShapeFill"
	| destForm tempForm |
	destForm := Form extent: self extent.  destForm fillBlack.
	tempForm := Form extent: self extent.
	(0@0) fourNeighbors do:
		[:dir |  "Smear self in all 4 directions, and AND the result"
		self displayOn: tempForm at: (0@0) - self offset.
		tempForm smear: dir distance: (dir dotProduct: tempForm extent) abs.
		tempForm displayOn: destForm at: 0@0
			clippingBox: destForm boundingBox
			rule: Form and fillColor: nil].
	destForm displayOn: self at: 0@0
		clippingBox: self boundingBox
		rule: Form over fillColor: aMask! !

!Form methodsFor: 'copying' stamp: 'tpr 3/15/2013 12:22'!
copyBits: sourceForm at: destOrigin translucent: factor
	"Make up a BitBlt table and copy the bits with the given colorMap."
	(BitBlt 
		destForm: self
		sourceForm: sourceForm
		halftoneForm: nil
		combinationRule: 30
		destOrigin: destOrigin
		sourceOrigin: 0@0
		extent: sourceForm extent
		clipRect: self boundingBox)
		copyBitsTranslucent: ((0 max: (factor*255.0) asInteger) min: 255)
"
 | f f2 f3 | f := Form fromUser. f2 := Form fromDisplay: (0@0 extent: f extent). f3 := f2 deepCopy.
0.0 to: 1.0 by: 1.0/32 do:
	[:t | f3 := f2 deepCopy. f3 copyBits: f at: 0@0 translucent: t.
	f3 displayAt: 0@0. (Delay forMilliseconds: 100) wait].
"! !

!Form methodsFor: 'copying' stamp: 'tpr 3/15/2013 12:23'!
copyBits: sourceRect from: sourceForm at: destOrigin clippingBox: clipRect rule: rule fillColor: aForm 
	"Make up a BitBlt table and copy the bits."

	(BitBlt 
		destForm: self
		sourceForm: sourceForm
		fillColor: aForm
		combinationRule: rule
		destOrigin: destOrigin
		sourceOrigin: sourceRect origin
		extent: sourceRect extent
		clipRect: clipRect) copyBits! !

!Form methodsFor: 'copying' stamp: 'tpr 3/15/2013 12:23'!
copyBits: sourceRect from: sourceForm at: destOrigin clippingBox: clipRect rule: rule fillColor: aForm map: map
	"Make up a BitBlt table and copy the bits.  Use a colorMap."

	((BitBlt 
		destForm: self
		sourceForm: sourceForm
		fillColor: aForm
		combinationRule: rule
		destOrigin: destOrigin
		sourceOrigin: sourceRect origin
		extent: sourceRect extent
		clipRect: clipRect) colorMap: map) copyBits! !

!Form methodsFor: 'copying' stamp: 'tpr 3/15/2013 12:23'!
copyBits: sourceRect from: sourceForm at: destOrigin colorMap: map 
	"Make up a BitBlt table and copy the bits with the given colorMap."
	((BitBlt 
		destForm: self
		sourceForm: sourceForm
		halftoneForm: nil
		combinationRule: Form over
		destOrigin: destOrigin
		sourceOrigin: sourceRect origin
		extent: sourceRect extent
		clipRect: self boundingBox) colorMap: map) copyBits! !

!Form methodsFor: 'converting' stamp: 'nice 12/27/2009 05:16'!
copyWithColorsReducedTo: nColors
	"Note: this has not been engineered.
	There are better solutions in the literature."
	| palette colorMap |
	palette := self reducedPaletteOfSize: nColors.
	colorMap := (1 to: (1 bitShift: depth)) collect:
		[:i | | pc closest |
		pc := Color colorFromPixelValue: i-1 depth: depth.
		closest := palette detectMin: [:c | c diff: pc].
		closest pixelValueForDepth: depth].
	^ self deepCopy copyBits: self boundingBox from: self at: 0@0 colorMap: (colorMap as: Bitmap)
		! !

!Form methodsFor: 'copying' stamp: 'cmm 1/19/2012 20:31'!
copy: aRect
 	"Return a new form which derives from the portion of the original form delineated by aRect."
	| newForm |
	newForm := self species extent: aRect extent depth: depth.
	^ newForm copyBits: aRect from: self at: 0@0
		clippingBox: newForm boundingBox rule: Form over fillColor: nil! !

!Form methodsFor: 'copying' stamp: 'tpr 3/15/2013 12:22'!
copy: destRectangle from: sourcePt in: sourceForm rule: rule 
	"Make up a BitBlt table and copy the bits."
	(BitBlt toForm: self)
		copy: destRectangle
		from: sourcePt in: sourceForm
		fillColor: nil rule: rule! !

!Form methodsFor: 'copying' stamp: ''!
copy: sourceRectangle from: sourceForm to: destPt rule: rule
	^ self copy: (destPt extent: sourceRectangle extent)
		from: sourceRectangle topLeft in: sourceForm rule: rule! !

!Form methodsFor: 'converting' stamp: 'ar 3/28/2010 15:35'!
darker
	"Answer a darker variant of this form."
	^self collectColors:[:color| color darker darker]! !

!Form methodsFor: 'postscript generation' stamp: 'ar 5/17/2001 15:39'!
decodeArray
	^self depth <= 8 ifTrue:['[1 0]'] ifFalse:['[0 1 0 1 0 1 ]'].
! !

!Form methodsFor: 'copying' stamp: 'nice 12/13/2013 21:26'!
deepCopy
	^self copy! !

!Form methodsFor: 'accessing' stamp: 'ar 5/28/2000 12:03'!
defaultCanvasClass
	"Return the default canvas used for drawing onto the receiver"
	^Display defaultCanvasClass! !

!Form methodsFor: 'accessing' stamp: 'ar 5/17/2001 15:45'!
depth
	^ depth < 0 ifTrue:[0-depth] ifFalse:[depth]! !

!Form methodsFor: 'accessing' stamp: ''!
depth: bitsPerPixel
	(bitsPerPixel > 32 or:
		[(bitsPerPixel bitAnd: bitsPerPixel-1) ~= 0])
		ifTrue: [self halt: 'bitsPerPixel must be 1, 2, 4, 8, 16 or 32'].
	depth := bitsPerPixel! !

!Form methodsFor: 'converting' stamp: 'ar 3/28/2010 15:35'!
dimmed
	"Answer a dimmed variant of this form."
	^self collectColors:[:color| (color alpha: (color alpha min: 0.2)) ]! !

!Form methodsFor: 'displaying' stamp: 'tpr 3/15/2013 12:40'!
displayInterpolatedIn: aRectangle on: aForm
	"Display the receiver on aForm, using interpolation if necessary.
		Form fromUser displayInterpolatedOn: Display.
	Note: When scaling we attempt to use bilinear interpolation based
	on the 3D engine. If the engine is not there then we use WarpBlt.
	"
	| engine adjustedR |
	self extent = aRectangle extent ifTrue:[^self displayOn: aForm at: aRectangle origin].
	engine := Smalltalk at: #B3DRenderEngine 
		ifPresent: [:engineClass | (engineClass defaultForPlatformOn: aForm)].
	engine ifNil:[
		"We've got no bilinear interpolation. Use WarpBlt instead"
		(WarpBlt toForm: aForm)
			sourceForm: self destRect: aRectangle;
			combinationRule: 3;
			cellSize: 2;
			warpBits.
		^self
	].

	"Otherwise use the 3D engine for our purposes"

	"there seems to be a slight bug in B3D which the following adjusts for"
	adjustedR := (aRectangle withRight: aRectangle right + 1) translateBy: 0@1.
	engine viewport: adjustedR.
	engine material: ((Smalltalk at: #B3DMaterial) new emission: Color white).
	engine texture: self.
	engine render: ((Smalltalk at: #B3DIndexedQuadMesh) new plainTextureRect).
	engine finish.! !

!Form methodsFor: 'displaying' stamp: 'tpr 3/15/2013 12:41'!
displayInterpolatedOn: aForm
	"Display the receiver on aForm, using interpolation if necessary.
		Form fromUser displayInterpolatedOn: Display.
	Note: When scaling we attempt to use bilinear interpolation based
	on the 3D engine. If the engine is not there then we use WarpBlt.
	"
	| engine |
	self extent = aForm extent ifTrue:[^self displayOn: aForm].
	engine := Smalltalk at: #B3DRenderEngine 
		ifPresent:[:engineClass| (engineClass defaultForPlatformOn: aForm)].
	engine ifNil:[
		"We've got no bilinear interpolation. Use WarpBlt instead"
		(WarpBlt toForm: aForm)
			sourceForm: self destRect: aForm boundingBox;
			combinationRule: 3;
			cellSize: 2;
			warpBits.
		^self
	].
	"Otherwise use the 3D engine for our purposes"
	engine viewport: aForm boundingBox.
	engine material: ((Smalltalk at: #B3DMaterial) new emission: Color white).
	engine texture: self.
	engine render: ((Smalltalk at: #B3DIndexedQuadMesh) new plainTextureRect).
	engine finish.! !

!Form methodsFor: 'displaying' stamp: ''!
displayOnPort: port at: location
	port copyForm: self to: location rule: Form over! !

!Form methodsFor: 'displaying' stamp: 'ar 5/14/2001 23:33'!
displayOn: aDisplayMedium at: aDisplayPoint clippingBox: clipRectangle rule: rule fillColor: aForm

	aDisplayMedium copyBits: self boundingBox
		from: self
		at: aDisplayPoint + self offset
		clippingBox: clipRectangle
		rule: rule
		fillColor: aForm
		map: (self colormapIfNeededFor: aDisplayMedium).
! !

!Form methodsFor: 'displaying' stamp: ''!
displayOn: aDisplayMedium transformation: displayTransformation clippingBox: clipRectangle align: alignmentPoint with: relativePoint rule: ruleInteger fillColor: aForm 
	"Graphically, it means nothing to scale a Form by floating point values.  
	Because scales and other display parameters are kept in floating point to 
	minimize round off errors, we are forced in this routine to round off to the 
	nearest integer."

	| absolutePoint scale magnifiedForm |
	absolutePoint := displayTransformation applyTo: relativePoint.
	absolutePoint := absolutePoint x asInteger @ absolutePoint y asInteger.
	displayTransformation noScale
		ifTrue: [magnifiedForm := self]
		ifFalse: 
			[scale := displayTransformation scale.
			scale := scale x @ scale y.
			(1@1 = scale)
					ifTrue: [scale := nil. magnifiedForm := self]
					ifFalse: [magnifiedForm := self magnify: self boundingBox by: scale]].
	magnifiedForm
		displayOn: aDisplayMedium
		at: absolutePoint - alignmentPoint
		clippingBox: clipRectangle
		rule: ruleInteger
		fillColor: aForm! !

!Form methodsFor: 'displaying' stamp: 'tpr 3/15/2013 12:41'!
displayResourceFormOn: aForm
	"a special display method for blowing up resource thumbnails"
	| engine tx cmap blitter |
	self extent = aForm extent ifTrue:[^self displayOn: aForm].
	engine := Smalltalk at: #B3DRenderEngine ifPresent:
		[:engineClass | engineClass defaultForPlatformOn: aForm].
	engine ifNil:[
		"We've got no bilinear interpolation. Use WarpBlt instead"
		(WarpBlt toForm: aForm)
			sourceForm: self destRect: aForm boundingBox;
			combinationRule: 3;
			cellSize: 2;
			warpBits.
		^self
	].
	tx := self asTexture.
	(blitter := BitBlt toForm: tx)
		sourceForm: self; destRect: aForm boundingBox;
		sourceOrigin: 0@0;
		combinationRule: Form paint.
	"map transparency to current World background color"
	(World color respondsTo: #pixelWordForDepth:) ifTrue: [
		cmap := Bitmap new: (self depth <= 8 ifTrue: [1 << self depth] ifFalse: [4096]).
		cmap at: 1 put: (tx pixelWordFor: World color).
		blitter colorMap: cmap.
	].
	blitter copyBits.
	engine viewport: aForm boundingBox.
	engine material: ((Smalltalk at: #B3DMaterial) new emission: Color white).
	engine texture: tx.
	engine render: ((Smalltalk at: #B3DIndexedQuadMesh) new plainTextureRect).
	engine finish.
	"the above, using bilinear interpolation doesn't leave transparent pixel values intact"
	(WarpBlt toForm: aForm)
		sourceForm: self destRect: aForm boundingBox;
		combinationRule: Form and;
		colorMap: (Color maskingMap: self depth);
		warpBits.! !

!Form methodsFor: 'displaying' stamp: 'tpr 3/15/2013 12:41'!
displayScaledOn: aForm
	"Display the receiver on aForm, scaling if necessary.
		Form fromUser displayScaledOn: Display.
	"
	self extent = aForm extent ifTrue:[^self displayOn: aForm].
	(WarpBlt toForm: aForm)
		sourceForm: self destRect: aForm boundingBox;
		combinationRule: Form paint;
		cellSize: 2;
		warpBits.! !

!Form methodsFor: 'accessing' stamp: 'ar 5/27/2000 16:56'!
displayScreen
	"Return the display screen the receiver is allocated on. 
	Forms in general are Squeak internal and not allocated on any particular display."
	^nil! !

!Form methodsFor: 'analyzing' stamp: 'ar 5/17/2001 15:40'!
dominantColor
	| tally max maxi |
	self depth > 16 ifTrue:
		[^(self asFormOfDepth: 16) dominantColor].
	tally := self tallyPixelValues.
	max := maxi := 0.
	tally withIndexDo: [:n :i | n > max ifTrue: [max := n. maxi := i]].
	^ Color colorFromPixelValue: maxi - 1 depth: self depth! !

!Form methodsFor: 'displaying' stamp: 'tpr 3/15/2013 12:24'!
drawLine: sourceForm from: beginPoint to: endPoint clippingBox: clipRect rule: anInteger fillColor: aForm 
	"Refer to the comment in 
	DisplayMedium|drawLine:from:to:clippingBox:rule:mask:." 
	
	| dotSetter |
	"set up an instance of BitBlt for display"
	dotSetter := BitBlt
		destForm: self
		sourceForm: sourceForm
		fillColor: aForm
		combinationRule: anInteger
		destOrigin: beginPoint
		sourceOrigin: 0 @ 0
		extent: sourceForm extent
		clipRect: clipRect.
	dotSetter drawFrom: beginPoint to: endPoint! !

!Form methodsFor: 'processing' stamp: 'tfel 4/17/2015 14:12'!
edgeDetect

	^ self processUsingKernel: (Matrix rows: 3 columns: 3 contents: #(
		-1 -1 -1
		-1  8 -1
		-1 -1 -1
	))! !

!Form methodsFor: 'editing' stamp: 'dtl 2/10/2010 14:00'!
edit
	"Open a form editor on this form. "
 
	Project current formEdit: self! !

!Form methodsFor: 'processing' stamp: 'tfel 4/17/2015 14:35'!
emboss

	^ self processUsingKernel: (Matrix rows: 3 columns: 3 contents: #(
		-2 -1  0
		-1  1  1
		 0  1  2
	))! !

!Form methodsFor: 'filling' stamp: 'tpr 3/15/2013 12:24'!
eraseShape: bwForm
	"use bwForm as a mask to clear all pixels where bwForm has 1's"
	((BitBlt destForm: self sourceForm: bwForm 
		fillColor: nil
		combinationRule: Form erase1bitShape	"Cut a hole in the picture with my mask"
		destOrigin: bwForm offset 
		sourceOrigin: 0@0
		extent: self extent clipRect: self boundingBox)
		colorMap: (Bitmap with: 0 with: 16rFFFFFFFF))
		copyBits.
! !

!Form methodsFor: 'accessing' stamp: ''!
extent
	^ width @ height! !

!Form methodsFor: 'transitions' stamp: 'Jb 11/19/2010 15:44'!
fadeImageCoarse: otherImage at: topLeft
	"Display fadeImageCoarse: (Form fromDisplay: (40@40 extent: 300@300)) reverse at: 40@40"
	| d pix|
	d := self depth.
	^ self fadeImage: otherImage at: topLeft indexAndMaskDo:
		[:i :mask | | j |
		i=1 ifTrue: [pix := (1 bitShift: d) - 1.
					1 to: 8//d-1 do: [:q | pix := pix bitOr: (pix bitShift: d*4)]]			.
		i <= 16 ifTrue:[
		j := i-1//4+1.
		(0 to: 28 by: 4) do: [:k |
			mask bits at: j+k
				put: (pix bitOr: (mask bits at: j+k))].
		true]
		ifFalse: [false]]! !

!Form methodsFor: 'transitions' stamp: 'Jb 11/19/2010 15:45'!
fadeImageFine: otherImage at: topLeft
	"Display fadeImageFine: (Form fromDisplay: (40@40 extent: 300@300)) reverse at: 40@40"
	| d pix|
	d := self depth.
	^ self fadeImage: otherImage at: topLeft indexAndMaskDo:
		[:i :mask | | j ii  |
		i=1 ifTrue: [pix := (1 bitShift: d) - 1.
					1 to: 8//d-1 do:
						[:q | pix := pix bitOr: (pix bitShift: d*4)]].
		i <= 16 ifTrue:
		[ii := #(0 10 2 8 7 13 5 15 1 11 3 9 6 12 4 14) at: i.
		j := ii//4+1.
		(0 to: 28 by: 4) do:
			[:k | mask bits at: j+k put:
				((mask bits at: j+k) bitOr: (pix))].
		true]
		ifFalse: [false]]! !

!Form methodsFor: 'transitions' stamp: ''!
fadeImageHorFine: otherImage at: topLeft
	"Display fadeImageHorFine: (Form fromDisplay: (10@10 extent: 300@300)) reverse at: 10@10"
	^ self fadeImage: otherImage at: topLeft indexAndMaskDo:
		[:i :mask |
		mask fill: (0@(i-1) extent: mask width@1) fillColor: Color black.
		mask fill: (0@(i-1+16) extent: mask width@1) fillColor: Color black.
		(i*2) <= mask width]! !

!Form methodsFor: 'transitions' stamp: ''!
fadeImageHor: otherImage at: topLeft
	"Display fadeImageHor: (Form fromDisplay: (10@10 extent: 300@300)) reverse at: 10@10"
	^ self fadeImage: otherImage at: topLeft indexAndMaskDo:
		[:i :mask |
		mask fill: (0@(mask height//2-i) extent: mask width@(i*2)) fillColor: Color black.
		(i*2) <= mask width]! !

!Form methodsFor: 'transitions' stamp: 'Jb 11/19/2010 16:29'!
fadeImageSquares: otherImage at: topLeft 
	"Display fadeImageSquares: (Form fromDisplay: (40@40 extent: 300@300)) reverse at: 40@40"
	^ self fadeImage: otherImage at: topLeft indexAndMaskDo:
		[:i :mask |
		mask fill: ((16-i) asPoint extent: (i*2) asPoint) fillColor: Color black.
		i <= 16]! !

!Form methodsFor: 'transitions' stamp: 'ar 5/17/2001 15:39'!
fadeImageVert: otherImage at: topLeft
	"Display fadeImageVert: (Form fromDisplay: (10@10 extent: 300@300)) reverse at: 10@10"
	| d |
	d := self depth.
	^ self fadeImage: otherImage at: topLeft indexAndMaskDo:
		[:i :mask |
		mask fill: ((mask width//2//d-i*d)@0 extent: i*2*d@mask height) fillColor: Color black.
		i <= (mask width//d)]! !

!Form methodsFor: 'transitions' stamp: 'Jb 11/19/2010 15:43'!
fadeImage: otherImage at: topLeft
	indexAndMaskDo: indexAndMaskBlock
	
	"This fade uses halftones as a blending hack.
	Zeros in the halftone produce the original image (self), and 
	ones in the halftone produce the 'otherImage'.
	IndexAndMaskBlock gets evaluated prior to each cycle,
	and the resulting boolean determines whether to continue cycling."
	| index imageRect maskForm resultForm pix returnPix|
	imageRect := otherImage boundingBox.
	resultForm := self copy: (topLeft extent: imageRect extent).
	maskForm := Form extent: 32@32.
	index := 0.

	[indexAndMaskBlock value: (index := index+1) value: maskForm]
	whileTrue:
		[maskForm reverse.
		resultForm copyBits: imageRect from: resultForm at: 0@0
			clippingBox: imageRect rule: Form over fillColor: maskForm.
		maskForm reverse.
		resultForm copyBits: imageRect from: otherImage at: 0@0
			clippingBox: imageRect rule: Form under fillColor: maskForm.
		self copyBits: imageRect from: resultForm at: topLeft
				clippingBox: self boundingBox rule: Form over fillColor: nil.
		Display forceDisplayUpdate]! !

!Form methodsFor: 'other' stamp: 'ar 4/30/2008 12:18'!
fillAlpha: alphaValue
	"Fill a 32bit form with a constant alpha value"
	| bb |
	self depth = 32 ifFalse:[^self error: 'Only valid for 32 bit forms'].
	bb := BitBlt toForm: self.
	bb combinationRule: 7. "bitOr:with:".
	bb fillColor: (Bitmap with: alphaValue << 24).
	bb copyBits.
! !

!Form methodsFor: 'filling' stamp: ''!
fillFromXColorBlock: colorBlock
	"Horizontal Gradient Fill.
	Supply relative x in [0.0 ... 1.0] to colorBlock,
	and paint each pixel with the color that comes back"
	| xRel |
	0 to: width-1 do:
		[:x |  xRel := x asFloat / (width-1) asFloat.
		self fill: (x@0 extent: 1@height) 
			fillColor: (colorBlock value: xRel)]
"
((Form extent: 100@100 depth: Display depth)
	fillFromXColorBlock: [:x | Color r: x g: 0.0 b: 0.5]) display
"! !

!Form methodsFor: 'filling' stamp: 'tpr 3/15/2013 12:25'!
fillFromXYColorBlock: colorBlock
	"General Gradient Fill.
	Supply relative x and y in [0.0 ... 1.0] to colorBlock,
	and paint each pixel with the color that comes back"
	| poker yRel xRel |
	poker := BitBlt bitPokerToForm: self.
	0 to: height-1 do:
		[:y | yRel := y asFloat / (height-1) asFloat.
		0 to: width-1 do:
			[:x |  xRel := x asFloat / (width-1) asFloat.
			poker pixelAt: x@y
				put: ((colorBlock value: xRel value: yRel) pixelWordForDepth: self depth)]]
"
 | d |
((Form extent: 100@20 depth: Display depth)
	fillFromXYColorBlock:
	[:x :y | d := 1.0 - (x - 0.5) abs - (y - 0.5) abs.
	Color r: d g: 0 b: 1.0-d]) display
"! !

!Form methodsFor: 'filling' stamp: ''!
fillFromYColorBlock: colorBlock
	"Vertical Gradient Fill.
	Supply relative y in [0.0 ... 1.0] to colorBlock,
	and paint each pixel with the color that comes back"
	| yRel |
	0 to: height-1 do:
		[:y |  yRel := y asFloat / (height-1) asFloat.
		self fill: (0@y extent: width@1) 
			fillColor: (colorBlock value: yRel)]
"
((Form extent: 100@100 depth: Display depth)
	fillFromYColorBlock: [:y | Color r: y g: 0.0 b: 0.5]) display
"! !

!Form methodsFor: 'filling' stamp: 'tpr 3/15/2013 12:25'!
fill: aRectangle rule: anInteger fillColor: aForm 
	"Replace a rectangular area of the receiver with the pattern described by aForm 
	according to the rule anInteger."
	(BitBlt toForm: self)
		copy: aRectangle
		from: 0@0 in: nil
		fillColor: aForm rule: anInteger! !

!Form methodsFor: 'filling' stamp: 'tpr 3/15/2013 12:25'!
findShapeAroundSeedBlock: seedBlock
	"Build a shape that is black in any region marked by seedBlock. 
	SeedBlock will be supplied a form, in which to blacken various
	pixels as 'seeds'.  Then the seeds are smeared until 
	there is no change in the smear when it fills the region, ie,
	when smearing hits a black border and thus goes no further."
	| smearForm previousSmear all count smearPort |
	self depth > 1 ifTrue: [self halt]. "Only meaningful for B/W forms."
	all := self boundingBox.
	smearForm := Form extent: self extent.
	smearPort := BitBlt toForm: smearForm.
	seedBlock value: smearForm.		"Blacken seeds to be smeared"
	smearPort copyForm: self to: 0 @ 0 rule: Form erase.  "Clear any in black"
	previousSmear := smearForm deepCopy.
	count := 1.
	[count = 10 and:   "check for no change every 10 smears"
		[count := 1.
		previousSmear copy: all from: 0 @ 0 in: smearForm rule: Form reverse.
		previousSmear isAllWhite]]
		whileFalse: 
			[smearPort copyForm: smearForm to: 1 @ 0 rule: Form under.
			smearPort copyForm: smearForm to: -1 @ 0 rule: Form under.
			"After horiz smear, trim around the region border"
			smearPort copyForm: self to: 0 @ 0 rule: Form erase.
			smearPort copyForm: smearForm to: 0 @ 1 rule: Form under.
			smearPort copyForm: smearForm to: 0 @ -1 rule: Form under.
			"After vert smear, trim around the region border"
			smearPort copyForm: self to: 0 @ 0 rule: Form erase.
			count := count + 1.
			count = 9 ifTrue: "Save penultimate smear for comparison"
				[previousSmear copy: all from: 0 @ 0 in: smearForm rule: Form over]].
	"Now paint the filled region in me with aHalftone"
	^ smearForm! !

!Form methodsFor: 'initialize-release' stamp: 'ar 5/26/2000 00:46'!
finish
	"If there are any pending operations on the receiver complete them. Do not return before all modifications have taken effect."! !

!Form methodsFor: 'other' stamp: 'ar 12/12/2003 18:24'!
fixAlpha
	"Fix the alpha channel if the receiver is 32bit"
	| bb |
	self depth = 32 ifFalse:[^self].
	bb := BitBlt toForm: self.
	bb combinationRule: 40 "fixAlpha:with:".
	bb copyBits.! !

!Form methodsFor: 'scaling, rotation' stamp: 'tpr 3/15/2013 12:41'!
flipBy: direction centerAt: aPoint
	"Return a copy of the receiver flipped either #vertical or #horizontal."
	| newForm quad |
	newForm := self class extent: self extent depth: depth.
	quad := self boundingBox innerCorners.
	quad := (direction = #vertical ifTrue: [#(2 1 4 3)] ifFalse: [#(4 3 2 1)])
		collect: [:i | quad at: i].
	(WarpBlt toForm: newForm)
		sourceForm: self;
		colorMap: (self colormapIfNeededFor: newForm);
		combinationRule: 3;
		copyQuad: quad toRect: newForm boundingBox.
	newForm offset: (self offset flipBy: direction centerAt: aPoint).
	^ newForm
"
[Sensor anyButtonPressed] whileFalse:
	[((Form fromDisplay: (Sensor cursorPoint extent: 130@66))
			flipBy: #vertical centerAt: 0@0) display]
"
"Consistency test...
 | f f2 p | [Sensor anyButtonPressed] whileFalse:
	[f := Form fromDisplay: ((p := Sensor cursorPoint) extent: 31@41).
	Display fillBlack: (p extent: 31@41).
	f2 := f flipBy: #vertical centerAt: 0@0.
	(f2 flipBy: #vertical centerAt: 0@0) displayAt: p]
"
! !

!Form methodsFor: 'converting' stamp: 'ar 3/22/2010 22:38'!
flipVertically
	"Flip the image along the y axis"
	| rowLen row topIndex botIndex |
	self unhibernate.
	rowLen := bits size // height.
	row := Bitmap new: rowLen.
	topIndex := 1.
	botIndex := bits size - rowLen + 1.
	1 to: height // 2 do: [:i |
		self assert:[topIndex+rowLen <= botIndex].
		row replaceFrom: 1 to: rowLen with: bits startingAt: topIndex.
		bits replaceFrom: topIndex to: topIndex+rowLen-1 with: bits startingAt: botIndex.
		bits replaceFrom: botIndex to: botIndex+rowLen-1 with: row startingAt: 1.
		topIndex := topIndex + rowLen.
		botIndex := botIndex - rowLen.
	].
! !

!Form methodsFor: 'filling' stamp: 'tpr 3/26/2013 11:11'!
floodFill2: aColor at: interiorPoint
	"Fill the shape (4-connected) at interiorPoint.  The algorithm is based on Paul Heckbert's 'A Seed Fill Algorithm', Graphic Gems I, Academic Press, 1990.
	NOTE: This is a less optimized variant for flood filling which is precisely along the lines of Heckbert's algorithm. For almost all cases #floodFill:at: will be faster (see the comment there) but this method is left in both as reference and as a fallback if such a strange case is encountered in reality."
	| poker stack old new x y top x1 x2 dy left goRight |
	poker := BitBlt bitPokerToForm: self.
	stack := OrderedCollection new: 50.
	"read old pixel value"
	old := self pixelValueAt: interiorPoint.
	"compute new value"
	new := self pixelValueFor: aColor.
	old = new ifTrue:[^self]. "no point, is there?!!"

	x := interiorPoint x.
	y := interiorPoint y.
	(y >= 0 and:[y < height]) ifTrue:[
		stack addLast: {y. x. x. 1}. "y, left, right, dy"
		stack addLast: {y+1. x. x. -1}].
	[stack isEmpty] whileFalse:[
		top := stack removeLast.
		y := top at: 1. x1 := top at: 2. x2 := top at: 3. dy := top at: 4.
		y := y + dy.
		"Segment of scanline (y-dy) for x1 <= x <= x2 was previously filled.
		Now explore adjacent pixels in scanline y."
		x := x1.
		[x >= 0 and:[(self pixelValueAt: x@y) = old]] whileTrue:[
			poker pixelAt: x@y put: new.
			x := x - 1].
		goRight := x < x1.
		left := x+1.
		(left < x1 and:[y-dy >= 0 and:[y-dy < height]]) 
			ifTrue:[stack addLast: {y. left. x1-1. 0-dy}].
		goRight ifTrue:[x := x1 + 1].
		[
			goRight ifTrue:[
				[x < width and:[(self pixelValueAt: x@y) = old]] whileTrue:[
					poker pixelAt: x@y put: new.
					x := x + 1].
				(y+dy >= 0 and:[y+dy < height]) 
					ifTrue:[stack addLast: {y. left. x-1. dy}].
				(x > (x2+1) and:[y-dy >= 0 and:[y-dy >= 0]]) 
					ifTrue:[stack addLast: {y. x2+1. x-1. 0-dy}]].
			[(x := x + 1) <= x2 and:[(self pixelValueAt: x@y) ~= old]] whileTrue.
			left := x.
			goRight := true.
		x <= x2] whileTrue.
	].
! !

!Form methodsFor: 'filling' stamp: 'di 10/20/2001 10:09'!
floodFillMapFrom: sourceForm to: scanlineForm mappingColorsWithin: dist to: centerPixVal
	"This is a helper routine for floodFill.  It's written for clarity (scanning the entire
	map using colors) rather than speed (which would require hacking rgb components
	in the nieghborhood of centerPixVal.  Note that some day a better proximity metric
	would be (h s v) where tolerance could be reduced in hue."

	| colorMap centerColor |
	scanlineForm depth = 32 ifFalse: [self error: 'depth 32 assumed'].
	"First get a modifiable identity map"
	colorMap := 	(Color cachedColormapFrom: sourceForm depth to: scanlineForm depth) copy.
	centerColor := Color colorFromPixelValue: (centerPixVal bitOr: 16rFFe6) depth: scanlineForm depth.
	"Now replace all entries that are close to the centerColor"
	1 to: colorMap size do:
		[:i | ((Color colorFromPixelValue: ((colorMap at: i) bitOr: 16rFFe6) depth: scanlineForm depth)
				diff: centerColor) <= dist ifTrue: [colorMap at: i put: centerPixVal]].
	^ colorMap! !

!Form methodsFor: 'filling' stamp: 'di 10/20/2001 22:03'!
floodFill: aColor at: interiorPoint
	Preferences areaFillsAreVeryTolerant ifTrue:
		[^ self floodFill: aColor at: interiorPoint tolerance: 0.2].
	Preferences areaFillsAreTolerant ifTrue:
		[^ self floodFill: aColor at: interiorPoint tolerance: 0.1].
	^ self floodFill: aColor at: interiorPoint tolerance: 0
! !

!Form methodsFor: 'filling' stamp: 'tpr 3/15/2013 12:26'!
floodFill: aColor at: interiorPoint tolerance: tolerance
	"Fill the shape (4-connected) at interiorPoint.  The algorithm is based on Paul Heckbert's 'A Seed Fill Algorithm', Graphic Gems I, Academic Press, 1990.
	NOTE (ar): This variant has been heavily optimized to prevent the overhead of repeated calls to BitBlt. Usually this is a really big winner but the runtime now depends a bit on the complexity of the shape to be filled. For extremely complex shapes (say, a Hilbert curve) with very few pixels to fill it can be slower than #floodFill2:at: since it needs to repeatedly read the source bits. However, in all practical cases I found this variant to be 15-20 times faster than anything else.
	Further note (di):  I have added a feature that allows this routine to fill areas of approximately constant color (such as  photos, scans, and jpegs).  It does this by computing a color map for the peeker that maps all colors close to 'old' into colors identical to old.  This mild colorblindness achieves the desired effect with no further change or degradation of the algorithm.  tolerance should be 0 (exact match), or a value corresponding to those returned by Color>>diff:, with 0.1 being a reasonable starting choice."

	| peeker poker stack old new x y top x1 x2 dy left goRight span spanBits w box debug |
	debug := false. "set it to true to see the filling process"
	box := interiorPoint extent: 1@1.
	span := Form extent: width@1 depth: 32.
	spanBits := span bits.

	peeker := BitBlt toForm: span.
	peeker 
		sourceForm: self; 
		combinationRule: 3; 
		width: width; 
		height: 1.

	"read old pixel value"
	peeker sourceOrigin: interiorPoint; destOrigin: interiorPoint x @ 0; width: 1; copyBits.
	old := spanBits at: interiorPoint x + 1.

	"compute new value (take care since the algorithm will fail if old = new)"
	new := self privateFloodFillValue: aColor.
	old = new ifTrue: [^ box].
	tolerance > 0 ifTrue:
		["Set up color map for approximate fills"
		peeker colorMap: (self floodFillMapFrom: self to: span mappingColorsWithin: tolerance to: old)].

	poker := BitBlt toForm: self.
	poker 
		fillColor: aColor;
		combinationRule: 3;
		width: width;
		height: 1.

	stack := OrderedCollection new: 50.
	x := interiorPoint x.
	y := interiorPoint y.
	(y >= 0 and:[y < height]) ifTrue:[
		stack addLast: {y. x. x. 1}. "y, left, right, dy"
		stack addLast: {y+1. x. x. -1}].

	[stack isEmpty] whileFalse:[
		debug ifTrue:[self displayOn: Display].
		top := stack removeLast.
		y := top at: 1. x1 := top at: 2. x2 := top at: 3. dy := top at: 4.
		y := y + dy.
		debug ifTrue:[
			Display 
				drawLine: (Form extent: 1@1 depth: 8) fillWhite
				from: (x1-1)@y to: (x2+1)@y 
				clippingBox: Display boundingBox
				rule: Form over fillColor: nil].
		"Segment of scanline (y-dy) for x1 <= x <= x2 was previously filled.
		Now explore adjacent pixels in scanline y."
		peeker sourceOrigin: 0@y; destOrigin: 0@0; width: width; copyBits.
			"Note: above is necessary since we don't know where we'll end up filling"
		x := x1.
		w := 0.
		[x >= 0 and:[(spanBits at: x+1) = old]] whileTrue:[
			w := w + 1.
			x := x - 1].
		w > 0 ifTrue:[
			"overwrite pixels"
			poker destOrigin: x+1@y; width: w; copyBits.
			box := box quickMerge: ((x+1@y) extent: w@1)].
		goRight := x < x1.
		left := x+1.
		(left < x1 and:[y-dy >= 0 and:[y-dy < height]]) 
			ifTrue:[stack addLast: {y. left. x1-1. 0-dy}].
		goRight ifTrue:[x := x1 + 1].
		[
			goRight ifTrue:[
				w := 0.
				[x < width and:[(spanBits at: x+1) = old]] whileTrue:[
					w := w + 1.
					x := x + 1].
				w > 0 ifTrue:[
					"overwrite pixels"
					poker destOrigin: (x-w)@y; width: w; copyBits.
					box := box quickMerge: ((x-w@y) extent: w@1)].
				(y+dy >= 0 and:[y+dy < height]) 
					ifTrue:[stack addLast: {y. left. x-1. dy}].
				(x > (x2+1) and:[y-dy >= 0 and:[y-dy >= 0]]) 
					ifTrue:[stack addLast: {y. x2+1. x-1. 0-dy}]].
			[(x := x + 1) <= x2 and:[(spanBits at: x+1) ~= old]] whileTrue.
			left := x.
			goRight := true.
		x <= x2] whileTrue.
	].
	^box! !

!Form methodsFor: 'initialize-release' stamp: 'ar 5/26/2000 00:45'!
flush
	"If there are any pending operations on the receiver start doing them. In time, they will show up on the receiver but not necessarily immediately after this method returns."! !

!Form methodsFor: 'accessing' stamp: ''!
form
	"Answer the receiver's form.  For vanilla Forms, this degenerates to self.  Makes several methods that operate on both Forms and MaskedForms much more straightforward.   6/1/96 sw"

	^ self! !

!Form methodsFor: 'other' stamp: 'jm 9/27/97 21:02'!
formForColorCount: colorCount
	"Return a ColorForm of sufficient depth to represent the given number of colors. The maximum number of colors is 256."

	colorCount > 256 ifTrue: [^ self error: 'too many colors'].

	colorCount > 16 ifTrue: [^ ColorForm extent: self extent depth: 8].
	colorCount > 4 ifTrue: [^ ColorForm extent: self extent depth: 4].
	colorCount > 2 ifTrue: [^ ColorForm extent: self extent depth: 2].
	^ ColorForm extent: self extent depth: 1
! !

!Form methodsFor: 'initialize-release' stamp: ''!
fromDisplay: aRectangle 
	"Create a virtual bit map from a user specified rectangular area on the 
	display screen. Reallocates bitmap only if aRectangle ~= the receiver's 
	extent."

	(width = aRectangle width and: [height = aRectangle height])
		ifFalse: [self setExtent: aRectangle extent depth: depth].
	self
		copyBits: (aRectangle origin extent: self extent)
		from: Display
		at: 0 @ 0
		clippingBox: self boundingBox
		rule: Form over
		fillColor: nil! !

!Form methodsFor: 'accessing' stamp: 'ar 5/28/2000 12:03'!
getCanvas
	"Return a Canvas that can be used to draw onto the receiver"
	^self defaultCanvasClass on: self! !

!Form methodsFor: 'private' stamp: 'tk 3/13/2000 15:21'!
hackBits: bitThing
	"This method provides an initialization so that BitBlt may be used, eg, to 
	copy ByteArrays and other non-pointer objects efficiently.
	The resulting form looks 4 wide, 8 deep, and bitThing-size-in-words high."
	width := 4.
	depth := 8.
	bitThing class isBits ifFalse: [self error: 'bitThing must be a non-pointer object'].
	bitThing class isBytes
		ifTrue: [height := bitThing basicSize // 4]
		ifFalse: [height := bitThing basicSize].
	bits := bitThing! !

!Form methodsFor: 'accessing' stamp: 'ar 5/28/2000 00:48'!
hasBeenModified
	"Return true if something *might* have been drawn into the receiver"
	^(bits == nil or:[bits class == ByteArray]) not
	"Read the above as: If the receiver has forgotten its contents (bits == nil) 
	or is still hibernated it can't be modified."! !

!Form methodsFor: 'accessing' stamp: 'ar 5/28/2000 00:48'!
hasBeenModified: aBool
	"Change the receiver to reflect the modification state"
	aBool ifTrue:[^self unhibernate].
	self shouldPreserveContents
		ifTrue:[self hibernate]
		ifFalse:[bits := nil]! !

!Form methodsFor: 'testing' stamp: 'ar 5/15/2001 16:14'!
hasNonStandardPalette
	"Return true if the receiver has a non-standard palette.
	Non-standard means that RGBA components may be located
	at positions differing from the standard Squeak RGBA layout
	at the receiver's depth."
	^false! !

!Form methodsFor: 'display box access' stamp: ''!
height
	^ height! !

!Form methodsFor: 'fileIn/Out' stamp: 'di 8/5/1998 11:37'!
hibernate
	"Replace my bitmap with a compactly encoded representation (a ByteArray).  It is vital that BitBlt and any other access to the bitmap (such as writing to a file) not be used when in this state.  Since BitBlt will fail if the bitmap size is wrong (not = bitsSize), we do not allow replacement by a byteArray of the same (or larger) size."

	"NOTE: This method copies code from Bitmap compressToByteArray so that it can
	nil out the old bits during the copy, thus avoiding 2x need for extra storage."
	| compactBits lastByte |
	(bits isMemberOf: Bitmap) ifFalse: [^ self  "already hibernated or weird state"].
	compactBits := ByteArray new: (bits size*4) + 7 + (bits size//1984*3).
	lastByte := bits compress: bits toByteArray: compactBits.
	lastByte < (bits size*4) ifTrue:
		[bits := nil.  "Let GC reclaim the old bits before the copy if necessary"
		bits := compactBits copyFrom: 1 to: lastByte]! !

!Form methodsFor: 'private' stamp: ''!
initFromArray: array
	"Fill the bitmap from array.  If the array is shorter,
	then cycle around in its contents until the bitmap is filled."
	| ax aSize array32 i j word16 |
	ax := 0.
	aSize := array size.
	aSize > bits size ifTrue:
		["backward compatibility with old 16-bit bitmaps and their forms"
		array32 := Array new: height * (width + 31 // 32).
		i := j := 0.
		1 to: height do:
			[:y | 1 to: width+15//16 do:
				[:x16 | word16 := array at: (i := i + 1).
				x16 odd ifTrue: [array32 at: (j := j+1) put: (word16 bitShift: 16)]
						ifFalse: [array32 at: j put: ((array32 at: j) bitOr: word16)]]].
		^ self initFromArray: array32].
	1 to: bits size do:
		[:index |
		(ax := ax + 1) > aSize ifTrue: [ax := 1].
		bits at: index put: (array at: ax)]! !

!Form methodsFor: 'analyzing' stamp: ''!
innerPixelRectFor: pv orNot: not
	"Return a rectangle describing the smallest part of me that includes 
	all pixels of value pv.
	Note:  If orNot is true, then produce a copy that includes all pixels
	that are DIFFERENT from the supplied (background) value"

	| xTally yTally |
	xTally := self xTallyPixelValue: pv orNot: not.
	yTally := self yTallyPixelValue: pv orNot: not.
	^ ((xTally findFirst: [:t | t>0]) - 1) @ ((yTally findFirst: [:t | t>0]) - 1)
		corner:
			(xTally findLast: [:t | t>0])@(yTally findLast: [:t | t>0])! !

!Form methodsFor: 'testing' stamp: 'ar 7/21/2007 21:37'!
isAllWhite
	"Answer whether all bits in the receiver are white"
	| word |
	self unhibernate.
	word := Color white pixelWordForDepth: self depth.
	1 to: bits size do: [:i | (bits at: i) = word ifFalse: [^ false]].
	^ true! !

!Form methodsFor: 'testing' stamp: 'ar 5/17/2001 15:46'!
isBigEndian
	"Return true if the receiver contains big endian pixels, meaning the left-most pixel is stored in the most significant bits of a word."
	^depth > 0! !

!Form methodsFor: 'testing' stamp: 'ar 5/28/2000 14:58'!
isBltAccelerated: ruleInteger for: sourceForm
	"Return true if the receiver can perform accelerated blts operations by itself"
	^false! !

!Form methodsFor: 'testing' stamp: 'ar 5/28/2000 15:04'!
isDisplayScreen
	^false! !

!Form methodsFor: 'testing' stamp: 'ar 5/27/2000 16:54'!
isExternalForm
	^false! !

!Form methodsFor: 'testing' stamp: 'ar 5/28/2000 14:58'!
isFillAccelerated: ruleInteger for: aColor
	"Return true if the receiver can perform accelerated fill operations by itself"
	^false! !

!Form methodsFor: 'testing' stamp: 'ar 10/30/2000 23:23'!
isForm
	^true! !

!Form methodsFor: 'testing' stamp: 'lpc 6/8/2016 11:35'!
isGrayScale
	^ false! !

!Form methodsFor: 'testing' stamp: 'ar 5/17/2001 15:47'!
isLittleEndian
	"Return true if the receiver contains little endian pixels, meaning the left-most pixel is stored in the least significant bits of a word."
	^depth < 0! !

!Form methodsFor: 'testing' stamp: 'RAA 8/14/2000 10:00'!
isStatic

	^false! !

!Form methodsFor: 'testing' stamp: 'ar 2/10/2004 17:18'!
isTranslucent
	"Answer whether this form may be translucent"
	^self depth = 32! !

!Form methodsFor: 'pixel access' stamp: 'ar 5/17/2001 15:39'!
isTransparentAt: aPoint 
	"Return true if the receiver is transparent at the given point."

	self depth = 1 ifTrue: [^ false].  "no transparency at depth 1"
	^ (self pixelValueAt: aPoint) = (self pixelValueFor: Color transparent)
! !

!Form methodsFor: 'converting' stamp: 'ar 3/28/2010 15:35'!
lighter
	"Answer a lighter variant of this form"
	^self collectColors:[:color| color lighter lighter].! !

!Form methodsFor: 'scaling, rotation' stamp: 'tpr 9/28/2004 17:00'!
magnifyBy: scale 
	"Answer a Form created as a scaling of the receiver.
	Scale may be a Float or even a Point, and may be greater or less than 1.0."

	^ self magnify: self boundingBox by: scale
			smoothing: (scale < 1 ifTrue: [2] ifFalse: [1])! !

!Form methodsFor: 'scaling, rotation' stamp: ''!
magnify: aRectangle by: scale 
	"Answer a Form created as a scaling of the receiver.
	Scale may be a Float, and may be greater or less than 1.0."
	^ self magnify: aRectangle by: scale smoothing: 1

"Dynamic test...
[Sensor anyButtonPressed] whileFalse:
	[(Display magnify: (Sensor cursorPoint extent: 31@41) by: 5@3) display]
"
"Scaling test...
| f cp | f := Form fromDisplay: (Rectangle originFromUser: 100@100).
Display restoreAfter: [Sensor waitNoButton.
[Sensor anyButtonPressed] whileFalse:
	[cp := Sensor cursorPoint.
	(f magnify: f boundingBox by: (cp x asFloat@cp y asFloat)/f extent) display]]
"
"Consistency test...
 | f f2 p | [Sensor anyButtonPressed] whileFalse:
	[f := Form fromDisplay: ((p := Sensor cursorPoint) extent: 31@41).
	Display fillBlack: (p extent: 31@41).
	f2 := f magnify: f boundingBox by: 5@3.
	(f2 shrink: f2 boundingBox by: 5@3) displayAt: p]
"
! !

!Form methodsFor: 'scaling, rotation' stamp: 'tpr 3/15/2013 12:41'!
magnify: aRectangle by: scale smoothing: cellSize
        "Answer a Form created as a scaling of the receiver.
        Scale may be a Float or even a Point, and may be greater or less than 1.0."
        | newForm |
        newForm := self blankCopyOf: aRectangle scaledBy: scale.
        (WarpBlt toForm: newForm)
                sourceForm: self;
                colorMap: (self colormapIfNeededFor: newForm);
                cellSize: cellSize;  "installs a new colormap if cellSize > 1"
                combinationRule: 3;
                copyQuad: aRectangle innerCorners toRect: newForm boundingBox.
        ^ newForm

"Dynamic test...
[Sensor anyButtonPressed] whileFalse:
        [(Display magnify: (Sensor cursorPoint extent: 131@81) by: 0.5 smoothing: 2) display]
"
"Scaling test...
| f cp | f := Form fromDisplay: (Rectangle originFromUser: 100@100).
Display restoreAfter: [Sensor waitNoButton.
[Sensor anyButtonPressed] whileFalse:
        [cp := Sensor cursorPoint.
        (f magnify: f boundingBox by: (cp x asFloat@cp y asFloat)/f extent smoothing: 2) display]]
"! !

!Form methodsFor: 'color mapping' stamp: ''!
makeBWForm: foregroundColor
	"Map this form into a B/W form with 1's in the foreground regions."
	| bwForm map |
	bwForm := Form extent: self extent.
	map := self newColorMap.  "All non-foreground go to 0's"
	map at: (foregroundColor indexInMap: map) put: 1.
	bwForm copyBits: self boundingBox from: self at: 0@0 colorMap: map.
	^ bwForm! !

!Form methodsFor: 'color mapping' stamp: 'tpr 3/15/2013 12:26'!
mapColors: oldColorBitsCollection to: newColorBits
	"Make all pixels of the given color in this Form to the given new color."
	"Warnings: This method modifies the receiver. It may lose some color accuracy on 32-bit Forms, since the transformation uses a color map with only 15-bit resolution."

	| map |
	self depth < 16
		ifTrue: [map := (Color cachedColormapFrom: self depth to: self depth) copy]
		ifFalse: [
			"use maximum resolution color map"
			"source is 16-bit or 32-bit RGB; use colormap with 5 bits per color component"
			map := Color computeRGBColormapFor: self depth bitsPerColor: 5].
	oldColorBitsCollection do:[ :oldColor | map at: oldColor put: newColorBits].

	(BitBlt toForm: self)
		sourceForm: self;
		sourceOrigin: 0@0;
		combinationRule: Form over;
		destX: 0 destY: 0 width: width height: height;
		colorMap: map;
		copyBits.
! !

!Form methodsFor: 'color mapping' stamp: 'tpr 3/15/2013 12:26'!
mapColor: oldColor to: newColor
	"Make all pixels of the given color in this Form to the given new color."
	"Warnings: This method modifies the receiver. It may lose some color accuracy on 32-bit Forms, since the transformation uses a color map with only 15-bit resolution."

	| map |
	map := (Color cachedColormapFrom: self depth to: self depth) copy.
	map at: (oldColor indexInMap: map) put: (newColor pixelWordForDepth: self depth).
	(BitBlt toForm: self)
		sourceForm: self;
		sourceOrigin: 0@0;
		combinationRule: Form over;
		destX: 0 destY: 0 width: width height: height;
		colorMap: map;
		copyBits.
! !

!Form methodsFor: 'color mapping' stamp: 'ar 12/14/2001 18:11'!
maskingMap
	"Return a color map that maps all colors except transparent to words of all ones. Used to create a mask for a Form whose transparent pixel value is zero."
	^Color maskingMap: self depth! !

!Form methodsFor: 'accessing' stamp: 'ar 5/17/2001 15:50'!
nativeDepth
	"Return the 'native' depth of the receiver, e.g., including the endianess"
	^depth! !

!Form methodsFor: 'color mapping' stamp: 'ar 5/17/2001 15:41'!
newColorMap 
	"Return an uninitialized color map array appropriate to this Form's depth."

	^ Bitmap new: (1 bitShift: (self depth min: 15))
! !

!Form methodsFor: 'postscript generation' stamp: 'ar 5/17/2001 15:43'!
numComponents
	^self depth <= 8 ifTrue:[1] ifFalse:[3].
! !

!Form methodsFor: 'fileIn/Out' stamp: 'ar 3/3/2001 16:16'!
objectForDataStream: refStream
	| prj repl |
	prj := refStream project.
	prj ifNil:[^super objectForDataStream: refStream].
	ResourceCollector current ifNil:[^super objectForDataStream: refStream].
	repl := ResourceCollector current objectForDataStream: refStream fromForm: self.
	^repl! !

!Form methodsFor: 'accessing' stamp: 'ar 2/16/2000 22:00'!
offset
	^offset ifNil:[0@0]! !

!Form methodsFor: 'accessing' stamp: ''!
offset: aPoint

	offset := aPoint! !

!Form methodsFor: 'converting' stamp: 'ar 7/23/1999 17:04'!
orderedDither32To16
	"Do an ordered dithering for converting from 32 to 16 bit depth."
	| ditherMatrix ii out inBits outBits index pv dmv r di dmi dmo g b pvOut outIndex |
	self depth = 32 ifFalse:[^self error:'Must be 32bit for this'].
	ditherMatrix := #(	0	8	2	10
						12	4	14	6
						3	11	1	9
						15	7	13	5).
	ii := (0 to: 31) collect:[:i| i].
	out := Form extent: self extent depth: 16.
	inBits := self bits.
	outBits := out bits.
	index := outIndex := 0.
	pvOut := 0.
	0 to: self height-1 do:[:y|
		0 to: self width-1 do:[:x|
			pv := inBits at: (index := index + 1).
			dmv := ditherMatrix at: (y bitAnd: 3) * 4 + (x bitAnd: 3) + 1.
			r := pv bitAnd: 255.	di := r * 496 bitShift: -8.
			dmi := di bitAnd: 15.	dmo := di bitShift: -4.
			r := dmv < dmi ifTrue:[ii at: 2+dmo] ifFalse:[ii at: 1+dmo].
			g := (pv bitShift: -8) bitAnd: 255.	di := g * 496 bitShift: -8.
			dmi := di bitAnd: 15.	dmo := di bitShift: -4.
			g := dmv < dmi ifTrue:[ii at: 2+dmo] ifFalse:[ii at: 1+dmo].
			b := (pv bitShift: -16) bitAnd: 255.	di := b * 496 bitShift: -8.
			dmi := di bitAnd: 15.	dmo := di bitShift: -4.
			b := dmv < dmi ifTrue:[ii at: 2+dmo] ifFalse:[ii at: 1+dmo].
			pvOut := (pvOut bitShift: 16) + 
						(b bitShift: 10) + (g bitShift: 5) + r.
			(x bitAnd: 1) = 1 ifTrue:[
				outBits at: (outIndex := outIndex+1) put: pvOut.
				pvOut := 0].
		].
		(self width bitAnd: 1) = 1 ifTrue:[
			outBits at: (outIndex := outIndex+1) put: (pvOut bitShift: -16).
			pvOut := 0].
	].
	^out! !

!Form methodsFor: 'postscript generation' stamp: ''!
paddedWidth
	^ (self width + (self rowPadding-1)// self rowPadding) * self rowPadding.! !

!Form methodsFor: 'transitions' stamp: 'nice 12/29/2010 14:46'!
pageImage: otherImage at: topLeft corner: corner
	"Produce a page-turning illusion that gradually reveals otherImage
	located at topLeft in this form.  Corner specifies which corner, as
		1=topLeft, 2=topRight, 3=bottomRight, 4=bottomLeft."
	| bb maskForm resultForm delta maskLoc maskRect stepSize cornerSel smallRect |
	stepSize := 10.
	bb := otherImage boundingBox.
	resultForm := self copy: (topLeft extent: bb extent).
	maskForm := Form extent: ((otherImage width min: otherImage height) + stepSize) asPoint.

	"maskLoc := starting loc rel to topLeft"
	otherImage width > otherImage height
		ifTrue: ["wide image; motion is horizontal."
				(corner between: 2 and: 3) not ifTrue:
					["motion is to the right"
					delta := 1 @ 0.
					maskLoc := bb topLeft - (corner = 1
						ifTrue: [maskForm width @ 0]
						ifFalse: [maskForm width @ stepSize])]
					ifFalse:
					["motion is to the left"
					delta := -1 @ 0.
					maskLoc := bb topRight - (corner = 2
						ifTrue: [0 @ 0]
						ifFalse: [0 @ stepSize])]]
		ifFalse: ["tall image; motion is vertical."
				corner <= 2 ifTrue:
					["motion is downward"
					delta := 0 @ 1.
					maskLoc := bb topLeft - (corner = 1
						ifTrue: [0 @ maskForm height]
						ifFalse: [stepSize @ maskForm height])]
					ifFalse:
					["motion is upward"
					delta := 0 @ -1.
					maskLoc := bb bottomLeft - (corner = 3
						ifTrue: [stepSize @ 0]
						ifFalse: [0 @ 0])]].

	"Build a solid triangle in the mask form"
	(Pen newOnForm: maskForm) in: [:p |
		corner even  "Draw 45-degree line"
			ifTrue: [p place: 0 @ 0; turn: 135; go: maskForm width * 3 // 2]
			ifFalse: [p place: 0 @ (maskForm height - 1); turn: 45; go: maskForm width * 3 // 2]].
	maskForm smear: delta negated distance: maskForm width.
	"Copy the mask to full resolution for speed.  Make it be the reversed
	so that it can be used for ORing in the page-corner color"
	maskForm := (Form extent: maskForm extent depth: otherImage depth)
		copyBits: maskForm boundingBox from: maskForm at: 0 @ 0
		colorMap: (Bitmap with: 16rFFFFFFFF with: 0).

	"Now move the triangle maskForm across the resultForm selecting the
	triangular part of otherImage to display, and across the resultForm,
	selecting the part of the original image to erase."
	cornerSel := #(topLeft topRight bottomRight bottomLeft) at: corner.
	1 to: (otherImage width + otherImage height // stepSize) + 1 do:
		[:i |		"Determine the affected square"
		maskRect := (maskLoc extent: maskForm extent) intersect: bb.
		((maskLoc x * delta x) + (maskLoc y * delta y)) < 0 ifTrue:
			[smallRect := 0 @ 0 extent: (maskRect width min: maskRect height) asPoint.
			maskRect := smallRect align: (smallRect perform: cornerSel)
								with: (maskRect perform: cornerSel)].

		"AND otherForm with triangle mask, and OR into result"
		resultForm copyBits: bb from: otherImage at: 0 @ 0
				clippingBox: maskRect rule: Form over fillColor: nil.
		resultForm copyBits: maskForm boundingBox from: maskForm at: maskLoc
				clippingBox: maskRect rule: Form erase fillColor: nil.
		resultForm copyBits: maskForm boundingBox from: maskForm at: maskLoc
				clippingBox: maskRect rule: Form under fillColor: Color lightBrown.

		"Now update Display in a single BLT."
		self copyBits: maskRect from: resultForm at: topLeft + maskRect topLeft
				clippingBox: self boundingBox rule: Form over fillColor: nil.
		Display forceDisplayUpdate.
		maskLoc := maskLoc + (delta * stepSize)]
"
1 to: 4 do: [:corner | Display pageImage:
				(Form fromDisplay: (10@10 extent: 200@300)) reverse
			at: 10@10 corner: corner]
"
! !

!Form methodsFor: 'transitions' stamp: 'tpr 3/15/2013 12:42'!
pageWarp: otherImage at: topLeft forward: forward
	"Produce a page-turning illusion that gradually reveals otherImage
	located at topLeft in this form.
	forward == true means turn pages toward you, else away. [ignored for now]"
	| pageRect oldPage nSteps buffer p leafRect sourceQuad warp oldBottom d |
	pageRect := otherImage boundingBox.
	oldPage := self copy: (pageRect translateBy: topLeft).
	(forward ifTrue: [oldPage] ifFalse: [otherImage])
		border: pageRect
		widthRectangle: (Rectangle
				left: 0
				right: 2
				top: 1
				bottom: 1)
		rule: Form over
		fillColor: Color black.
	oldBottom := self copy: ((pageRect bottomLeft + topLeft) extent: (pageRect width@(pageRect height//4))).
	nSteps := 8.
	buffer := Form extent: otherImage extent + (0@(pageRect height//4)) depth: self depth.
	d := pageRect topLeft + (0@(pageRect height//4)) - pageRect topRight.
	1 to: nSteps-1 do:
		[:i | forward
			ifTrue: [buffer copy: pageRect from: otherImage to: 0@0 rule: Form over.
					p := pageRect topRight + (d * i // nSteps)]
			ifFalse: [buffer copy: pageRect from: oldPage to: 0@0 rule: Form over.
					p := pageRect topRight + (d * (nSteps-i) // nSteps)].
		buffer copy: oldBottom boundingBox from: oldBottom to: pageRect bottomLeft rule: Form over.
		leafRect := pageRect topLeft corner: p x @ (pageRect bottom + p y).
		sourceQuad := Array with: pageRect topLeft
			with: pageRect bottomLeft + (0@p y)
			with: pageRect bottomRight
			with: pageRect topRight - (0@p y).
		warp := (WarpBlt toForm: buffer)
				clipRect: leafRect;
				sourceForm: (forward ifTrue: [oldPage] ifFalse: [otherImage]);
				combinationRule: Form paint.
		warp copyQuad: sourceQuad toRect: leafRect.
		self copy: buffer boundingBox from: buffer to: topLeft rule: Form over.
		Display forceDisplayUpdate].

	buffer copy: pageRect from: otherImage to: 0@0 rule: Form over.
	buffer copy: oldBottom boundingBox from: oldBottom to: pageRect bottomLeft rule: Form over.
	self copy: buffer boundingBox from: buffer to: topLeft rule: Form over.
	Display forceDisplayUpdate.
"
1 to: 4 do: [:corner | Display pageWarp:
				(Form fromDisplay: (10@10 extent: 200@300)) reverse
			at: 10@10 forward: false]
"
! !

!Form methodsFor: 'displaying' stamp: 'tpr 3/15/2013 12:27'!
paintBits: sourceForm at: destOrigin translucent: factor
	"Make up a BitBlt table and copy the bits with the given colorMap."
	(BitBlt destForm: self
		sourceForm: sourceForm
		halftoneForm: nil
		combinationRule: 31
		destOrigin: destOrigin
		sourceOrigin: 0@0
		extent: sourceForm extent
		clipRect: self boundingBox)
		copyBitsTranslucent: ((0 max: (factor*255.0) asInteger) min: 255)
"
 | f f2 f3 | f := Form fromUser. f replaceColor: f peripheralColor withColor: Color transparent.
f2 := Form fromDisplay: (0@0 extent: f extent). f3 := f2 deepCopy.
0.0 to: 1.0 by: 1.0/32 do:
	[:t | f3 := f2 deepCopy. f3 paintBits: f at: 0@0 translucent: t.
	f3 displayAt: 0@0. (Delay forMilliseconds: 100) wait].
"! !

!Form methodsFor: 'analyzing' stamp: 'tpr 3/15/2013 12:27'!
pixelCompare: aRect with: otherForm at: otherLoc
	"Compare the selected bits of this form (those within aRect) against
	those in a similar rectangle of otherFrom.  Return the sum of the
	absolute value of the differences of the color values of every pixel.
	Obviously, this is most useful for rgb (16- or 32-bit) pixels but,
	in the case of 8-bits or less, this will return the sum of the differing
	bits of the corresponding pixel values (somewhat less useful)"
	| pixPerWord temp |
	pixPerWord := 32//self depth.
	(aRect left\\pixPerWord = 0 and: [aRect right\\pixPerWord = 0]) ifTrue:
		["If word-aligned, use on-the-fly difference"
		^ (BitBlt toForm: self) copy: aRect from: otherLoc in: otherForm
				fillColor: nil rule: 32].
	"Otherwise, combine in a word-sized form and then compute difference"
	temp := self copy: aRect.
	temp copy: aRect from: otherLoc in: otherForm rule: 21.
	^ (BitBlt toForm: temp) copy: aRect from: otherLoc in: nil
				fillColor: (Bitmap with: 0) rule: 32
"  Dumb example prints zero only when you move over the original rectangle...
 | f diff | f := Form fromUser.
[Sensor anyButtonPressed] whileFalse:
	[diff := f pixelCompare: f boundingBox
		with: Display at: Sensor cursorPoint.
	diff printString , '        ' displayAt: 0@0]
"! !

!Form methodsFor: 'pixel access' stamp: 'tpr 3/14/2013 17:36'!
pixelValueAt: aPoint 
	"Return the raw pixel value at the given point. This pixel value depends on the receiver's depth. Typical clients use colorAt: to get a Color.  "

	^ self primPixelValueAtX: aPoint x y: aPoint y! !

!Form methodsFor: 'pixel access' stamp: 'tpr 3/15/2013 12:27'!
pixelValueAt: aPoint put: pixelValue
	"Store the given raw pixel value at the given point. Typical clients use colorAt:put: to store a color. "

	(BitBlt bitPokerToForm: self) pixelAt: aPoint put: pixelValue.
! !

!Form methodsFor: 'color mapping' stamp: 'ar 5/15/2001 16:16'!
pixelValueFor: aColor
	"Return the pixel word for representing the given color on the receiver"
	self hasNonStandardPalette
		ifTrue:[^self colormapFromARGB mapPixel: (aColor pixelValueForDepth: 32)]
		ifFalse:[^aColor pixelValueForDepth: self depth]! !

!Form methodsFor: 'color mapping' stamp: 'ar 5/15/2001 16:16'!
pixelWordFor: aColor
	"Return the pixel word for representing the given color on the receiver"
	| basicPattern |
	self hasNonStandardPalette 
		ifFalse:[^aColor pixelWordForDepth: self depth].
	basicPattern := self pixelValueFor: aColor.
	self depth = 32 
		ifTrue:[^basicPattern]
		ifFalse:[^aColor pixelWordFor: self depth filledWith: basicPattern]! !

!Form methodsFor: 'copying' stamp: 'nice 12/13/2013 21:25'!
postCopy
	super postCopy.
	bits := bits copy
! !

!Form methodsFor: 'other' stamp: 'bf 8/17/2009 13:08'!
preMultiplyAlpha
	"Pre-multiply each pixel by its alpha, for proper alpha compositing (BitBlt rule 34).
	E.g., half-transparent green 16r7F00FF00 becomes 16r7F007F00"

	depth = 32 ifFalse: [^self].
	1 to: bits size do: [:i |
		| v a r g b |
		v := bits at: i.
		a := v bitShift: -24.
		r := ((v bitShift: -16) bitAnd: 255) * a // 255.
		g := ((v bitShift: -8) bitAnd: 255) * a // 255.
		b := (v bitAnd: 255) * a // 255.
		bits at: i put: (a bitShift: 24) + (r bitShift: 16) + (g bitShift: 8) + b].! !

!Form methodsFor: 'analyzing' stamp: 'tpr 3/15/2013 12:27'!
primCountBits
	"Count the non-zero pixels of this form."
	self depth > 8 ifTrue:
		[^(self asFormOfDepth: 8) primCountBits].
	^ (BitBlt toForm: self)
		fillColor: (Bitmap with: 0);
		destRect: (0@0 extent: width@height);
		combinationRule: 32;
		copyBits! !

!Form methodsFor: 'pixel access' stamp: 'tpr 3/26/2013 11:10'!
primPixelValueAtX: x y: y 
	"Return the raw pixel value at the given point. This pixel value depends on the receiver's depth. Typical clients use colorAt: to get a Color. Make sure the colorMap is nil for ColorForms "

	<primitive: 'primitivePixelValueAt' module:'BitBltPlugin'>
	^(BitBlt bitPeekerFromForm: self) colorMap: nil;  pixelAt: x@y! !

!Form methodsFor: 'other' stamp: 'jm 1/6/98 10:37'!
primPrintHScale: hScale vScale: vScale landscape: aBoolean
	"On platforms that support it, this primitive prints the receiver, assumed to be a Form, to the default printer."
	"(Form extent: 10@10) primPrintHScale: 1.0 vScale: 1.0 landscape: true"

	<primitive: 232>
	self primitiveFailed
! !

!Form methodsFor: 'fileIn/Out' stamp: 'di 3/15/1999 14:50'!
printOn: aStream
    aStream
        nextPutAll: self class name;
        nextPut: $(; print: width;
        nextPut: $x; print: height;
        nextPut: $x; print: depth;
        nextPut: $).
! !

!Form methodsFor: 'postscript generation' stamp: 'nk 12/31/2003 15:46'!
printPostscript: aStream operator: operator 
	aStream preserveStateDuring: 
			[:inner | 
			inner rectclip: (0 @ 0 extent: width @ height).
			self setColorspaceOn: inner.
			inner
				print: '[ ';
				cr;
				print: '/ImageType 1';
				cr;
				print: '/ImageMatrix [1 0 0 1 0 0]';
				cr;
				print: '/MultipleDataSources false';
				cr;
				print: '/DataSource level1 { { currentfile ';
				write: self bytesPerRow;
				print: ' string readhexstring pop }} bind { currentfile /ASCIIHexDecode filter } ifelse';
				cr;
				print: '/Width ';
				write: self paddedWidth;
				cr;
				print: '/Height ';
				write: self height;
				cr;
				print: '/Decode ';
				print: self decodeArray;
				cr;
				print: '/BitsPerComponent ';
				write: self bitsPerComponent;
				cr;
				print: 'makeDict ';
				print: operator;
				cr.
			self storePostscriptHexOn: inner.
			inner
				print: $>;
				cr.
			inner cr].
	aStream cr! !

!Form methodsFor: 'private' stamp: 'ar 12/19/2000 16:23'!
privateFloodFillValue: aColor
	"Private. Compute the pixel value in the receiver's depth but take into account implicit color conversions by BitBlt."
	| f1 f2 bb |
	f1 := Form extent: 1@1 depth: depth.
	f2 := Form extent: 1@1 depth: 32.
	bb := BitBlt toForm: f1.
	bb fillColor: aColor; 
		destRect: (0@0 corner: 1@1); 
		combinationRule: 3; 
		copyBits.
	bb := BitBlt toForm: f2.
	bb sourceForm: f1; 
		sourceOrigin: 0@0;
		destRect: (0@0 corner: 1@1);
		combinationRule: 3;
		copyBits.
	^f2 pixelValueAt: 0@0.! !

!Form methodsFor: 'processing' stamp: 'tfel 4/17/2015 14:12'!
processUsingKernel: filter

	^ self processUsingKernel: filter factor: 1.0 bias: 0.0! !

!Form methodsFor: 'processing' stamp: 'tfel 4/17/2015 14:22'!
processUsingKernel: filter factor: factor bias: bias
	| image result |

	image := self.
	result := Form extent: image extent depth: image depth.

	0 to: image height - 1 do: [:y |
		0 to: image width - 1 do: [:x |
			| r g b |
			r := g := b := 0.0.

			0 to: filter rowCount - 1 do: [:filterY |
				0 to: filter columnCount - 1 do: [:filterX |
					| imageX imageY |
					imageX := (x - (filter columnCount // 2) + filterX + image width) \\
								image width.
					imageY := (y - (filter rowCount // 2) + filterY + image height) \\
								image height.
					r := r + ((image colorAt: imageX@imageY) red *
								(filter at: filterY + 1 at: filterX + 1)).
					g := g + ((image colorAt: imageX@imageY) green *
								(filter at: filterY + 1 at: filterX + 1)).
					b := b + ((image colorAt: imageX@imageY) blue *
								(filter at: filterY + 1 at: filterX + 1))]].

			result colorAt: x@y put: (Color
				r: ((factor * r + bias) min: 1.0 max: 0.0)
				g: ((factor * g + bias) min: 1.0 max: 0.0)
				b: ((factor * b + bias) min: 1.0 max: 0.0))]].
	^ result
! !

!Form methodsFor: 'fileIn/Out' stamp: 'mu 8/17/2003 00:44'!
readAttributesFrom: aBinaryStream
	| offsetX offsetY |
	depth := aBinaryStream next.
	(self depth isPowerOfTwo and: [self depth between: 1 and: 32])
		ifFalse: [self error: 'invalid depth; bad Form file?'].
	width := aBinaryStream nextWord.
	height := aBinaryStream nextWord.
	offsetX  := aBinaryStream nextWord.
	offsetY := aBinaryStream nextWord.
	offsetX > 32767 ifTrue: [offsetX := offsetX - 65536].
	offsetY > 32767 ifTrue: [offsetY := offsetY - 65536].
	offset := Point x: offsetX y: offsetY.
	
! !

!Form methodsFor: 'fileIn/Out' stamp: 'mu 8/17/2003 00:43'!
readBitsFrom: aBinaryStream
	
	bits := Bitmap newFromStream: aBinaryStream.
	bits size = self bitsSize ifFalse: [self error: 'wrong bitmap size; bad Form file?'].
	^ self
! !

!Form methodsFor: 'fileIn/Out' stamp: 'jm 3/27/98 16:54'!
readFromOldFormat: aBinaryStream
	"Read a Form in the original ST-80 format."

	| w h offsetX offsetY newForm theBits pos |
	self error: 'this method must be updated to read into 32-bit word bitmaps'.
	w := aBinaryStream nextWord.
	h := aBinaryStream nextWord.
	offsetX  := aBinaryStream nextWord.
	offsetY := aBinaryStream nextWord.
	offsetX > 32767 ifTrue: [offsetX := offsetX - 65536].
	offsetY > 32767 ifTrue: [offsetY := offsetY - 65536].
	newForm := Form extent: w @ h offset: offsetX @ offsetY.
	theBits := newForm bits.
	pos := 0.
	1 to: w + 15 // 16 do: [:j |
		1 to: h do: [:i |
			theBits at: (pos := pos+1) put: aBinaryStream nextWord]].
	newForm bits: theBits.
	^ newForm
! !

!Form methodsFor: 'fileIn/Out' stamp: 'mu 8/17/2003 00:44'!
readFrom: aBinaryStream
	"Reads the receiver from the given binary stream with the format:
		depth, extent, offset, bits."
	self readAttributesFrom: aBinaryStream.
	self readBitsFrom: aBinaryStream! !

!Form methodsFor: 'resources' stamp: 'nice 7/26/2014 23:57'!
readNativeResourceFrom: byteStream
	| img aStream |
	aStream := byteStream.
	img := [ImageReadWriter formFromStream: aStream] on: Error do:[:ex| nil].
	img ifNil:[^nil].
	(img isColorForm and:[self isColorForm]) ifTrue:[
		| cc |
		cc := img colors.
		img colors: nil.
		img displayOn: self.
		img colors: cc.
	] ifFalse:[
		img displayOn: self.
	].
	img := nil.! !

!Form methodsFor: 'resources' stamp: 'fbs 7/25/2013 07:09'!
readResourceFrom: aStream 
	"Store a resource representation of the receiver on aStream.
	Must be specific to the receiver so that no code is filed out."

	| bitsSize msb |
	(aStream next: 4) asString = self resourceTag 
		ifFalse: 
			[aStream position: aStream position - 4.
			^self readNativeResourceFrom: aStream].
	width := aStream nextNumber: 4.
	height := aStream nextNumber: 4.
	depth := aStream nextNumber: 4.
	bitsSize := aStream nextNumber: 4.
	bitsSize = 0 
		ifFalse: 
			[bits := aStream next: bitsSize.
			^self].
	msb := (aStream nextNumber: 4) = 1.
	bitsSize := aStream nextNumber: 4.
	bits := Bitmap new: self bitsSize.
	(Form 
		extent: width @ height
		depth: depth
		bits: (aStream next: bitsSize * 4)) displayOn: self.
	msb = Smalltalk isBigEndian 
		ifFalse: 
			[Bitmap 
				swapBytesIn: bits
				from: 1
				to: bits size]! !

!Form methodsFor: 'analyzing' stamp: 'tpr 3/15/2013 18:49'!
rectangleEnclosingPixelsNotOfColor: aColor
	"Answer the smallest rectangle enclosing all the pixels of me that are different from the given color. Useful for extracting a foreground graphic from its background."

	| cm slice copyBlt countBlt top bottom newH left right |
	"map the specified color to 1 and all others to 0"
	cm := Bitmap new: (1 bitShift: (self depth min: 15)).
	cm primFill: 1.
	cm at: (aColor indexInMap: cm) put: 0.

	"build a 1-pixel high horizontal slice and BitBlts for counting pixels of interest"
	slice := Form extent: width@1 depth: 1.
	copyBlt := (BitBlt toForm: slice)
		sourceForm: self;
		combinationRule: Form over;
		destX: 0 destY: 0 width: width height: 1;
		colorMap: cm.
	countBlt := (BitBlt toForm: slice)
		fillColor: (Bitmap with: 0);
		destRect: (0@0 extent: slice extent);
		combinationRule: 32.

	"scan in from top and bottom"
	top := (0 to: height)
		detect: [:y |
			copyBlt sourceOrigin: 0@y; copyBits.
			countBlt copyBits > 0]
		ifNone: [^ 0@0 extent: 0@0].
	bottom := (height - 1 to: top by: -1)
		detect: [:y |
			copyBlt sourceOrigin: 0@y; copyBits.
			countBlt copyBits > 0].

	"build a 1-pixel wide vertical slice and BitBlts for counting pixels of interest"
	newH := bottom - top + 1.
	slice := Form extent: 1@newH depth: 1.
	copyBlt := (BitBlt toForm: slice)
		sourceForm: self;
		combinationRule: Form over;
		destX: 0 destY: 0 width: 1 height: newH;
		colorMap: cm.
	countBlt := (BitBlt toForm: slice)
		fillColor: (Bitmap with: 0);
		destRect: (0@0 extent: slice extent);
		combinationRule: 32.

	"scan in from left and right"
	left := (0 to: width)
		detect: [:x |
			copyBlt sourceOrigin: x@top; copyBits.
			countBlt copyBits > 0].
	right := (width - 1 to: left by: -1)
		detect: [:x |
			copyBlt sourceOrigin: x@top; copyBits.
			countBlt copyBits > 0].

	^ left@top corner: (right + 1)@(bottom + 1)
! !

!Form methodsFor: 'color mapping' stamp: 'di 10/16/2001 15:23'!
reducedPaletteOfSize: nColors
	"Return an array of colors of size nColors, such that those colors
	represent well the pixel values actually found in this form."
	| threshold tallies colorTallies dist delta palette cts top cluster |
	tallies := self tallyPixelValues.  "An array of tallies for each pixel value"
	threshold := width * height // 500.

	"Make an array of (color -> tally) for all tallies over threshold"
	colorTallies := Array streamContents:
		[:s | tallies withIndexDo:
			[:v :i | v >= threshold ifTrue:
				[s nextPut: (Color colorFromPixelValue: i-1 depth: depth) -> v]]].

	"Extract a set of clusters by picking the top tally, and then removing all others
	whose color is within dist of it.  Iterate the process, adjusting dist until we get nColors."
	dist := 0.2.  delta := dist / 2.
		[cts := colorTallies copy.
		palette := Array streamContents: [:s |
			[cts isEmpty] whileFalse:
				[top := cts detectMax: [:a | a value].
				cluster := cts select: [:a | (a key diff: top key) < dist].
				s nextPut: top key -> (cluster detectSum: [:a | a value]).
				cts := cts copyWithoutAll: cluster]].
		palette size = nColors or: [delta < 0.001]]
		whileFalse:
			[palette size > nColors
				ifTrue: [dist := dist + delta]
				ifFalse: [dist := dist - delta].
			delta := delta / 2].
	^ palette collect: [:a | a key]
! !

!Form methodsFor: 'other' stamp: 'RAA 1/30/2002 16:42'!
relativeTextAnchorPosition

	^nil		"so forms can be in TextAnchors"! !

!Form methodsFor: 'fileIn/Out' stamp: 'ar 2/24/2001 22:39'!
replaceByResource: aForm
	"Replace the receiver by some resource that just got loaded"
	(self extent = aForm extent and:[self depth = aForm depth]) ifTrue:[
		bits := aForm bits.
	].! !

!Form methodsFor: 'image manipulation' stamp: 'tpr 3/15/2013 12:29'!
replaceColor: oldColor withColor: newColor
	"Replace one color with another everywhere is this form"

	| cm newInd target ff |
	self depth = 32
		ifTrue: [cm := (Color  cachedColormapFrom: 16 to: 32) copy]
		ifFalse: [cm := Bitmap new: (1 bitShift: (self depth min: 15)).
				1 to: cm size do: [:i | cm at: i put: i - 1]].
	newInd := newColor pixelValueForDepth: self depth.
	cm at: (oldColor pixelValueForDepth: (self depth min: 16))+1 put: newInd.
	target := newColor isTransparent 
		ifTrue: [ff := Form extent: self extent depth: depth.
			ff fillWithColor: newColor.  ff]
		ifFalse: [self].
	(BitBlt toForm: target)
		sourceForm: self;
		sourceOrigin: 0@0;
		combinationRule: Form paint;
		destX: 0 destY: 0 width: width height: height;
		colorMap: cm;
		copyBits.
	newColor = Color transparent 
		ifTrue: [target displayOn: self].! !

!Form methodsFor: 'resources' stamp: 'ar 2/27/2001 14:56'!
resourceTag
	^'FORM'! !

!Form methodsFor: 'color mapping' stamp: 'ar 5/27/2000 20:14'!
rgbaBitMasks
	"Return the masks for specifying the R,G,B, and A components in the receiver"
	self depth <= 8
		ifTrue:[^#(16rFF0000 16rFF00 16rFF 16rFF000000)].
	self depth = 16
		ifTrue:[^#(16r7C00 16r3E0 16r1F 16r0)].
	self depth = 32
		ifTrue:[^#(16rFF0000 16rFF00 16rFF 16rFF000000)].
	self error:'Bad depth for form'! !

!Form methodsFor: 'scaling, rotation' stamp: ''!
rotateBy: deg
	"Rotate the receiver by the indicated number of degrees."
	"rot is the destination form, bit enough for any angle."

	^ self rotateBy: deg smoothing: 1
"
 | a f |  f := Form fromDisplay: (0@0 extent: 200@200).  a := 0.
[Sensor anyButtonPressed] whileFalse:
	[((Form fromDisplay: (Sensor cursorPoint extent: 130@66))
		rotateBy: (a := a+5)) display].
f display
"! !

!Form methodsFor: 'scaling, rotation' stamp: 'tpr 3/15/2013 12:42'!
rotateBy: direction centerAt: aPoint
	"Return a rotated copy of the receiver. 
	direction = #none, #right, #left, or #pi"
	| newForm quad rot scale |
	direction == #none ifTrue: [^ self].
	scale :=  (direction = #pi ifTrue: [width@height] ifFalse: [height@width]) / self extent .
	newForm := self blankCopyOf: self boundingBox scaledBy: scale.
	quad := self boundingBox innerCorners.
	rot := #(right pi left) indexOf: direction.
	(WarpBlt toForm: newForm)
		sourceForm: self;
		colorMap: (self colormapIfNeededFor: newForm);
		combinationRule: 3;
		copyQuad: ((1+rot to: 4+rot) collect: [:i | quad atWrap: i])
			 toRect: newForm boundingBox.
	newForm offset: (self offset rotateBy: direction centerAt: aPoint).
	^ newForm
"
[Sensor anyButtonPressed] whileFalse:
	[((Form fromDisplay: (Sensor cursorPoint extent: 130@66))
		rotateBy: #left centerAt: 0@0) display]
"
"Consistency test...
 | f f2 p | [Sensor anyButtonPressed] whileFalse:
	[f := Form fromDisplay: ((p := Sensor cursorPoint) extent: 31@41).
	Display fillBlack: (p extent: 31@41).
	f2 := f rotateBy: #left centerAt: 0@0.
	(f2 rotateBy: #right centerAt: 0@0) displayAt: p]
"
! !

!Form methodsFor: 'scaling, rotation' stamp: 'tpr 3/15/2013 12:42'!
rotateBy: deg magnify: scale smoothing: cellSize
	"Rotate the receiver by the indicated number of degrees and magnify. scale can be a Point to make for interesting 3D effects "
	"rot is the destination form, big enough for any angle."

	| side rot warp r1 pts bigSide |
	side := 1 + self extent r asInteger.
	bigSide := (side asPoint * scale) rounded.
	rot := self blankCopyOf: self boundingBox scaledBy: ( bigSide / self extent ).
	warp := (WarpBlt toForm: rot)
		sourceForm: self;
		colorMap: (self colormapIfNeededFor: rot);
		cellSize: cellSize;  "installs a new colormap if cellSize > 1"
		combinationRule: Form paint.
	r1 := (0@0 extent: side@side) align: (side@side)//2 with: self boundingBox center.

	"Rotate the corners of the source rectangle." 
	pts := r1 innerCorners collect:
		[:pt | | p |
		p := pt - r1 center.
		(r1 center x asFloat + (p x asFloat*deg degreeCos) + (p y asFloat*deg degreeSin)) @
		(r1 center y asFloat - (p x asFloat*deg degreeSin) + (p y asFloat*deg degreeCos))].
	warp copyQuad: pts toRect: rot boundingBox.
	^ rot
"
 | a f |  f := Form fromDisplay: (0@0 extent: 200@200).  a := 0.
[Sensor anyButtonPressed] whileFalse:
	[((Form fromDisplay: (Sensor cursorPoint extent: 130@66))
		rotateBy: (a := a+5) magnify: 0.75@2 smoothing: 2) display].
f display
"! !

!Form methodsFor: 'scaling, rotation' stamp: 'tpr 9/28/2004 16:55'!
rotateBy: deg smoothing: cellSize
	"Rotate the receiver by the indicated number of degrees."
	^self rotateBy: deg magnify: 1 smoothing: cellSize
"
 | a f |  f := Form fromDisplay: (0@0 extent: 200@200).  a := 0.
[Sensor anyButtonPressed] whileFalse:
	[((Form fromDisplay: (Sensor cursorPoint extent: 130@66))
		rotateBy: (a := a+5) smoothing: 2) display].
f display
"! !

!Form methodsFor: 'postscript generation' stamp: 'mpw 11/15/1999 08:34'!
rowPadding
	^ 32 // self depth! !

!Form methodsFor: 'scaling, rotation' stamp: 'mt 8/25/2015 10:41'!
scaledToSize: numberOrPoint

	^ self scaledToSize: numberOrPoint smoothing: 2! !

!Form methodsFor: 'scaling, rotation' stamp: 'mt 8/25/2015 10:41'!
scaledToSize: numberOrPoint smoothing: factor

	| scale newExtent |
	newExtent := numberOrPoint asPoint.
	
	newExtent = self extent ifTrue: [^ self copy].
	
	(self height isZero or: [self width isZero])
		ifTrue: [^ self species extent: newExtent depth: self depth].
		
	scale := newExtent x / self width min: newExtent y / self height.
	^ self magnify: self boundingBox by: scale smoothing: factor! !

!Form methodsFor: 'other' stamp: 'dtl 2/27/2010 09:59'!
setAsBackground
	"Set this form as a background image."

	Project current setAsBackground: self
! !

!Form methodsFor: 'postscript generation' stamp: ''!
setColorspaceOn:aStream
	self numComponents = 1 ifTrue:[aStream print:'/DeviceGray setcolorspace 0 setgray'; cr.]
		ifFalse:[aStream print:'/DeviceRGB setcolorspace'; cr.].! !

!Form methodsFor: 'private' stamp: '6/9/97 16:10 di'!
setExtent: extent depth: bitsPerPixel
	"Create a virtual bit map with the given extent and bitsPerPixel."

	width := extent x asInteger.
	width < 0 ifTrue: [width := 0].
	height := extent y asInteger.
	height < 0 ifTrue: [height := 0].
	depth := bitsPerPixel.
	bits := Bitmap new: self bitsSize! !

!Form methodsFor: 'private' stamp: 'tfel 7/27/2016 15:17'!
setExtent: extent depth: bitsPerPixel bits: bitmap
	"Create a virtual bit map with the given extent and bitsPerPixel."

	width := extent x asInteger.
	width < 0 ifTrue: [width := 0].
	height := extent y asInteger.
	height < 0 ifTrue: [height := 0].
	depth := bitsPerPixel.
	depth := bitsPerPixel.
	(bits isNil
		or:[(bitmap class isWords and: [self bitsSize = bitmap size])
		or: [bitmap class isBytes and: [self bitsSize * 4 = bitmap size]]])
			ifFalse:[^self error:'Bad dimensions'].
	bits := bitmap! !

!Form methodsFor: 'private' stamp: 'ar 10/30/2000 23:22'!
setResourceBits: aForm
	"Private. Really. Used for setting the 'resource bits' when externalizing some form"
	bits := aForm.! !

!Form methodsFor: 'bordering' stamp: 'di 10/21/2001 09:39'!
shapeBorder: aColor width: borderWidth
	"A simplified version for shapes surrounded by transparency (as SketchMorphs).
	Note also this returns a new form that may be larger, and does not affect the original."
	| shapeForm borderForm newForm |
	newForm := Form extent: self extent + (borderWidth*2) depth: self depth.
	newForm fillColor: Color transparent.
	self displayOn: newForm at: (0@0) + borderWidth.
	"First identify the shape in question as a B/W form"
	shapeForm := (newForm makeBWForm: Color transparent) reverse.
	"Now find the border of that shape"
	borderForm := shapeForm borderFormOfWidth: borderWidth sharpCorners: false.
	"Finally use that shape as a mask to paint the border with color"
	^ newForm fillShape: borderForm fillColor: aColor! !

!Form methodsFor: 'bordering' stamp: ''!
shapeBorder: aColor width: borderWidth interiorPoint: interiorPoint
	sharpCorners: sharpen internal: internal
	"Identify the shape (region of identical color) at interiorPoint,
	and then add an outline of width=borderWidth and color=aColor.
	If sharpen is true, then cause right angles to be outlined by
	right angles.  If internal is true, then produce a border that lies
	within the identified shape.  Thus one can put an internal border
	around the whole background, thus effecting a normal border
	around every other foreground image."
	| shapeForm borderForm interiorColor |
	"First identify the shape in question as a B/W form"
	interiorColor := self colorAt: interiorPoint.
	shapeForm := (self makeBWForm: interiorColor) reverse
				findShapeAroundSeedBlock:
					[:form | form pixelValueAt: interiorPoint put: 1].
	"Reverse the image to grow the outline inward"
	internal ifTrue: [shapeForm reverse].
	"Now find the border fo that shape"
	borderForm := shapeForm borderFormOfWidth: borderWidth sharpCorners: sharpen.
	"Finally use that shape as a mask to paint the border with color"
	self fillShape: borderForm fillColor: aColor! !

!Form methodsFor: 'filling' stamp: 'di 10/17/2001 10:10'!
shapeFill: aColor interiorPoint: interiorPoint
	"Identify the shape (region of identical color) at interiorPoint,
	and then fill that shape with the new color, aColor
	: modified di's original method such that it returns the bwForm, for potential use by the caller"

	| bwForm interiorPixVal map ppd color ind |
	self depth = 1 ifTrue:
		[^ self shapeFill: aColor
			seedBlock: [:form | form pixelValueAt: interiorPoint put: 1]].

	"First map this form into a B/W form with 0's in the interior region."
		"bwForm := self makeBWForm: interiorColor."	"won't work for two whites"
	interiorPixVal := self pixelValueAt: interiorPoint.
	bwForm := Form extent: self extent.
	map := Bitmap new: (1 bitShift: (self depth min: 12)).  "Not calling newColorMap.  All 
			non-foreground go to 0.  Length is 2 to 4096."
	ppd := self depth.	"256 long color map in depth 8 is not one of the following cases"
	3 to: 5 do: [:bitsPerColor | 
		(2 raisedTo: bitsPerColor*3) = map size 
			ifTrue: [ppd := bitsPerColor*3]].	"ready for longer maps than 512"

	ppd <= 8
		ifTrue: [map at: interiorPixVal+1 put: 1]
		ifFalse: [interiorPixVal = 0 
			ifFalse: [color := Color colorFromPixelValue: interiorPixVal depth: self depth.
				ind := color pixelValueForDepth: ppd.
				map at: ind+1 put: 1]
			ifTrue: [map at: 1 put: 1]].
	bwForm copyBits: self boundingBox from: self at: 0@0 colorMap: map.
	bwForm reverse.  "Make interior region be 0's"

	"Now fill the interior region and return that shape"
	bwForm := bwForm findShapeAroundSeedBlock:
					[:form | form pixelValueAt: interiorPoint put: 1].

	"Finally use that shape as a mask to flood the region with color"
	self eraseShape: bwForm.
	self fillShape: bwForm fillColor: aColor.
	^ bwForm! !

!Form methodsFor: 'filling' stamp: 'ar 5/17/2001 15:38'!
shapeFill: aColor seedBlock: seedBlock
	self depth > 1 ifTrue: [self error: 'This call only meaningful for B/W forms'].
	(self findShapeAroundSeedBlock: seedBlock)
		displayOn: self at: 0@0 clippingBox: self boundingBox
		rule: Form under fillColor: aColor ! !

!Form methodsFor: 'processing' stamp: 'tfel 4/17/2015 14:12'!
sharpen

	^ self processUsingKernel: (Matrix rows: 3 columns: 3 contents: #(
		 0 -1  0
		-1  5 -1
		 0 -1  0
	))! !

!Form methodsFor: 'testing' stamp: 'ar 5/28/2000 14:58'!
shouldPreserveContents
	"Return true if the receiver should preserve it's contents when flagged to be clean. Most forms can not be trivially restored by some drawing operation but some may."
	^true! !

!Form methodsFor: 'scaling, rotation' stamp: ''!
shrink: aRectangle by: scale 
	| scalePt |
	scalePt := scale asPoint.
	^ self magnify: aRectangle by: (1.0 / scalePt x asFloat) @ (1.0 / scalePt y asFloat)! !

!Form methodsFor: 'initialize-release' stamp: 'ar 5/28/2000 18:45'!
shutDown
	"The system is going down. Try to preserve some space"
	self hibernate! !

!Form methodsFor: 'accessing' stamp: ''!
size
	"Should no longer be used -- use bitsSize instead.  length of variable part of instance."
	^ super size! !

!Form methodsFor: 'transitions' stamp: 'jm 5/21/1998 23:46'!
slideImage: otherImage at: topLeft delta: delta
	"Display slideImage: (Form fromDisplay: (40@40 extent: 300@300)) reverse
		at: 40@40 delta: 3@-4"
	| bb nSteps clipRect |
	bb := otherImage boundingBox.
	clipRect := topLeft extent: otherImage extent.
	nSteps := 1.
	delta x = 0 ifFalse: [nSteps := nSteps max: (bb width//delta x abs) + 1].
	delta y = 0 ifFalse: [nSteps := nSteps max: (bb height//delta y abs) + 1].
	1 to: nSteps do:
			[:i | self copyBits: bb from: otherImage
				at: delta*(i-nSteps) + topLeft
				clippingBox: clipRect rule: Form paint fillColor: nil.
			Display forceDisplayUpdate]! !

!Form methodsFor: 'image manipulation' stamp: 'tpr 3/15/2013 12:29'!
smear: dir distance: dist
	"Smear any black pixels in this form in the direction dir in Log N steps"
	| skew bb |
	bb := BitBlt destForm: self sourceForm: self fillColor: nil
		combinationRule: Form under destOrigin: 0@0 sourceOrigin: 0@0
		extent: self extent clipRect: self boundingBox.
	skew := 1.
	[skew < dist] whileTrue:
		[bb destOrigin: dir*skew; copyBits.
		skew := skew+skew]! !

!Form methodsFor: 'postscript generation' stamp: 'nice 12/14/2013 14:46'!
store15To24HexBitsOn:aStream

	| buf lineWidth |

	"write data for 16-bit form, optimized for encoders writing directly to files to do one single file write rather than 12. I'm not sure I understand the significance of the shifting pattern, but I think I faithfully translated it from the original"

	lineWidth := 0.
	buf := String new: 12.
	self unhibernate.
	bits do: [:word | | i | 
		i := 0.
		"upper pixel"
		buf at: (i := i + 1) put: ((word bitShift: -27) bitAnd: 15) asHexDigit.
		buf at: (i := i + 1) put: ((word bitShift: -32) bitAnd: 8) asHexDigit.

		buf at: (i := i + 1) put: ((word bitShift: -22) bitAnd: 15) asHexDigit.
		buf at: (i := i + 1) put: ((word bitShift: -27) bitAnd: 8) asHexDigit.

		buf at: (i := i + 1) put: ((word bitShift: -17) bitAnd: 15) asHexDigit.
		buf at: (i := i + 1) put: ((word bitShift: -22) bitAnd: 8) asHexDigit.

		"lower pixel"

		buf at: (i := i + 1) put: ((word bitShift: -11) bitAnd: 15) asHexDigit.
		buf at: (i := i + 1) put: ((word bitShift: -16) bitAnd: 8) asHexDigit.

		buf at: (i := i + 1) put: ((word bitShift: -6) bitAnd: 15) asHexDigit.
		buf at: (i := i + 1) put: ((word bitShift: -11) bitAnd: 8) asHexDigit.

		buf at: (i := i + 1) put: ((word bitShift: -1) bitAnd: 15) asHexDigit.
		buf at: (i := i + 1) put: ((word bitShift: -6) bitAnd: 8) asHexDigit.
		aStream nextPutAll: buf.
		lineWidth := lineWidth + 12.
		lineWidth > 100 ifTrue: [ aStream cr. lineWidth := 0 ].
		"#( 31 26 21 15 10 5 )  do:[:startBit | ]"
	].! !

!Form methodsFor: 'postscript generation' stamp: ''!
store32To24HexBitsOn:aStream
	^self storeBits:20 to:0 on:aStream.! !

!Form methodsFor: 'fileIn/Out' stamp: 'nice 12/14/2013 14:47'!
storeBitsOn:aStream base:anInteger
	self unhibernate.
	bits do: [:word | 
		anInteger = 10
			ifTrue: [aStream space]
			ifFalse: [aStream crtab: 2].
		word storeOn: aStream base: anInteger].
! !

!Form methodsFor: 'postscript generation' stamp: 'nice 12/14/2013 14:47'!
storeBits:startBit to:stopBit on:aStream
	self unhibernate.
	bits storeBits:startBit to:stopBit on:aStream.! !

!Form methodsFor: 'postscript generation' stamp: ''!
storeHexBitsOn:aStream
	^self storeBits:28 to:0 on:aStream.! !

!Form methodsFor: 'fileIn/Out' stamp: ''!
storeOn: aStream

	self storeOn: aStream base: 10! !

!Form methodsFor: 'fileIn/Out' stamp: ''!
storeOn: aStream base: anInteger 
	"Store the receiver out as an expression that can be evaluated to recreate a Form with the same contents as the original."

	self unhibernate.
	aStream nextPut: $(.
	aStream nextPutAll: self species name.
	aStream crtab: 1.
	aStream nextPutAll: 'extent: '.
	self extent printOn: aStream.
	aStream crtab: 1.
	aStream nextPutAll: 'depth: '.
	self depth printOn: aStream.
	aStream crtab: 1.
	aStream nextPutAll: 'fromArray: #('.
	self storeBitsOn:aStream base:anInteger.
	aStream nextPut: $).
	aStream crtab: 1.
	aStream nextPutAll: 'offset: '.
	self offset printOn: aStream.
	aStream nextPut: $).
! !

!Form methodsFor: 'postscript generation' stamp: 'nk 12/31/2003 15:46'!
storePostscriptHexOn: inner 
	self depth <= 8 ifTrue: [self storeHexBitsOn: inner].
	self depth = 16 ifTrue: [self store15To24HexBitsOn: inner].
	self depth = 32 ifTrue: [self store32To24HexBitsOn: inner]! !

!Form methodsFor: 'resources' stamp: 'fbs 7/25/2013 07:09'!
storeResourceOn: aStream
	"Store a resource representation of the receiver on aStream.
	Must be specific to the receiver so that no code is filed out."
	self hibernate.
	aStream nextPutAll: self resourceTag asByteArray. "tag"
	aStream nextNumber: 4 put: width.
	aStream nextNumber: 4 put: height.
	aStream nextNumber: 4 put: depth.
	(bits isMemberOf: ByteArray) ifFalse:[
		"must store bitmap"
		aStream nextNumber: 4 put: 0. "tag"
		aStream nextNumber: 4 put: (Smalltalk isBigEndian ifTrue:[1] ifFalse:[0]).
	].
	aStream nextNumber: 4 put: bits size.
	aStream nextPutAll: bits.
! !

!Form methodsFor: 'initialize-release' stamp: 'ar 6/16/2002 18:39'!
swapEndianness
	"Swap from big to little endian pixels and vice versa"
	depth := 0 - depth.! !

!Form methodsFor: 'analyzing' stamp: 'jm 6/18/1999 18:41'!
tallyPixelValues
	"Answer a Bitmap whose elements contain the number of pixels in this Form with the pixel value corresponding to their index. Note that the pixels of multiple Forms can be tallied together using tallyPixelValuesInRect:into:."

	^ self tallyPixelValuesInRect: self boundingBox
		into: (Bitmap new: (1 bitShift: (self depth min: 15)))
"
Move a little rectangle around the screen and print its tallies...
 | r tallies nonZero |
Cursor blank showWhile: [
[Sensor anyButtonPressed] whileFalse:
	[r := Sensor cursorPoint extent: 10@10.
	Display border: (r expandBy: 2) width: 2 rule: Form reverse fillColor: nil.
	tallies := (Display copy: r) tallyPixelValues.
	nonZero := (1 to: tallies size) select: [:i | (tallies at: i) > 0]
			thenCollect: [:i | (tallies at: i) -> (i-1)].
	nonZero printString , '          ' displayAt: 0@0.
	Display border: (r expandBy: 2) width: 2 rule: Form reverse fillColor: nil]]
"
! !

!Form methodsFor: 'analyzing' stamp: 'tpr 3/15/2013 12:29'!
tallyPixelValuesInRect: destRect into: valueTable
	"Tally the selected pixels of this Form into valueTable, a Bitmap of depth 2^depth similar to a color map. Answer valueTable."

	(BitBlt toForm: self)
		sourceForm: self;  "src must be given for color map ops"
		sourceOrigin: 0@0;
		tallyMap: valueTable;
		combinationRule: 33;
		destRect: destRect;
		copyBits.
	^ valueTable

"
Move a little rectangle around the screen and print its tallies...
 | r tallies nonZero |
Cursor blank showWhile: [
[Sensor anyButtonPressed] whileFalse:
	[r := Sensor cursorPoint extent: 10@10.
	Display border: (r expandBy: 2) width: 2 rule: Form reverse fillColor: nil.
	tallies := (Display copy: r) tallyPixelValues.
	nonZero := (1 to: tallies size) select: [:i | (tallies at: i) > 0]
			thenCollect: [:i | (tallies at: i) -> (i-1)].
	nonZero printString , '          ' displayAt: 0@0.
	Display border: (r expandBy: 2) width: 2 rule: Form reverse fillColor: nil]]
"! !

!Form methodsFor: 'image manipulation' stamp: 'jm 6/30/1999 15:36'!
trimBordersOfColor: aColor
	"Answer a copy of this Form with each edge trimmed in to the first pixel that is not of the given color. (That is, border strips of the given color are removed)."

	| r |
	r := self rectangleEnclosingPixelsNotOfColor: aColor.
	^ self copy: r
! !

!Form methodsFor: 'fileIn/Out' stamp: 'ar 3/3/2001 15:50'!
unhibernate
	"If my bitmap has been compressed into a ByteArray,
	then expand it now, and return true."
	| resBits |
	bits isForm ifTrue:[
		resBits := bits.
		bits := Bitmap new: self bitsSize.
		resBits displayResourceFormOn: self.
		^true].
	bits == nil ifTrue:[bits := Bitmap new: self bitsSize. ^true].
	(bits isMemberOf: ByteArray)
		ifTrue: [bits := Bitmap decompressFromByteArray: bits. ^ true].
	^ false! !

!Form methodsFor: 'copying' stamp: 'tk 8/19/1998 16:11'!
veryDeepCopyWith: deepCopier
	"Return self.  I am immutable in the Morphic world.  Do not record me."
	^ self! !

!Form methodsFor: 'display box access' stamp: ''!
width
	^ width! !

!Form methodsFor: 'transitions' stamp: 'jm 6/18/1998 12:57'!
wipeImage: otherImage at: topLeft clippingBox: clipBox rectForIndex: rectForIndexBlock

	| i clipRect t rectOrList waitTime |
	i := 0.
	clipRect := topLeft extent: otherImage extent.
	clipBox ifNotNil: [clipRect := clipRect intersect: clipBox].
	[rectOrList := rectForIndexBlock value: (i := i + 1).
	 rectOrList == nil]
		whileFalse: [
			t := Time millisecondClockValue.
			rectOrList asOrderedCollection do: [:r |
				self copyBits: r from: otherImage at: topLeft + r topLeft
					clippingBox: clipRect rule: Form over fillColor: nil].
			Display forceDisplayUpdate.
			waitTime := 3 - (Time millisecondClockValue - t).
			waitTime > 0 ifTrue:
				["(Delay forMilliseconds: waitTime) wait"]].
! !

!Form methodsFor: 'transitions' stamp: 'jm 10/16/97 15:21'!
wipeImage: otherImage at: topLeft delta: delta
	"Display wipeImage: (Form fromDisplay: (40@40 extent: 300@300)) reverse
		at: 40@40 delta: 0@-2"

	self wipeImage: otherImage at: topLeft delta: delta clippingBox: nil.
! !

!Form methodsFor: 'transitions' stamp: 'jm 10/16/97 15:17'!
wipeImage: otherImage at: topLeft delta: delta clippingBox: clipBox

	| wipeRect bb nSteps |
	bb := otherImage boundingBox.
	wipeRect := delta x = 0
		ifTrue:
		[delta y = 0 ifTrue: [nSteps := 1. bb "allow 0@0"] ifFalse: [
		nSteps := bb height//delta y abs + 1.  "Vertical movement"
		delta y > 0
			ifTrue: [bb topLeft extent: bb width@delta y]
			ifFalse: [bb bottomLeft+delta extent: bb width@delta y negated]]]
		ifFalse:
		[nSteps := bb width//delta x abs + 1.  "Horizontal movement"
		delta x > 0
			ifTrue: [bb topLeft extent: delta x@bb height]
			ifFalse: [bb topRight+delta extent: delta x negated@bb height]].
	^ self wipeImage: otherImage at: topLeft clippingBox: clipBox rectForIndex:
		[:i | i <= nSteps
			ifTrue: [wipeRect translateBy: (delta* (i-1))]
			ifFalse: [nil]]! !

!Form methodsFor: 'fileIn/Out' stamp: 'mu 8/17/2003 00:35'!
writeAttributesOn: file
	self unhibernate.
	file nextPut: depth.
	file nextWordPut: width.
	file nextWordPut: height.
	file nextWordPut: ((self offset x) >=0
					ifTrue: [self offset x]
					ifFalse: [self offset x + 65536]).
	file nextWordPut: ((self offset y) >=0
					ifTrue: [self offset y]
					ifFalse: [self offset y + 65536]).
	! !

!Form methodsFor: 'fileIn/Out' stamp: 'mu 8/17/2003 00:35'!
writeBitsOn: file
	bits writeOn: file! !

!Form methodsFor: 'fileIn/Out' stamp: 'ar 6/16/2002 17:53'!
writeBMPfileNamed: fName  "Display writeBMPfileNamed: 'display.bmp'"
	BMPReadWriter putForm: self onFileNamed: fName! !

!Form methodsFor: 'fileIn/Out' stamp: 'sw 2/20/2002 15:37'!
writeJPEGfileNamed: fileName 
	"Write a JPEG file to the given filename using default settings"

	self writeJPEGfileNamed: fileName progressive: false

"
Display writeJPEGfileNamed: 'display.jpeg'
Form fromUser writeJPEGfileNamed: 'yourPatch.jpeg'
"! !

!Form methodsFor: 'fileIn/Out' stamp: 'sw 2/20/2002 15:29'!
writeJPEGfileNamed: fileName  progressive: aBoolean
	"Write a JPEG file to the given filename using default settings.  Make it progressive or not, depending on the boolean argument"

	JPEGReadWriter2 putForm: self quality: -1 "default" progressiveJPEG: aBoolean onFileNamed: fileName

"
Display writeJPEGfileNamed: 'display.jpeg' progressive: false.
Form fromUser writeJPEGfileNamed: 'yourPatch.jpeg' progressive: true
"! !

!Form methodsFor: 'fileIn/Out' stamp: 'di 7/6/1998 23:00'!
writeOnMovie: file
	"Write just my bits on the file."
	self unhibernate.
	bits writeUncompressedOn: file! !

!Form methodsFor: 'fileIn/Out' stamp: 'mu 8/17/2003 00:36'!
writeOn: file
	"Write the receiver on the file in the format
		depth, extent, offset, bits."
	self writeAttributesOn: file.
	self writeBitsOn: file! !

!Form methodsFor: 'fileIn/Out' stamp: 'cbc 3/13/2013 16:10'!
writePNGfileNamed: fName  "Display writePNGfileNamed: 'display.png'"
	PNGReadWriter putForm: self onFileNamed: fName! !

!Form methodsFor: 'fileIn/Out' stamp: 'tk 2/19/1999 07:30'!
writeUncompressedOn: file
	"Write the receiver on the file in the format depth, extent, offset, bits.  Warning:  Caller must put header info on file!!  Use writeUncompressedOnFileNamed: instead."
	self unhibernate.
	file binary.
	file nextPut: depth.
	file nextWordPut: width.
	file nextWordPut: height.
	file nextWordPut: ((self offset x) >=0
					ifTrue: [self offset x]
					ifFalse: [self offset x + 65536]).
	file nextWordPut: ((self offset y) >=0
					ifTrue: [self offset y]
					ifFalse: [self offset y + 65536]).
	bits writeUncompressedOn: file! !

!Form methodsFor: 'analyzing' stamp: 'tpr 3/15/2013 12:29'!
xTallyPixelValue: pv orNot: not
	"Return an array of the number of pixels with value pv by x-value.
	Note that if not is true, then this will tally those different from pv."
	| cm slice countBlt copyBlt |
	cm := self newColorMap.		"Map all colors but pv to zero"
	not ifTrue: [cm atAllPut: 1].		"... or all but pv to one"
	cm at: pv+1 put: 1 - (cm at: pv+1).
	slice := Form extent: 1@height.
	copyBlt := (BitBlt destForm: slice sourceForm: self
				halftoneForm: nil combinationRule: Form over
				destOrigin: 0@0 sourceOrigin: 0@0 extent: 1 @ slice height
				clipRect: slice boundingBox) colorMap: cm.
	countBlt := (BitBlt toForm: slice)
				fillColor: (Bitmap with: 0);
				destRect: (0@0 extent: slice extent);
				combinationRule: 32.
	^ (0 to: width-1) collect:
		[:x |
		copyBlt sourceOrigin: x@0; copyBits.
		countBlt copyBits]! !

!Form methodsFor: 'analyzing' stamp: 'tpr 3/15/2013 12:29'!
yTallyPixelValue: pv orNot: not
	"Return an array of the number of pixels with value pv by y-value.
	Note that if not is true, then this will tally those different from pv."
	| cm slice copyBlt countBlt |
	cm := self newColorMap.		"Map all colors but pv to zero"
	not ifTrue: [cm atAllPut: 1].		"... or all but pv to one"
	cm at: pv+1 put: 1 - (cm at: pv+1).
	slice := Form extent: width@1.
	copyBlt := (BitBlt destForm: slice sourceForm: self
				halftoneForm: nil combinationRule: Form over
				destOrigin: 0@0 sourceOrigin: 0@0 extent: slice width @ 1
				clipRect: slice boundingBox) colorMap: cm.
	countBlt := (BitBlt toForm: slice)
				fillColor: (Bitmap with: 0);
				destRect: (0@0 extent: slice extent);
				combinationRule: 32.
	^ (0 to: height-1) collect:
		[:y |
		copyBlt sourceOrigin: 0@y; copyBits.
		countBlt copyBits]! !

!Form methodsFor: 'transitions' stamp: 'di 3/2/98 09:14'!
zoomInTo: otherImage at: topLeft
	"Display zoomInTo: (Form fromDisplay: (40@40 extent: 300@300)) reverse at: 40@40"
	^ self zoomIn: true orOutTo: otherImage at: topLeft
		vanishingPoint: otherImage extent//2+topLeft! !

!Form methodsFor: 'transitions' stamp: 'nice 12/27/2009 03:10'!
zoomIn: goingIn orOutTo: otherImage at: topLeft vanishingPoint: vp 
	"Display zoomInTo: (Form fromDisplay: (40@40 extent: 300@300)) reverse at: 40@40.
	Display zoomOutTo: (Form fromDisplay: (40@40 extent: 300@300)) reverse at: 40@40."
	| nSteps minTime startTime |
	nSteps := 16.
	minTime := 500.  "milliseconds"
	startTime := Time millisecondClockValue.
	^ self wipeImage: otherImage at: topLeft clippingBox: nil rectForIndex:
		[:i | | lead bigR j lilR | "i runs from 1 to nsteps"
		i > nSteps
			ifTrue: [nil "indicates all done"]
			ifFalse:
			["If we are going too fast, delay for a bit"
			lead := startTime + (i-1*minTime//nSteps) - Time millisecondClockValue.
			lead > 10 ifTrue: [(Delay forMilliseconds: lead) wait].

			"Return an array with the difference rectangles for this step."
			j := goingIn ifTrue: [i] ifFalse: [nSteps+1-i].
			bigR := vp - (vp*(j)//nSteps) corner:
				vp + (otherImage extent-vp*(j)//nSteps).
			lilR := vp - (vp*(j-1)//nSteps) corner:
				vp + (otherImage extent-vp*(j-1)//nSteps).
			bigR areasOutside: lilR]]! !

!Form methodsFor: 'transitions' stamp: 'di 3/2/98 09:15'!
zoomOutTo: otherImage at: topLeft
	"Display zoomOutTo: (Form fromDisplay: (40@40 extent: 300@300)) reverse at: 40@40"
	^ self zoomIn: false orOutTo: otherImage at: topLeft
		vanishingPoint: otherImage extent//2+topLeft! !

Form subclass: #StaticForm
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Display Objects'!

!StaticForm commentStamp: '<historical>' prior: 0!
An optimization for Nebraska - a StaticForm does not change once created so it may be cached on the remote end.!

!StaticForm methodsFor: 'as yet unclassified' stamp: 'RAA 8/14/2000 09:59'!
isStatic

	^true! !

!DisplayObject class methodsFor: 'fileIn/Out' stamp: 'mdr 8/31/2000 19:11'!
collectionFromFileNamed: fileName 
	"Answer a collection of Forms read from the external file 
	named fileName. The file format is: fileCode, {depth, extent, offset, bits}."

	| formList f fileCode |
	formList := OrderedCollection new.
	f := (FileStream readOnlyFileNamed: fileName) binary.
	fileCode := f next.
	fileCode = 1
		ifTrue: [
			[f atEnd] whileFalse: [formList add: (self new readFromOldFormat: f)]]
		ifFalse: [
			fileCode = 2 ifFalse: [self error: 'unknown Form file format'. ^ formList].
			[f atEnd] whileFalse: [formList add: (self new readFrom: f)]].
	f close.
	^ formList
! !

!DisplayObject class methodsFor: 'fileIn/Out' stamp: ''!
writeCollection: coll onFileNamed: fileName 
	"Saves a collection of Forms on the file fileName in the format:
		fileCode, {depth, extent, offset, bits}."
	| file |
	file := FileStream newFileNamed: fileName.
	file binary.
	file nextPut: 2.  "file code = 2"
	coll do: [:f | f writeOn: file].
	file close
"
 | f c | c := OrderedCollection new.
[(f := Form fromUser) boundingBox area>25] whileTrue: [c add: f].
Form writeCollection: c onFileNamed: 'test.forms'.
c := Form collectionFromFileNamed: 'test.forms'.
1 to: c size do: [:i | (c at: i) displayAt: 0@(i*100)].
"! !

!DisplayObject methodsFor: 'transforming' stamp: ''!
align: alignmentPoint with: relativePoint 
	"Translate the receiver's offset such that alignmentPoint aligns with 
	relativePoint."

	self offset: (self offset translateBy: relativePoint - alignmentPoint)! !

!DisplayObject methodsFor: 'display box access' stamp: ''!
boundingBox
	"Answer the rectangular area that represents the boundaries of the 
	receiver's space of information."

	^self computeBoundingBox! !

!DisplayObject methodsFor: 'display box access' stamp: ''!
center

	^ self boundingBox center! !

!DisplayObject methodsFor: 'display box access' stamp: ''!
computeBoundingBox
	"Answer the rectangular area that represents the boundaries of the 
	receiver's area for displaying information. This is the primitive for 
	computing the area if it is not already known."

	self subclassResponsibility! !

!DisplayObject methodsFor: 'displaying-Display' stamp: ''!
display 
	"Display the receiver on the Display at location 0,0."

	self displayOn: Display! !

!DisplayObject methodsFor: 'displaying-generic' stamp: ''!
displayAt: aDisplayPoint 
	"Display the receiver located at aDisplayPoint with default settings for 
	the displayMedium, rule and halftone."

	self displayOn: Display
		at: aDisplayPoint
		clippingBox: Display boundingBox
		rule: Form over
		fillColor: nil! !

!DisplayObject methodsFor: 'displaying-generic' stamp: ''!
displayOnPort: aPort 
	self displayOnPort: aPort at: 0@0! !

!DisplayObject methodsFor: 'displaying-generic' stamp: 'jm 10/21/97 16:56'!
displayOnPort: port at: location rule: rule

	port copyForm: self to: location rule: rule.
! !

!DisplayObject methodsFor: 'displaying-generic' stamp: ''!
displayOn: aDisplayMedium
	"Simple default display in order to see the receiver in the upper left 
	corner of screen."

	self displayOn: aDisplayMedium at: 0 @ 0! !

!DisplayObject methodsFor: 'displaying-generic' stamp: ''!
displayOn: aDisplayMedium at: aDisplayPoint 
	"Display the receiver located at aDisplayPoint with default settings for 
	rule and halftone."

	self displayOn: aDisplayMedium
		at: aDisplayPoint
		clippingBox: aDisplayMedium boundingBox
		rule: Form over
		fillColor: nil! !

!DisplayObject methodsFor: 'displaying-generic' stamp: ''!
displayOn: aDisplayMedium at: aDisplayPoint clippingBox: clipRectangle 
	"Display the receiver located at aDisplayPoint with default settings for 
	rule and halftone. Information to be displayed must be confined to the 
	area that intersects with clipRectangle."

	self displayOn: aDisplayMedium
		at: aDisplayPoint
		clippingBox: clipRectangle
		rule: Form over
		fillColor: nil! !

!DisplayObject methodsFor: 'displaying-generic' stamp: ''!
displayOn: aDisplayMedium at: aDisplayPoint clippingBox: clipRectangle rule: ruleInteger fillColor: aForm
	"This is the basic display primitive for graphic display objects. Display 
	the receiver located at aDisplayPoint with rule, ruleInteger, and mask, 
	aForm. Information to be displayed must be confined to the area that 
	intersects with clipRectangle."

	self subclassResponsibility! !

!DisplayObject methodsFor: 'displaying-generic' stamp: ''!
displayOn: aDisplayMedium at: aDisplayPoint rule: ruleInteger
	"Display the receiver located at aPoint with default setting for the 
	halftone and clippingBox."

	self displayOn: aDisplayMedium
		at: aDisplayPoint
		clippingBox: aDisplayMedium boundingBox
		rule: ruleInteger
		fillColor: nil! !

!DisplayObject methodsFor: 'displaying-generic' stamp: ''!
displayOn: aDisplayMedium transformation: displayTransformation clippingBox: clipRectangle 
	"Display primitive for the receiver where a DisplayTransformation is 
	provided as an argument. Alignment is defaulted to the receiver's 
	rectangle. Information to be displayed must be confined to the area that 
	intersects with clipRectangle."

	self displayOn: aDisplayMedium
		transformation: displayTransformation
		clippingBox: clipRectangle
		align: self relativeRectangle center
		with: self relativeRectangle center
		rule: Form over
		fillColor: nil! !

!DisplayObject methodsFor: 'displaying-generic' stamp: ''!
displayOn: aDisplayMedium transformation: displayTransformation clippingBox: clipRectangle align: alignmentPoint with: relativePoint 
	"Display primitive where a DisplayTransformation is provided as an 
	argument, rule is over and mask is Form black. Information to be 
	displayed must be confined to the area that intersects with clipRectangle."

	self displayOn: aDisplayMedium
		transformation: displayTransformation
		clippingBox: clipRectangle
		align: alignmentPoint
		with: relativePoint
		rule: Form over
		fillColor: nil! !

!DisplayObject methodsFor: 'displaying-generic' stamp: ''!
displayOn: aDisplayMedium transformation: displayTransformation clippingBox: clipRectangle align: alignmentPoint with: relativePoint rule: ruleInteger fillColor: aForm 
	"Display the receiver where a DisplayTransformation is provided as an 
	argument, rule is ruleInteger and mask is aForm. Translate by 
	relativePoint-alignmentPoint. Information to be displayed must be 
	confined to the area that intersects with clipRectangle."

	| absolutePoint |
	absolutePoint := displayTransformation applyTo: relativePoint.
	self displayOn: aDisplayMedium
		at: (absolutePoint - alignmentPoint) 
		clippingBox: clipRectangle 
		rule: ruleInteger 
		fillColor: aForm ! !

!DisplayObject methodsFor: 'displaying-generic' stamp: ''!
displayOn: aDisplayMedium transformation: displayTransformation clippingBox: clipRectangle fixedPoint: aPoint 
	"Display the receiver where a DisplayTransformation is provided as an 
	argument, rule is over and mask is Form black. No translation. 
	Information to be displayed must be confined to the area that intersects 
	with clipRectangle."

	self displayOn: aDisplayMedium
		transformation: displayTransformation
		clippingBox: clipRectangle
		align: aPoint
		with: aPoint
		rule: Form over
		fillColor: nil! !

!DisplayObject methodsFor: 'displaying-generic' stamp: ''!
displayOn: aDisplayMedium transformation: displayTransformation clippingBox: clipRectangle rule: ruleInteger fillColor: aForm 
	"Display the receiver where a DisplayTransformation is provided as an 
	argument, rule is ruleInteger and mask is aForm. No translation. 
	Information to be displayed must be confined to the area that intersects 
	with clipRectangle."

	self displayOn: aDisplayMedium
		transformation: displayTransformation
		clippingBox: clipRectangle
		align: self relativeRectangle origin
		with: self relativeRectangle origin
		rule: ruleInteger
		fillColor: aForm! !

!DisplayObject methodsFor: 'accessing' stamp: ''!
extent
	"Answer the point that represents the width and height of the receiver's 
	bounding box."

	^self boundingBox extent! !

!DisplayObject methodsFor: 'displaying-generic' stamp: ''!
followCursor
	"Just show the Form following the mouse. 6/21/96 tk"
	Cursor blank showWhile:
		[self follow: [Sensor cursorPoint] while: [Sensor noButtonPressed]]
! !

!DisplayObject methodsFor: 'displaying-Display' stamp: ''!
follow: locationBlock while: durationBlock
   "Move an image around on the Display. Restore the background
   continuously without causing flashing. The argument, locationBlock,
   supplies each new location, and the argument, durationBlock, supplies
   true to continue, and then false to stop.
   8/20/96 sw: call follow:while:bitsBehind: to do the real work.  Note that th
method
   now returns the final bits behind as method value."
 
   | bitsBehind loc |
   bitsBehind := Form fromDisplay: ((loc := locationBlock value) extent: self extent).
   ^ self follow: locationBlock while: durationBlock bitsBehind: bitsBehind startingLoc: loc! !

!DisplayObject methodsFor: 'displaying-Display' stamp: 'tpr 3/15/2013 12:20'!
follow: locationBlock while: durationBlock bitsBehind: initialBitsBehind startingLoc: loc
   "Move an image around on the Display. Restore the background continuously without causing flashing. The argument, locationBlock, supplies each new location, and the argument, durationBlock, supplies true to continue or false to stop. This variant takes the bitsBehind as an input argument, and returns the final saved saved bits as method value."

   | location rect1 save1 save1Blt buffer bufferBlt newLoc rect2 bothRects |
   location := loc.
   rect1 := location extent: self extent.
   save1 := initialBitsBehind.
   save1Blt := BitBlt toForm: save1.
   buffer := Form extent: self extent*2 depth: Display depth.  "Holds overlapping region"
   bufferBlt := BitBlt toForm: buffer.
   Display deferUpdates: true.
   self displayOn: Display at: location rule: Form paint.
   Display deferUpdates: false; forceToScreen: (location extent: self extent).
   [durationBlock value] whileTrue: [
		newLoc := locationBlock value.
		newLoc ~= location ifTrue: [
			rect2 := newLoc extent: self extent.
			bothRects := rect1 merge: rect2.
			(rect1 intersects: rect2)
				ifTrue: [  "when overlap, buffer background for both rectangles"
					bufferBlt copyFrom: bothRects in: Display to: 0@0.
					bufferBlt copyFrom: save1 boundingBox in: save1 to: rect1 origin - bothRects origin.
					"now buffer is clean background; get new bits for save1"
					save1Blt copy: (0@0 extent: self extent) from: rect2 origin - bothRects origin in: buffer.
					self displayOnPort: bufferBlt at: rect2 origin - bothRects origin rule: Form paint.
					Display deferUpdates: true.
					Display copy: bothRects from: 0@0 in: buffer rule: Form over.
					Display deferUpdates: false; forceToScreen: bothRects]
				ifFalse: [  "when no overlap, do the simple thing (both rects might be too big)"
					Display deferUpdates: true.
					Display copy: (location extent: save1 extent) from: 0@0 in: save1 rule: Form over.
					save1Blt copyFrom: rect2 in: Display to: 0@0.
					self displayOn: Display at: newLoc rule: Form paint.
					Display deferUpdates: false; 
						forceToScreen: (location extent: save1 extent); 
						forceToScreen: (newLoc extent: self extent)].
			location := newLoc.
			rect1 := rect2]].

	^ save1 displayOn: Display at: location
! !

!DisplayObject methodsFor: 'accessing' stamp: ''!
height
	"Answer the number that represents the height of the receiver's 
	bounding box."

	^self boundingBox height! !

!DisplayObject methodsFor: 'display box access' stamp: ''!
initialExtent
	"Included here for when a FormView is being opened
	as a window.  (4@4) covers border widths."

	^ self extent + (4@4) ! !

!DisplayObject methodsFor: 'displaying-Display' stamp: 'di 9/12/97 11:09'!
isTransparent
	^ false! !

!DisplayObject methodsFor: 'accessing' stamp: ''!
offset
	"Answer the amount by which the receiver should be offset when it is 
	displayed or its position is tested."

	self subclassResponsibility! !

!DisplayObject methodsFor: 'accessing' stamp: ''!
offset: aPoint 
	"Set the amount by which the receiver's position is offset."

	^self! !

!DisplayObject methodsFor: 'accessing' stamp: ''!
relativeRectangle
	"Answer a Rectangle whose top left corner is the receiver's offset position 
	and whose width and height are the same as the receiver."

	^Rectangle origin: self offset extent: self extent! !

!DisplayObject methodsFor: 'truncation and round off' stamp: ''!
rounded
	"Convert the offset of the receiver to integer coordinates."

	self offset: self offset rounded! !

!DisplayObject methodsFor: 'transforming' stamp: ''!
scaleBy: aPoint 
	"Scale the receiver's offset by aPoint."

	self offset: (self offset scaleBy: aPoint)! !

!DisplayObject methodsFor: 'displaying-Display' stamp: 'nice 1/10/2010 20:46'!
slideFrom: startPoint to: stopPoint nSteps: nSteps 
	"does not display at the first point, but does at the last"
	| i p delta |
	i := 0.
	p := startPoint.
	delta := stopPoint - startPoint // nSteps.
	^ self
		follow: [(p := p + delta) truncated]
		while: [(i := i + 1) < nSteps]! !

!DisplayObject methodsFor: 'displaying-Display' stamp: 'jm 10/22/97 07:43'!
slideFrom: startPoint to: stopPoint nSteps: nSteps delay: milliSecs
	"Slide this object across the display over the given number of steps, pausing for the given number of milliseconds after each step."
	"Note: Does not display at the first point, but does at the last."

	| i p delta |
	i := 0.
	p := startPoint.
	delta := (stopPoint - startPoint) / nSteps asFloat.
	^ self
		follow: [(p := p + delta) truncated]
		while: [
			(Delay forMilliseconds: milliSecs) wait.
			(i := i + 1) < nSteps]
! !

!DisplayObject methodsFor: 'displaying-Display' stamp: 'nice 12/27/2009 05:15'!
slideFrom: startPoint to: stopPoint nSteps: nSteps delay: milliSecs andStay: stayAtEnd
	"Does not display at the first point, but does at the last.
	Moreover, if stayAtEnd is true, it leaves the dragged image at the stopPoint"
	| i |
	i := 0.
	^ self follow: [startPoint + ((stopPoint-startPoint) * i // nSteps)]
		while: [ | done |
				milliSecs ifNotNil: [(Delay forMilliseconds: milliSecs) wait].
				((done := (i := i+1) > nSteps) and: [stayAtEnd])
					ifTrue: [^ self "Return without clearing the image"].
				done not]! !

!DisplayObject methodsFor: 'displaying-Display' stamp: 'sr 6/6/2000 05:37'!
slideWithFirstFrom: startPoint to: stopPoint nSteps: nSteps delay: milliSecs 
	"Slide this object across the display over the given number of steps, 
	pausing for the given number of milliseconds after each step."
	"Note: Does display at the first point and at the last."
	| i p delta |
	i := 0.
	delta := stopPoint - startPoint / nSteps asFloat.
	p := startPoint - delta.
	^ self follow: [(p := p + delta) truncated]
		while: 
			[(Delay forMilliseconds: milliSecs) wait.
			(i := i + 1) <= nSteps]! !

!DisplayObject methodsFor: 'transforming' stamp: ''!
translateBy: aPoint 
	"Translate the receiver's offset."

	self offset: (self offset translateBy: aPoint)! !

!DisplayObject methodsFor: 'accessing' stamp: ''!
width
	"Answer the number that represents the width of the receiver's bounding 
	box."

	^self boundingBox width! !

!DisplayObject methodsFor: 'fileIn/Out' stamp: ''!
writeOnFileNamed: fileName 
	"Saves the receiver on the file fileName in the format:
		fileCode, depth, extent, offset, bits."
	| file |
	file := FileStream newFileNamed: fileName.
	file binary.
	file nextPut: 2.  "file code = 2"
	self writeOn: file.
	file close
"
 | f |
[(f := Form fromUser) boundingBox area>25] whileTrue:
	[f writeOnFileNamed: 'test.form'.
	(Form newFromFileNamed: 'test.form') display].
"! !

!DisplayObject methodsFor: 'fileIn/Out' stamp: 'tk 2/19/1999 07:20'!
writeUncompressedOnFileNamed: fileName 
	"Saves the receiver on the file fileName in the format:
		fileCode, depth, extent, offset, bits."
	| file |
	file := FileStream newFileNamed: fileName.
	file binary.
	file nextPut: 2.  "file code = 2"
	self writeUncompressedOn: file.
	file close
"
 | f |
[(f := Form fromUser) boundingBox area>25] whileTrue:
	[f writeUncompressedOnFileNamed: 'test.form'.
	(Form fromBinaryStream: (FileStream oldFileNamed: 'test.form')) display].
"! !

DisplayObject subclass: #InfiniteForm
	instanceVariableNames: 'patternForm'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Display Objects'!

!InfiniteForm commentStamp: '<historical>' prior: 0!
I represent a Form obtained by replicating a pattern form indefinitely in all directions.!

!InfiniteForm class methodsFor: 'instance creation' stamp: ''!
with: aForm 
	"Answer an instance of me whose pattern form is the argument, aForm."

	^self new form: aForm! !

!InfiniteForm methodsFor: 'as yet unclassified' stamp: 'RAA 6/1/2000 10:50'!
addFillStyleMenuItems: aMenu hand: aHand from: aMorph
	"Add the items for changing the current fill style of the receiver"

	"prevents a walkback when control menu is built for morph with me as color"! !

!InfiniteForm methodsFor: 'accessing' stamp: 'mjg 7/9/2001 14:12'!
asColor
	^ patternForm dominantColor! !

!InfiniteForm methodsFor: 'accessing' stamp: ''!
asForm
	^ patternForm! !

!InfiniteForm methodsFor: 'fillstyle protocol' stamp: 'bolot 9/15/1999 10:13'!
bitPatternForDepth: suspectedDepth
	^ patternForm! !

!InfiniteForm methodsFor: 'displaying' stamp: 'sw 2/16/98 03:42'!
colorForInsets
	^ Color transparent! !

!InfiniteForm methodsFor: 'display box access' stamp: ''!
computeBoundingBox 
	"Refer to the comment in DisplayObject|computeBoundingBox."

	^0 @ 0 corner: SmallInteger maxVal @ SmallInteger maxVal! !

!InfiniteForm methodsFor: 'fillstyle protocol' stamp: 'ar 7/2/1999 14:56'!
direction
	^patternForm width @ 0! !

!InfiniteForm methodsFor: 'displaying' stamp: 'nk 4/17/2004 19:48'!
displayOnPort: aPort at: offset

	| targetBox patternBox savedMap top left |

	self flag: #bob.

	"this *may* not get called at the moment. I have been trying to figure out the right way for this to work and am using #displayOnPort:offsetBy: as my current offering - Bob"

	(patternForm isForm) ifFalse: [
		"patternForm is a Pattern or Color; just use it as a mask for BitBlt"
		^ aPort fill: aPort clipRect fillColor: patternForm rule: Form over].

	"do it iteratively"
	targetBox := aPort clipRect.
	patternBox := patternForm boundingBox.
	savedMap := aPort colorMap.
	aPort sourceForm: patternForm;
		fillColor: nil;
		combinationRule: Form paint;
		sourceRect: (0@0 extent: patternBox extent);
		colorMap: (patternForm colormapIfNeededFor: aPort destForm).
	top := (targetBox top truncateTo: patternBox height) "- (offset y \\ patternBox height)".
	left :=  (targetBox left truncateTo: patternBox width) "- (offset x \\ patternBox width)".
	left to: (targetBox right - 1) by: patternBox width do:
		[:x | top to: (targetBox bottom - 1) by: patternBox height do:
			[:y | aPort destOrigin: x@y; copyBits]].
	aPort colorMap: savedMap.
! !

!InfiniteForm methodsFor: 'displaying' stamp: 'nk 4/17/2004 19:48'!
displayOnPort: aPort offsetBy: offset

	| targetBox patternBox savedMap top left |

	"this version tries to get the form aligned where the user wants it and not just aligned with the cliprect"

	(patternForm isForm) ifFalse: [
		"patternForm is a Pattern or Color; just use it as a mask for BitBlt"
		^ aPort fill: aPort clipRect fillColor: patternForm rule: Form over].

	"do it iteratively"
	targetBox := aPort clipRect.
	patternBox := patternForm boundingBox.
	savedMap := aPort colorMap.
	aPort sourceForm: patternForm;
		fillColor: nil;
		combinationRule: Form paint;
		sourceRect: (0@0 extent: patternBox extent);
		colorMap: (patternForm colormapIfNeededFor: aPort destForm).
	top := (targetBox top truncateTo: patternBox height) + offset y.
	left :=  (targetBox left truncateTo: patternBox width) + offset x.

	left to: (targetBox right - 1) by: patternBox width do:
		[:x | top to: (targetBox bottom - 1) by: patternBox height do:
			[:y | aPort destOrigin: x@y; copyBits]].
	aPort colorMap: savedMap.
! !

!InfiniteForm methodsFor: 'displaying' stamp: 'tpr 3/15/2013 12:31'!
displayOn: aDisplayMedium at: aDisplayPoint clippingBox: clipRectangle rule: ruleInteger fillColor: aForm
	"This is the real display message, but it doesn't get used until the new
	display protocol is installed."
	| targetBox patternBox bb |
	(patternForm isForm) ifFalse:
		[^ aDisplayMedium fill: clipRectangle rule: ruleInteger fillColor: patternForm].

	"Do it iteratively"
	targetBox := aDisplayMedium boundingBox intersect: clipRectangle.
	patternBox := patternForm boundingBox.
	bb := BitBlt destForm: aDisplayMedium sourceForm: patternForm fillColor: aForm
		combinationRule: ruleInteger destOrigin: 0@0 sourceOrigin: 0@0
		extent: patternBox extent clipRect: clipRectangle.
	bb colorMap:
		(patternForm colormapIfNeededFor: aDisplayMedium).
	(targetBox left truncateTo: patternBox width)
		to: targetBox right - 1 by: patternBox width do:
		[:x |
		(targetBox top truncateTo: patternBox height)
			to: targetBox bottom - 1 by: patternBox height do:
			[:y |
			bb destOrigin: x@y; copyBits]]! !

!InfiniteForm methodsFor: 'accessing' stamp: 'di 9/2/97 20:21'!
dominantColor
	^ patternForm dominantColor! !

!InfiniteForm methodsFor: 'fillstyle protocol' stamp: 'ar 7/2/1999 14:54'!
form
	"Bitmap fills respond to #form"
	^patternForm! !

!InfiniteForm methodsFor: 'private' stamp: ''!
form: aForm

	patternForm := aForm! !

!InfiniteForm methodsFor: 'fillstyle protocol' stamp: 'ar 7/2/1999 14:54'!
isBitmapFill
	^true! !

!InfiniteForm methodsFor: 'fillstyle protocol' stamp: 'ar 7/2/1999 14:54'!
isGradientFill
	^false! !

!InfiniteForm methodsFor: 'fillstyle protocol' stamp: 'ar 7/2/1999 14:59'!
isOrientedFill
	^true! !

!InfiniteForm methodsFor: 'fillstyle protocol' stamp: 'ar 7/2/1999 14:54'!
isSolidFill
	^false! !

!InfiniteForm methodsFor: 'fillstyle protocol' stamp: 'ar 7/2/1999 14:55'!
isTiled
	"Return true if the receiver should be drawn as a tiled pattern"
	^true! !

!InfiniteForm methodsFor: 'fillstyle protocol' stamp: 'ar 9/2/1999 14:32'!
isTranslucent
	"Return true since the bitmap may be translucent and we don't really want to check"
	^true! !

!InfiniteForm methodsFor: 'fillstyle protocol' stamp: 'ar 7/2/1999 14:57'!
normal
	^0 @ patternForm height! !

!InfiniteForm methodsFor: 'accessing' stamp: ''!
offset 
	"Refer to the comment in DisplayObject|offset."

	^0 @ 0! !

!InfiniteForm methodsFor: 'fillstyle protocol' stamp: 'ar 7/2/1999 14:56'!
origin
	^0@0! !

!InfiniteForm methodsFor: 'fillstyle protocol' stamp: 'ar 7/2/1999 14:56'!
origin: aPoint
	"Ignored"
! !

!InfiniteForm methodsFor: 'displaying' stamp: 'ar 8/16/2001 12:47'!
raisedColor
	^ Color transparent! !

Object subclass: #DisplayTransform
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Transformations'!

!DisplayTransform commentStamp: '<historical>' prior: 0!
This class represents a base for generic transformations of 2D points between different coordinate systems (including scaling and rotation). The transformations map objects between one coordinate system and another where it is assumed that a nested hierarchy of transformations can be defined.

It is assumed that transformations deal with Integer points. All transformations should return Integer coordinates (even though float points may be passed in as argument).

Compositions of transformations MUST work in the following order. A 'global' transformation (the argument in #composedWithGlobal:) is defined as a transformation that takes place between the receiver (the 'local') transformation and any 'global' point computations, whereas a 'local' transformation (e.g., the argument in #composedWithLocal:) takes place between the receiver ('global') and any 'local' points. For the transformation methods this means that combining a global and a local transformation will result in the following order:

		globalPointToLocal: globalPoint
			"globalPoint -> globalTransform -> localTransform -> locaPoint"
			^localTransform globalPointToLocal:
				(globalTransform globalPointToLocal: globalPoint)

		localPointToGlobal: localPoint
			"localPoint -> localTransform -> globalTransform -> globalPoint"
			^globalTransform localPointToGlobal:
				(localTransform localPointToGlobal: localPoint)

!

DisplayTransform subclass: #CompositeTransform
	instanceVariableNames: 'globalTransform localTransform'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Transformations'!

!CompositeTransform commentStamp: '<historical>' prior: 0!
A composite transform provides the effect of several levels of coordinate transformations.!

!CompositeTransform class methodsFor: 'instance creation' stamp: 'ls 3/19/2000 16:44'!
globalTransform: gt localTransform: lt
	^self new globalTransform: gt localTransform: lt! !

!CompositeTransform methodsFor: 'accessing' stamp: 'di 10/26/1999 17:06'!
angle
	^ localTransform angle + globalTransform angle! !

!CompositeTransform methodsFor: 'converting' stamp: 'ar 11/2/1998 20:00'!
asCompositeTransform
	^self! !

!CompositeTransform methodsFor: 'converting' stamp: 'ar 11/2/1998 19:56'!
asMatrixTransform2x3
	^globalTransform asMatrixTransform2x3
		composedWithLocal: localTransform asMatrixTransform2x3! !

!CompositeTransform methodsFor: 'converting' stamp: 'di 10/26/1999 17:03'!
asMorphicTransform
	"Squash a composite transform down to a simple one"
	^ MorphicTransform offset: self offset angle: self angle scale: self scale! !

!CompositeTransform methodsFor: 'initialization' stamp: 'di 10/26/1999 17:08'!
composedWith: aTransform
	"Return a new transform that has the effect of transforming points first by the receiver and then by the argument."

	self isIdentity ifTrue: [^ aTransform].
	aTransform isIdentity ifTrue: [^ self].
	^ CompositeTransform new globalTransform: self
							localTransform: aTransform! !

!CompositeTransform methodsFor: 'transforming points' stamp: 'ar 11/2/1998 16:39'!
globalPointToLocal: aPoint
	"Transform aPoint from global coordinates into local coordinates"
	^localTransform globalPointToLocal:
		(globalTransform globalPointToLocal: aPoint)! !

!CompositeTransform methodsFor: 'initialization' stamp: 'di 3/4/98 19:17'!
globalTransform: gt localTransform: lt
	globalTransform := gt.
	localTransform := lt! !

!CompositeTransform methodsFor: 'accessing' stamp: 'ar 11/2/1998 19:45'!
inverseTransformation
	"Return the inverse transformation of the receiver"
	^self species new
		globalTransform: localTransform inverseTransformation
		localTransform: globalTransform inverseTransformation! !

!CompositeTransform methodsFor: 'transformations' stamp: 'di 10/1/1998 13:51'!
invert: aPoint
	^ globalTransform invert: (localTransform invert: aPoint)! !

!CompositeTransform methodsFor: 'testing' stamp: 'ar 11/2/1998 20:00'!
isCompositeTransform
	^true! !

!CompositeTransform methodsFor: 'testing' stamp: 'di 3/4/98 19:18'!
isIdentity
	^ globalTransform isIdentity and: [localTransform isIdentity]! !

!CompositeTransform methodsFor: 'testing' stamp: 'di 3/4/98 19:18'!
isPureTranslation
	^ globalTransform isPureTranslation and: [localTransform isPureTranslation]! !

!CompositeTransform methodsFor: 'transforming points' stamp: 'ar 11/2/1998 16:39'!
localPointToGlobal: aPoint
	"Transform aPoint from global coordinates into local coordinates"
	^globalTransform localPointToGlobal:
		(localTransform localPointToGlobal: aPoint)! !

!CompositeTransform methodsFor: 'accessing' stamp: 'di 10/26/1999 15:40'!
offset
	^ (self localPointToGlobal: 0@0) negated! !

!CompositeTransform methodsFor: 'accessing' stamp: 'di 10/26/1999 15:39'!
scale
	^ localTransform scale * globalTransform scale! !

!CompositeTransform methodsFor: 'transformations' stamp: 'di 3/4/98 19:20'!
transform: aPoint
	^ localTransform transform: (globalTransform transform: aPoint)! !

!DisplayTransform class methodsFor: 'instance creation' stamp: 'ar 11/2/1998 20:55'!
identity
	^self new setIdentity! !

!DisplayTransform methodsFor: 'converting' stamp: 'ar 11/2/1998 19:59'!
asCompositeTransform
	"Represent the receiver as a composite transformation"
	^CompositeTransform new
		globalTransform: self
		localTransform: self species identity! !

!DisplayTransform methodsFor: 'converting' stamp: 'ar 11/2/1998 20:01'!
asMatrixTransform2x3
	"Represent the receiver as a 2x3 matrix transformation"
	^self subclassResponsibility! !

!DisplayTransform methodsFor: 'composing' stamp: 'ar 11/2/1998 16:15'!
composedWithGlobal: aTransformation
	"Return the composition of the receiver and the global transformation passed in.
	A 'global' transformation is defined as a transformation that takes place
	between the receiver (the 'local') transformation and any 'global' point
	computations, e.g., for the methods

		globalPointToLocal: globalPoint
			globalPoint -> globalTransform -> localTransform -> locaPoint

		localPointToGlobal: localPoint
			localPoint -> localTransform -> globalTransform -> globalPoint

		"
	^aTransformation composedWithLocal: self! !

!DisplayTransform methodsFor: 'composing' stamp: 'ar 11/2/1998 16:41'!
composedWithLocal: aTransformation
	"Return the composition of the receiver and the local transformation passed in.
	A 'local' transformation is defined as a transformation that takes place
	between the receiver (the 'global') transformation and any 'local' point
	computations, e.g., for the methods

		globalPointToLocal: globalPoint
			globalPoint -> globalTransform -> localTransform -> locaPoint

		localPointToGlobal: localPoint
			localPoint -> localTransform -> globalTransform -> globalPoint

		"
	self isIdentity ifTrue:[^ aTransformation].
	aTransformation isIdentity ifTrue:[^ self].
	^ CompositeTransform new globalTransform: self
							localTransform: aTransformation! !

!DisplayTransform methodsFor: 'transforming rects' stamp: 'ar 11/2/1998 16:19'!
globalBoundsToLocal: aRectangle
	"Transform aRectangle from global coordinates into local coordinates"
	^Rectangle encompassing: (self globalPointsToLocal: aRectangle corners)! !

!DisplayTransform methodsFor: 'transforming points' stamp: 'ar 11/9/1998 14:35'!
globalPointsToLocal: inArray
	"Transform all the points of inArray from global into local coordinates"
	^inArray collect:[:pt| self globalPointToLocal: pt]! !

!DisplayTransform methodsFor: 'transforming points' stamp: 'ar 11/2/1998 16:17'!
globalPointToLocal: aPoint
	"Transform aPoint from global coordinates into local coordinates"
	^self subclassResponsibility! !

!DisplayTransform methodsFor: 'accessing' stamp: 'ar 11/2/1998 19:43'!
inverseTransformation
	"Return the inverse transformation of the receiver"
	^self subclassResponsibility! !

!DisplayTransform methodsFor: 'transforming points' stamp: 'gh 10/22/2001 13:24'!
invertBoundsRect: aRectangle
	"Return a rectangle whose coordinates have been transformed
	from local back to global coordinates."

	^self subclassResponsibility! !

!DisplayTransform methodsFor: 'transforming points' stamp: 'ar 12/8/2002 02:20'!
invertPoint: aPoint
	^self globalPointToLocal: aPoint! !

!DisplayTransform methodsFor: 'transforming rects' stamp: 'ar 12/8/2002 02:20'!
invertRect: aRectangle
	^self globalBoundsToLocal: aRectangle! !

!DisplayTransform methodsFor: 'testing' stamp: 'ar 11/2/1998 22:47'!
isCompositeTransform
	"Return true if the receiver is a composite transformation.
	Composite transformations may have impact on the accuracy."
	^false! !

!DisplayTransform methodsFor: 'testing' stamp: 'ar 11/2/1998 16:17'!
isIdentity
	"Return true if the receiver is the identity transform; that is, if applying to a point returns the point itself."
	^self subclassResponsibility! !

!DisplayTransform methodsFor: 'testing' stamp: 'ar 11/2/1998 22:48'!
isMatrixTransform2x3
	"Return true if the receiver is 2x3 matrix transformation"
	^false! !

!DisplayTransform methodsFor: 'testing' stamp: 'ar 11/2/1998 22:48'!
isMorphicTransform
	"Return true if the receiver is a MorphicTransform, that is specifies the transformation values explicitly."
	^false! !

!DisplayTransform methodsFor: 'testing' stamp: 'ar 11/2/1998 16:16'!
isPureTranslation
	"Return true if the receiver specifies no rotation or scaling."
	^self subclassResponsibility! !

!DisplayTransform methodsFor: 'transforming rects' stamp: 'ar 11/2/1998 16:19'!
localBoundsToGlobal: aRectangle
	"Transform aRectangle from local coordinates into global coordinates"
	^Rectangle encompassing: (self localPointsToGlobal: aRectangle corners)! !

!DisplayTransform methodsFor: 'transforming points' stamp: 'ar 11/9/1998 14:35'!
localPointsToGlobal: inArray
	"Transform all the points of inArray from local into global coordinates"
	^inArray collect:[:pt| self localPointToGlobal: pt]! !

!DisplayTransform methodsFor: 'transforming points' stamp: 'ar 11/2/1998 16:18'!
localPointToGlobal: aPoint
	"Transform aPoint from local coordinates into global coordinates"
	^self subclassResponsibility! !

!DisplayTransform methodsFor: 'initialize' stamp: 'ar 11/2/1998 23:18'!
setIdentity
	"Initialize the receiver to the identity transformation (e.g., not affecting points)"
	^self subclassResponsibility! !

!DisplayTransform methodsFor: 'transforming rects' stamp: 'di 10/25/1999 12:49'!
sourceQuadFor: aRectangle
	^ aRectangle innerCorners collect: 
		[:p | self globalPointToLocal: p]! !

!DisplayTransform methodsFor: 'converting' stamp: 'ar 12/8/2002 02:20'!
transformedBy: aTransform
	^self composedWithGlobal: aTransform! !

!DisplayTransform methodsFor: 'transforming points' stamp: 'ar 12/10/2009 00:18'!
transformPoint: aPoint
	"Point transform double dispatch"
	^self localPointToGlobal: aPoint! !

!DisplayTransform methodsFor: 'transforming rects' stamp: 'ar 12/8/2002 02:20'!
transformRect: aRectangle
	^self localBoundsToGlobal: aRectangle! !

DisplayTransform subclass: #IdentityTransform
	instanceVariableNames: ''
	classVariableNames: 'Default'
	poolDictionaries: ''
	category: 'Graphics-Transformations'!

!IdentityTransform class methodsFor: 'class initialization' stamp: 'ar 9/11/2000 21:24'!
initialize
	"IdentityTransform initialize"
	Default := self basicNew.! !

!IdentityTransform class methodsFor: 'instance creation' stamp: 'ar 9/11/2000 21:24'!
new
	"There can be only one"
	^Default! !

!IdentityTransform methodsFor: 'accessing' stamp: 'di 9/29/2000 09:04'!
angle
	^ 0.0! !

!IdentityTransform methodsFor: 'converting' stamp: 'ar 9/11/2000 21:21'!
asMatrixTransform2x3
	"Represent the receiver as a 2x3 matrix transformation"
	^MatrixTransform2x3 identity! !

!IdentityTransform methodsFor: 'composing' stamp: 'ar 9/11/2000 21:19'!
composedWithGlobal: aTransformation
	^aTransformation! !

!IdentityTransform methodsFor: 'composing' stamp: 'ar 9/11/2000 21:19'!
composedWithLocal: aTransformation
	^aTransformation! !

!IdentityTransform methodsFor: 'composing' stamp: 'ar 9/11/2000 21:27'!
composedWith: aTransform
	^aTransform! !

!IdentityTransform methodsFor: 'transforming rects' stamp: 'ar 9/11/2000 21:20'!
globalBoundsToLocal: aRectangle
	"Transform aRectangle from global coordinates into local coordinates"
	^aRectangle! !

!IdentityTransform methodsFor: 'transforming points' stamp: 'ar 9/11/2000 21:20'!
globalPointsToLocal: inArray
	"Transform all the points of inArray from global into local coordinates"
	^inArray! !

!IdentityTransform methodsFor: 'transforming points' stamp: 'ar 9/11/2000 21:19'!
globalPointToLocal: aPoint
	"Transform aPoint from global coordinates into local coordinates"
	^aPoint! !

!IdentityTransform methodsFor: 'accessing' stamp: 'ar 9/11/2000 21:18'!
inverseTransformation
	"Return the inverse transformation of the receiver"
	^self! !

!IdentityTransform methodsFor: 'transforming points' stamp: 'gh 10/22/2001 13:24'!
invertBoundsRect: aRectangle
	"Return a rectangle whose coordinates have been transformed
	from local back to global coordinates. Since I am the identity matrix
	no transformation is made."

	^aRectangle
! !

!IdentityTransform methodsFor: 'testing' stamp: 'ar 9/11/2000 21:18'!
isIdentity
	"Return true if the receiver is the identity transform; that is, if applying to a point returns the point itself."
	^true! !

!IdentityTransform methodsFor: 'testing' stamp: 'ar 9/11/2000 21:19'!
isPureTranslation
	"Return true if the receiver specifies no rotation or scaling."
	^true! !

!IdentityTransform methodsFor: 'transforming rects' stamp: 'ar 9/11/2000 21:20'!
localBoundsToGlobal: aRectangle
	"Transform aRectangle from local coordinates into global coordinates"
	^aRectangle! !

!IdentityTransform methodsFor: 'transforming points' stamp: 'ar 9/11/2000 21:20'!
localPointsToGlobal: inArray
	"Transform all the points of inArray from local into global coordinates"
	^inArray! !

!IdentityTransform methodsFor: 'transforming points' stamp: 'ar 9/11/2000 21:20'!
localPointToGlobal: aPoint
	"Transform aPoint from local coordinates into global coordinates"
	^aPoint! !

!IdentityTransform methodsFor: 'accessing' stamp: 'ar 4/19/2001 06:01'!
offset
	^0@0! !

!IdentityTransform methodsFor: 'initialize' stamp: 'ar 9/11/2000 21:18'!
setIdentity
	"I *am* the identity transform"
	^self! !

!IdentityTransform methodsFor: 'transforming rects' stamp: 'ar 9/11/2000 21:21'!
sourceQuadFor: aRectangle
	^ aRectangle innerCorners! !

DisplayTransform variableWordSubclass: #MatrixTransform2x3
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Transformations'!

!MatrixTransform2x3 commentStamp: '<historical>' prior: 0!
This class represents a transformation for points, that is a combination of scale, offset, and rotation. It is implemented as a 2x3 matrix containing the transformation from the local coordinate system in the global coordinate system. Thus, transforming points from local to global coordinates is fast and cheap whereas transformations from global to local coordinate systems are relatively expensive.

Implementation Note: It is assumed that the transformation deals with Integer points. All transformations will return Integer coordinates (even though float points may be passed in here).!

!MatrixTransform2x3 class methodsFor: 'instance creation' stamp: 'ar 11/2/1998 22:50'!
identity
	^self new setScale: 1.0! !

!MatrixTransform2x3 class methodsFor: 'instance creation' stamp: 'ar 7/9/1998 20:09'!
new
	^self new: 6! !

!MatrixTransform2x3 class methodsFor: 'instance creation' stamp: 'mir 6/12/2001 15:34'!
newFromStream: s
	"Only meant for my subclasses that are raw bits and word-like.  For quick unpack form the disk."
	self isPointers | self isWords not ifTrue: [^ super newFromStream: s].
		"super may cause an error, but will not be called."
	^ s nextWordsInto: (self new: 6)! !

!MatrixTransform2x3 class methodsFor: 'instance creation' stamp: 'ar 11/12/1998 01:25'!
transformFromLocal: localBounds toGlobal: globalBounds
	^((self withOffset: (globalBounds center)) composedWithLocal:
		(self withScale: (globalBounds extent / localBounds extent) asFloatPoint))
			composedWithLocal: (self withOffset: localBounds center negated)
"
	^(self identity)
		setScale: (globalBounds extent / localBounds extent) asFloatPoint;
		setOffset: localBounds center negated asFloatPoint;
		composedWithGlobal:(self withOffset: globalBounds center asFloatPoint)
"! !

!MatrixTransform2x3 class methodsFor: 'instance creation' stamp: 'ar 11/2/1998 02:49'!
withAngle: angle
	^self new setAngle: angle! !

!MatrixTransform2x3 class methodsFor: 'instance creation' stamp: 'ar 11/3/1998 02:52'!
withOffset: aPoint
	^self identity setOffset: aPoint! !

!MatrixTransform2x3 class methodsFor: 'instance creation' stamp: 'ar 11/2/1998 23:17'!
withRotation: angle
	^self new setAngle: angle! !

!MatrixTransform2x3 class methodsFor: 'instance creation' stamp: 'ar 11/2/1998 02:49'!
withScale: aPoint
	^self new setScale: aPoint! !

!MatrixTransform2x3 methodsFor: 'element access' stamp: 'ar 11/2/1998 22:56'!
a11
	^self at: 1! !

!MatrixTransform2x3 methodsFor: 'element access' stamp: 'ar 11/2/1998 22:57'!
a11: value
	 self at: 1 put: value! !

!MatrixTransform2x3 methodsFor: 'element access' stamp: 'ar 11/2/1998 22:56'!
a12
	^self at: 2! !

!MatrixTransform2x3 methodsFor: 'element access' stamp: 'ar 11/2/1998 22:57'!
a12: value
	 self at: 2 put: value! !

!MatrixTransform2x3 methodsFor: 'element access' stamp: 'ar 11/2/1998 22:56'!
a13
	^self at: 3! !

!MatrixTransform2x3 methodsFor: 'element access' stamp: 'ar 11/2/1998 22:57'!
a13: value
	 self at: 3 put: value! !

!MatrixTransform2x3 methodsFor: 'element access' stamp: 'ar 11/2/1998 22:56'!
a21
	 ^self at: 4! !

!MatrixTransform2x3 methodsFor: 'element access' stamp: 'ar 11/2/1998 22:57'!
a21: value
	 self at: 4 put: value! !

!MatrixTransform2x3 methodsFor: 'element access' stamp: 'ar 11/2/1998 22:56'!
a22
	 ^self at: 5! !

!MatrixTransform2x3 methodsFor: 'element access' stamp: 'ar 11/2/1998 22:57'!
a22: value
	 self at: 5 put: value! !

!MatrixTransform2x3 methodsFor: 'element access' stamp: 'ar 11/2/1998 22:56'!
a23
	 ^self at: 6! !

!MatrixTransform2x3 methodsFor: 'element access' stamp: 'ar 11/2/1998 22:57'!
a23: value
	 self at: 6 put: value! !

!MatrixTransform2x3 methodsFor: 'converting' stamp: 'ar 11/2/1998 15:34'!
asMatrixTransform2x3
	^self! !

!MatrixTransform2x3 methodsFor: 'accessing' stamp: 'ar 2/2/2001 15:47'!
at: index
	<primitive: 'primitiveAt' module: 'FloatArrayPlugin'>
	^Float fromIEEE32Bit: (self basicAt: index)! !

!MatrixTransform2x3 methodsFor: 'accessing' stamp: 'ar 2/2/2001 15:47'!
at: index put: value
	<primitive: 'primitiveAtPut' module: 'FloatArrayPlugin'>
	value isFloat 
		ifTrue:[self basicAt: index put: value asIEEE32BitWord]
		ifFalse:[self at: index put: value asFloat].
	^value! !

!MatrixTransform2x3 methodsFor: 'objects from disk' stamp: 'nk 3/17/2004 16:06'!
byteSize
	^self basicSize * self bytesPerBasicElement! !

!MatrixTransform2x3 methodsFor: 'objects from disk' stamp: 'nk 3/17/2004 15:04'!
bytesPerBasicElement
	"Answer the number of bytes that each of my basic elements requires.
	In other words:
		self basicSize * self bytesPerBasicElement
	should equal the space required on disk by my variable sized representation."
	^4! !

!MatrixTransform2x3 methodsFor: 'objects from disk' stamp: 'yo 3/6/2004 12:57'!
bytesPerElement

	^ 4.
! !

!MatrixTransform2x3 methodsFor: 'composing' stamp: 'RAA 9/20/2000 13:10'!
composedWithLocal: aTransformation
	"Return the composition of the receiver and the local transformation passed in"
	aTransformation isMatrixTransform2x3 ifFalse:[^super composedWithLocal: aTransformation].
	^self composedWithLocal: aTransformation asMatrixTransform2x3 into: self class new! !

!MatrixTransform2x3 methodsFor: 'composing' stamp: 'ar 2/2/2001 15:47'!
composedWithLocal: aTransformation into: result
	"Return the composition of the receiver and the local transformation passed in.
	Store the composed matrix into result."
	| a11 a12 a13 a21 a22 a23 b11 b12 b13 b21 b22 b23 matrix |
	<primitive: 'primitiveComposeMatrix' module: 'Matrix2x3Plugin'>
	matrix := aTransformation asMatrixTransform2x3.
	a11 := self a11.		b11 := matrix a11.
	a12 := self a12.		b12 := matrix a12.
	a13 := self a13.		b13 := matrix a13.
	a21 := self a21.		b21 := matrix a21.
	a22 := self a22.		b22 := matrix a22.
	a23 := self a23.		b23 := matrix a23.
	result a11: (a11 * b11) + (a12 * b21).
	result a12: (a11 * b12) + (a12 * b22).
	result a13: a13 + (a11 * b13) + (a12 * b23).
	result a21: (a21 * b11) + (a22 * b21).
	result a22: (a21 * b12) + (a22 * b22).
	result a23: a23 + (a21 * b13) + (a22 * b23).
	^result! !

!MatrixTransform2x3 methodsFor: 'explorer' stamp: 'bf 7/13/2011 18:51'!
explorerContents
	^(FloatArray newFrom: self) explorerContents! !

!MatrixTransform2x3 methodsFor: 'transforming rects' stamp: 'ar 11/9/1998 14:40'!
globalBoundsToLocal: aRectangle
	"Transform aRectangle from global coordinates into local coordinates"
	^self globalBounds: aRectangle toLocal: Rectangle new! !

!MatrixTransform2x3 methodsFor: 'transforming rects' stamp: 'ar 2/2/2001 15:47'!
globalBounds: srcRect toLocal: dstRect
	"Transform aRectangle from global coordinates into local coordinates"
	<primitive: 'primitiveInvertRectInto' module: 'Matrix2x3Plugin'>
	^super globalBoundsToLocal: srcRect! !

!MatrixTransform2x3 methodsFor: 'transforming points' stamp: 'ar 2/2/2001 15:47'!
globalPointToLocal: aPoint
	"Transform aPoint from global coordinates into local coordinates"
	<primitive: 'primitiveInvertPoint' module: 'Matrix2x3Plugin'>
	^(self invertPoint: aPoint) rounded! !

!MatrixTransform2x3 methodsFor: 'comparing' stamp: 'ar 5/3/2001 13:02'!
hash
	| result |
	<primitive: 'primitiveHashArray' module: 'FloatArrayPlugin'>
	result := 0.
	1 to: self size do:[:i| result := result + (self basicAt: i) ].
	^result bitAnd: 16r1FFFFFFF! !

!MatrixTransform2x3 methodsFor: 'accessing' stamp: 'ar 11/18/1998 14:03'!
inverseTransformation
	"Return the inverse transformation of the receiver.
	The inverse transformation is computed by first calculating
	the inverse offset and then computing transformations
	for the two identity vectors (1@0) and (0@1)"
	| r1 r2 r3 m |
	r3 := self invertPoint: 0@0.
	r1 := (self invertPoint: 1@0) - r3.
	r2 := (self invertPoint: 0@1) - r3.
	m := self species new.
	m
		a11: r1 x; a12: r2 x; a13: r3 x;
		a21: r1 y; a22: r2 y; a23: r3 y.
	^m! !

!MatrixTransform2x3 methodsFor: 'transforming points' stamp: 'ar 11/16/1998 23:46'!
invertPoint: aPoint
	"Transform aPoint from global coordinates into local coordinates"
	| x y det a11 a12 a21 a22 detX detY |
	x := aPoint x asFloat - (self a13).
	y := aPoint y asFloat - (self a23).
	a11 := self a11.	a12 := self a12.
	a21 := self a21.	a22 := self a22.
	det := (a11 * a22) - (a12 * a21).
	det = 0.0 ifTrue:[^0@0]. "So we have at least a valid result"
	det := 1.0 / det.
	detX := (x * a22) - (a12 * y).
	detY := (a11 * y) - (x * a21).
	^(detX * det) @ (detY * det)! !

!MatrixTransform2x3 methodsFor: 'testing' stamp: 'ar 2/2/2001 15:47'!
isIdentity
	"Return true if the receiver is the identity transform; that is, if applying to a point returns the point itself."
	<primitive: 'primitiveIsIdentity' module: 'Matrix2x3Plugin'>
	^self isPureTranslation and:[self a13 = 0.0 and:[self a23 = 0.0]]! !

!MatrixTransform2x3 methodsFor: 'testing' stamp: 'ar 11/2/1998 23:15'!
isMatrixTransform2x3
	"Return true if the receiver is 2x3 matrix transformation"
	^true! !

!MatrixTransform2x3 methodsFor: 'testing' stamp: 'ar 2/2/2001 15:47'!
isPureTranslation
	"Return true if the receiver specifies no rotation or scaling."
	<primitive: 'primitiveIsPureTranslation' module: 'Matrix2x3Plugin'>
	^self a11 = 1.0 and:[self a12 = 0.0 and:[self a22 = 0.0 and:[self a21 = 1.0]]]! !

!MatrixTransform2x3 methodsFor: 'transforming rects' stamp: 'ar 11/9/1998 14:40'!
localBoundsToGlobal: aRectangle
	"Transform aRectangle from local coordinates into global coordinates"
	^self localBounds: aRectangle toGlobal: Rectangle new! !

!MatrixTransform2x3 methodsFor: 'transforming rects' stamp: 'ar 2/2/2001 15:47'!
localBounds: srcRect toGlobal: dstRect
	"Transform aRectangle from local coordinates into global coordinates"
	<primitive: 'primitiveTransformRectInto' module: 'Matrix2x3Plugin'>
	^super localBoundsToGlobal: srcRect! !

!MatrixTransform2x3 methodsFor: 'transforming points' stamp: 'ar 2/2/2001 15:47'!
localPointToGlobal: aPoint
	"Transform aPoint from local coordinates into global coordinates"
	<primitive: 'primitiveTransformPoint' module: 'Matrix2x3Plugin'>
	^(self transformPoint: aPoint) rounded! !

!MatrixTransform2x3 methodsFor: 'accessing' stamp: 'ar 11/2/1998 23:19'!
offset
	^self a13 @ self a23! !

!MatrixTransform2x3 methodsFor: 'accessing' stamp: 'ar 11/2/1998 23:05'!
offset: aPoint
	self a13: aPoint x asFloat.
	self a23: aPoint y asFloat.! !

!MatrixTransform2x3 methodsFor: 'printing' stamp: 'ar 11/2/1998 23:11'!
printOn: aStream
	aStream 
		nextPutAll: self class name;
		nextPut: $(;
		cr; print: self a11; tab; print: self a12; tab; print: self a13;
		cr; print: self a21; tab; print: self a22; tab; print: self a23;
		cr; nextPut:$).! !

!MatrixTransform2x3 methodsFor: 'objects from disk' stamp: 'fbs 7/25/2013 07:14'!
restoreEndianness
	"This word object was just read in from a stream.  It was stored in Big Endian (Mac) format.  Swap each pair of bytes (16-bit word), if the current machine is Little Endian.
	Why is this the right thing to do?  We are using memory as a byteStream.  High and low bytes are reversed in each 16-bit word, but the stream of words ascends through memory.  Different from a Bitmap."

	| w b1 b2 b3 b4 |
	Smalltalk  isLittleEndian ifTrue: [
		1 to: self basicSize do: [:i |
			w := self basicAt: i.
			b1 := w digitAt: 1.
			b2 := w digitAt: 2.
			b3 := w digitAt: 3.
			b4 := w digitAt: 4.
			w := (b1 << 24) + (b2 << 16) + (b3 << 8) + b4.
			self basicAt: i put: w.
		]
	].

! !

!MatrixTransform2x3 methodsFor: 'private' stamp: 'ar 11/2/1998 23:17'!
setAngle: angle
	"Set the raw rotation angle in the receiver"
	| rad s c |
	rad := angle degreesToRadians.
	s := rad sin.
	c := rad cos.
	self a11: c.
	self a12: s negated.
	self a21: s.
	self a22: c.! !

!MatrixTransform2x3 methodsFor: 'initialize' stamp: 'ar 11/2/1998 23:17'!
setIdentiy
	"Initialize the receiver to the identity transformation (e.g., not affecting points)"
	self
		a11: 1.0; a12: 0.0; a13: 0.0;
		a21: 0.0; a22: 1.0; a23: 0.0.! !

!MatrixTransform2x3 methodsFor: 'private' stamp: 'ar 11/2/1998 23:17'!
setOffset: aPoint
	"Set the raw offset in the receiver"
	| pt |
	pt := aPoint asPoint.
	self a13: pt x asFloat.
	self a23: pt y asFloat.! !

!MatrixTransform2x3 methodsFor: 'private' stamp: 'ar 11/2/1998 23:16'!
setScale: aPoint
	"Set the raw scale in the receiver"
	| pt |
	pt := aPoint asPoint.
	self a11: pt x asFloat.
	self a22: pt y asFloat.! !

!MatrixTransform2x3 methodsFor: 'transforming points' stamp: 'ar 8/26/2001 20:54'!
transformDirection: aPoint
	"Transform aPoint from local coordinates into global coordinates"
	| x y |
	x := (aPoint x * self a11) + (aPoint y * self a12).
	y := (aPoint x * self a21) + (aPoint y * self a22).
	^x @ y! !

!MatrixTransform2x3 methodsFor: 'transforming points' stamp: 'ar 11/2/1998 23:09'!
transformPoint: aPoint
	"Transform aPoint from local coordinates into global coordinates"
	| x y |
	x := (aPoint x * self a11) + (aPoint y * self a12) + self a13.
	y := (aPoint x * self a21) + (aPoint y * self a22) + self a23.
	^x @ y! !

!MatrixTransform2x3 methodsFor: 'objects from disk' stamp: 'ar 8/6/2001 17:52'!
writeOn: aStream
	aStream nextWordsPutAll: self.! !

!MatrixTransform2x3 methodsFor: 'comparing' stamp: 'ar 2/2/2001 15:47'!
= aMatrixTransform2x3 
	| length |
	<primitive: 'primitiveEqual' module: 'FloatArrayPlugin'>
	self class = aMatrixTransform2x3 class ifFalse: [^ false].
	length := self size.
	length = aMatrixTransform2x3 size ifFalse: [^ false].
	1 to: self size do: [:i | (self at: i)
			= (aMatrixTransform2x3 at: i) ifFalse: [^ false]].
	^ true! !

DisplayTransform subclass: #MorphicTransform
	instanceVariableNames: 'offset angle scale'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Transformations'!

!MorphicTransform commentStamp: '<historical>' prior: 0!
This class implements simple translation, scaling and rotation for points, as well as inverse transformations.  These transformations are used in TransformMorphs (clipping scrollers) and TransformationMorphs (general flex-morph wrappers) to map, eg, global mouse coords into local coords, and to invert, eg, local damage rectangles into global damage rectangles.!

!MorphicTransform class methodsFor: 'instance creation' stamp: ''!
identity

	^ self offset: 0@0 angle: 0.0 scale: 1.0! !

!MorphicTransform class methodsFor: 'instance creation' stamp: ''!
new

	^ self offset: 0@0
! !

!MorphicTransform class methodsFor: 'instance creation' stamp: ''!
offset: aPoint

	^ self offset: aPoint angle: 0.0 scale: 1.0! !

!MorphicTransform class methodsFor: 'instance creation' stamp: ''!
offset: aPoint angle: a scale: s

	^ self basicNew setOffset: aPoint angle: a scale: s! !

!MorphicTransform methodsFor: 'accessing' stamp: ''!
angle
	^ angle! !

!MorphicTransform methodsFor: 'converting' stamp: 'ar 11/2/1998 20:14'!
asMatrixTransform2x3
	^((MatrixTransform2x3 withRotation: angle radiansToDegrees negated) composedWithLocal:
		(MatrixTransform2x3 withScale: scale))
			offset: offset negated! !

!MorphicTransform methodsFor: 'converting' stamp: 'di 10/26/1999 17:03'!
asMorphicTransform

	^ self! !

!MorphicTransform methodsFor: 'composing' stamp: 'nk 3/9/2001 13:55'!
composedWithLocal: aTransform
	aTransform isIdentity ifTrue:[^self].
	self isIdentity ifTrue:[^aTransform].
	aTransform isMorphicTransform ifFalse:[^super composedWithLocal: aTransform].
	self isPureTranslation ifTrue:[
		^aTransform withOffset: aTransform offset + self offset].
	aTransform isPureTranslation ifTrue:[
		^self withOffset: (self localPointToGlobal: aTransform offset negated) negated].
	^super composedWithLocal: aTransform.! !

!MorphicTransform methodsFor: 'transformations' stamp: 'di 3/4/98 19:10'!
composedWith: aTransform
	"Return a new transform that has the effect of transforming points first by the receiver and then by the argument."

	self isIdentity ifTrue: [^ aTransform].
	aTransform isIdentity ifTrue: [^ self].
	^ CompositeTransform new globalTransform: self
							localTransform: aTransform! !

!MorphicTransform methodsFor: 'transforming points' stamp: 'ar 11/2/1998 16:13'!
globalPointToLocal: aPoint
	"Transform aPoint from global coordinates into local coordinates"
	^self transform: aPoint! !

!MorphicTransform methodsFor: 'accessing' stamp: 'ar 11/9/1998 14:33'!
inverseTransformation
	"Return the inverse transformation of the receiver"
	^MorphicTransform
		offset: (self transform: 0@0) - (self transform: offset)
		angle: angle negated
		scale: scale reciprocal! !

!MorphicTransform methodsFor: 'transformations' stamp: 'di 10/3/1998 00:18'!
invertBoundsRect: aRectangle
	"Return a rectangle whose coordinates have been transformed
	from local back to global coordinates.  NOTE: if the transformation
	is not just a translation, then it will compute the bounding box
	in global coordinates."
	| outerRect |
	self isPureTranslation
	ifTrue:
		[^ (self invert: aRectangle topLeft)
			corner: (self invert: aRectangle bottomRight)]
	ifFalse:
		[outerRect := Rectangle encompassing:
			(aRectangle innerCorners collect: [:p | self invert: p]).
		"Following asymmetry due to likely subsequent truncation"
		^ outerRect topLeft - (1@1) corner: outerRect bottomRight + (2@2)]! !

!MorphicTransform methodsFor: 'transformations' stamp: 'di 10/2/1998 08:54'!
invertRect: aRectangle

	self error: 'method name changed to emphasize enclosing bounds'.
	^ self invertBoundsRect: aRectangle! !

!MorphicTransform methodsFor: 'transformations' stamp: 'di 10/28/1999 09:10'!
invert: aPoint
	"Transform the given point from local to global coordinates."
	| p3 p2 |
	self isPureTranslation ifTrue: [^ aPoint - offset].
	p3 :=  aPoint * scale.
	p2 := ((p3 x * angle cos) + (p3 y * angle sin))
		@ ((p3 y * angle cos) - (p3 x * angle sin)).
	^ (p2 - offset)
! !

!MorphicTransform methodsFor: 'testing' stamp: 'ar 11/2/1998 20:57'!
isIdentity
	"Return true if the receiver is the identity transform; that is, if applying to a point returns the point itself."

	^ self isPureTranslation and: [offset = (0@0)]
! !

!MorphicTransform methodsFor: 'testing' stamp: 'ar 11/2/1998 19:51'!
isMorphicTransform
	^true! !

!MorphicTransform methodsFor: 'testing' stamp: 'ar 11/2/1998 20:57'!
isPureTranslation
	"Return true if the receiver specifies no rotation or scaling."

	^ angle = 0.0 and: [scale = 1.0]
! !

!MorphicTransform methodsFor: 'transforming points' stamp: 'ar 11/2/1998 16:32'!
localPointToGlobal: aPoint
	"Transform aPoint from global coordinates into local coordinates"
	^self invert: aPoint! !

!MorphicTransform methodsFor: 'accessing' stamp: ''!
offset
	^ offset
! !

!MorphicTransform methodsFor: 'printing' stamp: 'ar 5/19/1999 18:21'!
printOn: aStream
	super printOn: aStream.
	aStream nextPut:$(;
		nextPutAll:'angle = '; print: angle;
		nextPutAll:'; scale = '; print: scale;
		nextPutAll:'; offset = '; print: offset;
		nextPut:$).! !

!MorphicTransform methodsFor: 'accessing' stamp: ''!
scale
	^ scale! !

!MorphicTransform methodsFor: 'private' stamp: ''!
setAngle: aFloat

	angle := aFloat.
! !

!MorphicTransform methodsFor: 'initialize' stamp: 'ar 11/2/1998 20:58'!
setIdentiy
	scale := 1.0.
	offset := 0@0.
	angle := 0.0.! !

!MorphicTransform methodsFor: 'private' stamp: ''!
setOffset: aPoint

	offset := aPoint.
! !

!MorphicTransform methodsFor: 'private' stamp: ''!
setOffset: aPoint angle: a scale: s

	offset := aPoint.
	angle := a.
	scale := s! !

!MorphicTransform methodsFor: 'private' stamp: ''!
setScale: aFloat

	scale := aFloat.
! !

!MorphicTransform methodsFor: 'transformations' stamp: 'di 10/3/1998 00:18'!
transformBoundsRect: aRectangle
	"Return a rectangle whose coordinates have been transformed
	from global to local coordinates.  NOTE: if the transformation
	is not just a translation, then it will compute the bounding box
	in global coordinates."
	| outerRect |
	self isPureTranslation
	ifTrue:
		[^ (self transform: aRectangle topLeft)
			corner: (self transform: aRectangle bottomRight)]
	ifFalse:
		[outerRect := Rectangle encompassing:
			(aRectangle innerCorners collect: [:p | self transform: p]).
		"Following asymmetry due to likely subsequent truncation"
		^ outerRect topLeft - (1@1) corner: outerRect bottomRight + (2@2)]! !

!MorphicTransform methodsFor: 'transformations' stamp: 'ar 12/10/2009 00:18'!
transformPoint: aPoint
	"Point transform double dispatch"
	^self transform: aPoint! !

!MorphicTransform methodsFor: 'transformations' stamp: 'di 10/28/1999 09:05'!
transform: aPoint
	"Transform the given point from global to local coordinates."
	| p2 p3 |
	self isPureTranslation ifTrue: [^ aPoint + offset].
	p2 := aPoint + offset.
	p3 := (((p2 x * angle cos) - (p2 y * angle sin))
		@ ((p2 y * angle cos) + (p2 x * angle sin)))
			/ scale.
	^ p3! !

!MorphicTransform methodsFor: 'accessing' stamp: ''!
withAngle: a
	"Return a copy of me with a different Angle"
	^ self copy setAngle: a! !

!MorphicTransform methodsFor: 'accessing' stamp: ''!
withOffset: a
	"Return a copy of me with a different Offset"
	^ self copy setOffset: a! !

!MorphicTransform methodsFor: 'accessing' stamp: ''!
withScale: a
	"Return a copy of me with a different Scale"
	^ self copy setScale: a! !

Object subclass: #FontSet
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Fonts'!

!FontSet commentStamp: '<historical>' prior: 0!
FontSet provides a mechanism for storing a set of fonts as a class that can be conveniently filedOut, filedIn, and installed as a TextStyle.

The most common use is...
	Find a font you like.
	Use BitFont to convert a bunch of sizes to data files named, eg, LovelyNN.BF
	Use FontSet convertFontsNamed: 'Lovely' to produce a FontSet named Lovely.
	FileOut that FontSet for later use.
	Use Lovely installAsTextStyle to make all sizes available in a TextStyle
		named #Lovely in the TextConstants dictionary.
	Use ctrl-k in any text pane to select the new Lovely style for that paragraph.
	Then use cmd-1 through 5 or cmd-k to set the point-size for any selection.
!

!FontSet class methodsFor: 'compiling' stamp: 'sma 12/29/1999 11:48'!
acceptsLoggingOfCompilation
	"Dont log sources for my subclasses, so as not to waste time
	and space storing printString versions of the string literals."

	^ self == FontSet! !

!FontSet class methodsFor: 'compiling' stamp: 'di 1/24/2005 12:40'!
compileFont: strikeFont 
	| tempName literalString header sizeStr familyName |
	tempName := 'FontTemp.sf2'.
	strikeFont writeAsStrike2named: tempName.
	literalString := (Base64MimeConverter mimeEncode: (FileStream readOnlyFileNamed: tempName) binary) contents fullPrintString.
	sizeStr := strikeFont pointSize asString.
	familyName := strikeFont name first: (strikeFont name findLast: [:x | x isDigit not]).

	header := 'size' , sizeStr , '
	^ self fontNamed: ''' , familyName , sizeStr , ''' fromMimeLiteral:
' .
	self class
		compile: header , literalString
		classified: 'fonts'
		notifying: nil.
	FileDirectory default deleteFileNamed: tempName
! !

!FontSet class methodsFor: 'as yet unclassified' stamp: 'di 9/15/97 12:01'!
convertFontsNamed: familyName  "FontSet convertFontsNamed: 'Palatino' "
	^ self convertFontsNamed: familyName inDirectoryNamed: ''! !

!FontSet class methodsFor: 'converting' stamp: 'sma 12/29/1999 21:18'!
convertFontsNamed: familyName inDirectoryNamed: dirName
		"FontSet convertFontsNamed: 'Tekton' inDirectoryNamed: 'Tekton Fonts' "
	"This utility is for use after you have used BitFont to produce data files 
	for the fonts you wish to use.  It will read the BitFont files and build
	a fontset class from them.  If one already exists, the sizes that can be
	found will be overwritten."
	"For this utility to work as is, the BitFont data files must be named 'familyNN.BF',
	and must reside in the directory named by dirName (use '' for the current directory)."

	| allFontNames fontSet dir |
	"Check first for matching file names and usable FontSet class name."
	dir := dirName isEmpty
		ifTrue: [FileDirectory default]
		ifFalse: [FileDirectory default directoryNamed: dirName].
	allFontNames := dir fileNamesMatching: familyName , '##.BF'.
	allFontNames isEmpty ifTrue: [^ self error: 'No files found like ' , familyName , 'NN.BF'].
	fontSet := self fontSetClass: familyName.
	allFontNames do:
		[:each |
		Transcript cr; show: each.
		fontSet compileFont: (StrikeFont new readFromBitFont: (dir fullNameFor: each))]! !

!FontSet class methodsFor: 'converting' stamp: 'sma 12/29/1999 12:27'!
convertTextStyleNamed: aString
	| style fontSet |
	(style := TextStyle named: aString) ifNil: [^ self error: 'unknown text style ' , aString].
	fontSet := self fontSetClass: aString.
	style fontArray do: [:each | fontSet compileFont: each]! !

!FontSet class methodsFor: 'filein/out' stamp: 'sma 12/29/1999 11:49'!
fileOut
	"FileOut and then change the properties of the file so that it won't be
	treated as text by, eg, email attachment facilities"

	super fileOut.
	(FileStream oldFileNamed: self name , '.st') setFileTypeToObject; close! !

!FontSet class methodsFor: 'private' stamp: 'nice 9/4/2013 21:19'!
fontCategory
	^ #'Graphics-Fonts'! !

!FontSet class methodsFor: 'private' stamp: 'RAA 6/20/2000 13:29'!
fontName

	self flag: #bob.		"temporary hack until I figure out what's happening here"
	(self name beginsWith: superclass name) ifFalse: [^self name].
	^ (self name copyFrom: superclass name size + 1 to: self name size) asSymbol! !

!FontSet class methodsFor: 'installing' stamp: 'di 1/24/2005 12:48'!
fontNamed: fontName fromLiteral: aString
	"NOTE -- THIS IS AN OBSOLETE METHOD THAT MAY CAUSE ERRORS.

The old form of fileOut for FontSets produced binary literal strings which may not be accurately read in systems with support for international character sets.  If possible, file the FontSet out again from a system that produces the newer MIME encoding (current def of compileFont:), and uses the corresponding altered version of this method.  If this is not easy, then
	file the fontSet into an older system (3.7 or earlier),
	assume it is called FontSetZork...
	execute FontSetZork installAsTextStyle.
	copy the compileFont: method from this system into that older one.
	remove the class FontSetZork.
	Execute:  FontSet convertTextStyleNamed: 'Zork', and see that it creates a new FontSetZork.
	FileOut the new class FontSetZork.
	The resulting file should be able to be read into this system.
"

	^ StrikeFont new 
		name: fontName;
		readFromStrike2Stream: (ReadStream on: aString asByteArray)! !

!FontSet class methodsFor: 'installing' stamp: 'di 1/24/2005 11:13'!
fontNamed: fontName fromMimeLiteral: aString
	"This method allows a font set to be captured as sourcecode in a subclass.
	The string literals will presumably be created by printing, eg,
		(FileStream readOnlyFileNamed: 'Palatino24.sf2') contentsOfEntireFile,
		and following the logic in compileFont: to encode and add a heading.

	See the method installAsTextStyle to see how this can be used."

	^ StrikeFont new 
		name: fontName;
		readFromStrike2Stream: (Base64MimeConverter mimeDecodeToBytes: aString readStream)! !

!FontSet class methodsFor: 'private' stamp: 'sma 12/29/1999 12:58'!
fontSetClass: aString
	| className fontSet |
	className := (self name , (aString select: [:c | c isAlphaNumeric]) capitalized) asSymbol.
	fontSet := Smalltalk
		at: className
		ifAbsentPut: [self
			subclass: className
			instanceVariableNames: ''
			classVariableNames: ''
			poolDictionaries: ''
			category: self fontCategory].
	(fontSet inheritsFrom: self) ifFalse: [^ self error: 'The name ' , className , ' is already in use'].
	^ fontSet! !

!FontSet class methodsFor: 'installing' stamp: 'ar 8/6/2009 18:22'!
installAsDefault  "FontSetNewYork installAsDefault"
	(UIManager default confirm: 'Do you want to install
''' , self fontName , ''' as default font?')
		ifFalse: [^ self].
	self installAsTextStyle.
	"TextConstants at: #OldDefaultTextStyle put: TextStyle default."
	TextConstants at: #DefaultTextStyle put: (TextStyle named: self fontName).
	#(ListParagraph PopUpMenu StandardSystemView) do:[:className|
		Smalltalk at: className ifPresent:[:aClass| aClass initialize].
	].! !

!FontSet class methodsFor: 'installing' stamp: 'sma 12/30/1999 15:05'!
installAsTextStyle  "FontSetNewYork installAsTextStyle"
	| selectors |
	(TextConstants includesKey: self fontName) ifTrue:
		[(self confirm: 
self fontName , ' is already defined in TextConstants.
Do you want to replace that definition?')
			ifFalse: [^ self]].
	selectors := (self class selectors select: [:s | s beginsWith: 'size']) asSortedCollection.
	TextConstants
		at: self fontName
		put: (TextStyle fontArray: (selectors collect: [:each | self perform: each]))! !

!FontSet class methodsFor: 'installing' stamp: 'nk 8/31/2004 09:23'!
size: pointSize fromLiteral: aString 
	"This method allows a font set to be captured as sourcecode in a subclass.
	The string literals will presumably be created by printing, eg,
		(FileStream readOnlyFileNamed: 'Palatino24.sf2') contentsOfEntireFile,
		and then pasting into a browser after a heading like, eg,
size24
	^ self size: 24 fromLiteral:
	'--unreadable binary data--'

	See the method installAsTextStyle to see how this can be used."

	"This method is old and for backward compatibility only.
	please use fontNamed:fromLiteral: instead."

	self flag: #bob.	"used in Alan's projects"
	^(StrikeFont new)
		name: self fontName , (pointSize < 10 
							ifTrue: ['0' , pointSize printString]
							ifFalse: [pointSize printString]);
		readFromStrike2Stream: ((RWBinaryOrTextStream with: aString)
					reset;
					binary);
		yourself! !

Object subclass: #HostWindowProxy
	instanceVariableNames: 'windowHandle sourceForm'
	classVariableNames: 'ActiveProxyClass Registry'
	poolDictionaries: ''
	category: 'Graphics-External-Ffenestri'!

!HostWindowProxy commentStamp: 'bf 1/4/2012 18:37' prior: 0!
This is a proxy for a Host OS window and as such is considered a disposable item. When an image is restarted the client must recreate suitable instances from the information they hold. Platform specific subclasses are available to translate abstract requirements into possible platform concrete data.
There is a registry of instances so that when users let go they can be guaranteed to close down properly. Because the instances point to the source Form in use this can on occasion result in a cycle that defeats the Weak mechanism - hence the implementation of #executor & #asExecutor.
The only requirements placed on the sourceForm instvar are those of being like a DisplayScreen - can return a bits array, the width, depth etc PLUS implement processEvent: AND able to respond to #resetProxy to remove and rebuild the window proxy!

!HostWindowProxy class methodsFor: 'system startup' stamp: 'tpr 10/14/2004 16:02'!
activeWindowProxyClass
	"Return the concrete HostWindowProxy subclass for the platform on which we are
currently running."

	HostWindowProxy allSubclasses do: [:class |
		class isActiveHostWindowProxyClass ifTrue: [^ class]].

	"no responding subclass; use HostWindowProxy"
	^ HostWindowProxy
! !

!HostWindowProxy class methodsFor: 'class initialization' stamp: 'bf 1/3/2012 15:20'!
initialize
"Add me to the system startup list and make sure to do a file-in init for first time loading"
"HostWindowProxy initialize"
	self setDefaultWindowProxyClass.
	Smalltalk addToStartUpList: self.! !

!HostWindowProxy class methodsFor: 'system startup' stamp: 'tpr 10/1/2004 16:07'!
isActiveHostWindowProxyClass
"subclasses must override this"
	self subclassResponsibility! !

!HostWindowProxy class methodsFor: 'initialize-release' stamp: 'tpr 10/1/2004 16:35'!
on: aSourceForm
"Build a new window proxy by finding the appropriate platform specific subclass
and setting it up for this Form-like argument"
	^ActiveProxyClass new on: aSourceForm! !

!HostWindowProxy class methodsFor: 'events' stamp: 'bf 1/4/2012 15:42'!
processEvent: evt
	"evt is a raw event buffer from VM. Pass it on to the appropiate proxy."
	self registry keys do: [:proxy |
		(proxy wantsEvent: evt) ifTrue: [proxy processEvent: evt]].
! !

!HostWindowProxy class methodsFor: 'registry' stamp: 'HenrikSperreJohansen 5/20/2010 22:37'!
register: anObject
"boilerplate WeakRegistry usage"
	^self registry add: anObject! !

!HostWindowProxy class methodsFor: 'registry' stamp: 'HenrikSperreJohansen 5/20/2010 22:37'!
registry
"boilerplate WeakRegistry usage"
	^Registry ifNil: [Registry := WeakRegistry new]! !

!HostWindowProxy class methodsFor: 'system startup' stamp: 'lr 7/4/2009 10:42'!
setDefaultWindowProxyClass
	"connect to the proper platform subclass of proxy"
	ActiveProxyClass := self activeWindowProxyClass! !

!HostWindowProxy class methodsFor: 'system startup' stamp: 'bf 1/3/2012 15:03'!
startUp: resuming
	resuming ifFalse: [^self].
	"system startup - find the appropriate proxy class for this platform"
	self setDefaultWindowProxyClass.
	"any currently extant instances must tell their sourceForm to resetProxy in order to kill potentially wrong-platform versions and reset to correct-platform"
	self registry keys do: [:i | i resetProxy]! !

!HostWindowProxy class methodsFor: 'registry' stamp: 'HenrikSperreJohansen 5/20/2010 22:38'!
unregister: anObject
"boilerplate WeakRegistry usage"
	^self registry remove: anObject ifAbsent:[]! !

!HostWindowProxy methodsFor: 'finalization' stamp: 'lr 7/4/2009 10:42'!
asExecutor
	sourceForm := nil! !

!HostWindowProxy methodsFor: 'window decorations' stamp: 'tpr 9/28/2004 15:52'!
attributes
"return the ByteArray representing the desired window attributes. This is utterly platform dependent and my default is an empty ByteArray to signify a default window"
	^ByteArray new! !

!HostWindowProxy methodsFor: 'metrics' stamp: 'tpr 9/28/2004 15:47'!
bits
"return the bits - normally of the sourceForm"
	^sourceForm bits! !

!HostWindowProxy methodsFor: 'initialize-release' stamp: 'bf 1/3/2012 16:24'!
close
	"close this window"
	windowHandle ifNil: [^self].
	self unregister.
	self primitiveWindowClose: windowHandle.
	windowHandle := nil.
! !

!HostWindowProxy methodsFor: 'window decorations' stamp: 'tpr 10/7/2004 11:33'!
defaultWindowType
"set up my attributes to be a default window - a titlebar, usual decorations etc"
	^self subclassResponsibility! !

!HostWindowProxy methodsFor: 'metrics' stamp: 'tpr 9/28/2004 16:08'!
depth
"return the depth - normally of the sourceForm"
	^sourceForm depth! !

!HostWindowProxy methodsFor: 'finalization' stamp: 'tpr 9/30/2004 13:10'!
executor
	^self shallowCopy asExecutor! !

!HostWindowProxy methodsFor: 'finalization' stamp: 'tpr 10/6/2004 21:20'!
finalize
	"close this window"
	self close! !

!HostWindowProxy methodsFor: 'window manipulation' stamp: 'tpr 9/28/2004 15:47'!
forceToScreen: damageRectangle 
	"update the area of the sourceForm defined by damageRectangle"
	self
		primitiveUpdateHostWindow: windowHandle
		bitmap: self bits
		width: self width
		height: self height
		depth: self depth
		left: damageRectangle left
		right: damageRectangle right
		top: damageRectangle top
		bottom: damageRectangle bottom! !

!HostWindowProxy methodsFor: 'metrics' stamp: 'tpr 9/28/2004 15:47'!
height
"return the height - normally of the sourceForm"
	^sourceForm height! !

!HostWindowProxy methodsFor: 'accessing' stamp: 'tpr 10/6/2004 14:29'!
isOpen
"am I already opened?"
	^windowHandle notNil! !

!HostWindowProxy methodsFor: 'metrics' stamp: 'tpr 9/28/2004 15:47'!
offset
"return the offset - normally of the sourceForm"
	^sourceForm offset! !

!HostWindowProxy methodsFor: 'initialize-release' stamp: 'lr 7/4/2009 10:42'!
on: aSourceForm 
	"set my sourceForm; usually an actual Form but so long as methods like bits, height etc work, it can be anything"
	sourceForm := aSourceForm! !

!HostWindowProxy methodsFor: 'initialize-release' stamp: 'tpr 10/7/2004 11:17'!
open
	"open a host window built around my position, size and bitmap"
	windowHandle
		ifNil: [sourceForm
				ifNotNil:[windowHandle := self
						primitiveCreateHostWindowWidth: self width
						height: self height
						originX: self offset x
						y: self offset y
						attributes: self attributes.
						windowHandle ifNotNil:[self register].
						^windowHandle]]! !

!HostWindowProxy methodsFor: 'system primitives' stamp: 'tpr 9/28/2004 13:22'!
primitiveCreateHostWindowWidth: w height: h originX: x y: y attributes: list
"create and open a host window. list is a ByteArray list of window attributes in some platform manner. See subclasses for information"
	<primitive: 'primitiveCreateHostWindow' module: 'HostWindowPlugin'>
	^self error: 'Unable to create Host Window'! !

!HostWindowProxy methodsFor: 'system primitives' stamp: 'tpr 10/7/2004 10:31'!
primitiveUpdateHostWindow: id bitmap: bitmap width: w height: h depth: d left: l
right: r top: t bottom: b 
	"Force the pixels to the screen. The bitmap details and affected area are given
explicitly to avoid dependence upon any object structure"
	<primitive: 'primitiveShowHostWindowRect' module:'HostWindowPlugin'>
	^self windowProxyError: 'update'! !

!HostWindowProxy methodsFor: 'system primitives' stamp: 'tpr 10/7/2004 10:31'!
primitiveWindowClose: id
"Close the window"
	<primitive: 'primitiveCloseHostWindow' module: 'HostWindowPlugin'>
	^self windowProxyError: 'close'! !

!HostWindowProxy methodsFor: 'system primitives' stamp: 'tpr 10/7/2004 10:32'!
primitiveWindowPosition: id
"Find the topleft corner of the window"
	<primitive: 'primitiveHostWindowPosition' module: 'HostWindowPlugin'>
	^self windowProxyError: 'get position'! !

!HostWindowProxy methodsFor: 'system primitives' stamp: 'tpr 10/7/2004 10:32'!
primitiveWindowPosition: id x: x y: y
"Set the topleft corner of the window - return what is actually set"
	<primitive: 'primitiveHostWindowPositionSet' module: 'HostWindowPlugin'>
	^self windowProxyError: 'set position'! !

!HostWindowProxy methodsFor: 'system primitives' stamp: 'tpr 10/7/2004 10:32'!
primitiveWindowSize: id
"Find the size of the window, just like primitiveScreenSize"
	<primitive: 'primitiveHostWindowSize' module: 'HostWindowPlugin'>
	^self windowProxyError: 'get size'! !

!HostWindowProxy methodsFor: 'system primitives' stamp: 'tpr 10/7/2004 10:33'!
primitiveWindowSize: id x: x y: y
"Set the size of the window, just like primitiveScreenSize. Return the actually
achieved size"
	<primitive: 'primitiveHostWindowSizeSet' module: 'HostWindowPlugin'>
	^self windowProxyError: 'set size'! !

!HostWindowProxy methodsFor: 'system primitives' stamp: 'tpr 9/28/2004 13:26'!
primitiveWindowTitle: id string: titleString
"Set the label of the title bar of the window"
	<primitive: 'primitiveHostWindowTitle' module: 'HostWindowPlugin'>
	^self error: 'Unable to set title of Host Window'! !

!HostWindowProxy methodsFor: 'printing' stamp: 'tpr 9/29/2004 11:59'!
printOn: aStream
	super printOn:aStream.
	aStream nextPutAll: ' (windowIndex '.
	windowHandle printOn: aStream.
	aStream nextPut: $)! !

!HostWindowProxy methodsFor: 'events' stamp: 'bf 1/4/2012 18:16'!
processEvent: evt
	"evt is a raw event buffer from VM. delegate to client window"
	sourceForm processEvent: evt! !

!HostWindowProxy methodsFor: 'window manipulation' stamp: 'tpr 10/6/2004 14:31'!
recreate
"something has changed that require deleting the host window before opening it
with new attributes"
	self close; open! !

!HostWindowProxy methodsFor: 'finalization' stamp: 'tpr 9/30/2004 12:56'!
register
	^self class register: self! !

!HostWindowProxy methodsFor: 'finalization' stamp: 'tpr 10/12/2004 19:43'!
resetProxy
"tell my sourceForm to kill me (gulp) and resurrect me in the correct clothing"
	sourceForm ifNotNil:[ sourceForm resetProxy]! !

!HostWindowProxy methodsFor: 'finalization' stamp: 'tpr 9/30/2004 12:56'!
unregister
	^self class unregister: self! !

!HostWindowProxy methodsFor: 'events' stamp: 'bf 1/4/2012 15:42'!
wantsEvent: evt
	"evt is a raw event buffer from VM. check if its window field matches ours"
	^ windowHandle = (evt at: 8)! !

!HostWindowProxy methodsFor: 'metrics' stamp: 'tpr 9/28/2004 15:47'!
width
"return the width - normally of the sourceForm"
	^sourceForm width! !

!HostWindowProxy methodsFor: 'window manipulation' stamp: 'tpr 9/28/2004 13:34'!
windowPosition
	"return the current position of the window"
		^self primitiveWindowPosition: windowHandle! !

!HostWindowProxy methodsFor: 'window manipulation' stamp: 'tpr 9/28/2004 13:34'!
windowPosition: aPoint
	"set the position of the window and then return the new position"
		^self primitiveWindowPosition: windowHandle x: aPoint x y: aPoint y! !

!HostWindowProxy methodsFor: 'accessing' stamp: 'tpr 10/7/2004 10:30'!
windowProxyError: problemString
	"Could be useful to raise an exception but not yet"! !

!HostWindowProxy methodsFor: 'window manipulation' stamp: 'tpr 9/28/2004 13:35'!
windowSize
	"return the current size of the window "
		^self primitiveWindowSize: windowHandle! !

!HostWindowProxy methodsFor: 'window manipulation' stamp: 'tpr 9/28/2004 13:35'!
windowSize: aPoint
	"Set the size of the window and then return the actually set size of the window - not neccessarily the same "
		^self primitiveWindowSize: windowHandle x: aPoint x y: aPoint y! !

!HostWindowProxy methodsFor: 'window manipulation' stamp: 'bf 1/3/2012 14:49'!
windowTitle: titleString
"set the label in the window titlebar to titleString"
	^self primitiveWindowTitle: windowHandle string: titleString squeakToUtf8! !

HostWindowProxy subclass: #MacOS9WindowProxy
	instanceVariableNames: 'windowClass windowAttributes'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-External-Ffenestri'!

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:40'!
altDBoxProc
	^3
! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:29'!
closeBoxAttribute
	^1! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:40'!
dBoxProc
	^1! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:40'!
documentProc
	^0! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:39'!
documentWindowClass
	^self zoomDocProc! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:41'!
floatGrowProc
	^1987
! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:41'!
floatProc
	^1985
! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:42'!
floatSideGrowProc
	^1995
! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:42'!
floatSideProc
	^1993
! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:42'!
floatSideZoomGrowProc
	^1999! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:42'!
floatSideZoomProc
	^1997! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:42'!
floatZoomGrowProc
	^1991
! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:41'!
floatZoomProc
	^1989
! !

!MacOS9WindowProxy class methodsFor: 'system startup' stamp: 'fbs 7/25/2013 07:14'!
isActiveHostWindowProxyClass
"Am I active?"
	^Smalltalk platformName  = 'Mac OS' and: [Smalltalk osVersion asInteger < 1000]! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:40'!
movableDBoxProc
	^5
! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:10'!
noAttributes
	^0! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:40'!
noGrowDocProc
	^4
! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:40'!
plainDBox
	^2! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:41'!
rDocProc
	^16
! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:43'!
standardDocumentAttributes 
	^self closeBoxAttribute! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:39'!
zoomDocProc
	^8! !

!MacOS9WindowProxy class methodsFor: 'constants' stamp: 'JMM 10/8/2004 12:41'!
zoomNoGrow
	^12
! !

!MacOS9WindowProxy methodsFor: 'accessing' stamp: 'StephaneDucasse 3/17/2010 21:30'!
attributes
	| val |
	val := ByteArray new: 8.
	val 
		unsignedLongAt: 1
		put: windowClass
		bigEndian: Smalltalk isBigEndian.
	val 
		unsignedLongAt: 5
		put: windowAttributes
		bigEndian: Smalltalk isBigEndian.
	^ val! !

!MacOS9WindowProxy methodsFor: 'metrics' stamp: 'JMM 10/7/2004 20:53'!
defaultWindowType
	self windowClass: self class documentWindowClass.
	self windowAttributes: self class standardDocumentAttributes.! !

!MacOS9WindowProxy methodsFor: 'accessing' stamp: 'JMM 10/7/2004 17:38'!
windowAttributes
	^windowAttributes
! !

!MacOS9WindowProxy methodsFor: 'accessing' stamp: 'JMM 10/7/2004 17:38'!
windowAttributes: aNumber
	windowAttributes := aNumber! !

!MacOS9WindowProxy methodsFor: 'accessing' stamp: 'JMM 10/7/2004 17:38'!
windowClass
	^windowClass
! !

!MacOS9WindowProxy methodsFor: 'accessing' stamp: 'JMM 10/7/2004 17:38'!
windowClass: aNumber
	windowClass := aNumber! !

HostWindowProxy subclass: #MacOSXWindowProxy
	instanceVariableNames: 'windowClass windowAttributes'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-External-Ffenestri'!

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:19'!
activatesAttribute 
	^2 raisedTo: 17! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:25'!
alertWindowClass
	^1! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:28'!
altPlainWindowClass
	^16! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:20'!
asyncDragAttribute 
	^2 raisedTo: 23! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:16'!
closeBoxAttribute
	^2 raisedTo: 0! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:17'!
collapseBoxAttribute
	^2 raisedTo: 3! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:19'!
compositingAttribute 
	^2 raisedTo: 19! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:27'!
documentWindowClass
	^6! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:18'!
doesNotCycleAttribute
	^2 raisedTo: 15! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:29'!
drawerWindowClass
	^20! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:26'!
floatingWindowClass
	^5! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:13'!
fullZoomAttribute
	^self verticalZoomAttribute bitOr: self horizontalZoomAttribute! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:27'!
helpWindowClass
	^10! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:21'!
hideOnFullScreenAttribute 
	^2 raisedTo: 26! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:20'!
hideOnSuspendAttribute 
	^2 raisedTo: 24! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:16'!
horizontalZoomAttribute
	^2 raisedTo: 1! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:22'!
ignoreClicksAttribute 
	^2 raisedTo: 29! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:21'!
inWindowMenuAttribute 
	^2 raisedTo: 27! !

!MacOSXWindowProxy class methodsFor: 'system startup' stamp: 'fbs 7/25/2013 07:14'!
isActiveHostWindowProxyClass
"Am I active?"
	^Smalltalk platformName  = 'Mac OS' and: [Smalltalk osVersion asInteger >= 1000]! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:22'!
liveResizeAttribute 
	^2 raisedTo: 28! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:18'!
metalAttribute
	^2 raisedTo: 8! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:26'!
modalWindowClass
	^3! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:26'!
movableAlertWindowClass
	^2! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:26'!
movableModalWindowClass
	^4! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:10'!
noAttributes
	^0! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:22'!
noConstrainAttribute 
	^2 raisedTo: 31! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:20'!
noShadowAttribute 
	^2 raisedTo: 21! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:18'!
noUpdatesAttribute 
	^2 raisedTo: 16! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:19'!
opaqueForEventsAttribute 
	^2 raisedTo: 18! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:28'!
overlayWindowClass
	^14! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:28'!
plainWindowClass
	^13! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:17'!
resizableAttribute
	^2 raisedTo: 4! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:28'!
sheetAlertWindowClass
	^15! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:27'!
sheetWindowClass
	^11! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:17'!
sideTitlebarAttribute
	^2 raisedTo: 5! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:28'!
simpleWindowClass
	^18! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 20:40'!
standardDocumentAttributes 
	^self noConstrainAttribute + self standardHandlerAttribute + self closeBoxAttribute + self fullZoomAttribute + self collapseBoxAttribute + self resizableAttribute


"16r8200001E printStringBase: 2 '2r 10000010 00000000 00000000 00011110'"! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:25'!
standardFloatingAttributes
	^self closeBoxAttribute + self collapseBoxAttribute
! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:21'!
standardHandlerAttribute 
	^2 raisedTo: 25! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:18'!
toolbarButtonAttribute
	^2 raisedTo: 6! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:27'!
toolbarWindowClass
	^12! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 17:27'!
utilityWindowClass
	^8! !

!MacOSXWindowProxy class methodsFor: 'constants' stamp: 'JMM 10/7/2004 20:31'!
verticalZoomAttribute
	^2 raisedTo: 2! !

!MacOSXWindowProxy methodsFor: 'accessing' stamp: 'StephaneDucasse 3/17/2010 21:12'!
attributes
	| val |
	val := ByteArray new: 8.
	val 
		unsignedLongAt: 1
		put: windowClass
		bigEndian: Smalltalk isBigEndian.
	val 
		unsignedLongAt: 5
		put: windowAttributes
		bigEndian: Smalltalk isBigEndian.
	^ val! !

!MacOSXWindowProxy methodsFor: 'metrics' stamp: 'JMM 10/7/2004 20:53'!
defaultWindowType
	self windowClass: self class documentWindowClass.
	self windowAttributes: self class standardDocumentAttributes.! !

!MacOSXWindowProxy methodsFor: 'accessing' stamp: 'JMM 10/7/2004 17:38'!
windowAttributes
	^windowAttributes
! !

!MacOSXWindowProxy methodsFor: 'accessing' stamp: 'JMM 10/7/2004 17:38'!
windowAttributes: aNumber
	windowAttributes := aNumber! !

!MacOSXWindowProxy methodsFor: 'accessing' stamp: 'JMM 10/7/2004 17:38'!
windowClass
	^windowClass
! !

!MacOSXWindowProxy methodsFor: 'accessing' stamp: 'JMM 10/7/2004 17:38'!
windowClass: aNumber
	windowClass := aNumber! !

HostWindowProxy subclass: #UnixX11WindowProxy
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-External-Ffenestri'!

!UnixX11WindowProxy class methodsFor: 'as yet unclassified' stamp: 'tpr 6/8/2016 11:48'!
isActiveHostWindowProxyClass
"Am I active?"
	^Smalltalk platformName = 'unix' ! !

!UnixX11WindowProxy methodsFor: 'window decorations' stamp: 'tpr 6/8/2016 11:48'!
defaultWindowType! !

HostWindowProxy subclass: #Win32WindowProxy
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-External-Ffenestri'!

!Win32WindowProxy class methodsFor: 'as yet unclassified' stamp: 'fbs 7/25/2013 07:21'!
isActiveHostWindowProxyClass
"Am I active?"
	^Smalltalk platformName  = 'Win32'! !

!Win32WindowProxy methodsFor: 'window decorations' stamp: 'ar 1/7/2005 17:22'!
defaultWindowType! !

Object subclass: #IdentityGlyphMap
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Fonts'!

!IdentityGlyphMap methodsFor: 'as yet unclassified' stamp: 'yo 2/13/2004 04:07'!
at: index

	^ index - 1.
! !

Object subclass: #ImageReadWriter
	instanceVariableNames: 'stream'
	classVariableNames: 'ImageNotStoredSignal MagicNumberErrorSignal'
	poolDictionaries: ''
	category: 'Graphics-Files'!

!ImageReadWriter commentStamp: '<historical>' prior: 0!
Copyright (c) Kazuki Yasumatsu, 1995. All rights reserved.

I am an abstract class to provide for encoding and/or decoding an image on a stream.

Instance Variables:
	stream		<ReadStream | WriteStream>	stream for image storages

Class Variables:
	ImageNotStoredSignal		<Signal>	image not stored error signal
	MagicNumberErrorSignal		<Signal>	magic number error signal

Subclasses must implement the following messages:
	accessing
		nextImage
		nextPutImage:
	testing
		canUnderstand         (added tao 10/26/97)!

ImageReadWriter subclass: #BMPReadWriter
	instanceVariableNames: 'bfType bfSize bfOffBits biSize biWidth biHeight biPlanes biBitCount biCompression biSizeImage biXPelsPerMeter biYPelsPerMeter biClrUsed biClrImportant'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Files'!

!BMPReadWriter class methodsFor: 'testing' stamp: 'ar 6/16/2002 18:55'!
displayAllFrom: fd
	"BMPReadWriter displayAllFrom: FileDirectory default"
	fd fileNames do:[:fName|
		(fName endsWith: '.bmp') ifTrue:[
			[(Form fromBinaryStream: (fd readOnlyFileNamed: fName)) display.
			Display forceDisplayUpdate] on: Error do:[:nix|].
		].
	].
	fd directoryNames do:[:fdName|
		self displayAllFrom: (fd directoryNamed: fdName)
	].! !

!BMPReadWriter class methodsFor: 'testing' stamp: 'ar 6/16/2002 18:56'!
readAllFrom: fd
	"MessageTally spyOn:[BMPReadWriter readAllFrom: FileDirectory default]"
	fd fileNames do:[:fName|
		(fName endsWith: '.bmp') ifTrue:[
			[Form fromBinaryStream: (fd readOnlyFileNamed: fName)] on: Error do:[:nix].
		].
	].
	fd directoryNames do:[:fdName|
		self readAllFrom: (fd directoryNamed: fdName)
	].! !

!BMPReadWriter class methodsFor: 'image reading/writing' stamp: 'nk 7/16/2003 17:56'!
typicalFileExtensions
	"Answer a collection of file extensions (lowercase) which files that I can read might commonly have"
	^#('bmp')! !

!BMPReadWriter methodsFor: 'reading' stamp: 'ar 6/16/2002 15:36'!
nextImage
	| colors |
	stream binary.
	self readHeader.
	biBitCount = 24 ifTrue:[^self read24BmpFile].
	"read the color map"
	colors := self readColorMap.
	^self readIndexedBmpFile: colors! !

!BMPReadWriter methodsFor: 'writing' stamp: 'ar 12/21/2010 20:03'!
nextPutImage: aForm
	| bhSize rowBytes rgb data colorValues depth image ppw scanLineLen pixline |
	depth := aForm depth.
	depth := #(1 4 8 32 ) detect: [ :each | each >= depth].
	image := aForm asFormOfDepth: depth.
	image unhibernate.
	bhSize := 14.  "# bytes in file header"
	biSize := 40.  "info header size in bytes"
	biWidth := image width.
	biHeight := image height.
	biClrUsed := depth = 32 ifTrue: [0] ifFalse:[1 << depth].  "No. color table entries"
	bfOffBits := biSize + bhSize + (4*biClrUsed).
	rowBytes := ((depth min: 24) * biWidth + 31 // 32) * 4.
	biSizeImage := biHeight * rowBytes.

	"Write the file header"
	stream position: 0.
	stream nextLittleEndianNumber: 2 put: 19778.  "bfType = BM"
	stream nextLittleEndianNumber: 4 put: bfOffBits + biSizeImage.  "Entire file size in bytes"
	stream nextLittleEndianNumber: 4 put: 0.  "bfReserved"
	stream nextLittleEndianNumber: 4 put: bfOffBits.  "Offset of bitmap data from start of hdr (and file)"

	"Write the bitmap info header"
	stream position: bhSize.
	stream nextLittleEndianNumber: 4 put: biSize.  "info header size in bytes"
	stream nextLittleEndianNumber: 4 put: image width.  "biWidth"
	stream nextLittleEndianNumber: 4 put: image height.  "biHeight"
	stream nextLittleEndianNumber: 2 put: 1.  "biPlanes"
	stream nextLittleEndianNumber: 2 put: (depth min: 24).  "biBitCount"
	stream nextLittleEndianNumber: 4 put: 0.  "biCompression"
	stream nextLittleEndianNumber: 4 put: biSizeImage.  "size of image section in bytes"
	stream nextLittleEndianNumber: 4 put: 2800.  "biXPelsPerMeter"
	stream nextLittleEndianNumber: 4 put: 2800.  "biYPelsPerMeter"
	stream nextLittleEndianNumber: 4 put: biClrUsed.
	stream nextLittleEndianNumber: 4 put: 0.  "biClrImportant"
	biClrUsed > 0 ifTrue: [
		"write color map; this works for ColorForms, too"
		colorValues := image colormapIfNeededForDepth: 32.
		1 to: biClrUsed do: [:i |
			rgb := colorValues at: i.
			0 to: 24 by: 8 do: [:j | stream nextPut: (rgb >> j bitAnd: 16rFF)]]].

	depth < 32 ifTrue: [
		"depth = 1, 4 or 8."
		data := image bits asByteArray.
		ppw := 32 // depth.
		scanLineLen := biWidth + ppw - 1 // ppw * 4.  "# of bytes in line"
		1 to: biHeight do: [:i |
			stream next: scanLineLen putAll: data startingAt: (biHeight-i)*scanLineLen+1.
		].
	] ifFalse: [
		data := image bits.
		pixline := ByteArray new: (((biWidth * 3 + 3) // 4) * 4).
		1 to: biHeight do:[:i |
			self store24BitBmpLine: pixline from: data startingAt: (biHeight-i)*biWidth+1 width: biWidth.
			stream nextPutAll: pixline.
		].
	].
	stream position = (bfOffBits + biSizeImage) ifFalse: [self error:'Write failure'].
	stream close.! !

!BMPReadWriter methodsFor: 'reading' stamp: 'ar 10/25/2005 13:48'!
read24BmpFile
	"Read 24-bit pixel data from the given a BMP stream."
	| form formBits pixelLine bitsIndex bitBlt |
	form := Form extent: biWidth@biHeight depth: 32.
	pixelLine := ByteArray new: (((24 * biWidth) + 31) // 32) * 4.
	bitsIndex := form height - 1 * biWidth + 1.
	formBits := form bits.
	1 to: biHeight do: [:i |
		pixelLine := stream nextInto: pixelLine.
		self read24BmpLine: pixelLine into: formBits startingAt: bitsIndex width: biWidth.
		bitsIndex := bitsIndex - biWidth.
	].
	bitBlt := BitBlt toForm: form.
	bitBlt combinationRule: 7 "bitOr:with:".
	bitBlt halftoneForm: (Bitmap with: 16rFF000000).
	bitBlt copyBits.
	^ form
! !

!BMPReadWriter methodsFor: 'reading' stamp: 'ar 12/21/2010 20:11'!
read24BmpLine: pixelLine into: formBits startingAt: formBitsIndex width: width
	"Swizzles the bytes in a 24bpp scanline and fills in the given 32bpp form bits.
	Ensures that color black is represented as 16rFF000001 so that Form paint
	works properly."

	| pixIndex rgb bitsIndex |
	<primitive: 'primitiveRead24BmpLine' module:'BMPReadWriterPlugin'>
	pixIndex := 0. "pre-increment"
	bitsIndex := formBitsIndex-1. "pre-increment"
	1 to: width do: [:j |
		rgb := 
			(pixelLine at: (pixIndex := pixIndex+1)) +
			((pixelLine at: (pixIndex := pixIndex+1)) bitShift: 8) +
			((pixelLine at: (pixIndex := pixIndex+1)) bitShift: 16).
		rgb = 0 ifTrue:[rgb := 16rFF000001] ifFalse:[rgb := rgb + 16rFF000000].
		formBits at: (bitsIndex := bitsIndex+1) put: rgb.
	].
! !

!BMPReadWriter methodsFor: 'reading' stamp: 'ar 10/24/2005 20:57'!
readColorMap
	"Read colorCount BMP color map entries from the given binary stream. Answer an array of Colors."
	| colorCount colors maxLevel b g r ccStream |
	colorCount := (bfOffBits - 54) // 4.
	"Note: some programs (e.g. Photoshop 4.0) apparently do not set colorCount; assume that any data between the end of the header and the start of the pixel data is the color map"
	biBitCount >= 16 ifTrue:[^nil].
	colorCount = 0 ifTrue: [ "this BMP file does not have a color map"
		"default monochrome color map"
		biBitCount = 1 ifTrue: [^ Array with: Color white with: Color black].
		"default gray-scale color map"
		maxLevel := (2 raisedTo: biBitCount) - 1.
		^ (0 to: maxLevel) collect: [:level | Color gray: (level asFloat / maxLevel)]].
	ccStream := ReadStream on: (stream next: colorCount*4).
	colors := Array new: colorCount.
	1 to: colorCount do: [:i |
		b := ccStream next.
		g := ccStream next.
		r := ccStream next.
		ccStream next. "skip reserved"
		colors at: i put: (Color r: r g: g b: b range: 255)].
	^ colors
! !

!BMPReadWriter methodsFor: 'reading' stamp: 'ar 6/16/2002 15:20'!
readHeader
	| reserved |
	bfType := stream nextLittleEndianNumber: 2.
	bfSize := stream nextLittleEndianNumber: 4.
	reserved := stream nextLittleEndianNumber: 4.
	bfOffBits := stream nextLittleEndianNumber: 4.
	biSize := stream nextLittleEndianNumber: 4.
	biWidth := stream nextLittleEndianNumber: 4.
	biHeight := stream nextLittleEndianNumber: 4.
	biPlanes := stream nextLittleEndianNumber: 2.
	biBitCount := stream nextLittleEndianNumber: 2.
	biCompression := stream nextLittleEndianNumber: 4.
	biSizeImage := stream nextLittleEndianNumber: 4.
	biXPelsPerMeter := stream nextLittleEndianNumber: 4.
	biYPelsPerMeter := stream nextLittleEndianNumber: 4.
	biClrUsed := stream nextLittleEndianNumber: 4.
	biClrImportant := stream nextLittleEndianNumber: 4.
! !

!BMPReadWriter methodsFor: 'reading' stamp: 'ar 10/25/2005 13:45'!
readIndexedBmpFile: colors
	"Read uncompressed pixel data of depth d from the given BMP stream, where d is 1, 4, 8, or 16"
	| form bytesPerRow pixelData pixelLine startIndex map bitBlt mask |
	colors 
		ifNil:[form := Form extent: biWidth@biHeight depth: biBitCount]
		ifNotNil:[form := ColorForm extent: biWidth@biHeight depth: biBitCount.
				form colors: colors].
	bytesPerRow := (((biBitCount* biWidth) + 31) // 32) * 4.
	pixelData := ByteArray new: bytesPerRow * biHeight.
	biHeight to: 1 by: -1 do: [:y |
		pixelLine := stream next: bytesPerRow.
		startIndex := ((y - 1) * bytesPerRow) + 1.
		pixelData 
			replaceFrom: startIndex 
			to: startIndex + bytesPerRow - 1 
			with: pixelLine 
			startingAt: 1].
	form bits copyFromByteArray: pixelData.
	biBitCount = 16 ifTrue:[
		map := ColorMap shifts: #(8 -8 0 0) masks: #(16rFF 16rFF00 0 0).
		mask := 16r80008000.
	].
	biBitCount = 32 ifTrue:[
		map := ColorMap shifts: #(24 8 -8 -24) masks: #(16rFF 16rFF00 16rFF0000 16rFF000000).
		mask := 16rFF000000.
	].
	map ifNotNil:[
		bitBlt := BitBlt toForm: form.
		bitBlt sourceForm: form.
		bitBlt colorMap: map.
		bitBlt combinationRule: Form over.
		bitBlt copyBits.
	].
	mask ifNotNil:[
		bitBlt := BitBlt toForm: form.
		bitBlt combinationRule: 7 "bitOr:with:".
		bitBlt halftoneForm: (Bitmap with: mask).
		bitBlt copyBits.
	].
	^ form
! !

!BMPReadWriter methodsFor: 'writing' stamp: 'ar 12/21/2010 20:12'!
store24BitBmpLine: pixelLine from: formBits startingAt: formBitsIndex width: width
	"Stores a single scanline containing 32bpp RGBA values in a 24bpp scanline.
	Swizzles the bytes as needed."

	| pixIndex rgb bitsIndex |
	<primitive: 'primitiveWrite24BmpLine' module:'BMPReadWriterPlugin'>
	pixIndex := 0. "pre-increment"
	bitsIndex := formBitsIndex-1. "pre-increment"
	1 to: width do: [:j |
		rgb := (formBits at: (bitsIndex := bitsIndex+1)) bitAnd: 16rFFFFFF.
		pixelLine at: (pixIndex := pixIndex+1) put: (rgb bitAnd: 255).
		pixelLine at: (pixIndex := pixIndex+1) put: ((rgb bitShift: -8) bitAnd: 255).
		pixelLine at: (pixIndex := pixIndex+1) put: ((rgb bitShift: -16) bitAnd: 255).
	].
! !

!BMPReadWriter methodsFor: 'testing' stamp: 'ar 6/16/2002 15:27'!
understandsImageFormat
	stream size < 54 ifTrue:[^false]. "min size = BITMAPFILEHEADER+BITMAPINFOHEADER"
	self readHeader.
	bfType = 19778 "BM" ifFalse:[^false].
	biSize = 40 ifFalse:[^false].
	biPlanes = 1 ifFalse:[^false].
	bfSize <= stream size ifFalse:[^false].
	biCompression = 0 ifFalse:[^false].
	^true! !

ImageReadWriter subclass: #GIFReadWriter
	instanceVariableNames: 'width height bitsPerPixel colorPalette rowByteSize xpos ypos pass interlace codeSize clearCode eoiCode freeCode maxCode prefixTable suffixTable remainBitCount bufByte bufStream transparentIndex mapOf32 localColorTable delay loopCount offset'
	classVariableNames: 'Extension ImageSeparator Terminator'
	poolDictionaries: ''
	category: 'Graphics-Files'!

!GIFReadWriter commentStamp: '<historical>' prior: 0!
Copyright (c) Kazuki Yasumatsu, 1995. All rights reserved.

Used with permission.  Modified for use in Squeak.!

GIFReadWriter subclass: #AnimatedGIFReadWriter
	instanceVariableNames: 'forms delays comments'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Files'!

!AnimatedGIFReadWriter class methodsFor: 'image reading/writing' stamp: 'mir 11/18/2003 17:00'!
formsFromFileNamed: fileName 
	| stream |
	stream := FileStream readOnlyFileNamed: fileName.
	^ self formsFromStream: stream! !

!AnimatedGIFReadWriter class methodsFor: 'image reading/writing' stamp: 'mir 11/18/2003 17:00'!
formsFromStream: stream 
	| reader |
	reader := self new on: stream reset.
	Cursor read
		showWhile: [reader allImages.
			reader close].
	^reader! !

!AnimatedGIFReadWriter class methodsFor: 'image reading/writing' stamp: 'nk 6/12/2004 13:12'!
typicalFileExtensions
	"Answer a collection of file extensions (lowercase) which files that I can read might commonly have"
	^#('gif')! !

!AnimatedGIFReadWriter class methodsFor: 'image reading/writing' stamp: 'asm 12/11/2003 21:29'!
wantsToHandleGIFs
	^true! !

!AnimatedGIFReadWriter methodsFor: 'accessing' stamp: 'nice 7/22/2014 00:57'!
allImages
	| body colorTable |
	localColorTable := nil.
	forms := OrderedCollection new.
	delays := OrderedCollection new.
	comments := OrderedCollection new.
	self readHeader.
	[(body := self readBody) == nil]
		whileFalse: [colorTable := localColorTable
						ifNil: [colorPalette].
			transparentIndex
				ifNotNil: [transparentIndex + 1 > colorTable size
						ifTrue: [colorTable := colorTable forceTo: transparentIndex + 1 paddingWith: Color white].
					colorTable at: transparentIndex + 1 put: Color transparent].
			body colors: colorTable.
			forms add: body.
			delays add: delay].
	^ forms! !

!AnimatedGIFReadWriter methodsFor: 'private' stamp: 'mir 11/19/2003 12:25'!
comment: aString
	comments add: aString! !

!AnimatedGIFReadWriter methodsFor: 'accessing' stamp: 'mir 11/19/2003 14:16'!
delays
	^ delays! !

!AnimatedGIFReadWriter methodsFor: 'accessing' stamp: 'mir 11/19/2003 14:16'!
forms
	^ forms! !

!AnimatedGIFReadWriter methodsFor: 'private-decoding' stamp: 'mir 11/19/2003 12:21'!
readBitData
	| form |
	form := super readBitData.
	form offset: offset.
	^form! !

!GIFReadWriter class methodsFor: 'examples' stamp: 'bf 5/29/2003 01:56'!
exampleAnim
	"GIFReadWriter exampleAnim"

	| writer extent center |
	writer := GIFReadWriter on: (FileStream newFileNamed: 'anim.gif').
	writer loopCount: 20.		"Repeat 20 times"
	writer delay: 10.		"Wait 10/100 seconds"
	extent := 42@42.
	center := extent / 2.
	Cursor write showWhile: [
		[2 to: center x - 1 by: 2 do: [:r |
			"Make a fancy anim without using Canvas - inefficient as hell"
			| image |
			image := ColorForm extent: extent depth: 8.
			0.0 to: 359.0 do: [:theta | image colorAt: (center + (Point r: r degrees: theta)) rounded put: Color red].
			writer nextPutImage: image]
		]	ensure: [writer close]].! !

!GIFReadWriter class methodsFor: 'examples' stamp: 'fbs 7/12/2013 20:50'!
grabScreenAndSaveOnDisk
	"GIFReaderWriter grabScreenAndSaveOnDisk"

	| form fileName |
	form := Form fromUser.
	form bits size = 0 ifTrue: [^Beeper beep].
	fileName := FileDirectory default nextNameFor: 'Squeak' extension: 'gif'.
	UIManager default informUser: 'Writing ' , fileName
		during: [GIFReadWriter putForm: form onFileNamed: fileName]! !

!GIFReadWriter class methodsFor: 'class initialization' stamp: ''!
initialize
	"GIFReadWriter initialize"

	ImageSeparator := $, asInteger.
	Extension := $!! asInteger.
	Terminator := $; asInteger.
! !

!GIFReadWriter class methodsFor: 'image reading/writing' stamp: 'asm 12/11/2003 21:29'!
typicalFileExtensions
	"Answer a collection of file extensions (lowercase) which files that I can 
	read might commonly have"

	self
		allSubclasses detect: [:cls | cls wantsToHandleGIFs ]
					 ifNone: ["if none of my subclasses wants , then i''ll have to do"
							^ #('gif' )].
	^ #( )! !

!GIFReadWriter class methodsFor: 'image reading/writing' stamp: 'asm 12/11/2003 21:29'!
wantsToHandleGIFs
	^ false! !

!GIFReadWriter methodsFor: 'private' stamp: ''!
checkCodeSize
	(freeCode > maxCode and: [codeSize < 12])
		ifTrue:
			[codeSize := codeSize + 1.
			maxCode := (1 bitShift: codeSize) - 1]! !

!GIFReadWriter methodsFor: 'accessing' stamp: 'bf 5/29/2003 01:43'!
delay: aNumberOrNil
	"Set delay for next image in hundredth (1/100) of seconds"
	delay := aNumberOrNil! !

!GIFReadWriter methodsFor: 'private-packing' stamp: ''!
fillBuffer
	| packSize |
	packSize := self next.
	bufStream := ReadStream on: (self next: packSize)! !

!GIFReadWriter methodsFor: 'private-bits access' stamp: ''!
flushBits
	remainBitCount = 0 ifFalse:
		[self nextBytePut: bufByte.
		remainBitCount := 0].
	self flushBuffer! !

!GIFReadWriter methodsFor: 'private-packing' stamp: ''!
flushBuffer
	bufStream isEmpty ifTrue: [^self].
	self nextPut: bufStream size.
	self nextPutAll: bufStream contents.
	bufStream := WriteStream on: (ByteArray new: 256)! !

!GIFReadWriter methodsFor: 'private-encoding' stamp: ''!
flushCode
	self flushBits! !

!GIFReadWriter methodsFor: 'accessing' stamp: 'bf 5/29/2003 01:39'!
loopCount: aNumber
	"Set looping. This must be done before any image is written!!"
	loopCount := aNumber! !

!GIFReadWriter methodsFor: 'private-bits access' stamp: ''!
nextBits
	| integer readBitCount shiftCount byte |
	integer := 0.
	remainBitCount = 0
		ifTrue:
			[readBitCount := 8.
			shiftCount := 0]
		ifFalse:
			[readBitCount := remainBitCount.
			shiftCount := remainBitCount - 8].
	[readBitCount < codeSize]
		whileTrue:
			[byte := self nextByte.
			byte == nil ifTrue: [^eoiCode].
			integer := integer + (byte bitShift: shiftCount).
			shiftCount := shiftCount + 8.
			readBitCount := readBitCount + 8].
	(remainBitCount := readBitCount - codeSize) = 0
		ifTrue:	[byte := self nextByte]
		ifFalse:	[byte := self peekByte].
	byte == nil ifTrue: [^eoiCode].
	^(integer + (byte bitShift: shiftCount)) bitAnd: maxCode! !

!GIFReadWriter methodsFor: 'private-bits access' stamp: ''!
nextBitsPut: anInteger
	| integer writeBitCount shiftCount |
	shiftCount := 0.
	remainBitCount = 0
		ifTrue:
			[writeBitCount := 8.
			integer := anInteger]
		ifFalse:
			[writeBitCount := remainBitCount.
			integer := bufByte + (anInteger bitShift: 8 - remainBitCount)].
	[writeBitCount < codeSize]
		whileTrue:
			[self nextBytePut: ((integer bitShift: shiftCount) bitAnd: 255).
			shiftCount := shiftCount - 8.
			writeBitCount := writeBitCount + 8].
	(remainBitCount := writeBitCount - codeSize) = 0
		ifTrue: [self nextBytePut: (integer bitShift: shiftCount)]
		ifFalse: [bufByte := integer bitShift: shiftCount].
	^anInteger! !

!GIFReadWriter methodsFor: 'private-packing' stamp: ''!
nextByte
	bufStream atEnd
		ifTrue:
			[self atEnd ifTrue: [^nil].
			self fillBuffer].
	^bufStream next! !

!GIFReadWriter methodsFor: 'private-packing' stamp: ''!
nextBytePut: aByte
	bufStream nextPut: aByte.
	bufStream size >= 254 ifTrue: [self flushBuffer]! !

!GIFReadWriter methodsFor: 'accessing' stamp: 'nice 7/22/2014 00:57'!
nextImage
	"Read in the next GIF image from the stream."

	| f thisImageColorTable |

	localColorTable := nil.
	self readHeader.
	f := self readBody.
	self close.
	f == nil ifTrue: [^ self error: 'corrupt GIF file'].

	thisImageColorTable := localColorTable ifNil: [colorPalette].
	transparentIndex ifNotNil: [
		transparentIndex + 1 > thisImageColorTable size ifTrue: [
			thisImageColorTable := thisImageColorTable 
				forceTo: transparentIndex + 1 
				paddingWith: Color white
		].
		thisImageColorTable at: transparentIndex + 1 put: Color transparent
	].
	f colors: thisImageColorTable.
	^ f
! !

!GIFReadWriter methodsFor: 'accessing' stamp: 'cmm 1/19/2012 20:39'!
nextPutImage: aForm

	| reduced tempForm |
	aForm unhibernate.
	aForm depth > 8 ifTrue:[
		reduced := aForm colorReduced.  "minimize depth"
		reduced depth > 8 ifTrue: [
			"Not enough color space; do it the hard way."
			reduced := reduced asFormOfDepth: 8].
	] ifFalse:[reduced := aForm].
	reduced depth < 8 ifTrue: [
		"writeBitData: expects depth of 8"
		tempForm := reduced species extent: reduced extent depth: 8.
		(reduced isColorForm) ifTrue:[
			tempForm
				copyBits: reduced boundingBox
				from: reduced at: 0@0
				clippingBox: reduced boundingBox
				rule: Form over
				fillColor: nil
				map: nil.
			tempForm colors: reduced colors.
		] ifFalse: [reduced displayOn: tempForm].
		reduced := tempForm.
	].
	(reduced isColorForm) ifTrue:[
		(reduced colorsUsed includes: Color transparent) ifTrue: [
			transparentIndex := (reduced colors indexOf: Color transparent) - 1.
		]
	] ifFalse: [transparentIndex := nil].
	width := reduced width.
	height := reduced height.
	bitsPerPixel := reduced depth.
	colorPalette := reduced colormapIfNeededForDepth: 32.
	interlace := false.
	self writeHeader.
	self writeBitData: reduced bits.
! !

!GIFReadWriter methodsFor: 'private-packing' stamp: ''!
peekByte
	bufStream atEnd
		ifTrue:
			[self atEnd ifTrue: [^nil].
			self fillBuffer].
	^bufStream peek! !

!GIFReadWriter methodsFor: 'private-decoding' stamp: 'wiz 11/13/2008 21:36'!
readBitData
	"using modified Lempel-Ziv Welch algorithm."

	| outCodes outCount bitMask initCodeSize code curCode oldCode inCode finChar i bytes f c packedBits hasLocalColor localColorSize maxOutCodes |

	maxOutCodes _ 4096.
	offset := self readWord@self readWord. "Image Left@Image Top"
	width _ self readWord.
	height _ self readWord.

	"---
	Local Color Table Flag        1 Bit
	Interlace Flag                1 Bit
	Sort Flag                     1 Bit
	Reserved                      2 Bits
	Size of Local Color Table     3 Bits
	----"
	packedBits _ self next.
	interlace _ (packedBits bitAnd: 16r40) ~= 0.
	hasLocalColor _ (packedBits bitAnd: 16r80) ~= 0.
	localColorSize _ 1 bitShift: ((packedBits bitAnd: 16r7) + 1).
	hasLocalColor ifTrue: [localColorTable _ self readColorTable: localColorSize].

	pass _ 0.
	xpos _ 0.
	ypos _ 0.
	rowByteSize _ ((width + 3) // 4) * 4.
	remainBitCount _ 0.
	bufByte _ 0.
	bufStream _ ReadStream on: ByteArray new.

	outCodes _ ByteArray new: maxOutCodes + 1.
	outCount _ 0.
	
	prefixTable _ Array new: 4096.
	suffixTable _ Array new: 4096.

	initCodeSize _ self next.
	bitMask _ (1 bitShift: initCodeSize ) - 1.
	self setParameters: initCodeSize.
	bitsPerPixel > 8 ifTrue: [^self error: 'never heard of a GIF that deep'].
	bytes _ ByteArray new: rowByteSize * height.
	[(code _ self readCode) = eoiCode] whileFalse:
		[code = clearCode
			ifTrue:
				[self setParameters: initCodeSize.
				curCode _ oldCode _ code _ self readCode.
				finChar _ curCode bitAnd: bitMask.
				"Horrible hack to avoid running off the end of the bitmap.  Seems to cure problem reading some gifs!!? tk 6/24/97 20:16"
				xpos = 0 ifTrue: [
						ypos < height ifTrue: [
							bytes at: (ypos * rowByteSize) + xpos + 1 put: finChar]]
					ifFalse: [bytes at: (ypos * rowByteSize) + xpos + 1 put: finChar].
				self updatePixelPosition]
			ifFalse:
				[curCode _ inCode _ code.
				curCode >= freeCode ifTrue:
					[curCode _ oldCode.
					outCodes at: (outCount _ outCount + 1) put: finChar].
				[curCode > bitMask] whileTrue:
					[outCount > maxOutCodes
						ifTrue: [^self error: 'corrupt GIF file (OutCount)'].
					outCodes at: (outCount _ outCount + 1)
						put: (suffixTable at: curCode + 1).
					curCode _ prefixTable at: curCode + 1].
				finChar _ curCode bitAnd: bitMask.
				outCodes at: (outCount _ outCount + 1) put: finChar.
				i _ outCount.
				[i > 0] whileTrue:
					["self writePixel: (outCodes at: i) to: bits"
					bytes at: (ypos * rowByteSize) + xpos + 1 put: (outCodes at: i).
					self updatePixelPosition.
					i _ i - 1].
				outCount _ 0.
				prefixTable at: freeCode + 1 put: oldCode.
				suffixTable at: freeCode + 1 put: finChar.
				oldCode _ inCode.
				freeCode _ freeCode + 1.
				self checkCodeSize]].
	prefixTable _ suffixTable _ nil.

	f _ ColorForm extent: width@height depth: 8.
	f bits copyFromByteArray: bytes.
	"Squeak can handle depths 1, 2, 4, and 8"
	bitsPerPixel > 4 ifTrue: [^ f].
	"reduce depth to save space"
	c _ ColorForm extent: width@height
		depth: (bitsPerPixel = 3 ifTrue: [4] ifFalse: [bitsPerPixel]).
	f displayOn: c.
	^ c
! !

!GIFReadWriter methodsFor: 'private-decoding' stamp: 'kfr 1/10/2015 15:17'!
readBody
	"Read the GIF blocks. Modified to return a form.  "

	| form extype block blocksize packedFields delay1 |
	form := nil.
	[stream atEnd] whileFalse: [
		block := self next.
		block = Terminator ifTrue: [^ form].
		block = ImageSeparator ifTrue: [
			form isNil
				ifTrue: [form := self readBitData]
				ifFalse: [self skipBitData].
		] ifFalse: [
			block = Extension
				ifFalse: [^ form "^ self error: 'Unknown block type'"].
			"Extension block"
			extype := self next.	"extension type"
			extype = 16rF9 ifTrue: [  "graphics control"
				self next = 4 ifFalse: [^ form "^ self error: 'corrupt GIF file'"].
				"====
				Reserved                      3 Bits
				Disposal Method               3 Bits
				User Input Flag               1 Bit
				Transparent Color Flag        1 Bit
				==="
 
				packedFields := self next.
				delay1 := self next.	"delay time 1"
				delay := (self next*256 + delay1) *10.	 "delay time 2"
				transparentIndex := self next.
				(packedFields bitAnd: 1) = 0 ifTrue: [transparentIndex := nil].
				self next = 0 ifFalse: [^ form "^ self error: 'corrupt GIF file'"].
			] ifFalse: [
				"Skip blocks"
				[(blocksize := self next) > 0]
					whileTrue: [
						"Read the block and ignore it and eat the block terminator"
						self next: blocksize]]]].
		^nil! !

!GIFReadWriter methodsFor: 'private-decoding' stamp: ''!
readCode
	^self nextBits! !

!GIFReadWriter methodsFor: 'private-decoding' stamp: 'RAA 4/25/2001 08:48'!
readColorTable: numberOfEntries

	| array r g b |

	array := Array new: numberOfEntries.
	1 to: array size do: [ :i |
		r := self next.  
		g := self next.  
		b := self next.
		array at: i put: (Color r: r g: g b: b range: 255)
	].
	^array! !

!GIFReadWriter methodsFor: 'private-decoding' stamp: 'RAA 4/25/2001 08:49'!
readHeader
	| is89 byte hasColorMap |
	(self hasMagicNumber: 'GIF87a' asByteArray)
		ifTrue: [is89 := false]
		ifFalse: [(self hasMagicNumber: 'GIF89a' asByteArray)
			ifTrue: [is89 := true]
			ifFalse: [^ self error: 'This does not appear to be a GIF file']].
	self readWord.	"skip Screen Width"
	self readWord.	"skip Screen Height"
	byte := self next.
	hasColorMap := (byte bitAnd: 16r80) ~= 0.
	bitsPerPixel := (byte bitAnd: 7) + 1.
	byte := self next.	"skip background color."
	self next ~= 0
		ifTrue: [is89
			ifFalse: [^self error: 'corrupt GIF file (screen descriptor)']].
	hasColorMap
		ifTrue:
			[colorPalette := self readColorTable: (1 bitShift: bitsPerPixel)]
		ifFalse:
			["Transcript cr; show: 'GIF file does not have a color map.'."
			colorPalette := nil "Palette monochromeDefault"].! !

!GIFReadWriter methodsFor: 'private-encoding' stamp: 'tk 9/14/97 16:25'!
readPixelFrom: bits
	"Since bits is a Bitmap with 32 bit values, watch out for the
padding at the end of each row.  But, GIF format already wants padding to
32 bit boundary!!  OK as is.  tk 9/14/97"

	| pixel |
	ypos >= height ifTrue: [^nil].
	pixel := bits byteAt: (ypos * rowByteSize + xpos + 1).
	self updatePixelPosition.
	^pixel! !

!GIFReadWriter methodsFor: 'private-decoding' stamp: ''!
readWord
	^self next + (self next bitShift: 8)! !

!GIFReadWriter methodsFor: 'private' stamp: ''!
setParameters: initCodeSize
	clearCode := 1 bitShift: initCodeSize.
	eoiCode := clearCode + 1.
	freeCode := clearCode + 2.
	codeSize := initCodeSize + 1.
	maxCode := (1 bitShift: codeSize) - 1! !

!GIFReadWriter methodsFor: 'accessing' stamp: '6/18/97 13:18 '!
setStream: aStream
	"Feed it in from an existing source"
	stream := aStream! !

!GIFReadWriter methodsFor: 'private-decoding' stamp: ''!
skipBitData
	| misc blocksize |
	self readWord.  "skip Image Left"
	self readWord.  "skip Image Top"
	self readWord.  "width"
	self readWord.  "height"
	misc := self next.
	(misc bitAnd: 16r80) = 0 ifFalse: [ "skip colormap"
		1 to: (1 bitShift: (misc bitAnd: 7) + 1) do: [:i |
			self next; next; next]].
	self next.  "minimum code size"
	[(blocksize := self next) > 0]
		whileTrue: [self next: blocksize]! !

!GIFReadWriter methodsFor: 'accessing' stamp: 'di 9/15/1998 09:53'!
understandsImageFormat
	^('abc' collect: [:x | stream next asCharacter]) = 'GIF'! !

!GIFReadWriter methodsFor: 'private' stamp: ''!
updatePixelPosition
	(xpos := xpos + 1) >= width ifFalse: [^self].
	xpos := 0.
	interlace
		ifFalse: [ypos := ypos + 1. ^self].
	pass = 0 ifTrue:
		[(ypos := ypos + 8) >= height
			ifTrue:
				[pass := pass + 1.
				ypos := 4].
		^self].
	pass = 1 ifTrue:
		[(ypos := ypos + 8) >= height
			ifTrue:
				[pass := pass + 1.
				ypos := 2].
		^self].
	pass = 2 ifTrue:
		[(ypos := ypos + 4) >= height
			ifTrue:
				[pass := pass + 1.
				ypos := 1].
		^self].
	pass = 3 ifTrue:
		[ypos := ypos + 2.
		^self].

	^self error: 'can''t happen'! !

!GIFReadWriter methodsFor: 'private-encoding' stamp: 'bf 5/29/2003 01:21'!
writeBitData: bits
	"using modified Lempel-Ziv Welch algorithm."

	| maxBits maxMaxCode tSize initCodeSize ent tShift fCode pixel index disp nomatch |
	pass := 0.
	xpos := 0.
	ypos := 0.
	rowByteSize := width * 8 + 31 // 32 * 4.
	remainBitCount := 0.
	bufByte := 0.
	bufStream := WriteStream on: (ByteArray new: 256).

	maxBits := 12.
	maxMaxCode := 1 bitShift: maxBits.
	tSize := 5003.
	prefixTable := Array new: tSize.
	suffixTable := Array new: tSize.

	initCodeSize := bitsPerPixel <= 1 ifTrue: [2] ifFalse: [bitsPerPixel].
	self nextPut: initCodeSize.
	self setParameters: initCodeSize.

	tShift := 0.
	fCode := tSize.
	[fCode < 65536] whileTrue:
		[tShift := tShift + 1.
		fCode := fCode * 2].
	tShift := 8 - tShift.
	1 to: tSize do: [:i | suffixTable at: i put: -1].

	self writeCodeAndCheckCodeSize: clearCode.
	ent := self readPixelFrom: bits.
	[(pixel := self readPixelFrom: bits) == nil] whileFalse:
		[
		fCode := (pixel bitShift: maxBits) + ent.
		index := ((pixel bitShift: tShift) bitXor: ent) + 1.
		(suffixTable at: index) = fCode
			ifTrue: [ent := prefixTable at: index]
			ifFalse:
				[nomatch := true.
				(suffixTable at: index) >= 0
					ifTrue:
						[disp := tSize - index + 1.
						index = 1 ifTrue: [disp := 1].
						"probe"
						[(index := index - disp) < 1 ifTrue: [index := index + tSize].
						(suffixTable at: index) = fCode
							ifTrue:
								[ent := prefixTable at: index.
								nomatch := false.
								"continue whileFalse:"].
						nomatch and: [(suffixTable at: index) > 0]]
							whileTrue: ["probe"]].
				"nomatch"
				nomatch ifTrue:
					[self writeCodeAndCheckCodeSize: ent.
					ent := pixel.
					freeCode < maxMaxCode
						ifTrue:
							[prefixTable at: index put: freeCode.
							suffixTable at: index put: fCode.
							freeCode := freeCode + 1]
						ifFalse:
							[self writeCodeAndCheckCodeSize: clearCode.
							1 to: tSize do: [:i | suffixTable at: i put: -1].
							self setParameters: initCodeSize]]]].
	prefixTable := suffixTable := nil.
	self writeCodeAndCheckCodeSize: ent.
	self writeCodeAndCheckCodeSize: eoiCode.
	self flushCode.

	self nextPut: 0.	"zero-length packet"
! !

!GIFReadWriter methodsFor: 'private-encoding' stamp: ''!
writeCodeAndCheckCodeSize: aCode
	self writeCode: aCode.
	self checkCodeSize! !

!GIFReadWriter methodsFor: 'private-encoding' stamp: ''!
writeCode: aCode
	self nextBitsPut: aCode! !

!GIFReadWriter methodsFor: 'private-encoding' stamp: 'bf 5/29/2003 01:38'!
writeHeader

	| byte |
	stream position = 0 ifTrue: [
		"For first image only"
		self nextPutAll: 'GIF89a' asByteArray.
		self writeWord: width.	"Screen Width"
		self writeWord: height.	"Screen Height"
		byte := 16r80.  "has color map"
		byte := byte bitOr: ((bitsPerPixel - 1) bitShift: 5).  "color resolution"
		byte := byte bitOr: bitsPerPixel - 1.  "bits per pixel"
		self nextPut: byte.
		self nextPut: 0.		"background color."
		self nextPut: 0.		"reserved"
		colorPalette do: [:pixelValue |
			self	nextPut: ((pixelValue bitShift: -16) bitAnd: 255);
				nextPut: ((pixelValue bitShift: -8) bitAnd: 255);
				nextPut: (pixelValue bitAnd: 255)].
		loopCount notNil ifTrue: [
			"Write a Netscape loop chunk"
			self nextPut: Extension.
			self nextPutAll: #(255 11 78 69 84 83 67 65 80 69 50 46 48 3 1) asByteArray.
			self writeWord: loopCount.
			self nextPut: 0]].

	delay notNil | transparentIndex notNil ifTrue: [
		self nextPut: Extension;
			nextPutAll: #(16rF9 4) asByteArray;
			nextPut: (transparentIndex isNil ifTrue: [0] ifFalse: [9]);
			writeWord: (delay isNil ifTrue: [0] ifFalse: [delay]);
			nextPut: (transparentIndex isNil ifTrue: [0] ifFalse: [transparentIndex]);
			nextPut: 0].

	self nextPut: ImageSeparator.
	self writeWord: 0.		"Image Left"
	self writeWord: 0.		"Image Top"
	self writeWord: width.	"Image Width"
	self writeWord: height.	"Image Height"
	byte := interlace ifTrue: [16r40] ifFalse: [0].
	self nextPut: byte.
! !

!GIFReadWriter methodsFor: 'private-encoding' stamp: ''!
writeWord: aWord
	self nextPut: (aWord bitAnd: 255).
	self nextPut: ((aWord bitShift: -8) bitAnd: 255).
	^aWord! !

!ImageReadWriter class methodsFor: 'image reading/writing' stamp: 'nk 7/16/2003 17:59'!
allTypicalFileExtensions
	"Answer a collection of file extensions (lowercase) which files that my subclasses can read might commonly have"
	"ImageReadWriter allTypicalFileExtensions"
	| extensions |
	extensions := Set new.
	self allSubclassesDo: [ :cls | extensions addAll: cls typicalFileExtensions ].
	^extensions! !

!ImageReadWriter class methodsFor: 'image reading/writing' stamp: 'ls 9/15/1998 19:08'!
formFromFileNamed: fileName
	"Answer a ColorForm stored on the file with the given name."
	| stream |
	stream := FileStream readOnlyFileNamed: fileName.
	^self formFromStream: stream! !

!ImageReadWriter class methodsFor: 'image reading/writing' stamp: 'mt 8/12/2014 10:01'!
formFromStream: aBinaryStream
	"Answer a ColorForm stored on the given stream.  closes the stream"
	| reader readerClass form  |

	readerClass := self withAllSubclasses
		detect: [:subclass |
			aBinaryStream reset.
			subclass understandsImageFormat: aBinaryStream]
		ifNone: [
			aBinaryStream close.
			^self error: 'image format not recognized'].
	aBinaryStream reset.
	reader := readerClass new on: aBinaryStream.
	Cursor read showWhile: [
		form := reader nextImage.
		reader close].
	^ form
! !

!ImageReadWriter class methodsFor: 'instance creation' stamp: ''!
on: aStream
	"Answer an instance of the receiver for encoding and/or decoding images on the given."

	^ self new on: aStream
! !

!ImageReadWriter class methodsFor: 'image reading/writing' stamp: 'tk 4/7/2015 17:11'!
putForm: aForm onFileNamed: fileName
	"Store the given form on a file of the given name."

	| writer theFile |
	theFile := FileStream newFileNamed: fileName.
	writer := self on: theFile binary.
	Cursor write showWhile: [writer nextPutImage: aForm].
	writer close.
	theFile directory setMacFileNamed: theFile localName type: '    ' creator: '    '.! !

!ImageReadWriter class methodsFor: 'image reading/writing' stamp: 'tk 9/13/97 16:13'!
putForm: aForm onStream: aWriteStream
	"Store the given form on a file of the given name."

	| writer |
	writer := self on: aWriteStream.
	Cursor write showWhile: [writer nextPutImage: aForm].
	writer close.
! !

!ImageReadWriter class methodsFor: 'image reading/writing' stamp: 'nk 7/16/2003 17:55'!
typicalFileExtensions
	"Answer a collection of file extensions (lowercase) which files that I can read might commonly have"
	^#()! !

!ImageReadWriter class methodsFor: 'image reading/writing' stamp: 'ar 3/1/2006 22:59'!
understandsImageFormat: aStream 
	^[(self new on: aStream) understandsImageFormat] on: Error do:[:ex| ex return: false]! !

!ImageReadWriter methodsFor: 'stream access' stamp: ''!
atEnd

	^stream atEnd! !

!ImageReadWriter methodsFor: 'private' stamp: ''!
changePadOfBits: bits width: width height: height depth: depth from: oldPad
to: newPad
	"Change padding size of bits."

	| srcRowByteSize dstRowByteSize newBits srcRowBase rowEndOffset |
	(#(8 16 32) includes: oldPad)
		ifFalse: [^self error: 'Invalid pad: ', oldPad printString].
	(#(8 16 32) includes: newPad)
		ifFalse: [^self error: 'Invalid pad: ', newPad printString].
	srcRowByteSize := width * depth + oldPad - 1 // oldPad * (oldPad / 8).
	srcRowByteSize * height = bits size
		ifFalse: [^self error: 'Incorrect bitmap array size.'].
	dstRowByteSize := width * depth + newPad - 1 // newPad * (newPad / 8).
	newBits := ByteArray new: dstRowByteSize * height.
	srcRowBase := 1.
	rowEndOffset := dstRowByteSize - 1.
	1 to: newBits size by: dstRowByteSize do:
		[:dstRowBase |
		newBits replaceFrom: dstRowBase
			to: dstRowBase + rowEndOffset
			with: bits
			startingAt: srcRowBase.
		srcRowBase := srcRowBase + srcRowByteSize].
	^newBits! !

!ImageReadWriter methodsFor: 'stream access' stamp: 'sd 1/30/2004 15:18'!
close
	
	stream close! !

!ImageReadWriter methodsFor: 'stream access' stamp: ''!
contents

	^stream contents! !

!ImageReadWriter methodsFor: 'stream access' stamp: ''!
cr

	^stream nextPut: Character cr asInteger! !

!ImageReadWriter methodsFor: 'private' stamp: ''!
hasMagicNumber: aByteArray
	| position |
	position := stream position.
	((stream size - position) >= aByteArray size and:
	[(stream next: aByteArray size)  = aByteArray])
		ifTrue: [^true].
	stream position: position.
	^false! !

!ImageReadWriter methodsFor: 'stream access' stamp: ''!
lf
	"PPM and PBM are used LF as CR."

	^stream nextPut: Character lf asInteger! !

!ImageReadWriter methodsFor: 'stream access' stamp: ''!
next

	^stream next! !

!ImageReadWriter methodsFor: 'accessing' stamp: ''!
nextImage
	"Dencoding an image on stream and answer the image."

	^self subclassResponsibility! !

!ImageReadWriter methodsFor: 'stream access' stamp: ''!
nextLong
	"Read a 32-bit quantity from the input stream."

	^(stream next bitShift: 24) + (stream next bitShift: 16) +
		(stream next bitShift: 8) + stream next! !

!ImageReadWriter methodsFor: 'stream access' stamp: ''!
nextLongPut: a32BitW
	"Write out a 32-bit integer as 32 bits."

	stream nextPut: ((a32BitW bitShift: -24) bitAnd: 16rFF).
	stream nextPut: ((a32BitW bitShift: -16) bitAnd: 16rFF).
	stream nextPut: ((a32BitW bitShift: -8) bitAnd: 16rFF).
	stream nextPut: (a32BitW bitAnd: 16rFF).
	^a32BitW! !

!ImageReadWriter methodsFor: 'stream access' stamp: ''!
nextPutAll: aByteArray

	^stream nextPutAll: aByteArray! !

!ImageReadWriter methodsFor: 'accessing' stamp: ''!
nextPutImage: anImage
	"Encoding anImage on stream."

	^self subclassResponsibility! !

!ImageReadWriter methodsFor: 'stream access' stamp: ''!
nextPut: aByte

	^stream nextPut: aByte! !

!ImageReadWriter methodsFor: 'stream access' stamp: ''!
nextWord
	"Read a 16-bit quantity from the input stream."

	^(stream next bitShift: 8) + stream next! !

!ImageReadWriter methodsFor: 'stream access' stamp: ''!
nextWordPut: a16BitW
	"Write out a 16-bit integer as 16 bits."

	stream nextPut: ((a16BitW bitShift: -8) bitAnd: 16rFF).
	stream nextPut: (a16BitW bitAnd: 16rFF).
	^a16BitW! !

!ImageReadWriter methodsFor: 'stream access' stamp: ''!
next: size

	^stream next: size! !

!ImageReadWriter methodsFor: 'private' stamp: 'nice 7/28/2014 12:09'!
on: aStream
	stream := aStream.
	stream binary.! !

!ImageReadWriter methodsFor: 'stream access' stamp: 'tao 10/23/97 18:00'!
peekFor: aValue

	^stream peekFor: aValue! !

!ImageReadWriter methodsFor: 'stream access' stamp: ''!
position

	^stream position! !

!ImageReadWriter methodsFor: 'stream access' stamp: ''!
position: anInteger

	^stream position: anInteger! !

!ImageReadWriter methodsFor: 'stream access' stamp: ''!
size

	^stream size! !

!ImageReadWriter methodsFor: 'stream access' stamp: ''!
skip: anInteger

	^stream skip: anInteger! !

!ImageReadWriter methodsFor: 'stream access' stamp: ''!
space

	^stream nextPut: Character space asInteger! !

!ImageReadWriter methodsFor: 'stream access' stamp: ''!
tab

	^stream nextPut: Character tab asInteger! !

!ImageReadWriter methodsFor: 'testing' stamp: 'tao 10/27/97 09:26'!
understandsImageFormat
	"Test to see if the image stream format is understood by this decoder.
	This should be implemented in each subclass of ImageReadWriter so that
	a proper decoder can be selected without ImageReadWriter having to know
	about all possible image file types."

	^ false! !

!ImageReadWriter methodsFor: 'private' stamp: ''!
unpackBits: bits depthTo8From: depth with: width height: height pad: pad
	"Unpack bits of depth 1, 2, or 4 image to it of depth 8 image."

	| bitMask pixelInByte bitsWidth upBitsWidth stopWidth
	 trailingSize upBits bitIndex upBitIndex val |
	(#(1 2 4) includes: depth)
		ifFalse: [^self error: 'depth must be 1, 2, or 4'].
	(#(8 16 32) includes: pad)
		ifFalse: [^self error: 'pad must be 8, 16, or 32'].
	bitMask := (1 bitShift: depth) - 1.
	pixelInByte := 8 / depth.
	bitsWidth := width * depth + pad - 1 // pad * (pad / 8).
	upBitsWidth := width * 8 + pad - 1 // pad * (pad / 8).
	stopWidth := width * depth + 7 // 8.
	trailingSize := width - (stopWidth - 1 * pixelInByte).
	upBits := ByteArray new: upBitsWidth * height.
	1 to: height do: [:i |
		bitIndex := i - 1 * bitsWidth.
		upBitIndex := i - 1 * upBitsWidth.
		1 to: stopWidth - 1 do: [:j |
			val := bits at: (bitIndex := bitIndex + 1).
			upBitIndex := upBitIndex + pixelInByte.
			1 to: pixelInByte do: [:k |
				upBits at: (upBitIndex - k + 1) put: (val bitAnd: bitMask).
				val := val bitShift: depth negated]].
		val := (bits at: (bitIndex := bitIndex + 1))
				bitShift: depth negated * (pixelInByte - trailingSize).
		upBitIndex := upBitIndex + trailingSize.
		1 to: trailingSize do: [:k |
			upBits at: (upBitIndex - k + 1) put: (val bitAnd: bitMask).
			val := val bitShift: depth negated]].
	^ upBits
! !

ImageReadWriter subclass: #JPEGReadWriter
	instanceVariableNames: 'width height components currentComponents qTable hACTable hDCTable restartInterval restartsToGo mcuWidth mcuHeight mcusPerRow mcuRowsInScan mcuMembership mcuSampleBuffer mcuImageBuffer majorVersion minorVersion dataPrecision densityUnit xDensity yDensity ss se ah al sosSeen residuals ditherMask'
	classVariableNames: 'ConstBits DCTK1 DCTK2 DCTK3 DCTK4 DCTSize DCTSize2 DitherMasks FIXn0n298631336 FIXn0n34414 FIXn0n390180644 FIXn0n541196100 FIXn0n71414 FIXn0n765366865 FIXn0n899976223 FIXn1n175875602 FIXn1n40200 FIXn1n501321110 FIXn1n77200 FIXn1n847759065 FIXn1n961570560 FIXn2n053119869 FIXn2n562915447 FIXn3n072711026 FloatSampleOffset HuffmanTableSize JFIFMarkerParser JPEGNaturalOrder MaxSample Pass1Bits Pass1Div Pass2Div QTableScaleFactor QuantizationTableSize SampleOffset'
	poolDictionaries: ''
	category: 'Graphics-Files'!

!JPEGReadWriter commentStamp: '<historical>' prior: 0!
I am a subclass of ImageReadWriter that understands JFIF file streams, and can decode JPEG images.
This code is based upon the Independent Joint Photographic Experts Group (IJPEG) software, originally written in C by Tom Lane, Philip Gladstone, Luis Ortiz, Jim Boucher, Lee Crocker, Julian Minguillon, George Phillips, Davide Rossi, Ge' Weijers, and other members of the Independent JPEG Group.

!

!JPEGReadWriter class methodsFor: 'initialization' stamp: 'ar 3/3/2001 23:07'!
initialize
	"JPEGReadWriter initialize"
	"general constants"
	DCTSize := 8.
	MaxSample := (2 raisedToInteger: DCTSize) - 1.
	SampleOffset := MaxSample // 2.
	FloatSampleOffset := SampleOffset asFloat.
	DCTSize2 := DCTSize squared.
	QuantizationTableSize := 4.
	HuffmanTableSize := 4.

	"floating-point Inverse Discrete Cosine Transform (IDCT) constants"
	ConstBits := 13.
	Pass1Bits := 2.
	DCTK1 := 2 sqrt.
	DCTK2 := 1.847759065.
	DCTK3 := 1.082392200.
	DCTK4 := -2.613125930.
	Pass1Div := 1 bitShift: ConstBits - Pass1Bits.
	Pass2Div := 1 bitShift: ConstBits + Pass1Bits + 3.

	"fixed-point Inverse Discrete Cosine Transform (IDCT) constants"
	FIXn0n298631336 := 2446.
	FIXn0n390180644 := 3196.
	FIXn0n541196100 := 4433.
	FIXn0n765366865 := 6270.
	FIXn0n899976223 := 7373.
	FIXn1n175875602 := 9633.
	FIXn1n501321110 := 12299.
	FIXn1n847759065 := 15137.
	FIXn1n961570560 := 16069.
	FIXn2n053119869 := 16819.
	FIXn2n562915447 := 20995.
	FIXn3n072711026 := 25172.

	"fixed-point color conversion constants"
	FIXn0n34414 := 22554.
	FIXn0n71414 := 46802.
	FIXn1n40200 := 91881.
	FIXn1n77200 :=  116130.

	"reordering table from JPEG zig-zag order"
	JPEGNaturalOrder := #(
		1 2 9 17 10 3 4 11
		18 25 33 26 19 12 5 6
		13 20 27 34 41 49 42 35
		28 21 14 7 8 15 22 29
		36 43 50 57 58 51 44 37
		30 23 16 24 31 38 45 52
		59 60 53 46 39 32 40 47
		54 61 62 55 48 56 63 64).

	"scale factors for the values in the Quantization Tables"
	QTableScaleFactor := (0 to: DCTSize-1) collect:
		[:k | k = 0
			ifTrue: [1.0]
			ifFalse: [(k * Float pi / 16) cos * 2 sqrt]].

	"dithering masks"
	(DitherMasks := Dictionary new)
		add: 0 -> 0;
		add: 1 -> 127;
		add: 2 -> 63;
		add: 4 -> 63;
		add: 8 -> 31;
		add: 16 -> 7;
		add: 32 -> 0.

	"dictionary of marker parsers"
	(JFIFMarkerParser := Dictionary new)
		add: (16r01 -> #parseNOP);
		add: (16rC0 -> #parseStartOfFile);
		add: (16rC4 -> #parseHuffmanTable);
		addAll: ((16rD0 to: 16rD7) collect: [:m | Association key: m value: #parseNOP]);
		add: (16rD8 -> #parseStartOfInput);
		add: (16rD9 -> #parseEndOfInput);
		add: (16rDA -> #parseStartOfScan);
		add: (16rDB -> #parseQuantizationTable);
		add: (16rDD -> #parseDecoderRestartInterval);
		add: (16rE0 -> #parseAPPn);
		add: (16rE1 -> #parseAPPn)! !

!JPEGReadWriter class methodsFor: 'image reading/writing' stamp: 'bf 9/4/2007 15:25'!
typicalFileExtensions
	"Answer a collection of file extensions (lowercase) which files that I can read might commonly have"
	^#('jpg' 'jpeg' 'jpe')! !

!JPEGReadWriter class methodsFor: 'image reading/writing' stamp: 'nice 7/28/2014 12:02'!
understandsImageFormat: aStream
	(JPEGReadWriter2 understandsImageFormat: aStream) ifTrue:[^false].
	aStream reset; binary.
	aStream next = 16rFF ifFalse: [^ false].
	aStream next = 16rD8 ifFalse: [^ false].
	^true! !

!JPEGReadWriter methodsFor: 'colorspace conversion' stamp: 'ar 3/4/2001 22:18'!
colorConvertFloatYCbCrMCU

	| ySampleStream crSampleStream cbSampleStream y cb cr red green blue bits |
	ySampleStream := currentComponents at: 1.
	cbSampleStream := currentComponents at: 2.
	crSampleStream := currentComponents at: 3.
	ySampleStream resetSampleStream.
	cbSampleStream resetSampleStream.
	crSampleStream resetSampleStream.
	bits := mcuImageBuffer bits.
	1 to: bits size do:
		[:i |
		y := ySampleStream nextSample.
		cb := cbSampleStream nextSample - FloatSampleOffset.
		cr := crSampleStream nextSample - FloatSampleOffset.
		red := self sampleFloatRangeLimit: (y + (1.40200 * cr)).
		green := self sampleFloatRangeLimit: (y - (0.34414 * cb) - (0.71414 * cr)).
		blue := self sampleFloatRangeLimit: (y + (1.77200 * cb)).
		bits at: i put: 16rFF000000 + (red << 16) + (green << 8) + blue].
	! !

!JPEGReadWriter methodsFor: 'colorspace conversion' stamp: 'ar 3/4/2001 22:17'!
colorConvertGrayscaleMCU

	| ySampleStream y bits |
	ySampleStream := currentComponents at: 1.
	ySampleStream resetSampleStream.
	bits := mcuImageBuffer bits.
	1 to: bits size do:
		[:i |
		y := (ySampleStream nextSample) + (residuals at: 2).
		y > MaxSample ifTrue: [y := MaxSample].
		residuals at: 2 put: (y bitAnd: ditherMask).
		y := y bitAnd: MaxSample - ditherMask.
		y < 1 ifTrue: [y := 1].
		bits at: i put: 16rFF000000 + (y<<16) + (y<<8) + y].
	! !

!JPEGReadWriter methodsFor: 'colorspace conversion' stamp: 'ar 3/4/2001 22:18'!
colorConvertIntYCbCrMCU

	| ySampleStream crSampleStream cbSampleStream y cb cr red green blue bits |
	ySampleStream := currentComponents at: 1.
	cbSampleStream := currentComponents at: 2.
	crSampleStream := currentComponents at: 3.
	ySampleStream resetSampleStream.
	cbSampleStream resetSampleStream.
	crSampleStream resetSampleStream.
	bits := mcuImageBuffer bits.
	1 to: bits size do:
		[:i |
		y := ySampleStream nextSample.
		cb := cbSampleStream nextSample - SampleOffset.
		cr := crSampleStream nextSample - SampleOffset.
		red := y + ((FIXn1n40200 * cr) // 65536) + (residuals at: 1).
		red > MaxSample
			ifTrue: [red := MaxSample]
			ifFalse: [red < 0 ifTrue: [red := 0]].
		residuals at: 1 put: (red bitAnd: ditherMask).
		red := red bitAnd: MaxSample - ditherMask.
		red < 1 ifTrue: [red := 1].
		green := y - ((FIXn0n34414 * cb) // 65536) -
			((FIXn0n71414 * cr) // 65536) + (residuals at: 2).
		green > MaxSample
			ifTrue: [green := MaxSample]
			ifFalse: [green < 0 ifTrue: [green := 0]].
		residuals at: 2 put: (green bitAnd: ditherMask).
		green := green bitAnd: MaxSample - ditherMask.
		green < 1 ifTrue: [green := 1].
		blue := y + ((FIXn1n77200 * cb) // 65536) + (residuals at: 3).
		blue > MaxSample
			ifTrue: [blue := MaxSample]
			ifFalse: [blue < 0 ifTrue: [blue := 0]].
		residuals at: 3 put: (blue bitAnd: ditherMask).
		blue := blue bitAnd: MaxSample - ditherMask.
		blue < 1 ifTrue: [blue := 1].
		bits at: i put: 16rFF000000 + (red bitShift: 16) + (green bitShift: 8) + blue].
	! !

!JPEGReadWriter methodsFor: 'colorspace conversion' stamp: 'ar 3/7/2001 01:02'!
colorConvertMCU

	^ currentComponents size = 3
		ifTrue:
			[self useFloatingPoint
				ifTrue: [self colorConvertFloatYCbCrMCU]
				ifFalse: [self primColorConvertYCbCrMCU: currentComponents
								bits: mcuImageBuffer bits
								residuals: residuals
								ditherMask: ditherMask.]]
		ifFalse: [self primColorConvertGrayscaleMCU]! !

!JPEGReadWriter methodsFor: 'dct' stamp: 'tao 10/26/97 15:16'!
dctFloatRangeLimit: value

	^ (value / 8.0) + FloatSampleOffset.! !

!JPEGReadWriter methodsFor: 'huffman encoding' stamp: 'ar 3/4/2001 20:55'!
decodeBlockInto: anArray component: aColorComponent dcTable: huffmanDC acTable: huffmanAC

	| byte i zeroCount |
	byte := stream decodeValueFrom: huffmanDC.
	byte ~= 0 ifTrue: [byte := self scaleAndSignExtend: ( self getBits: byte) inFieldWidth: byte].
	byte := aColorComponent updateDCValue: byte.
	anArray atAllPut: 0.
	anArray at: 1 put: byte.
	i := 2.
	[i <= DCTSize2] whileTrue:
		[byte := stream decodeValueFrom: huffmanAC.
		zeroCount := byte >> 4.
		byte := byte bitAnd: 16r0F.
		byte ~= 0
			ifTrue:
				[i := i + zeroCount.
				byte := self scaleAndSignExtend: ( self getBits: byte) inFieldWidth: byte.
				anArray at:	 (JPEGNaturalOrder at: i) put: byte]
			ifFalse:
				[zeroCount = 15 ifTrue: [i := i + zeroCount] ifFalse: [^ self]].
		i := i + 1]
		! !

!JPEGReadWriter methodsFor: 'huffman encoding' stamp: 'ar 3/7/2001 01:00'!
decodeMCU

	| comp ci |
	(restartInterval ~= 0 and: [restartsToGo = 0]) ifTrue: [self processRestart].
	1 to: mcuMembership size do:[:i|
		ci := mcuMembership at: i.
		comp := currentComponents at: ci.
		self
			primDecodeBlockInto: (mcuSampleBuffer at: i)
			component: comp
			dcTable: (hDCTable at: comp dcTableIndex)
			acTable: (hACTable at: comp acTableIndex)
			stream: stream.
	].
	restartsToGo := restartsToGo - 1.! !

!JPEGReadWriter methodsFor: 'huffman encoding' stamp: 'ar 3/4/2001 17:27'!
getBits: requestedBits
	^stream getBits: requestedBits! !

!JPEGReadWriter methodsFor: 'accessing' stamp: 'tao 10/19/97 13:46'!
hACTable

	hACTable ifNil: [hACTable := Array new: HuffmanTableSize].
	^ hACTable! !

!JPEGReadWriter methodsFor: 'accessing' stamp: 'tao 10/19/97 13:46'!
hDCTable

	hDCTable ifNil: [hDCTable := Array new: HuffmanTableSize].
	^ hDCTable! !

!JPEGReadWriter methodsFor: 'dct' stamp: 'nice 1/8/2010 22:14'!
idctBlockFloat: anArray component: aColorComponent

	| t0 t1 t2 t3 t4 t5 t6 t7 t10 t11 t12 t13 z5 z10 z11 z12 z13 qt ws |
	qt := self qTable at: (aColorComponent qTableIndex).
	ws := Array new: DCTSize2.

	"Pass 1: process columns from input, store into work array"
	1 to: DCTSize do: [:i |
		t0 := (anArray at: i) * (qt at: i).
		t1 := (anArray at: (DCTSize*2 + i)) * (qt at: (DCTSize*2 + i)).
		t2 := (anArray at: (DCTSize*4 + i)) * (qt at: (DCTSize*4 + i)).
		t3 := (anArray at: (DCTSize*6 + i)) * (qt at: (DCTSize*6 + i)).
		t10 := t0 + t2.
		t11 := t0 - t2.
		t13 := t1 + t3.
		t12 := (t1 - t3) * DCTK1 - t13.
		t0 := t10 + t13.
		t3 := t10 - t13.
		t1 := t11 + t12.
		t2 := t11 - t12.
		t4 := (anArray at: (DCTSize + i)) * (qt at: (DCTSize + i)).
		t5 := (anArray at: (DCTSize*3 + i)) * (qt at: (DCTSize*3 + i)).
		t6 := (anArray at: (DCTSize*5 + i)) * (qt at: (DCTSize*5 + i)).
		t7 := (anArray at: (DCTSize*7 + i)) * (qt at: (DCTSize*7 + i)).
		z13 := t6 + t5.
		z10 := t6 - t5.
		z11 := t4 + t7.
		z12 := t4 - t7.
		t7 := z11 + z13.
		t11 := (z11 - z13) * DCTK1.
		z5 := (z10 + z12) * DCTK2.
		t10 := DCTK3 * z12 - z5.
		t12 := DCTK4 * z10 + z5.
		t6 := t12 - t7.
		t5 := t11 - t6.
		t4 := t10 + t5.
		ws at: i put: t0 + t7.
		ws at: (DCTSize*7 + i) put: t0 - t7.
		ws at: (DCTSize + i) put: t1 + t6.
		ws at: (DCTSize*6 + i) put: t1 - t6.
		ws at: (DCTSize*2 + i) put: t2 + t5.
		ws at: (DCTSize*5 + i) put: t2 - t5.
		ws at: (DCTSize*4 + i) put: t3 + t4.
		ws at: (DCTSize*3 + i) put: t3 - t4].

		"Pass 2: process rows from the workspace"
	0 to: DCTSize2-DCTSize by: DCTSize do: [:i |
		t10 := (ws at: (i+1)) + (ws at: (i+5)).
		t11 := (ws at: (i+1)) - (ws at: (i+5)).
		t13 := (ws at: (i+3)) + (ws at: (i+7)).
		t12 := ((ws at: (i+3)) - (ws at: (i+7))) * DCTK1 - t13.
		t0 := t10 + t13.
		t3 := t10 - t13.
		t1 := t11 + t12.
		t2 := t11 - t12.
		z13 := (ws at: (i+6)) + (ws at: (i+4)).
		z10 := (ws at: (i+6)) - (ws at: (i+4)).
		z11 := (ws at: (i+2)) + (ws at: (i+8)).
		z12 := (ws at: (i+2)) - (ws at: (i+8)).
		t7 := z11 + z13.
		t11 := (z11 - z13) * DCTK1.
		z5 := (z10 + z12) * DCTK2.
		t10 := DCTK3 * z12 - z5.
		t12 := DCTK4 * z10 + z5.
		t6 := t12 - t7.
		t5 := t11 - t6.
		t4 := t10 + t5.

		"final output stage: scale down by a factor of 8 and range-limit"
		anArray at: (i+1) put: (self dctFloatRangeLimit: (t0 + t7)).
		anArray at: (i+8) put: (self dctFloatRangeLimit: (t0 - t7)).
		anArray at: (i+2) put: (self dctFloatRangeLimit: (t1 + t6)).
		anArray at: (i+7) put: (self dctFloatRangeLimit: (t1 - t6)).
		anArray at: (i+3) put: (self dctFloatRangeLimit: (t2 + t5)).
		anArray at: (i+6) put: (self dctFloatRangeLimit: (t2 - t5)).
		anArray at: (i+5) put: (self dctFloatRangeLimit: (t3 + t4)).
		anArray at: (i+4) put: (self dctFloatRangeLimit: (t3 - t4))]


! !

!JPEGReadWriter methodsFor: 'dct' stamp: 'ar 3/4/2001 21:35'!
idctBlockInt: anArray component: aColorComponent
	^self idctBlockInt: anArray qt: (self qTable at: aColorComponent qTableIndex)! !

!JPEGReadWriter methodsFor: 'dct' stamp: 'ar 3/4/2001 21:34'!
idctBlockInt: anArray qt: qt

	|  ws anACTerm dcval z1 z2 z3 z4 z5 t0 t1 t2 t3 t10 t11 t12 t13 shift |
	ws := Array new: DCTSize2.

	"Pass 1: process columns from anArray, store into work array"
	shift := 1 bitShift: ConstBits - Pass1Bits.
	1 to: DCTSize do:
		[:i |
		anACTerm := nil.
		1 to: DCTSize-1 do:[:row|
			anACTerm ifNil:[
				(anArray at: row * DCTSize + i) = 0 ifFalse:[anACTerm := row]]].
		anACTerm == nil
			ifTrue:
				[dcval := (anArray at: i) * (qt at: 1) bitShift: Pass1Bits.
				0 to: DCTSize-1 do: [:j | ws at: (j * DCTSize + i) put: dcval]]
			ifFalse:
				[z2 := (anArray at: (DCTSize * 2 + i)) * (qt at: (DCTSize * 2 + i)).
				z3 := (anArray at: (DCTSize * 6 + i)) * (qt at: (DCTSize * 6 + i)).
				z1 := (z2 + z3) * FIXn0n541196100.
				t2 := z1 + (z3 * FIXn1n847759065 negated).
				t3 := z1 + (z2 * FIXn0n765366865).
				z2 := (anArray at: i) * (qt at: i).
				z3 := (anArray at: (DCTSize * 4 + i)) * (qt at: (DCTSize * 4 + i)).
				t0 := (z2 + z3) bitShift: ConstBits.
				t1 := (z2 - z3) bitShift: ConstBits.
				t10 := t0 + t3.
				t13 := t0 - t3.
				t11 := t1 + t2.
				t12 := t1 - t2.
				t0 := (anArray at: (DCTSize * 7 + i)) * (qt at: (DCTSize * 7 + i)).
				t1 := (anArray at: (DCTSize * 5 + i)) * (qt at: (DCTSize * 5 + i)).
				t2 := (anArray at: (DCTSize * 3 + i)) * (qt at: (DCTSize * 3 + i)).
				t3 := (anArray at: (DCTSize + i)) * (qt at: (DCTSize + i)).
				z1 := t0 + t3.
				z2 := t1 + t2.
				z3 := t0 + t2.
				z4 := t1 + t3.
				z5 := (z3 + z4) * FIXn1n175875602.
				t0 := t0 * FIXn0n298631336.
				t1 := t1 * FIXn2n053119869.
				t2 := t2 * FIXn3n072711026.
				t3 := t3 * FIXn1n501321110.
				z1 := z1 * FIXn0n899976223 negated.
				z2 := z2 * FIXn2n562915447 negated.
				z3 := z3 * FIXn1n961570560 negated.
				z4 := z4 * FIXn0n390180644 negated.
				z3 := z3 + z5.
				z4 := z4 + z5.
				t0 := t0 + z1 + z3.
				t1 := t1 +z2 +z4.
				t2 := t2 + z2 + z3.
				t3 := t3 + z1 + z4.
				ws at: i put: (t10 + t3) >> (ConstBits - Pass1Bits).
				ws at: (DCTSize * 7 + i) put: (t10 - t3) // shift.
				ws at: (DCTSize * 1 + i) put: (t11 + t2) // shift.
				ws at: (DCTSize * 6 + i) put: (t11 - t2) // shift.
				ws at: (DCTSize * 2 + i) put: (t12 + t1) // shift.
				ws at: (DCTSize * 5 + i) put: (t12 - t1) // shift.
				ws at: (DCTSize * 3 + i) put: (t13 + t0) // shift.
				ws at: (DCTSize * 4 + i) put: (t13 - t0) // shift]].

	"Pass 2: process rows from work array, store back into anArray"
	shift := 1 bitShift: ConstBits + Pass1Bits + 3.
	0 to: DCTSize2-DCTSize by: DCTSize do:
		[:i |
		z2 := ws at: i + 3.
		z3 := ws at: i + 7.
		z1 := (z2 + z3) * FIXn0n541196100.
		t2 := z1 + (z3 * FIXn1n847759065 negated).
		t3 := z1 + (z2 * FIXn0n765366865).
		t0 := (ws at: (i + 1)) + (ws at: (i + 5)) bitShift: ConstBits.
		t1 := (ws at: (i + 1)) - (ws at: (i + 5)) bitShift: ConstBits.
		t10 := t0 + t3.
		t13 := t0 - t3.
		t11 := t1 + t2.
		t12 := t1 -t2.
		t0 := ws at: (i + 8).
		t1 := ws at: (i + 6).
		t2 := ws at: (i + 4).
		t3 := ws at: (i + 2).
		z1 := t0 + t3.
		z2 := t1 + t2.
		z3 := t0 + t2.
		z4 := t1 + t3.
		z5 := (z3 + z4) * FIXn1n175875602.
		t0 := t0 * FIXn0n298631336.
		t1 := t1 * FIXn2n053119869.
		t2 := t2 * FIXn3n072711026.
		t3 := t3 * FIXn1n501321110.
		z1 := z1 * FIXn0n899976223 negated.
		z2 := z2 * FIXn2n562915447 negated.
		z3 := z3 * FIXn1n961570560 negated.
		z4 := z4 * FIXn0n390180644 negated.
		z3 := z3 + z5.
		z4 := z4 + z5.
		t0 := t0 + z1 + z3.
		t1 := t1 + z2 + z4.
		t2 := t2 + z2 + z3.
		t3 := t3 + z1 + z4.
		anArray at: (i + 1) put: (self sampleRangeLimit: (t10 + t3) // shift + SampleOffset).
		anArray at: (i + 8) put: (self sampleRangeLimit: (t10 - t3) // shift + SampleOffset).
		anArray at: (i + 2) put: (self sampleRangeLimit: (t11 + t2) // shift + SampleOffset).
		anArray at: (i + 7) put: (self sampleRangeLimit: (t11 - t2) // shift + SampleOffset).
		anArray at: (i + 3) put: (self sampleRangeLimit: (t12 + t1) // shift + SampleOffset).
		anArray at: (i + 6) put: (self sampleRangeLimit: (t12 - t1) // shift + SampleOffset).
		anArray at: (i + 4) put: (self sampleRangeLimit: (t13 + t0) // shift + SampleOffset).
		anArray at: (i + 5) put: (self sampleRangeLimit: (t13 - t0) // shift + SampleOffset)].


! !

!JPEGReadWriter methodsFor: 'dct' stamp: 'ar 3/7/2001 00:58'!
idctMCU

	| comp fp ci |
	fp := self useFloatingPoint.
	1 to: mcuMembership size do:[:i|
		ci := mcuMembership at: i.
		comp := currentComponents at: ci.
		fp ifTrue:[
			self idctBlockFloat: (mcuSampleBuffer at: i) component: comp.
		] ifFalse:[
			self primIdctInt: (mcuSampleBuffer at: i)
				qt: (qTable at: comp qTableIndex)]].! !

!JPEGReadWriter methodsFor: 'marker parsing' stamp: 'ar 3/4/2001 18:38'!
initialSOSSetup

	mcuWidth := (components detectMax: [:c | c widthInBlocks]) widthInBlocks.
	mcuHeight := (components detectMax: [:c | c heightInBlocks]) heightInBlocks.
	components do:[:c |
		c mcuWidth: mcuWidth mcuHeight: mcuHeight dctSize: DCTSize].
	stream resetBitBuffer.! !

!JPEGReadWriter methodsFor: 'public access' stamp: 'tao 9/18/1998 08:53'!
nextImage

	^ self nextImageDitheredToDepth: Display depth
! !

!JPEGReadWriter methodsFor: 'public access' stamp: 'tpr 3/15/2013 12:31'!
nextImageDitheredToDepth: depth

	| form xStep yStep x y bb |
	ditherMask := DitherMasks
		at: depth
		ifAbsent: [self error: 'can only dither to display depths'].
	residuals := WordArray new: 3.
	sosSeen := false.
	self parseFirstMarker.
	[sosSeen] whileFalse: [self parseNextMarker].
	form := Form extent: (width @ height) depth: depth.
	bb := BitBlt toForm: form.
	bb sourceForm: mcuImageBuffer.
	bb colorMap: (mcuImageBuffer colormapIfNeededFor: form).
	bb sourceRect: mcuImageBuffer boundingBox.
	bb combinationRule: Form over.
	xStep := mcuWidth * DCTSize.
	yStep := mcuHeight * DCTSize.
	y := 0.
	1 to: mcuRowsInScan do:
		[:row |
		x := 0.
		1 to: mcusPerRow do:
			[:col |
			self decodeMCU.
			self idctMCU.
			self colorConvertMCU.
			bb destX: x; destY: y; copyBits.
			x := x + xStep].
		y := y + yStep].
	^ form! !

!JPEGReadWriter methodsFor: 'error handling' stamp: 'tao 10/19/97 12:25'!
notSupported: aString

	self error: aString , ' is not currently supported'! !

!JPEGReadWriter methodsFor: 'marker parsing' stamp: 'mir 6/13/2001 13:06'!
okToIgnoreMarker: aMarker

	^ (((16rE0 to: 16rEF) includes: aMarker) "unhandled APPn markers"
		or: [aMarker = 16rDC or: [aMarker = 16rFE]]) "DNL or COM markers"
		or: [aMarker = 16r99] "Whatever that is"! !

!JPEGReadWriter methodsFor: 'private' stamp: 'ar 3/4/2001 17:34'!
on: aStream
	super on: aStream.
	stream := JPEGReadStream on: stream upToEnd.! !

!JPEGReadWriter methodsFor: 'marker parsing' stamp: 'ar 3/6/2001 22:28'!
parseAPPn

	| length buffer thumbnailLength markerStart |
	markerStart := self position.
	length := self nextWord.
	buffer := self next: 4.
	(buffer asString = 'JFIF') ifFalse: [
		"Skip APPs that we're not interested in"
		stream next: length-6.
		^self].
	self next.
	majorVersion := self next.
	minorVersion := self next.
	densityUnit := self next.
	xDensity := self nextWord.
	yDensity := self nextWord.
	thumbnailLength := self next * self next * 3.
	length := length - (self position - markerStart).
	length = thumbnailLength ifFalse: [self error: 'APP0 thumbnail length is incorrect.'].
	self next: length! !

!JPEGReadWriter methodsFor: 'marker parsing' stamp: 'tao 10/20/97 13:36'!
parseDecoderRestartInterval

	| length |
	length := self nextWord.
	length = 4 ifFalse: [self error: 'DRI length incorrect'].
	restartInterval := self nextWord.! !

!JPEGReadWriter methodsFor: 'marker parsing' stamp: 'mir 6/12/2001 11:28'!
parseFirstMarker

	| marker |
	self next = 16rFF ifFalse: [self error: 'JFIF marker expected'].
	marker := self next.
	marker = 16rD9
		ifTrue: [^self "halt: 'EOI encountered.'"].
	marker = 16rD8 ifFalse: [self error: 'SOI marker expected'].
	self parseStartOfInput.
! !

!JPEGReadWriter methodsFor: 'marker parsing' stamp: 'ar 3/4/2001 18:36'!
parseHuffmanTable

	| length markerStart index bits count huffVal isACTable hTable |
	markerStart := self position.
	length := self nextWord.
	[self position - markerStart >= length] whileFalse:
		[index := self next.
		isACTable := (index bitAnd: 16r10) ~= 0.
		index := (index bitAnd: 16r0F) + 1.
		index > HuffmanTableSize
			ifTrue: [self error: 'image has more than ', HuffmanTableSize printString,
				' quantization tables'].
		bits := self next: 16.
		count := bits sum.
		(count > 256 or: [(count > (length - (self position - markerStart)))])
			ifTrue: [self error: 'Huffman Table count is incorrect'].
		huffVal := self next: count.
		hTable := stream buildLookupTable: huffVal counts: bits.
		isACTable
			ifTrue:
				[self hACTable at: index put: hTable]
			ifFalse:
				[self hDCTable at: index put: hTable]].! !

!JPEGReadWriter methodsFor: 'marker parsing' stamp: 'BG 3/16/2005 08:24'!
parseNextMarker
	"Parse the next marker of the stream"

	| byte discardedBytes |
	discardedBytes := 0.
	[(byte := self next) = 16rFF] whileFalse: [discardedBytes := discardedBytes + 1].	
	[[(byte := self next) = 16rFF] whileTrue. byte = 16r00] whileTrue:
		[discardedBytes := discardedBytes + 2].
	discardedBytes > 0 ifTrue: [self "notifyWithLabel: 'warning: extraneous data discarded'"].
	self perform:
		(JFIFMarkerParser
			at: byte
			ifAbsent:
				[(self okToIgnoreMarker: byte)
					ifTrue: [#skipMarker]
					ifFalse: [self error: 'marker ', byte printStringHex , ' cannot be handled']])! !

!JPEGReadWriter methodsFor: 'marker parsing' stamp: 'tao 10/24/97 17:32'!
parseNOP

	"don't need to do anything, here"! !

!JPEGReadWriter methodsFor: 'marker parsing' stamp: 'ar 3/3/2001 22:19'!
parseQuantizationTable

	| length markerStart n prec value table |
	markerStart := self position.
	length := self nextWord.
	[self position - markerStart >= length] whileFalse:
		[value := self next.
		n := (value bitAnd: 16r0F) + 1.
		prec := (value >> 4) > 0.
		n > QuantizationTableSize
			 ifTrue: [self error: 'image has more than ',
				QuantizationTableSize printString,
				' quantization tables'].
		table := IntegerArray new: DCTSize2.
		1 to: DCTSize2 do:
			[:i |
			value := (prec
				ifTrue: [self nextWord]
				ifFalse: [self next]).
			table at: (JPEGNaturalOrder at: i) put: value].
		self useFloatingPoint ifTrue: [self scaleQuantizationTable: table].
		self qTable at: n put: table]! !

!JPEGReadWriter methodsFor: 'marker parsing' stamp: 'tao 10/24/97 17:07'!
parseStartOfFile

	| length markerStart value n |
	markerStart := self position.
	length := self nextWord.
	dataPrecision := self next.
	dataPrecision = 8
		ifFalse: [self error: 'cannot handle ', dataPrecision printString, '-bit components'].
	height := self nextWord.
	width := self nextWord.
	n := self next.
	(height = 0) | (width = 0) | (n = 0) ifTrue: [self error: 'empty image'].
	(length - (self position - markerStart)) ~= (n * 3)
		ifTrue: [self error: 'component length is incorrect'].
	components := Array new: n.
	1 to: components size do:
		[:i |
		components
			at: i
			put:
				(JPEGColorComponent new
					id: self next;
					"heightInBlocks: (((value := self next) >> 4) bitAnd: 16r0F);
					widthInBlocks: (value bitAnd: 16r0F);"
					widthInBlocks: (((value := self next) >> 4) bitAnd: 16r0F);
					heightInBlocks: (value bitAnd: 16r0F);

					qTableIndex: self next + 1)]! !

!JPEGReadWriter methodsFor: 'marker parsing' stamp: 'tao 10/22/97 17:38'!
parseStartOfInput

	restartInterval := 0.
	densityUnit := 0.
	xDensity := 1.
	yDensity := 1
! !

!JPEGReadWriter methodsFor: 'marker parsing' stamp: 'tao 10/26/97 21:53'!
parseStartOfScan

	| length n id value dcNum acNum comp |
	length := self nextWord.
	n := self next.
	(length ~= (n*2 + 6)) | (n < 1) ifTrue: [self error: 'SOS length is incorrect'].
	currentComponents := Array new: n.
	1 to: n do: [:i |
		id := self next.
		value := self next.
		dcNum := (value >> 4) bitAnd: 16r0F.
		acNum := value bitAnd: 16r0F.
		comp := components detect: [:c | c id = id].
		comp
			dcTableIndex: dcNum+1;
			acTableIndex: acNum+1.
		currentComponents at: i put: comp].
	ss := self next.
	se := self next.
	value := self next.
	ah := (value >> 4) bitAnd: 16r0F.
	al := value bitAnd: 16r0F.
	self initialSOSSetup.
	self perScanSetup.
	sosSeen := true! !

!JPEGReadWriter methodsFor: 'marker parsing' stamp: 'ar 3/7/2001 01:01'!
perScanSetup

	mcusPerRow := (width / (mcuWidth * DCTSize)) ceiling.
	mcuRowsInScan := (height / (mcuHeight * DCTSize)) ceiling.
	(currentComponents size = 3 or: [currentComponents size = 1])
		ifFalse: [self error: 'JPEG color space not recognized'].
	mcuMembership := OrderedCollection new.
	currentComponents withIndexDo:
		[:c :i |
		c priorDCValue: 0.
		mcuMembership addAll: ((1 to: c totalMcuBlocks) collect: [:b | i])].
	mcuMembership := mcuMembership asArray.
	mcuSampleBuffer := (1 to: mcuMembership size) collect: [:i | IntegerArray new: DCTSize2].
	currentComponents withIndexDo:
		[:c :i |
			c initializeSampleStreamBlocks:
				((1 to: mcuMembership size)
					select: [:j | i = (mcuMembership at: j)]
					thenCollect: [:j | mcuSampleBuffer at: j])].
	mcuImageBuffer := Form
		extent: (mcuWidth @ mcuHeight) * DCTSize
		depth: 32.
	restartsToGo := restartInterval.! !

!JPEGReadWriter methodsFor: 'colorspace conversion' stamp: 'ar 3/4/2001 22:19'!
primColorConvertGrayscaleMCU
	self primColorConvertGrayscaleMCU: (currentComponents at: 1)
			bits: mcuImageBuffer bits
			residuals: residuals
			ditherMask: ditherMask.! !

!JPEGReadWriter methodsFor: 'colorspace conversion' stamp: 'ar 3/15/2001 18:11'!
primColorConvertGrayscaleMCU: componentArray bits: bits residuals: residualArray ditherMask: mask
	<primitive: 'primitiveColorConvertGrayscaleMCU' module: 'JPEGReaderPlugin'>
	"JPEGReaderPlugin doPrimitive: #primitiveColorConvertGrayscaleMCU."
	^self colorConvertGrayscaleMCU! !

!JPEGReadWriter methodsFor: 'colorspace conversion' stamp: 'ar 3/4/2001 21:36'!
primColorConvertIntYCbCrMCU
	self primColorConvertYCbCrMCU: currentComponents
			bits: mcuImageBuffer bits
			residuals: residuals
			ditherMask: ditherMask.! !

!JPEGReadWriter methodsFor: 'colorspace conversion' stamp: 'ar 3/4/2001 21:36'!
primColorConvertYCbCrMCU: componentArray bits: bits residuals: residualArray ditherMask: mask
	<primitive: 'primitiveColorConvertMCU' module: 'JPEGReaderPlugin'>
	^self colorConvertIntYCbCrMCU! !

!JPEGReadWriter methodsFor: 'huffman encoding' stamp: 'ar 3/4/2001 21:32'!
primDecodeBlockInto: sampleBuffer component: comp dcTable: dcTable acTable: acTable stream: jpegStream
	<primitive: 'primitiveDecodeMCU' module: 'JPEGReaderPlugin'>
	^self decodeBlockInto: sampleBuffer component: comp dcTable: dcTable acTable: acTable! !

!JPEGReadWriter methodsFor: 'dct' stamp: 'ar 3/4/2001 21:37'!
primIdctBlockInt: anArray component: aColorComponent
	^self primIdctInt: anArray qt: (self qTable at: aColorComponent qTableIndex)! !

!JPEGReadWriter methodsFor: 'dct' stamp: 'ar 3/4/2001 21:35'!
primIdctInt: anArray qt: qt
	<primitive: 'primitiveIdctInt' module: 'JPEGReaderPlugin'>
	^self idctBlockInt: anArray qt: qt! !

!JPEGReadWriter methodsFor: 'huffman encoding' stamp: 'ar 3/4/2001 17:40'!
processRestart
	stream resetBitBuffer.
	self parseNextMarker.
	currentComponents do: [:c | c priorDCValue: 0].
	restartsToGo := restartInterval.! !

!JPEGReadWriter methodsFor: 'accessing' stamp: 'tao 10/19/97 08:46'!
qTable

	qTable ifNil: [qTable := Array new: QuantizationTableSize].
	^ qTable! !

!JPEGReadWriter methodsFor: 'colorspace conversion' stamp: 'tao 10/26/97 15:43'!
sampleFloatRangeLimit: aNumber

	^ (aNumber rounded max: 0) min: MaxSample! !

!JPEGReadWriter methodsFor: 'colorspace conversion' stamp: 'di 9/15/1998 14:30'!
sampleRangeLimit: aNumber

	aNumber < 0 ifTrue: [^ 0].
	aNumber > MaxSample ifTrue: [^ MaxSample].
	^ aNumber! !

!JPEGReadWriter methodsFor: 'huffman encoding' stamp: 'ar 3/4/2001 01:17'!
scaleAndSignExtend: aNumber inFieldWidth: w

	aNumber < (1 bitShift: (w - 1))
		ifTrue: [^aNumber - (1 bitShift: w) + 1]
		ifFalse: [^aNumber]! !

!JPEGReadWriter methodsFor: 'dct' stamp: 'tao 10/26/97 16:16'!
scaleQuantizationTable: table

	| index |

	index := 1.
	1 to: DCTSize do:
		[:row |
		1 to: DCTSize do:
			[:col |
			table at: index
				put: ((table at: index) * (QTableScaleFactor at: row) *
					(QTableScaleFactor at: col)) rounded.
			index := index + 1]].
	^ table
! !

!JPEGReadWriter methodsFor: 'public access' stamp: 'ar 3/4/2001 17:26'!
setStream: aStream
	"Feed it in from an existing source"
	stream := JPEGReadStream on: aStream upToEnd.! !

!JPEGReadWriter methodsFor: 'marker parsing' stamp: 'tao 10/22/97 16:27'!
skipMarker

	| length markerStart |
	markerStart := self position.
	length := self nextWord.
	self next: length - (self position - markerStart)
! !

!JPEGReadWriter methodsFor: 'testing' stamp: 'ar 3/4/2001 00:50'!
understandsImageFormat
	"Answer true if the image stream format is understood by this decoder."
	self next = 16rFF ifFalse: [^ false].
	self next = 16rD8 ifFalse: [^ false].
	^ true
! !

!JPEGReadWriter methodsFor: 'preferences' stamp: 'tao 10/26/97 22:09'!
useFloatingPoint

	^ false! !

ImageReadWriter subclass: #JPEGReadWriter2
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Files'!

!JPEGReadWriter2 commentStamp: '<historical>' prior: 0!
I provide fast JPEG compression and decompression. I require the VM pluginJPEGReadWriter2Plugin, which is typically stored in same directory as the Squeak virtual machine.

JPEGReadWriter2Plugin is based on LIBJPEG library. This sentence applies to the plugin:
   "This software is based in part on the work of the Independent JPEG Group".

The LIBJPEG license allows it to be used free for any purpose so long as its origin and copyright are acknowledged. You can read more about LIBJPEG and get the complete source code at www.ijg.org.
!

!JPEGReadWriter2 class methodsFor: 'image reading/writing' stamp: 'ar 6/16/2002 18:54'!
primJPEGPluginIsPresent
	<primitive: 'primJPEGPluginIsPresent' module: 'JPEGReadWriter2Plugin'>
	^false! !

!JPEGReadWriter2 class methodsFor: 'image reading/writing' stamp: 'tk 4/7/2015 17:06'!
putForm: aForm quality: quality progressiveJPEG: progressiveFlag onFileNamed: fileName
	"Store the given Form as a JPEG file of the given name, overwriting any existing file of that name. Quality goes from 0 (low) to 100 (high), where -1 means default. If progressiveFlag is true, encode as a progressive JPEG."

	| writer theFile |
	FileDirectory deleteFilePath: fileName.
	theFile := FileStream newFileNamed: fileName.
	writer := self on: theFile binary.
	Cursor write showWhile: [
		writer nextPutImage: aForm quality: quality progressiveJPEG: progressiveFlag].
	writer close.
	theFile directory setMacFileNamed: theFile localName type: '    ' creator: '    '.! !

!JPEGReadWriter2 class methodsFor: 'image reading/writing' stamp: 'bf 9/4/2007 15:25'!
typicalFileExtensions
	"Answer a collection of file extensions (lowercase) which files that I can read might commonly have"
	^#('jpg' 'jpeg' 'jpe')! !

!JPEGReadWriter2 methodsFor: 'public access' stamp: 'lpc 6/8/2016 11:25'!
compress: aForm quality: quality
	"Encode the given Form and answer the compressed ByteArray. Quality goes from 0 (low) to 100 (high), where -1 means default.
	We can only compress:
		* 32-bit deep Forms 
		* -32-bit deep Forms
		* 16-bit deep Forms
		* -16-bit deep Forms
		* GrayScale ColorForms (see #isGrayScale)"
	| sourceForm jpegCompressStruct jpegErrorMgr2Struct buffer byteCount |
	
	aForm unhibernate.
	
	sourceForm := self supports8BitGrayscaleJPEGs 
		ifTrue: [ 
			(aForm depth = 32) | (aForm depth = 16) | (aForm isGrayScale)
				ifTrue: [aForm]
				ifFalse: [aForm asFormOfDepth: 32 ]]
		ifFalse: [
			(aForm nativeDepth > 0) & ((aForm depth = 32) | ((aForm depth = 16) & (aForm width even)))
				ifTrue: [aForm]
				ifFalse: [aForm asFormOfDepth: 32 ]].
	
	jpegCompressStruct := ByteArray new: self primJPEGCompressStructSize.
	jpegErrorMgr2Struct := ByteArray new: self primJPEGErrorMgr2StructSize.
	buffer := ByteArray new: sourceForm width * sourceForm height + 1024.
	byteCount := self primJPEGWriteImage: jpegCompressStruct 
		onByteArray: buffer
		form: sourceForm
		quality: quality
		progressiveJPEG: false
		errorMgr: jpegErrorMgr2Struct.
	byteCount = 0 ifTrue: [self error: 'buffer too small for compressed data'].
	^ buffer copyFrom: 1 to: byteCount
! !

!JPEGReadWriter2 methodsFor: 'public access' stamp: 'jm 11/20/2001 10:01'!
imageExtent: aByteArray 
	"Answer the extent of the compressed image encoded in the given ByteArray."

	| jpegDecompressStruct jpegErrorMgr2Struct w h |
	jpegDecompressStruct := ByteArray new: self primJPEGDecompressStructSize.
	jpegErrorMgr2Struct := ByteArray new: self primJPEGErrorMgr2StructSize.
	self
		primJPEGReadHeader: jpegDecompressStruct 
		fromByteArray: aByteArray
		errorMgr: jpegErrorMgr2Struct.
	w := self primImageWidth: jpegDecompressStruct.
	h := self primImageHeight: jpegDecompressStruct.
	^ w @ h
! !

!JPEGReadWriter2 methodsFor: 'testing' stamp: 'ar 11/27/2001 00:40'!
isPluginPresent
	^self primJPEGPluginIsPresent! !

!JPEGReadWriter2 methodsFor: 'public access' stamp: 'jm 11/20/2001 10:23'!
nextImage
	"Decode and answer a Form from my stream."

	^ self nextImageSuggestedDepth: Display depth
! !

!JPEGReadWriter2 methodsFor: 'public access' stamp: 'lpc 6/8/2016 11:34'!
nextImageSuggestedDepth: suggestedDepth
	"Decode and answer a Form of the given depth from my stream. Close the stream if it is a file stream.
	We can read RGB JPEGs into:
		* 32-bit Forms
		* -32-bit Forms
		* 16-bit Forms (with or without dithering!!)
		* -16-bit Forms (with or without dithering!!)
	We can read grayscale JPEGs into:
		* 32-bit Forms
		* -32-bit Forms
		* 16-bit Forms (with or without dithering!!)
		* -16-bit Forms (with or without dithering!!)
		* 8-bit grayScale ColorForms (see #isGrayScale)
		* -8-bit grayScale ColorForms (see #isGrayScale)"

	| bytes width height components form jpegDecompressStruct jpegErrorMgr2Struct |
	bytes := stream upToEnd.
	stream close.
	jpegDecompressStruct := ByteArray new: self primJPEGDecompressStructSize.
	jpegErrorMgr2Struct := ByteArray new: self primJPEGErrorMgr2StructSize.
	self 
		primJPEGReadHeader: jpegDecompressStruct 
		fromByteArray: bytes
		errorMgr: jpegErrorMgr2Struct.
	width := self primImageWidth: jpegDecompressStruct.
	height := self primImageHeight: jpegDecompressStruct.
	components := self primImageNumComponents: jpegDecompressStruct.
	form :=
		self supports8BitGrayscaleJPEGs
			ifTrue: [
				components = 3
					ifTrue: [ Form extent: width@height depth: suggestedDepth ]
					ifFalse: [ (Form extent: width@height depth: suggestedDepth) asGrayScale ]]
			ifFalse: [
				Form
					extent: width@height
					depth: 
						(suggestedDepth = 32 
							ifTrue: [ 32 ]
							ifFalse: [
								((suggestedDepth = 16) & (width even))
									ifTrue: [ 16 ]
									ifFalse: [ 32 ]])].
					
	self
		primJPEGReadImage: jpegDecompressStruct
		fromByteArray: bytes
		onForm: form
		doDithering: true
		errorMgr: jpegErrorMgr2Struct.
	^ form! !

!JPEGReadWriter2 methodsFor: 'public access' stamp: 'jm 11/20/2001 10:21'!
nextPutImage: aForm
	"Encode the given Form on my stream with default quality."

	^ self nextPutImage: aForm quality: -1 progressiveJPEG: false
! !

!JPEGReadWriter2 methodsFor: 'public access' stamp: 'lpc 6/8/2016 11:27'!
nextPutImage: aForm quality: quality progressiveJPEG: progressiveFlag
	"Encode the given Form on my stream with the given settings. Quality goes from 0 (low) to 100 (high), where -1 means default. If progressiveFlag is true, encode as a progressive JPEG.
	We can compress:
		* 32-bit deep Forms 
		* -32-bit deep Forms
		* 16-bit deep
		* -16-bit deep
		* GrayScale ColorForms (see #isGrayScale)"

	| sourceForm jpegCompressStruct jpegErrorMgr2Struct buffer byteCount |
	
	aForm unhibernate.
	
	sourceForm := self supports8BitGrayscaleJPEGs 
		ifTrue: [ 
			(aForm depth = 32) | (aForm depth = 16) | (aForm isGrayScale)
				ifTrue: [aForm]
				ifFalse: [aForm asFormOfDepth: 32 ]]
		ifFalse: [
			(aForm nativeDepth > 0) & ((aForm depth = 32) | ((aForm depth = 16) & (aForm width even)))
				ifTrue: [aForm]
				ifFalse: [aForm asFormOfDepth: 32 ]].
	
	jpegCompressStruct := ByteArray new: self primJPEGCompressStructSize.
	jpegErrorMgr2Struct := ByteArray new: self primJPEGErrorMgr2StructSize.
	buffer := ByteArray new: sourceForm width * sourceForm height + 1024.
	"Try to write the image. Retry with a larger buffer if needed."
	[
		byteCount := self primJPEGWriteImage: jpegCompressStruct 
			onByteArray: buffer
			form: sourceForm
			quality: quality
			progressiveJPEG: progressiveFlag
			errorMgr: jpegErrorMgr2Struct.
		byteCount = 0 and: [ buffer size < (sourceForm width * sourceForm height * 3 + 1024) ] ]
			whileTrue: [ buffer := ByteArray new: buffer size * 2 ].
	byteCount = 0 ifTrue: [ self error: 'buffer too small for compressed data' ].
	stream next: byteCount putAll: buffer startingAt: 1.
	self close.
! !

!JPEGReadWriter2 methodsFor: 'primitives' stamp: 'jm 11/20/2001 10:34'!
primImageHeight: aJPEGCompressStruct

	<primitive: 'primImageHeight' module: 'JPEGReadWriter2Plugin'>
	self primitiveFailed
! !

!JPEGReadWriter2 methodsFor: 'primitives' stamp: 'lpc 6/8/2016 11:14'!
primImageNumComponents: aJPEGDecompressStruct

	<primitive: 'primImageNumComponents' module: 'JPEGReadWriter2Plugin'>
	^ 3! !

!JPEGReadWriter2 methodsFor: 'primitives' stamp: 'jm 11/20/2001 10:35'!
primImageWidth: aJPEGCompressStruct

	<primitive: 'primImageWidth' module: 'JPEGReadWriter2Plugin'>
	self primitiveFailed
! !

!JPEGReadWriter2 methodsFor: 'primitives' stamp: 'jm 11/20/2001 10:35'!
primJPEGCompressStructSize

	<primitive: 'primJPEGCompressStructSize' module: 'JPEGReadWriter2Plugin'>
	self primitiveFailed
! !

!JPEGReadWriter2 methodsFor: 'primitives' stamp: 'jm 11/20/2001 10:35'!
primJPEGDecompressStructSize

	<primitive: 'primJPEGDecompressStructSize' module: 'JPEGReadWriter2Plugin'>
	self primitiveFailed
! !

!JPEGReadWriter2 methodsFor: 'primitives' stamp: 'jm 11/20/2001 10:35'!
primJPEGErrorMgr2StructSize

	<primitive: 'primJPEGErrorMgr2StructSize' module: 'JPEGReadWriter2Plugin'>
	self primitiveFailed
! !

!JPEGReadWriter2 methodsFor: 'primitives' stamp: 'ar 11/27/2001 00:39'!
primJPEGPluginIsPresent
	<primitive: 'primJPEGPluginIsPresent' module: 'JPEGReadWriter2Plugin'>
	^false! !

!JPEGReadWriter2 methodsFor: 'primitives' stamp: 'jm 11/20/2001 10:35'!
primJPEGReadHeader: aJPEGDecompressStruct fromByteArray: source errorMgr: aJPEGErrorMgr2Struct

	<primitive: 'primJPEGReadHeaderfromByteArrayerrorMgr' module: 'JPEGReadWriter2Plugin'>
	self primitiveFailed
! !

!JPEGReadWriter2 methodsFor: 'primitives' stamp: 'jmv 12/7/2001 13:45'!
primJPEGReadImage: aJPEGDecompressStruct fromByteArray: source onForm: form doDithering: ditherFlag errorMgr: aJPEGErrorMgr2Struct

	<primitive: 'primJPEGReadImagefromByteArrayonFormdoDitheringerrorMgr' module: 'JPEGReadWriter2Plugin'>
	self primitiveFailed
! !

!JPEGReadWriter2 methodsFor: 'primitives' stamp: 'jm 11/20/2001 10:35'!
primJPEGWriteImage: aJPEGCompressStruct onByteArray: destination form: form quality: quality progressiveJPEG: progressiveFlag errorMgr: aJPEGErrorMgr2Struct

	<primitive: 'primJPEGWriteImageonByteArrayformqualityprogressiveJPEGerrorMgr' module: 'JPEGReadWriter2Plugin'>
	self primitiveFailed
! !

!JPEGReadWriter2 methodsFor: 'primitives' stamp: 'lpc 6/8/2016 10:51'!
primSupports8BitGrayscaleJPEGs
	<primitive: 'primSupports8BitGrayscaleJPEGs' module: 'JPEGReadWriter2Plugin'>
	^ false! !

!JPEGReadWriter2 methodsFor: 'testing' stamp: 'lpc 6/8/2016 10:51'!
supports8BitGrayscaleJPEGs
	^ self primSupports8BitGrayscaleJPEGs! !

!JPEGReadWriter2 methodsFor: 'public access' stamp: 'lpc 5/18/2016 15:51'!
uncompress: aByteArray into: aForm
	^ self uncompress: aByteArray into: aForm doDithering: true
! !

!JPEGReadWriter2 methodsFor: 'public access' stamp: 'lpc 6/8/2016 11:22'!
uncompress: aByteArray into: aForm doDithering: ditherFlag
	"Uncompress an image from the given ByteArray into the given Form. 
	Fails if the given Form has the wrong dimensions or depth.
	We can read RGB JPEGs into:
		* 32-bit Forms
		* -32-bit Forms
		* 16-bit Forms (with or without dithering!!)
		* -16-bit Forms (with or without dithering!!)
	We can read grayscale JPEGs into:
		* 32-bit Forms
		* -32-bit Forms
		* 16-bit Forms (with or without dithering!!)
		* -16-bit Forms (with or without dithering!!)
		* 8-bit grayScale ColorForms (see #isGrayScale)
		* -8-bit grayScale ColorForms (see #isGrayScale)"

	| jpegDecompressStruct jpegErrorMgr2Struct width height components |
	
	aForm unhibernate.
	
	jpegDecompressStruct := ByteArray new: self primJPEGDecompressStructSize.
	jpegErrorMgr2Struct := ByteArray new: self primJPEGErrorMgr2StructSize.
	self 
		primJPEGReadHeader: jpegDecompressStruct 
		fromByteArray: aByteArray
		errorMgr: jpegErrorMgr2Struct.
	width := self primImageWidth: jpegDecompressStruct.
	height := self primImageHeight: jpegDecompressStruct.
	components := self primImageNumComponents: jpegDecompressStruct.
	
	((aForm width = width) & (aForm height = height)) ifFalse: [
		^ self error: 'form dimensions do not match' ].
	self supports8BitGrayscaleJPEGs
		ifTrue: [
			components = 3
				ifTrue: [
					aForm depth = 8
						ifTrue: [ ^ self error: 'Cannot uncompress multi-channel JPEGs into 8-bit deep forms' ]].
			components = 1
				ifTrue: [
					aForm depth = 8
						ifTrue: [
							aForm isGrayScale 
								ifFalse: [ ^ self error: 'Cannot uncompress single-channel JPEGs into 8-bit deep forms that are not grayscale' ]]]]
						
		ifFalse: [
			aForm nativeDepth < 0
				ifTrue: [ ^ self error: 'Current plugin version doesn''t support uncompressing JPEGs into little-endian forms' ]
				ifFalse: [
					aForm depth = 16
						ifTrue: [
							width odd
								ifTrue: [ ^ self error: 'Current plugin version doesn''t support uncompressing JPEGs with an odd width into 16-bit deep forms' ]].
					aForm depth = 8
						ifTrue: [ ^ self error: 'Current plugin version doesn''t support uncompressing JPEGs into 8-bit deep forms' ]]].

	self primJPEGReadImage: jpegDecompressStruct
		fromByteArray: aByteArray
		onForm: aForm
		doDithering: ditherFlag
		errorMgr: jpegErrorMgr2Struct.
! !

!JPEGReadWriter2 methodsFor: 'testing' stamp: 'ar 11/27/2001 00:39'!
understandsImageFormat
	"Answer true if the image stream format is understood by this decoder."
	self isPluginPresent ifFalse:[^false]. "cannot read it otherwise"
	self next = 16rFF ifFalse: [^ false].
	self next = 16rD8 ifFalse: [^ false].
	^ true
! !

ImageReadWriter subclass: #PCXReadWriter
	instanceVariableNames: 'version encoding colorPlanes isGrayScale width height bitsPerPixel colorPalette rowByteSize'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Files'!

!PCXReadWriter class methodsFor: 'image reading/writing' stamp: 'nk 7/16/2003 17:57'!
typicalFileExtensions
	"Answer a collection of file extensions (lowercase) which files that I can read might commonly have"
	^#('pcx')! !

!PCXReadWriter methodsFor: 'accessing' stamp: 'tao 10/6/97 10:11'!
nextImage
	"Read in the next PCX image from the stream."

	| bytes form |
	self readHeader.
	bytes := self readBody.
	colorPalette := self readPalette.
	self close.
	form := ColorForm extent: width@height depth: bitsPerPixel.
	(Form new hackBits: bytes) displayOn: (Form new hackBits: form bits).
	form colors: colorPalette.
	^ form
! !

!PCXReadWriter methodsFor: 'private-decoding' stamp: 'tao 10/6/97 08:38'!
nextWord
	^self next + (self next bitShift: 8)! !

!PCXReadWriter methodsFor: 'private-decoding' stamp: 'tao 10/6/97 10:07'!
readBody

	| array scanLine rowBytes position byte count pad |
	pad := #(0 3 2 1) at: (width \\ 4 + 1).
	array := ByteArray new: ((width + pad) * height * bitsPerPixel) // 8.
	scanLine := ByteArray new: rowByteSize.
	position := 1.
	1 to: height do:
		[:line |
		rowBytes := 0.
		[rowBytes < rowByteSize] whileTrue:
			[byte := self next.
			byte < 16rC0
				ifTrue:
					[rowBytes := rowBytes + 1.
					scanLine at: rowBytes put: byte]
				ifFalse:
					[count := byte - 16rC0.
					byte := self next.
					1 to: count do: [:i | scanLine at: rowBytes + i put: byte].
					rowBytes := rowBytes + count]].
		array
			replaceFrom: position
			to: position + width - 1
			with: scanLine
			startingAt: 1.
		position := position + width + pad].
	^ array
! !

!PCXReadWriter methodsFor: 'private-decoding' stamp: 'md 11/14/2003 16:51'!
readHeader

	| xMin xMax yMin yMax |
	self next.	"skip over manufacturer field"
	version := self next.
	encoding := self next.
	bitsPerPixel := self next.
	xMin := self nextWord.
	yMin := self nextWord.
	xMax := self nextWord.
	yMax := self nextWord.
	width := xMax - xMin + 1.
	height := yMax - yMin + 1.
	self next: 4. "skip over device resolution"
	self next: 49. "skip over EGA color palette"
	colorPlanes := self next.
	rowByteSize := self nextWord.
	isGrayScale := (self next: 2) = 2.
	self next: 58. "skip over filler"



! !

!PCXReadWriter methodsFor: 'private-decoding' stamp: 'tao 10/6/97 08:29'!
readPalette

	| r g b array |
	self next = 12 ifFalse: [self error: 'no Color Palette!!'].
	array := Array new: (1 bitShift: bitsPerPixel).
	1 to: array size do:
		[:i |
		r := self next.  g := self next.  b := self next.
		array at: i put: (Color r: r g: g b: b range: 255)].
	^ array.
! !

ImageReadWriter subclass: #PNGReadWriter
	instanceVariableNames: 'chunk form width height depth backColor bitsPerChannel colorType interlaceMethod bitsPerPixel bytesPerScanline thisScanline prevScanline rowSize idatChunkStream unknownChunks palette transparentPixelValue filtersSeen swizzleMap cachedDecoderMap bigEndian'
	classVariableNames: 'BlockHeight BlockWidth BPP Debugging StandardColors StandardSwizzleMaps'
	poolDictionaries: ''
	category: 'Graphics-Files'!

!PNGReadWriter commentStamp: '<historical>' prior: 0!
I am a subclass of ImageReadWriter that decodes Portable Network Graphics
(PNG) images.

Submitted by Duane Maxwell!

!PNGReadWriter class methodsFor: 'as yet unclassified' stamp: 'ar 2/11/2004 00:54'!
computeSwizzleMapForDepth: depth
	"Answer a map that maps pixels in a word to their opposite location. Used for 'middle-endian' forms where the byte-order is different from the bit order (good joke, eh?)."
	| map swizzled |
	map := Bitmap new: 256.
	depth = 4 ifTrue:[
		0 to: 255 do:[:pix|
			swizzled := 0.
			swizzled := swizzled bitOr: (((pix bitShift: 0) bitAnd: 15) bitShift: 4).
			swizzled := swizzled bitOr: (((pix bitShift: -4) bitAnd: 15) bitShift: 0).
			map at: pix+1 put: swizzled.
		].
		^ColorMap colors: map
	].

	depth = 2 ifTrue:[
		0 to: 255 do:[:pix|
			swizzled := 0.
			swizzled := swizzled bitOr: (((pix bitShift: 0) bitAnd: 3) bitShift: 6).
			swizzled := swizzled bitOr: (((pix bitShift: -2) bitAnd: 3) bitShift: 4).
			swizzled := swizzled bitOr: (((pix bitShift: -4) bitAnd: 3) bitShift: 2).
			swizzled := swizzled bitOr: (((pix bitShift: -6) bitAnd: 3) bitShift: 0).
			map at: pix+1 put: swizzled.
		].
		^ColorMap colors: map
	].

	depth = 1 ifTrue:[
		0 to: 255 do:[:pix|
			swizzled := 0.
			swizzled := swizzled bitOr: (((pix bitShift: 0) bitAnd: 1) bitShift: 7).
			swizzled := swizzled bitOr: (((pix bitShift: -1) bitAnd: 1) bitShift: 6).
			swizzled := swizzled bitOr: (((pix bitShift: -2) bitAnd: 1) bitShift: 5).
			swizzled := swizzled bitOr: (((pix bitShift: -3) bitAnd: 1) bitShift: 4).
			swizzled := swizzled bitOr: (((pix bitShift: -4) bitAnd: 1) bitShift: 3).
			swizzled := swizzled bitOr: (((pix bitShift: -5) bitAnd: 1) bitShift: 2).
			swizzled := swizzled bitOr: (((pix bitShift: -6) bitAnd: 1) bitShift: 1).
			swizzled := swizzled bitOr: (((pix bitShift: -7) bitAnd: 1) bitShift: 0).
			map at: pix+1 put: swizzled.
		].
		^ColorMap colors: map
	].
	self error: 'Unrecognized depth'! !

!PNGReadWriter class methodsFor: 'as yet unclassified' stamp: 'RAA 11/7/2000 09:20'!
debugging: aBoolean

	Debugging := aBoolean! !

!PNGReadWriter class methodsFor: 'as yet unclassified' stamp: 'ar 2/11/2004 00:55'!
initialize
	"
	PNGReadWriter initialize
	"

	BPP := {	#(1 2 4 8 16).
			#(0 0 0 0 0).
			#(0 0 0 24 48).
			#(1 2 4 8 0).
			#(0 0 0 16 32).
			#(0 0 0 0 0).
			#(0 0 0 32 64).
			#(0 0 0 0 0) }.

	BlockHeight := #(8 8 4 4 2 2 1).
	BlockWidth := #(8 4 4 2 2 1 1).

	StandardColors := Color indexedColors collect:[:aColor|
		Color 
			r: (aColor red * 255) truncated / 255
			g: (aColor green * 255) truncated / 255
			b: (aColor blue * 255) truncated / 255.
	].

	StandardSwizzleMaps := Array new: 4.
	#(1 2 4) do:[:i| StandardSwizzleMaps at: i put: (self computeSwizzleMapForDepth: i)].! !

!PNGReadWriter class methodsFor: 'as yet unclassified' stamp: 'RAA 11/7/2000 09:15'!
insertMorph: aMorph named: aString into: aBook

	| newPage |

	aBook ifNil: [^self].
	newPage := aBook insertPageLabel: aString morphs: {aMorph}.
	newPage color: Color lightYellow.
	newPage extent: (
		newPage submorphs inject: 10@10 into: [ :ex :m |
			m left: 10.
			ex max: m width @ m bottom
		]
	) + (20@20).
! !

!PNGReadWriter class methodsFor: 'image reading/writing' stamp: 'nk 7/16/2003 17:57'!
typicalFileExtensions
	"Answer a collection of file extensions (lowercase) which files that I can read might commonly have"
	^#('png')! !

!PNGReadWriter methodsFor: 'pixel copies' stamp: 'tpr 3/15/2013 12:32'!
copyPixelsGrayAlpha: y
	"Handle non-interlaced grayscale with alpha color mode (colorType = 4)"

	| i pixel gray b |
	b := BitBlt bitPokerToForm: form.
	bitsPerChannel = 8
		ifTrue: [
			0 to: width-1 do: [ :x |
				i := (x << 1) + 1.
				gray := thisScanline at: i.
				pixel := ((thisScanline at: i+1)<<24) + (gray<<16) + (gray<<8) + gray.
				b pixelAt: x@y put: pixel.
				]
			]
		ifFalse: [
			0 to: width-1 do: [ :x |
				i := (x << 2) + 1.
				gray := thisScanline at: i.
				pixel := ((thisScanline at: i+2)<<24) + (gray<<16) + (gray<<8) + gray.
				b pixelAt: x@y put: pixel.
				]
			]
! !

!PNGReadWriter methodsFor: 'pixel copies' stamp: 'tpr 3/15/2013 12:32'!
copyPixelsGrayAlpha: y at: startX by: incX
	"Handle interlaced grayscale with alpha color mode (colorType = 4)"

	| i pixel gray b |
	b := BitBlt bitPokerToForm: form.
	bitsPerChannel = 8
		ifTrue: [
			startX to: width-1 by: incX do: [ :x |
				i := (x // incX << 1) + 1.
				gray := thisScanline at: i.
				pixel := ((thisScanline at: i+1)<<24) + (gray<<16) + (gray<<8) + gray.
				b pixelAt: x@y put: pixel.
				]
			]
		ifFalse: [
			startX to: width-1 by: incX do: [ :x |
				i := (x // incX << 2) + 1.
				gray := thisScanline at: i.
				pixel := ((thisScanline at: i+2)<<24) + (gray<<16) + (gray<<8) + gray.
				b pixelAt: x@y put: pixel.
				]
			]
! !

!PNGReadWriter methodsFor: 'pixel copies' stamp: 'nice 5/10/2014 12:11'!
copyPixelsGray: y 
	"Handle non-interlaced grayscale color mode (colorType = 0)"

	| base bits bytesLeft word |
	bitsPerChannel = 16 ifTrue: [
		"Warning: This is extremely slow. Besides we are downsampling to 8 bits!!"
		| blitter |
		blitter := BitBlt bitPokerToForm: form.
		0 to: width - 1 do: [ :x |
			| high low value |
			high := thisScanline at: x * 2 + 1.
			low := thisScanline at: x * 2 + 2.
			value := (high * 256 + low = transparentPixelValue)
				ifTrue: [0 "transparent"]
				ifFalse: [high max: 1].
			blitter pixelAt: x @ y put: value ].
			^self ].

	"Just copy the bits"

	"This Smalltalk version might be easier to understand than the others below."
	base := y * (form width * bitsPerChannel + 31 // 32) + 1.
	bits := form bits.
	0 to: thisScanline size // 4 - 1 do: [ :i |
		| ii |
		ii := i * 4.
		"This somewhat weird mixture of (#* and #+) with (#bitShift: and #bitOr:) 
		is to make use of faster arithmetic bytecodes, but not of slow largeintegers."
		word :=
			(((thisScanline at: ii + 1) * 256 + 
			(thisScanline at: ii + 2) * 256 + 
			(thisScanline at: ii + 3)) bitShift: 8) bitOr: 
			(thisScanline at: ii + 4).
		bits at: base + i put: word ].	
	(bytesLeft := thisScanline size bitAnd: 3) = 0 ifFalse: [
		word := 0.
		thisScanline size - bytesLeft + 1 to: thisScanline size do: [ :ii |
			word := word * 256 + (thisScanline at: ii) ].
		word := word bitShift: 8 * (4 - bytesLeft).
		bits at: base + (thisScanline size // 4) put: word ].

	"This interesting technique (By Andreas Raab) is faster for very large images, but might be slower for small ones"
	"^self copyPixelsGrayWeirdBitBltHack: y ".
	"It uses the following method:
	PNGReadWriter >> copyPixelsGrayWeirdBitBltHack: y 
	""Handle non-interlaced black and white color mode (colorType = 0)
	By Andreas Raab""
	
	| source dest cmap |
	source := Form extent: 1 @ (thisScanline size // 4) depth: 32 bits: thisScanline.
	dest := Form extent: 1 @ (form bits size) depth: 32 bits: form bits.
	cmap := Smalltalk isLittleEndian
		ifTrue:[ColorMap 
					shifts: #(-24 -8 8 24) 
					masks: #(16rFF000000 16r00FF0000 16r0000FF00 16r000000FF)].
	(BitBlt toForm: dest)
		sourceForm: source;
		destX: 0 destY: (y * form width*bitsPerChannel//32) width: 1 height: (form width+31*bitsPerChannel//32);
		colorMap: cmap;
		combinationRule: 3;
		copyBits."
		
	"This interesting technique  (By Yoshiki Ohshima) is faster for very large images, but might be slower for small ones"
	"form bits copyFromByteArray2: thisScanline to: y * (form width* bitsPerChannel // 32)".
	"It uses the following method:
	BitMap >> copyFromByteArray2: byteArray to: i
	""This method should work with either byte orderings""

	| myHack byteHack |
	myHack := Form new hackBits: self.
	byteHack := Form new hackBits: byteArray.
	Smalltalk  isLittleEndian ifTrue: [byteHack swapEndianness].
	byteHack displayOn: myHack at:  0@i"! !

!PNGReadWriter methodsFor: 'pixel copies' stamp: 'nice 5/10/2014 13:54'!
copyPixelsGray: y at: startX by: incX
	"Handle interlaced grayscale color mode (colorType = 0)"

	| offset bits blitter pixPerByte shifts b pixel mask pixelNumber |
	bitsPerChannel = 16
		ifTrue: [
			"Warning: This is extremely slow. Besides we are downsampling to 8 bits!!"
			blitter := BitBlt bitPokerToForm: form.
			startX to: width-1 by: incX do: [ :x |
				| high low value |
				high := thisScanline at: x//incX<<1 + 1.
				low := thisScanline at: x//incX<<1 + 2.
				value := (high * 256 + low = transparentPixelValue)
					ifTrue: [0 "transparent"]
					ifFalse: [high max: 1].
				blitter pixelAt: x @ y put: value ].
				^self ].
	offset := y*rowSize+1.
	bits := form bits.
	bitsPerChannel = 8 ifTrue: [
		startX to: width-1 by: incX do: [ :x | | w |
			w := offset + (x>>2).
			b := 3- (x \\ 4) * 8.
			pixel := (thisScanline at: x // incX + 1)<<b.
			mask := (255<<b) bitInvert32.
			bits at: w put: (((bits at: w) bitAnd: mask) bitOr: pixel)
		].
		^ self
	].
	bitsPerChannel = 1 ifTrue: [
		pixPerByte := 8.
		mask := 1.
		shifts := #(7 6 5 4 3 2 1 0).
	].
	bitsPerChannel = 2 ifTrue: [
		pixPerByte := 4.
		mask := 3.
		shifts := #(6 4 2 0).
	].
	bitsPerChannel = 4 ifTrue: [
		pixPerByte := 2.
		mask := 15.
		shifts := #(4 0).
	].

	blitter := BitBlt bitPokerToForm: form.
	pixelNumber := 0.
	startX to: width-1 by: incX do: [ :x | | rawByte |
		rawByte := thisScanline at: (pixelNumber // pixPerByte) + 1.
		pixel := (rawByte >> (shifts at: (pixelNumber \\ pixPerByte) + 1)) bitAnd: mask.
		blitter pixelAt: (x@y) put: pixel.
		pixelNumber := pixelNumber + 1.
	].
! !

!PNGReadWriter methodsFor: 'pixel copies' stamp: 'ar 1/1/1970 21:00'!
copyPixelsIndexed: y
	"Handle non-interlaced indexed color mode (colorType = 3)"
	| hack hackBlt swizzleHack swizzleBlt scanline hackDepth |
	scanline := ByteArray new: bytesPerScanline + 3 // 4 * 4.
	scanline replaceFrom: 1 to: thisScanline size with: thisScanline startingAt: 1.
	hackDepth := bigEndian ifTrue:[form depth] ifFalse:[form depth negated].
	hack := Form extent: width@1 depth: hackDepth bits: scanline.
	hackBlt := BitBlt toForm: form.
	hackBlt sourceForm: hack.
	hackBlt combinationRule: Form over.
	hackBlt destOrigin: 0@y.
	hackBlt width: width; height: 1.

	(form depth < 8 and:[bigEndian not]) ifTrue:[
		swizzleHack := Form new hackBits: scanline.
		swizzleBlt := BitBlt toForm: swizzleHack.
		swizzleBlt sourceForm: swizzleHack.
		swizzleBlt combinationRule: Form over.
		swizzleBlt colorMap: (StandardSwizzleMaps at: form depth).
		swizzleBlt copyBits.
	].

	hackBlt copyBits.! !

!PNGReadWriter methodsFor: 'pixel copies' stamp: 'tpr 3/15/2013 12:32'!
copyPixelsIndexed: y at: startX by: incX
	"Handle interlaced indexed color mode (colorType = 3)"

	| offset bits pixPerByte shifts blitter pixel mask pixelNumber |
	offset := y*rowSize+1.
	bits := form bits.
	bitsPerChannel = 8
		ifTrue: [
			startX to: width-1 by: incX do: [ :x | | b w |
				w := offset + (x>>2).
				b := 3 - (x \\ 4) * 8.
				pixel := (thisScanline at: x // incX + 1)<<b.
				mask := (255<<b) bitInvert32.
				bits at: w put: (((bits at: w) bitAnd: mask) bitOr: pixel)].
			^ self ].
	bitsPerChannel = 1 ifTrue: [
		pixPerByte := 8.
		mask := 1.
		shifts := #(7 6 5 4 3 2 1 0).
	].
	bitsPerChannel = 2 ifTrue: [
		pixPerByte := 4.
		mask := 3.
		shifts := #(6 4 2 0).
	].
	bitsPerChannel = 4 ifTrue: [
		pixPerByte := 2.
		mask := 15.
		shifts := #(4 0).
	].

	blitter := BitBlt bitPokerToForm: form.
	pixelNumber := 0.
	startX to: width-1 by: incX do: [ :x | | rawByte |
		rawByte := thisScanline at: (pixelNumber // pixPerByte) + 1.
		pixel := (rawByte >> (shifts at: (pixelNumber \\ pixPerByte) + 1)) bitAnd: mask.
		blitter pixelAt: (x@y) put: pixel.
		pixelNumber := pixelNumber + 1.
	].
! !

!PNGReadWriter methodsFor: 'pixel copies' stamp: 'ar 2/18/2004 23:58'!
copyPixelsRGBA: y
	"Handle non-interlaced RGBA color modes (colorType = 6)"

	| i pixel tempForm tempBits ff |
	bitsPerChannel = 8 ifTrue: [
		ff := Form extent: width@1 depth: 32 bits: thisScanline.
		cachedDecoderMap 
			ifNil:[cachedDecoderMap := self rgbaDecoderMapForDepth: depth].
		(BitBlt toForm: form)
			sourceForm: ff;
			destOrigin: 0@y;
			combinationRule: Form over;
			colorMap: cachedDecoderMap;
			copyBits.
		^self.
	].
	tempForm := Form extent: width@1 depth: 32.
	tempBits := tempForm bits.
	pixel := LargePositiveInteger new: 4.
	i := -7.
	0 to: width-1 do: [ :x |
			i := i + 8.
			pixel at: 4 put: (thisScanline at: i+6);
				at: 3 put: (thisScanline at: i);
				at: 2 put: (thisScanline at: i+2);
				at: 1 put: (thisScanline at: i+4).
			tempBits at: x+1 put: pixel.
	].
	tempForm displayOn: form at: 0@y rule: Form over.
! !

!PNGReadWriter methodsFor: 'pixel copies' stamp: 'nk 7/27/2004 17:57'!
copyPixelsRGBA: y at: startX by: incX
	"Handle interlaced RGBA color modes (colorType = 6)"

	| i pixel tempForm tempBits |

	tempForm := Form extent: width@1 depth: 32.
	tempBits := tempForm bits.
	pixel := LargePositiveInteger new: 4.
	bitsPerChannel = 8 ifTrue: [
		i := (startX // incX << 2) + 1.
		startX to: width-1 by: incX do: [ :x |
			pixel at: 4 put: (thisScanline at: i+3);
				at: 3 put: (thisScanline at: i);
				at: 2 put: (thisScanline at: i+1);
				at: 1 put: (thisScanline at: i+2).
			tempBits at: x+1 put: pixel.
			i := i + 4.
		]
	] ifFalse: [
		i := (startX // incX << 3) +1.
		startX to: width-1 by: incX do: [ :x |
			pixel at: 4 put: (thisScanline at: i+6);
				at: 3 put: (thisScanline at: i);
				at: 2 put: (thisScanline at: i+2);
				at: 1 put: (thisScanline at: i+4).
			tempBits at: x+1 put: pixel.
			i := i + 8.
		].
	].
	tempForm displayOn: form at: 0@y rule: Form paintAlpha.

! !

!PNGReadWriter methodsFor: 'pixel copies' stamp: 'nice 5/10/2014 14:58'!
copyPixelsRGB: y
	"Handle non-interlaced RGB color mode (colorType = 2)"

	| i pixel tempForm tempBits |
	(transparentPixelValue isNil and: [ bitsPerChannel = 8 ]) ifTrue: [ "Do the same trick as in #copyPixelsRGBA:"
		| targetIndex |
		tempBits := ByteArray new: thisScanline size * 4 // 3 withAll: 16rFF.
		tempForm := Form extent: width@1 depth: 32 bits: tempBits.
		targetIndex := 1.
		1 to: thisScanline size by: 3 do: [ :index |
			tempBits
				at: targetIndex put: (thisScanline at: index);
				at: targetIndex + 1 put: (thisScanline at: index + 1);
				at: targetIndex + 2 put: (thisScanline at: index + 2).
			targetIndex := targetIndex + 4 ].
		cachedDecoderMap 
			ifNil:[cachedDecoderMap := self rgbaDecoderMapForDepth: depth].
		(BitBlt toForm: form)
			sourceForm: tempForm;
			destOrigin: 0@y;
			combinationRule: Form over;
			colorMap: cachedDecoderMap;
			copyBits.
		^self ].
	tempForm := Form extent: width@1 depth: 32.
	tempBits := tempForm bits.
	pixel := LargePositiveInteger new: 4.
	pixel at: 4 put: 16rFF.
	bitsPerChannel = 8
		ifTrue:
			[i := 1.
			1 to: width do:
				[ :x |
				pixel
					at: 3 put: (thisScanline at: i);
					at: 2 put: (thisScanline at: i+1);
					at: 1 put: (thisScanline at: i+2).
				tempBits at: x put: pixel.
				i := i + 3].
			transparentPixelValue
				ifNotNil:
					[1 to: width do: [ :x |
						(tempBits at: x) = transparentPixelValue
							ifTrue: [tempBits at: x put: 0]]]]
		ifFalse:
			[i := 1.
			1 to: width do:
				[ :x |
				(transparentPixelValue == nil or: [(1 to: 6) anySatisfy: [:k | (transparentPixelValue digitAt: k) ~= (thisScanline at: i + 6 - k)]])
					ifTrue:
						[pixel
							at: 3 put: (thisScanline at: i);
							at: 2 put: (thisScanline at: i+2);
							at: 1 put: (thisScanline at: i+4).
						tempBits at: x put: pixel]
					ifFalse:
						[tempBits at: x put: 0].
				i := i + 6]].
	
	tempForm displayOn: form at: 0@y rule: Form over.
! !

!PNGReadWriter methodsFor: 'pixel copies' stamp: 'nice 5/10/2014 15:07'!
copyPixelsRGB: y at: startX by: incX
	"Handle interlaced RGB color mode (colorType = 2)"

	| i pixel tempForm tempBits xx loopsToDo |

	tempForm := Form extent: width@1 depth: 32.
	tempBits := tempForm bits.
	pixel := LargePositiveInteger new: 4.
	pixel at: 4 put: 16rFF.
	loopsToDo := width - startX + incX - 1 // incX.
	bitsPerChannel = 8
		ifTrue:
			[i := (startX // incX * 3) + 1.
			xx := startX+1.
			1 to: loopsToDo do:
				[ :j |
				pixel
					at: 3 put: (thisScanline at: i);
					at: 2 put: (thisScanline at: i+1);
					at: 1 put: (thisScanline at: i+2).
				tempBits at: xx put: pixel.
				i := i + 3.
				xx := xx + incX].
			transparentPixelValue
				ifNotNil: [startX to: width-1 by: incX do: [ :x |
					(tempBits at: x+1) = transparentPixelValue
						ifTrue: [	tempBits at: x+1 put: 0]]]]
		ifFalse:
			[i := (startX // incX * 6) + 1.
			xx := startX+1.
			1 to: loopsToDo do:
				[ :j |
				(transparentPixelValue == nil or: [(1 to: 6) anySatisfy: [:k | (transparentPixelValue digitAt: k) ~= (thisScanline at: i + 6 - k)]])
					ifTrue:
						[pixel
							at: 3 put: (thisScanline at: i);
							at: 2 put: (thisScanline at: i+2);
							at: 1 put: (thisScanline at: i+4).
						tempBits at: xx put: pixel.]
					ifFalse:
						[tempBits at: xx put: 0].
				i := i + 6.
				xx := xx + incX]].
	tempForm displayOn: form at: 0@y rule: Form over.

! !

!PNGReadWriter methodsFor: 'pixel copies' stamp: 'DSM 3/26/2000 21:32'!
copyPixels: y
	"Handle non-interlaced pixels of supported colorTypes"

	| s |
	s := #(copyPixelsGray: nil copyPixelsRGB: copyPixelsIndexed:
		  copyPixelsGrayAlpha: nil copyPixelsRGBA:) at: colorType+1.
	self perform: s asSymbol with: y
! !

!PNGReadWriter methodsFor: 'pixel copies' stamp: 'RAA 11/4/2000 16:08'!
copyPixels: y at: startX by: incX
	"Handle interlaced pixels of supported colorTypes"

	| s |
	s := #(copyPixelsGray:at:by: nil copyPixelsRGB:at:by: copyPixelsIndexed:at:by:
		  copyPixelsGrayAlpha:at:by: nil copyPixelsRGBA:at:by:) at: colorType+1.
	self perform: s asSymbol with: y with: startX with: incX
! !

!PNGReadWriter methodsFor: 'accessing' stamp: 'RAA 11/7/2000 09:20'!
debugging

	^Debugging == true! !

!PNGReadWriter methodsFor: 'miscellaneous' stamp: 'DSM 4/27/2000 13:09'!
doPass: pass
	"Certain interlace passes are skipped with certain small image
dimensions"

	pass = 1 ifTrue: [ ^ true ].
	((width = 1) and: [height = 1]) ifTrue: [ ^ false ].
	pass = 2 ifTrue: [ ^ width >= 5 ].
	pass = 3 ifTrue: [ ^ height >= 5 ].
	pass = 4 ifTrue: [ ^ (width >=3 ) or: [height >= 5] ].
	pass = 5 ifTrue: [ ^ height >=3 ].
	pass = 6 ifTrue: [ ^ width >=2 ].
	pass = 7 ifTrue: [ ^ height >=2 ].

! !

!PNGReadWriter methodsFor: 'filtering' stamp: 'RAA 11/7/2000 09:43'!
filterAverage: count
	"Use the average of the pixel to the left and the pixel above as a predictor"

	| delta |
	delta := bitsPerPixel // 8 max: 1.
	1 to: delta do: [:i |
		thisScanline at: i put: ((thisScanline at: i) + ((prevScanline at: i) // 2) bitAnd: 255)].
	delta + 1 to: count do: [:i |
		thisScanline at: i put:
			((thisScanline at: i)
			+ ((prevScanline at: i)
			+ (thisScanline at: i - delta) // 2) bitAnd: 255)]! !

!PNGReadWriter methodsFor: 'filtering' stamp: 'DSM 3/25/2000 17:54'!
filterHorizontal: count
	"Use the pixel to the left as a predictor"

	| delta |
	delta := bitsPerPixel // 8 max: 1.
	delta+1 to: count do: [ :i |
		thisScanline at: i put: (((thisScanline at: i) +
(thisScanline at: i-delta)) bitAnd: 255) ]


! !

!PNGReadWriter methodsFor: 'filtering' stamp: 'DSM 3/25/2000 17:55'!
filterNone: count
! !

!PNGReadWriter methodsFor: 'filtering' stamp: 'RAA 11/7/2000 09:45'!
filterPaeth: count
	"Select one of (the pixel to the left, the pixel above and the pixel to above left) to
	predict the value of this pixel"

	| delta |
	delta := bitsPerPixel // 8 max: 1.
	1 to: delta do: [ :i |
		thisScanline at: i put:
			(((thisScanline at: i) + (prevScanline at: i)) bitAnd: 255)].
	delta+1 to: count do: [ :i |
		thisScanline
			at: i
			put: (((thisScanline at: i) + (self
				paethPredictLeft: (thisScanline at: i-delta)
				above: (prevScanline at: i)
				aboveLeft: (prevScanline at: i-delta)))
					bitAnd: 255)]

! !

!PNGReadWriter methodsFor: 'filtering' stamp: 'eat 9/11/2000 20:08'!
filterScanline: filterType count: count

	self
		perform: (
			#(filterNone: filterHorizontal: filterVertical: filterAverage: filterPaeth:)
				at: filterType+1)
		with: count.

! !

!PNGReadWriter methodsFor: 'filtering' stamp: 'DSM 3/25/2000 17:54'!
filterVertical: count
	"Use the pixel above as a predictor"

	1 to: count do: [ :i |
		thisScanline at: i put: (((thisScanline at: i) +
(prevScanline at: i)) bitAnd: 255) ]

! !

!PNGReadWriter methodsFor: 'miscellaneous' stamp: 'jmv 4/15/2010 10:19'!
grayColorsFor: d
	"return a color table for a gray image"

	palette := Array new: 1<<d.
	d = 1 ifTrue: [
		palette at: 1 put: Color black.
		palette at: 2 put: Color white.
		^  palette
		].
	d = 2 ifTrue: [
		palette at: 1 put: Color black.
		palette at: 2 put: (Color gray: 85.0 / 255.0).
		palette at: 3 put: (Color gray: 170.0 / 255.0).
		palette at: 4 put: Color white.
		^ palette
		].
	d = 4 ifTrue: [
		0 to: 15 do: [ :g |
			palette at: g+1 put: (Color gray: (g/15) asFloat) ].
		^ palette
		].
	d = 8 ifTrue: [
		0 to: 255 do: [ :g |
			palette at: g+1 put: (Color gray: (g/255) asFloat) ].
		^ palette
		].
! !

!PNGReadWriter methodsFor: 'accessing' stamp: 'ul 10/25/2013 16:46'!
nextImage
	bigEndian := Smalltalk isBigEndian.
	filtersSeen := Bag new.
	idatChunkStream := nil.
	transparentPixelValue := nil.
	unknownChunks := Set new.
	stream reset.
	stream binary.
	stream skip: 8.
	[stream atEnd] whileFalse: [self processNextChunk].
	"Set up our form"
	palette ifNotNil: 
			["Dump the palette if it's the same as our standard palette"

			palette = (StandardColors copyFrom: 1 to: palette size) 
				ifTrue: [palette := nil]].
	(depth <= 8 and: [palette notNil]) 
		ifTrue: 
			[form := ColorForm extent: width @ height depth: depth.
			form colors: palette]
		ifFalse: [form := Form extent: width @ height depth: depth].
	backColor ifNotNil: [form fillColor: backColor].
	idatChunkStream 
		ifNil: [ self error: 'image data is missing' ]
		ifNotNil: [ self processIDATChunk ].
	unknownChunks isEmpty 
		ifFalse: 
			["Transcript show: ' ',unknownChunks asSortedCollection asArray printString."

			].
	self debugging 
		ifTrue: 
			[Transcript
				cr;
				show: 'form = ' , form printString.
			Transcript
				cr;
				show: 'colorType = ' , colorType printString.
			Transcript
				cr;
				show: 'interlaceMethod = ' , interlaceMethod printString.
			Transcript
				cr;
				show: 'filters = ' , filtersSeen sortedCounts asArray printString].
	^form! !

!PNGReadWriter methodsFor: 'writing' stamp: 'ar 12/12/2003 16:37'!
nextPutImage: aForm
	"Write out the given form. We're keeping it simple here, no interlacing, no filters."
	^self nextPutImage: aForm interlace: 0 filter: 0. "no filtering"! !

!PNGReadWriter methodsFor: 'writing' stamp: 'fbs 7/25/2013 07:15'!
nextPutImage: aForm interlace: aMethod filter: aFilterType 
	"Note: For now we keep it simple - interlace and filtering are simply ignored"

	| crcStream |
	bigEndian := Smalltalk isBigEndian.
	form := aForm.
	width := aForm width.
	height := aForm height.
	aForm depth <= 8 
		ifTrue: 
			[bitsPerChannel := aForm depth.
			colorType := 3.
			bytesPerScanline := (width * aForm depth + 7) // 8]
		ifFalse: 
			[bitsPerChannel := 8.
			colorType := 6.
			bytesPerScanline := width * 4].
	self writeFileSignature.
	crcStream := WriteStream on: (ByteArray new: 1000).
	crcStream resetToStart.
	self writeIHDRChunkOn: crcStream.
	self writeChunk: crcStream.
	form depth <= 8 
		ifTrue: 
			[crcStream resetToStart.
			self writePLTEChunkOn: crcStream.
			self writeChunk: crcStream.
			form isColorForm 
				ifTrue: 
					[crcStream resetToStart.
					self writeTRNSChunkOn: crcStream.
					self writeChunk: crcStream]].
	form depth = 16 
		ifTrue: 
			[crcStream resetToStart.
			self writeSBITChunkOn: crcStream.
			self writeChunk: crcStream].
	crcStream resetToStart.
	self writeIDATChunkOn: crcStream.
	self writeChunk: crcStream.
	crcStream resetToStart.
	self writeIENDChunkOn: crcStream.
	self writeChunk: crcStream! !

!PNGReadWriter methodsFor: 'filtering' stamp: 'eat 9/11/2000 20:05'!
paethPredictLeft: a above: b aboveLeft: c
	"Predicts the value of a pixel based on nearby pixels, based on
Paeth (GG II, 1991)"

	| pa pb pc |
	pa := b > c ifTrue: [b - c] ifFalse: [c - b].
	pb := a > c ifTrue: [a - c] ifFalse: [c - a].
	pc := a + b - c - c.
	pc < 0 ifTrue: [
		pc := pc * -1].
	((pa <= pb) and: [pa <= pc]) ifTrue: [^ a].
	(pb <= pc) ifTrue: [^ b].
	^ c
! !

!PNGReadWriter methodsFor: 'chunks' stamp: 'ar 2/10/2004 23:55'!
processBackgroundChunk

	| val red green blue max |

	"Transcript show: '  BACKGROUND: ',chunk printString."
	colorType = 3 ifTrue: [
		backColor := palette at: chunk first + 1.
		^self
	].
	max := (2 raisedTo: bitsPerChannel) - 1.
	(colorType = 0 or: [colorType = 4]) ifTrue: [
		val := chunk unsignedShortAt: 1 bigEndian: true.
		backColor := Color gray: val / max.
		^self
	].
	(colorType = 2 or: [colorType = 6]) ifTrue: [
		red := chunk unsignedShortAt: 1 bigEndian: true.
		green := chunk unsignedShortAt: 3 bigEndian: true.
		blue := chunk unsignedShortAt: 5 bigEndian: true.
		backColor := Color r: red/max g: green/max b: blue/max.
		^self
	].
"self halt."

"====
The bKGD chunk specifies a default background color to present the image against. Note that viewers are not bound to honor this chunk; a viewer can choose to use a different background. 

For color type 3 (indexed color), the bKGD chunk contains: 


   Palette index:  1 byte

The value is the palette index of the color to be used as background. 

For color types 0 and 4 (grayscale, with or without alpha), bKGD contains: 


   Gray:  2 bytes, range 0 .. (2^bitdepth)-1

(For consistency, 2 bytes are used regardless of the image bit depth.) The value is the gray level to be used as background. 

For color types 2 and 6 (truecolor, with or without alpha), bKGD contains: 


   Red:   2 bytes, range 0 .. (2^bitdepth)-1
   Green: 2 bytes, range 0 .. (2^bitdepth)-1
   Blue:  2 bytes, range 0 .. (2^bitdepth)-1

(For consistency, 2 bytes per sample are used regardless of the image bit depth.) This is the RGB color to be used as background. 

When present, the bKGD chunk must precede the first IDAT chunk, and must follow the PLTE chunk, if any. 
==="
! !

!PNGReadWriter methodsFor: 'chunks' stamp: 'RAA 11/4/2000 17:00'!
processIDATChunk

	interlaceMethod = 0
		ifTrue: [ self processNonInterlaced ]
		ifFalse: [ self processInterlaced ]
! !

!PNGReadWriter methodsFor: 'chunks' stamp: 'ar 2/10/2004 23:55'!
processIHDRChunk
	width := chunk longAt: 1 bigEndian: true.
	height := chunk longAt: 5 bigEndian: true.
	bitsPerChannel := chunk at: 9.
	colorType := chunk at: 10.
	"compression := chunk at: 11." "TODO - validate compression"
	"filterMethod := chunk at: 12." "TODO - validate filterMethod"
	interlaceMethod := chunk at: 13. "TODO - validate interlace method"
	(#(2 4 6) includes: colorType)
		ifTrue: [depth := 32].
	(#(0 3) includes: colorType) ifTrue: [
		depth := bitsPerChannel min: 8.
		colorType = 0 ifTrue: [ "grayscale"
			palette := self grayColorsFor: depth.
		].
	].
	bitsPerPixel := (BPP at: colorType+1) at: bitsPerChannel highBit.
	bytesPerScanline := width * bitsPerPixel + 7 // 8.
	rowSize := width * depth + 31 >> 5.
! !

!PNGReadWriter methodsFor: 'chunks' stamp: 'ul 10/25/2013 16:46'!
processInterlaced
	| z startingCol colIncrement rowIncrement startingRow |
	startingCol := #(0 4 0 2 0 1 0 ).
	colIncrement := #(8 8 4 4 2 2 1 ).
	rowIncrement := #(8 8 8 4 4 2 2 ).
	startingRow := #(0 0 4 0 2 0 1 ).
	z := ZLibReadStream 
		on: idatChunkStream originalContents
		from: 1
		to: idatChunkStream position.
	1 to: 7 do: [:pass |
		| cx sc bytesPerPass |
		(self doPass: pass)
			ifTrue:
				[cx := colIncrement at: pass.
				sc := startingCol at: pass.
				bytesPerPass := width - sc + cx - 1 // cx * bitsPerPixel + 7 // 8.
				prevScanline := ByteArray new: bytesPerPass.
				thisScanline := ByteArray new: bytesPerScanline.
				(startingRow at: pass)
					to: height - 1
					by: (rowIncrement at: pass)
					do: [:y |
						| filter temp |
						filter := z next.
						filtersSeen add: filter.
						(filter isNil or: [(filter between: 0 and: 4) not])
							ifTrue: [^ self].
						thisScanline := z next: bytesPerPass into: thisScanline startingAt: 1.
						self filterScanline: filter count: bytesPerPass.
						self copyPixels: y at: sc by: cx.
						temp := prevScanline.
						prevScanline := thisScanline.
						thisScanline := temp.
					]
				]
	].
	z atEnd ifFalse:[self error:'Unexpected data'].! !

!PNGReadWriter methodsFor: 'chunks' stamp: 'bf 5/25/2016 15:29'!
processNextChunk

	| length chunkType crc chunkCrc |

	length := self nextLong.

	chunkType := (self next: 4) asString.
	(chunk isNil or: [ chunk size ~= length ])
		ifTrue: [ chunk := self next: length ]
		ifFalse: [ stream next: length into: chunk startingAt: 1 ].
	chunkCrc := self nextLong bitXor: 16rFFFFFFFF.
	crc := self updateCrc: 16rFFFFFFFF from: 1 to: 4 in: chunkType.
	crc := self updateCrc: crc from: 1 to: length in: chunk.
	crc = chunkCrc ifFalse:[
		self error: 'PNGReadWriter crc error in chunk ', chunkType.
	].

	chunkType = 'IEND' ifTrue: [stream setToEnd. ^self	"*should* be the last chunk"].
	chunkType = 'sBIT' ifTrue: [^self processSBITChunk "could indicate unusual sample depth in original"].
	chunkType = 'gAMA' ifTrue: [^self 	"indicates gamma correction value"].
	chunkType = 'bKGD' ifTrue: [^self processBackgroundChunk].
	chunkType = 'pHYs' ifTrue: [^self processPhysicalPixelChunk].
	chunkType = 'tRNS' ifTrue: [^self processTransparencyChunk].

	chunkType = 'IHDR' ifTrue: [^self processIHDRChunk].
	chunkType = 'PLTE' ifTrue: [^self processPLTEChunk].
	chunkType = 'IDAT' ifTrue: [
		"---since the compressed data can span multiple
		chunks, stitch them all together first. later,
		if memory is an issue, we need to figure out how
		to do this on the fly---"
		idatChunkStream
			ifNil: [ idatChunkStream := WriteStream with: chunk copy ]
			ifNotNil: [ idatChunkStream nextPutAll: chunk ].
		^self
	].
	unknownChunks add: chunkType.
! !

!PNGReadWriter methodsFor: 'chunks' stamp: 'ul 10/25/2013 16:47'!
processNonInterlaced
	| z filter temp copyMethod debug |
	debug := self debugging.
	copyMethod := #(copyPixelsGray: nil copyPixelsRGB: copyPixelsIndexed:
		  copyPixelsGrayAlpha: nil copyPixelsRGBA:) at: colorType+1.
	debug ifTrue: [ Transcript cr; nextPutAll: 'NI chunk size='; print: idatChunkStream position ].
	z := ZLibReadStream 
		on: idatChunkStream originalContents
		from: 1
		to: idatChunkStream position.
	prevScanline := ByteArray new: bytesPerScanline.
	thisScanline := ByteArray new: bytesPerScanline.
	0 to: height-1 do: [ :y |
		filter := z next.
		debug ifTrue:[filtersSeen add: filter].
		thisScanline := z next: bytesPerScanline into: thisScanline startingAt: 1.
		(debug and: [ thisScanline size < bytesPerScanline ]) ifTrue: [ Transcript nextPutAll: ('wanted {1} but only got {2}' format: { bytesPerScanline. thisScanline size }); cr ].
		filter = 0 ifFalse:[self filterScanline: filter count: bytesPerScanline].
		self perform: copyMethod with: y.
		temp := prevScanline.
		prevScanline := thisScanline.
		thisScanline := temp.
		].
	z atEnd ifFalse:[self error:'Unexpected data'].
	debug ifTrue: [Transcript  nextPutAll: ' compressed size='; print: z position  ].
! !

!PNGReadWriter methodsFor: 'chunks' stamp: 'RAA 11/5/2000 11:24'!
processPhysicalPixelChunk

	"Transcript show: '  PHYSICAL: ',chunk printString."
! !

!PNGReadWriter methodsFor: 'chunks' stamp: 'ar 2/11/2004 01:02'!
processPLTEChunk

	| colorCount i |

	colorCount := chunk size // 3. "TODO - validate colorCount against depth"
	palette := Array new: colorCount.
	0 to: colorCount-1 do: [ :index |
		i := index * 3 + 1.
		palette at: index+1 put:
			(Color r: (chunk at: i)/255.0 g: (chunk at: i+1)/255.0 b: (chunk at: i+2)/255.0)
		].! !

!PNGReadWriter methodsFor: 'chunks' stamp: 'ar 12/12/2003 18:33'!
processSBITChunk
	| rBits gBits bBits aBits |
	colorType = 6 ifFalse:[^self].
	rBits := chunk at: 1.
	gBits := chunk at: 2.
	bBits := chunk at: 3.
	aBits := chunk at: 4.
	(rBits = 5 and:[gBits = 5 and:[bBits = 5 and:[aBits = 1]]]) ifTrue:[
		depth := 16.
	].! !

!PNGReadWriter methodsFor: 'chunks' stamp: 'nice 5/10/2014 14:59'!
processTransparencyChunk

	"Transcript show: '  TRANSPARENCY ',chunk printString."
	colorType = 0
		ifTrue:
			[transparentPixelValue := chunk unsignedShortAt: 1 bigEndian: true.
			bitsPerChannel <= 8
				ifTrue: [palette at: transparentPixelValue + 1 put: Color transparent]
				ifFalse: [palette at: 1 put: Color transparent].
			^self].
	colorType = 2
		ifTrue:
			[| red green blue |
			red :=  chunk unsignedShortAt: 1 bigEndian: true.
			green :=  chunk unsignedShortAt: 3 bigEndian: true.
			blue :=  chunk unsignedShortAt: 5 bigEndian: true.
			transparentPixelValue := bitsPerChannel <= 8
				ifTrue: [16rFF00 + red << 8 + green << 8 + blue]
				ifFalse: [red << 16 + green << 16 + blue].
			^self].
	colorType = 3
		ifTrue:
			[chunk withIndexDo: [ :alpha :index |
				palette at: index put: ((palette at: index) alpha: alpha/255)].
			^self].
! !

!PNGReadWriter methodsFor: 'pixel copies' stamp: 'ar 2/19/2004 00:10'!
rgbaDecoderMapForDepth: decoderDepth
	bigEndian ifTrue:[
		depth = 16 ifTrue:[
			"Big endian, 32 -> 16 color mapping."
			^ColorMap
				shifts: #(-17 -14 -11 0)
				masks: #(16rF8000000 16rF80000 16rF800 16r00)
		] ifFalse:[
			"Big endian, 32 -> 32 color mapping"
			^ColorMap 
				shifts: #(-8 -8 -8 24) 
				masks: #(16rFF000000 16rFF0000 16rFF00 16rFF).
		].
	].
	depth = 16 ifTrue:[
		"Little endian, 32 -> 16 color mapping."
		^ColorMap
			shifts: #(7 -6 -19 0)
			masks: #(16rF8 16rF800 16rF80000 0)
	] ifFalse:[
		"Little endian, 32 -> 32 color mapping"
		^ColorMap 
			shifts: #(-16 0 16 0) 
			masks: #(16rFF0000 16rFF00 16rFF 16rFF000000).
	].! !

!PNGReadWriter methodsFor: 'accessing' stamp: 'DSM 3/24/2000 01:12'!
understandsImageFormat
	#(137 80 78 71 13 10 26 10) do: [ :byte |
		stream next = byte ifFalse: [^ false]].
	^ true
! !

!PNGReadWriter methodsFor: 'writing' stamp: 'nk 2/17/2004 16:51'!
updateCrc: oldCrc from: start to: stop in: aCollection
	^ZipWriteStream updateCrc: oldCrc from: start to: stop in: aCollection! !

!PNGReadWriter methodsFor: 'writing' stamp: 'BG 3/16/2005 08:26'!
writeChunk: crcStream
	| bytes length crc debug |
	debug := self debugging.
	bytes := crcStream originalContents.
	length := crcStream position.
	crc := self updateCrc: 16rFFFFFFFF from: 1 to: length in: bytes.
	crc := crc bitXor: 16rFFFFFFFF.
	debug ifTrue: [ Transcript cr;
		print: stream position; space;
		nextPutAll: (bytes copyFrom: 1 to: 4) asString;
		nextPutAll: ' len='; print: length;
		nextPutAll: ' crc=0x'; nextPutAll: crc printStringHex  ].
	stream nextNumber: 4 put: length-4. "exclude chunk name"
	stream next: length putAll: bytes startingAt: 1.
	stream nextNumber: 4 put: crc.
	debug ifTrue: [ Transcript nextPutAll: ' afterPos='; print: stream position ].
	crcStream resetToStart.! !

!PNGReadWriter methodsFor: 'writing' stamp: 'nice 1/18/2010 18:08'!
writeFileSignature
	stream nextPutAll: #[ 16r89 16r50 16r4E  16r47 16r0D 16r0A 16r1A 16r0A ]! !

!PNGReadWriter methodsFor: 'writing' stamp: 'nk 2/17/2004 14:57'!
writeIDATChunkOn: aStream
	"Write the IDAT chunk"
	| z |
	aStream nextPutAll: 'IDAT' asByteArray.
	z := ZLibWriteStream on: aStream.
	form depth <= 8 
		ifTrue:[self writeType3DataOn: z]
		ifFalse:[ self writeType6DataOn: z].
	self debugging ifTrue: [
		Transcript cr;
			nextPutAll: 'compressed size=';
			print: aStream position;
			nextPutAll: ' uncompressed size=';
			print: z position  ]
! !

!PNGReadWriter methodsFor: 'writing' stamp: 'ar 12/12/2003 17:08'!
writeIENDChunkOn: aStream
	"Write the IEND chunk"
	aStream nextPutAll: 'IEND' asByteArray.! !

!PNGReadWriter methodsFor: 'writing' stamp: 'ar 12/12/2003 17:21'!
writeIHDRChunkOn: aStream
	"Write the IHDR chunk"
	aStream nextPutAll: 'IHDR' asByteArray.
	aStream nextInt32Put: width.
	aStream nextInt32Put: height.
	aStream nextNumber: 1 put: bitsPerChannel.
	aStream nextNumber: 1 put: colorType.
	aStream nextNumber: 1 put: 0. "compression"
	aStream nextNumber: 1 put: 0. "filter method"
	aStream nextNumber: 1 put: 0. "interlace method"
! !

!PNGReadWriter methodsFor: 'writing' stamp: 'nice 12/26/2009 19:05'!
writePLTEChunkOn: aStream
	"Write the PLTE chunk"
	| colors |
	aStream nextPutAll: 'PLTE' asByteArray.
	(form isColorForm) 
		ifTrue:[colors := form colors]
		ifFalse:[colors := Color indexedColors copyFrom: 1 to: (1 bitShift: form depth)].
	colors do:[:aColor|
		| r g b |
		r := (aColor red * 255) truncated.
		g := (aColor green * 255) truncated.
		b := (aColor blue * 255) truncated.
		aStream nextPut: r; nextPut: g; nextPut: b.
	].! !

!PNGReadWriter methodsFor: 'writing' stamp: 'ar 12/12/2003 18:29'!
writeSBITChunkOn: aStream
	"Write the IDAT chunk"
	aStream nextPutAll: 'sBIT' asByteArray.
	form depth = 16 ifFalse:[self error: 'Unimplemented feature'].
	aStream nextPut: 5.
	aStream nextPut: 5.
	aStream nextPut: 5.
	aStream nextPut: 1.! !

!PNGReadWriter methodsFor: 'writing' stamp: 'ar 12/12/2003 17:34'!
writeTRNSChunkOn: aStream
	"Write out tRNS chunk"
	aStream nextPutAll: 'tRNS' asByteArray.
	form colors do:[:aColor|
		aStream nextPut: (aColor alpha * 255) truncated.
	].! !

!PNGReadWriter methodsFor: 'writing' stamp: 'ar 1/1/1970 20:58'!
writeType3DataOn: zStream
	"Write color indexed data."
	| scanline hack hackBlt swizzleBlt swizzleHack hackDepth |
	scanline := ByteArray new: bytesPerScanline + 3 // 4 * 4.
	hackDepth := bigEndian ifTrue:[form depth] ifFalse:[form depth negated].
	hack := Form extent: width@1 depth: hackDepth bits: scanline.
	hackBlt := BitBlt toForm: hack.
	hackBlt sourceForm: form.
	hackBlt combinationRule: Form over.
	hackBlt destOrigin: 0@0.
	hackBlt width: width; height: 1.
	(form depth < 8 and:[bigEndian not]) ifTrue:[
		swizzleHack := Form new hackBits: scanline.
		swizzleBlt := BitBlt toForm: swizzleHack.
		swizzleBlt sourceForm: swizzleHack.
		swizzleBlt combinationRule: Form over.
		swizzleBlt colorMap: (StandardSwizzleMaps at: form depth).
	].
	0 to: height-1 do:[:i|
		hackBlt sourceOrigin: 0@i; copyBits.
		swizzleBlt ifNotNil:[swizzleBlt copyBits].
		zStream nextPut: 0. "filterType"
		zStream next: bytesPerScanline putAll: scanline startingAt: 1.
	].
	zStream close.! !

!PNGReadWriter methodsFor: 'writing' stamp: 'ar 2/19/2004 00:10'!
writeType6DataOn: zStream
	"Write RGBA data."
	| scanline hack hackBlt cm miscBlt |
	scanline := ByteArray new: bytesPerScanline.
	hack := Form extent: width@1 depth: 32 bits: scanline.
	form depth = 16 ifTrue:[
		"Expand 16 -> 32"
		miscBlt := BitBlt toForm: hack.
		miscBlt sourceForm: form.
		miscBlt combinationRule: Form over.
		miscBlt destOrigin: 0@0.
		miscBlt width: width; height: 1.
	].
	hackBlt := BitBlt toForm: hack.
	hackBlt sourceForm: (miscBlt ifNil:[form] ifNotNil:[hack]).
	hackBlt combinationRule: Form over.
	hackBlt destOrigin: 0@0.
	hackBlt width: width; height: 1.
	bigEndian ifTrue:[
		cm := ColorMap 
			shifts: #(8 8 8 -24) 
			masks: #(16rFF0000 16rFF00 16rFF 16rFF000000).
	] ifFalse:[
		cm := ColorMap 
			shifts: #(-16 0 16 0) 
			masks: #(16rFF0000 16rFF00 16rFF 16rFF000000).
	].
	hackBlt colorMap: cm.
	0 to: height-1 do:[:i|
		miscBlt ifNil:[
			hackBlt sourceOrigin: 0@i; copyBits.
		] ifNotNil:[
			miscBlt sourceOrigin: 0@i; copyBits.
			hack fixAlpha.
			hackBlt copyBits.
		].
		zStream nextPut: 0. "filterType"
		zStream nextPutAll: scanline.
	].
	zStream close.! !

ImageReadWriter subclass: #PNMReadWriter
	instanceVariableNames: 'first type origin cols rows depth maxValue tupleType pragma'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Files'!

!PNMReadWriter commentStamp: 'nice 3/24/2010 07:37' prior: 0!
I am a subclass of ImageReadWriter that decodes portable anymap file formats
(pbm, pgm, ppm and  pam) images.

I accept the #origin pragma for SE files as described in:
Algoritms For Image Processing And Computer Vision. J. R. Parker

Don't work with 2 bytes samples (16 bit grays, > 32 bits color, etc...), 
pam files preliminary support.

f := ImageReadWriter formFromFileNamed: 'Tools:Squeak3.4:Carmen.ppm'.
f morphEdit

Submitted by Javier Diaz Reinoso, Oct/2003!

!PNMReadWriter class methodsFor: 'testing' stamp: 'jdr 10/15/2003 15:43'!
testToSEFile: filename
	"write SE file with origin
		PNMReadWriter testToSEFile: 'Tools:Squeak3.4:outSE.pbm'.
	"
	| prw f |
	prw := self new.
	prw stream: ((FileStream newFileNamed: filename) binary).
	prw pragma: '#origin 10 10', String lf.
	f := Form fromUser.
	prw nextPutImage: f! !

!PNMReadWriter class methodsFor: 'image reading/writing' stamp: 'jdr 1/21/2011 11:47'!
typicalFileExtensions
	"Answer a collection of file extensions (lowercase) which files that I can read might commonly have"
	^#('pbm' 'pgm' 'pnm' 'ppm' 'pam')! !

!PNMReadWriter methodsFor: 'reading' stamp: 'nice 1/12/2014 21:51'!
cleanLine
	"upTo LF or CR, tab as space"

	^stream nextLine ifNotNil: [:line | line replaceAll: Character tab with: Character space]! !

!PNMReadWriter methodsFor: 'reading' stamp: 'jdr 10/15/2003 12:20'!
getTokenPbm: aCollection
	"get a number, return rest of collection"
	| line tokens token |
	tokens := aCollection.
	tokens size = 0 ifTrue:[
		[
			line := self pbmGetLine.
			line ifNil:[^{nil . nil}].
			tokens := line findTokens: ' '.
			tokens size = 0
		] whileTrue:[].
	].
	"Transcript cr; show: tokens asString."
	token := tokens removeFirst.
	^{token asInteger . tokens}
! !

!PNMReadWriter methodsFor: 'reading' stamp: 'jdr 10/16/2003 16:39'!
nextImage
	"read one image"
	| data p |
	first ifNil:[
		first := false.
		data := stream contentsOfEntireFile.
		stream := (RWBinaryOrTextStream with: data) reset.
	]
	ifNotNil:[
		type < 4 ifTrue:[
			self error:'Plain PBM, PGM or PPM have only one image'
		].
	].
	stream ascii.
	p := stream next.
	type := (stream next) asInteger - 48.
	(p = $P and:[type > 0 and:[type < 8]]) ifFalse:[
		self error:'Not a PNM file'
	].
	type = 7 ifTrue:[
		self readHeaderPAM
	]
	ifFalse: [
		self readHeader
	].
	type caseOf: {
		[1] 	->	[^self readPlainBW].
		[2] 	->	[^self readPlainGray].
		[3] 	->	[^self readPlainRGB].
		[4] 	->	[^self readBWreverse: false].
		[5] 	->	[^self readGray].
		[6] 	->	[^self readRGB].
		[7] 	->	[	"PAM"
					(tupleType asUppercase) caseOf: {
						['BLACKANDWHITE'] 		-> [^self readBWreverse: true].
						['GRAYSCALE'] 			-> [^self readGray].
						['RGB'] 					-> [^self readRGB].
						['RGB_ALPHA'] 			-> [^self error:'Not implemented'].
						['GRAYSCALE_ALPHA'] 	-> [^self error:'Not implemented'].
					} otherwise: [^self readData].
				]
	}! !

!PNMReadWriter methodsFor: 'writing' stamp: 'jdr 10/16/2003 16:08'!
nextPutBW: aForm reverse: flagXor
	| myType val nBytes bytesRow |
	cols := aForm width.
	rows := aForm height.
	depth := aForm depth.
	"stream position: 0."
	aForm depth = 1 ifTrue:[myType := $4] ifFalse:[myType := $5].
	self writeHeader: myType.
	stream binary.
	nBytes := (cols/8) ceiling.
	bytesRow := (cols/32) ceiling * 4.
	0 to: rows-1 do: [:y | | i |
		i := 1 + (bytesRow*y).
		0 to: nBytes-1 do: [:x |
			val := aForm bits byteAt: i.
			flagXor ifTrue:[val := val bitXor: 16rFF].
			stream nextPut: val.
			i := i+1.
		]
	].
! !

!PNMReadWriter methodsFor: 'writing' stamp: 'tpr 3/26/2013 11:12'!
nextPutGray: aForm
	| myType val |
	cols := aForm width.
	rows := aForm height.
	depth := aForm depth.
	"stream position: 0."
	aForm depth = 1 ifTrue:[myType := $4] ifFalse:[myType := $5].
	self writeHeader: myType.
	0 to: rows-1 do: [:y |
		0 to: cols-1 do: [:x |
			val := aForm pixelValueAt: x@y.
			stream nextPut: val.
		]
	].
! !

!PNMReadWriter methodsFor: 'writing' stamp: 'jdr 10/16/2003 14:22'!
nextPutImage: aForm
	aForm unhibernate.
	aForm depth	 caseOf: {
		[1] 		-> [self nextPutBW: aForm reverse: false].
		[16] 	-> [self nextPutRGB: aForm].
		[32] 	-> [self nextPutRGB: aForm].
	} otherwise: [
		(aForm respondsTo: #colors) ifTrue:[
			aForm colors ifNil: [
				self nextPutGray: aForm
			]
			ifNotNil: [
				self nextPutRGB: aForm
			]
		]
		ifFalse:[
			self nextPutGray: aForm
		]
	]! !

!PNMReadWriter methodsFor: 'writing' stamp: 'tpr 3/26/2013 11:12'!
nextPutRGB: aForm
	| myType f shift mask |
	cols := aForm width.
	rows := aForm height.
	depth := aForm depth.
	f := aForm.
	depth < 16 ifTrue:[
		f := aForm asFormOfDepth: 32.
		depth := 32.
	].
	myType := $6.
	"stream position: 0."
	self writeHeader: myType.
	depth = 32 ifTrue:[shift := 8. mask := 16rFF] ifFalse:[shift := 5. mask := 16r1F].
	0 to: rows-1 do: [:y |
		0 to: cols-1 do: [:x | | p r g b |
			p := f pixelValueAt: x@y.
			b := p bitAnd: mask. p := p >> shift.
			g := p bitAnd: mask. p := p >> shift.
			r := p bitAnd: mask.
			stream nextPut: r.
			stream nextPut: g.
			stream nextPut: b.
		]
	].
! !

!PNMReadWriter methodsFor: 'accessing' stamp: 'jdr 10/16/2003 14:52'!
origin
	^origin! !

!PNMReadWriter methodsFor: 'reading' stamp: 'jdr 10/10/2003 15:09'!
pbmGetLine
	"Get the next non-comment line from the PBM stream
	Look for 'pragmas' - commands hidden in the comments"
	
 	| line |
	[
		line := self cleanLine.
		line ifNil: [^nil].
		(line size > 0 and:[(line at: 1) = $#]) ifTrue:[
			self pbmParam: line.
		].
		(line size = 0) or:[(line at: 1) = $#]
	]
 	whileTrue: [].
	^line! !

!PNMReadWriter methodsFor: 'reading' stamp: 'jdr 10/10/2003 15:11'!
pbmParam: line
	"Look for a parameter hidden in a comment"
	| key tokens |
	tokens := line findTokens: ' '.
	key := (tokens at: 1) asLowercase.
	(key = '#origin' and:[tokens size = 3]) ifTrue:[	"ORIGIN key word"
		"This is for SE files as described in:
		Algoritms For Image Processing And Computer Vision. J. R. Parker"
		origin := ((tokens at: 2) asInteger) @ ((tokens at: 3) asInteger)
	].
! !

!PNMReadWriter methodsFor: 'accessing' stamp: 'jdr 10/15/2003 15:35'!
pragma: s
	pragma := s! !

!PNMReadWriter methodsFor: 'reading' stamp: 'jdr 10/16/2003 15:49'!
readBWreverse: flagXor
	"B&W for PAM"
	| val form bytesRow nBytes |
	stream binary.
	form := Form extent: cols@rows depth: 1.
	nBytes := (cols/8) ceiling.
	bytesRow := (cols/32) ceiling * 4.
	0 to: rows-1 do: [:y | | i |
		i := 1 + (bytesRow*y).
		0 to: nBytes-1 do: [:x |
			val := stream next.
			flagXor ifTrue:[val := val bitXor: 16rFF].
			form bits byteAt: i put: val.
			i := i+1.
		]
	].
	^form
! !

!PNMReadWriter methodsFor: 'reading' stamp: 'md 10/20/2004 15:45'!
readData
	"generic data"
	| data nBits nBytes val sample |
	stream binary.
	data := OrderedCollection new.
	nBits := maxValue floorLog:2.
	nBytes := (nBits+1) >> 3.
	(nBits+1 rem: 8) > 0 ifTrue:[nBytes := nBytes+1].

	0 to: rows-1 do: [:y |
		0 to: cols-1 do: [:x |
			val := 0.
			1 to: nBytes do: [:n |
				sample := stream next.
				val := val << 8 + sample.
			].
			data add: val.
		]
	].
	^data

! !

!PNMReadWriter methodsFor: 'reading' stamp: 'tpr 3/15/2013 12:33'!
readGray
	"gray form, return ColorForm with gray ramp"
	| form poker |
	maxValue > 255 ifTrue:[self error:'Gray value > 8 bits not supported in Squeak'].
	stream binary.
	form := ColorForm extent: cols@rows depth: depth.
	form colors: nil.
	poker := BitBlt bitPokerToForm: form.
	0 to: rows-1 do: [:y |
		0 to: cols-1 do: [:x |
			|val|
			val := stream next.
			poker pixelAt: x@y put: val.
		]
	].
	"a better way is using a gamma corrected palette"
	form colors: ((0 to: 255) collect:[:c|
		c > maxValue
			ifTrue:[Color white]
			ifFalse:[Color gray: (c/maxValue) asFloat]]).
	form colors at: 1 put: (Color black).
	^form
! !

!PNMReadWriter methodsFor: 'reading' stamp: 'jdr 10/15/2003 15:44'!
readHeader
	"read header for pbm, pgm or ppm"
	| tokens aux d c  |
	tokens := OrderedCollection new.
	aux := self getTokenPbm: tokens.
	cols := aux at: 1. tokens := aux at: 2.
	aux := self getTokenPbm: tokens.
	rows := aux at: 1. tokens := aux at: 2.

	(type = 1 or:[type = 4]) ifTrue:[
		maxValue := 1
	]
	ifFalse: [
		aux := self getTokenPbm: tokens.
		maxValue := aux at: 1. tokens := aux at: 2.
	].
	d := {1 . 2 . 4 . 	8 . 		16 . 32}.
	c := {2 . 4 . 16 . 256 . 32768 . 16777216}. 
	(type = 3 or:[type = 6]) ifTrue: [
		maxValue >= 65536 ifTrue:[
			self error:'Pixmap > 48 bits not supported in PPM'
		].
		maxValue >= 256 ifTrue:[
			self error:'Pixmap > 32 bits are not supported in Squeak'
		].
		maxValue < 32 ifTrue:[depth := 16] ifFalse:[depth := 32].
	]
	ifFalse: [
		depth := nil.
		1 to: c size do:[:i| ((c at: i) > maxValue and:[depth = nil]) ifTrue:[depth:=d at: i]].
	].
	Transcript cr; show: 'PBM file class ', type asString, ' size ', cols asString, ' x ', 
		rows asString, ' maxValue =', maxValue asString, ' depth=', depth asString.
! !

!PNMReadWriter methodsFor: 'reading' stamp: 'nice 12/27/2009 03:10'!
readHeaderPAM
	"read pam header, not tested"
	| loop |
	tupleType := ''.
	loop := true.
	loop whileTrue:[ | key val tokens line |
		line := self pbmGetLine.
		tokens := line findTokens: ' '.
		tokens size = 2 ifTrue:[
			key := tokens at: 1 asUppercase.
			val := tokens at: 2.
			key caseOf: {
				['WIDTH'] 		-> [cols := val asInteger].
				['HEIGHT'] 		-> [rows := val asInteger].
				['DEPTH'] 		-> [depth := val asInteger].
				['MAXVAL']		-> [maxValue := val asInteger].
				['TUPLETYPE']	-> [tupleType := tupleType, ' ', val].
				['ENDHDR']		-> [loop := false].
			}
		]
	].
	Transcript cr; show: 'PAM file class ', type asString, ' size ', cols asString, ' x ', 
		rows asString, ' maxValue =', maxValue asString, ' depth=', depth asString.
! !

!PNMReadWriter methodsFor: 'reading' stamp: 'tpr 3/15/2013 12:33'!
readPlainBW
	"plain BW"
	| val form poker |
	form := Form extent: cols@rows depth: depth.
	poker := BitBlt bitPokerToForm: form.
	0 to: rows-1 do: [:y |
		0 to: cols-1 do: [:x |
			[val := stream next. (val = $0 or:[val = $1])] whileFalse:[
				val ifNil:[self error:'End of file reading PBM'].
			].
			poker pixelAt: x@y put: (val asInteger).
		]
	].
	^form
! !

!PNMReadWriter methodsFor: 'reading' stamp: 'tpr 3/15/2013 12:33'!
readPlainGray
	"plain gray"
	| val form poker aux tokens |
	form := Form extent: cols@rows depth: depth.
	poker := BitBlt bitPokerToForm: form.
	tokens := OrderedCollection new.
	0 to: rows-1 do: [:y |
		0 to: cols-1 do: [:x |
			aux := self getTokenPbm: tokens.
			val := aux at: 1. tokens := aux at: 2.
			poker pixelAt: x@y put: val.
		]
	].
	^form
! !

!PNMReadWriter methodsFor: 'reading' stamp: 'tpr 3/15/2013 12:34'!
readPlainRGB
	"RGB form, use 32 bits"
	| val form poker tokens aux |
	maxValue > 255 ifTrue:[self error:'RGB value > 32 bits not supported in Squeak'].
	form := Form extent: cols@rows depth: 32.
	poker := BitBlt bitPokerToForm: form.
	tokens := OrderedCollection new.
	0 to: rows-1 do: [:y |
		0 to: cols-1 do: [:x | | r g b|
			aux := self getTokenPbm: tokens. r := aux at: 1. tokens := aux at: 2.
			aux := self getTokenPbm: tokens. g := aux at: 1. tokens := aux at: 2.
			aux := self getTokenPbm: tokens. b := aux at: 1. tokens := aux at: 2.
			val := self r: r g: g b: b for: depth.
			poker pixelAt: x@y put: val.
		]
	].
	^form
! !

!PNMReadWriter methodsFor: 'reading' stamp: 'tpr 3/15/2013 12:34'!
readRGB
	"RGB form, use 16/32 bits"
	| val form poker sample shift |
	maxValue > 255 ifTrue:[self error:'RGB value > 32 bits not supported in Squeak'].
	stream binary.
	form := Form extent: cols@rows depth: depth.
	poker := BitBlt bitPokerToForm: form.
	depth = 32 ifTrue:[shift := 8] ifFalse:[shift := 5].
	0 to: rows-1 do: [:y |
		0 to: cols-1 do: [:x |
			val := 16rFF.	"no transparency"
			1 to: 3 do: [:i |
				sample := stream next.
				val := val << shift + sample.
			].
			poker pixelAt: x@y put: val.
		]
	].
	^form
! !

!PNMReadWriter methodsFor: 'reading' stamp: 'jdr 7/18/2005 17:02'!
r: r g: g b: b for: aDepth
	"integer value according depth"
	| val |
	aDepth = 16 ifTrue: [
		val := (1 << 15) + (r << 10) + (g << 5) + b.
	]
	ifFalse:[
		val := (16rFF << 24) + (r << 16) + (g << 8) + b.
	].
	^val
! !

!PNMReadWriter methodsFor: 'accessing' stamp: 'jdr 10/10/2003 18:04'!
stream: s
	stream := s! !

!PNMReadWriter methodsFor: 'accessing' stamp: 'jdr 10/16/2003 14:53'!
tupleType
	^tupleType! !

!PNMReadWriter methodsFor: 'testing' stamp: 'jdr 10/11/2003 14:52'!
understandsImageFormat
	"P1 to P7"
	| p  |
	p := stream next asCharacter.
	type := stream next - 48.
	^(p = $P and:[type > 0 and:[type < 8]])
	! !

!PNMReadWriter methodsFor: 'writing' stamp: 'jdr 10/15/2003 15:48'!
writeHeader: myType
	"this is ascii"
	stream nextPut: ($P asciiValue).
	stream nextPut: (myType asciiValue).
	stream nextPut: 10.		"nl"
	pragma ifNotNil:[
		stream nextPutAll: (pragma asByteArray).
	].
	stream nextPutAll: (cols printString) asByteArray.
	stream nextPut: 32.		" "
	stream nextPutAll: (rows printString) asByteArray.
	stream nextPut: 10.		"nl"
	depth > 1 ifTrue: [| d c maxV |
		d := {1 . 2 . 4  . 8   . 16 . 32}.
		c := {1 . 3 . 15 . 255 . 31 . 255}. 
		maxV := nil.
		1 to: d size do:[:i| ((d at: i) = depth and:[maxV = nil]) ifTrue:[maxV := c at: i]].
		stream nextPutAll: (maxV printString) asByteArray.
		stream nextPut: 10.		"nl"
	]
	! !

ImageReadWriter subclass: #XBMReadWriter
	instanceVariableNames: 'width height'
	classVariableNames: 'Flipbits'
	poolDictionaries: ''
	category: 'Graphics-Files'!

!XBMReadWriter class methodsFor: 'class initialization' stamp: 'nice 12/26/2009 22:30'!
initialize
	"XBMReadWriter initialize"
	Flipbits := (0 to: 255) collect:
		[:n |  "Compute the bit-reversal of the 8-bit value, n"
		| flippedByte |
		flippedByte := 0.
		0 to: 7 do: 
			[:i | 
			flippedByte := flippedByte bitOr: ((n >> i bitAnd: 1) << (7-i))].
			flippedByte]! !

!XBMReadWriter class methodsFor: 'class initialization' stamp: 'nk 7/16/2003 17:57'!
typicalFileExtensions
	"Answer a collection of file extensions (lowercase) which files that I can read might commonly have"
	^#('xbm')! !

!XBMReadWriter methodsFor: 'accessing' stamp: 'wdc 2/1/1999 07:15'!
nextImage
	"Read in the next xbm image from the stream."
	| form long incount chunks byteWidth pad fourway outcount total |
	stream reset.
	stream ascii.
	self readHeader.
	form := ColorForm extent: width@height depth: 1.
	incount := 0.	outcount :=1.
	chunks := Array new: 4.	byteWidth := width + 7 // 8.
	total := byteWidth * height.
	byteWidth > 4
		ifTrue: [ pad := byteWidth \\ 4]
		ifFalse: [ pad := 4 - byteWidth ].
	fourway := 0.
	[(incount = total)] whileFalse: [
		incount := incount + 1.
		fourway := fourway + 1.
		chunks at: fourway put: (Flipbits at: ((self parseByteValue) +1)).
		(pad > 0 and: [(incount \\ byteWidth) = 0]) ifTrue: [
			1 to: pad do:
				[:q |	
  			fourway := fourway + 1.	
			chunks at: fourway put: 0]
		].
		fourway = 4 ifTrue: [
			long := Integer
				byte1: (chunks at: 4)
				byte2: (chunks at: 3)
				byte3: (chunks at: 2)
				byte4: (chunks at: 1).
			(form bits) at: outcount put: long.
			fourway := 0.
			outcount := outcount + 1].
		].
	 ^ form ! !

!XBMReadWriter methodsFor: 'private' stamp: 'nice 2/23/2013 19:06'!
parseByteValue
	"skip over separators and return next bytevalue parsed as a C language number:
		0ddd is an octal digit.
		0xddd is a hex digit.
		ddd is decimal."
	| source mybase |
	stream skipSeparators.
	source := stream upToAnyOf: CharacterSet separators.
	source = '0' ifTrue: [^0]..
	mybase := 10. "Base 10 default"
	source := source asUppercase readStream.
	(source peekFor: $0) ifTrue: [
		mybase := 8. "Octal or Hex, say its Octal unless overridden."
		(source peekFor: $X) ifTrue: [
			mybase := 16. "Ah.  It's Hex."
			]
		].
	^ Integer readFrom: source base: mybase! !

!XBMReadWriter methodsFor: 'private' stamp: 'ul 11/15/2010 10:03'!
readHeader
	"Set width and height, and position stream at start of bytes"
	| number setwidth setheight fieldName |
	setwidth := setheight := false.
		[((stream atEnd) or: [setwidth and: [setheight]])]
		whileFalse: [
	  	self skipCComments.
		(stream nextMatchAll: '#define ') ifFalse: [^ false].
		(stream skipTo: $_) ifFalse: [^ false].
		fieldName := String streamContents:
			[:source |
			[(stream atEnd) or: [ stream peek isSeparator ]]
				whileFalse: [ source nextPut: stream next]].
	  	(fieldName = 'width') ifTrue: [
			stream skipSeparators.
			number := Integer readFrom: stream.
			(number > 0) ifTrue: [setwidth := true].
	  		width := number.].
		(fieldName = 'height') ifTrue: [
			stream skipSeparators.
			number := Integer readFrom: stream.
			(number > 0) ifTrue: [setheight := true].
			height := number.
			].
		].
	(setwidth & setheight) ifFalse: [^ false].
	^ stream skipTo: ${
! !

!XBMReadWriter methodsFor: 'private' stamp: 'nk 7/16/2003 18:15'!
skipCComments
	[ stream skipSeparators.
	stream peekFor: $/ ] whileTrue: [
		stream next.		"skip next *"
		[ (stream skipTo: $*) ifFalse: [ ^false ].
			stream peekFor: $/ ] whileFalse ]! !

!XBMReadWriter methodsFor: 'accessing' stamp: 'nk 7/16/2003 18:18'!
understandsImageFormat
	"Test to see if the image stream format is understood by this decoder.	This should be implemented in each subclass of ImageReadWriter so that	a proper decoder can be selected without ImageReadWriter having to know about all possible image file types."
	| first |
	stream ascii.
	self skipCComments.
	first := (stream next: 7) asString.
	stream binary.
	^ (first = '#define')! !

Object subclass: #JPEGColorComponent
	instanceVariableNames: 'currentX currentY hSampleFactor vSampleFactor mcuBlocks widthInBlocks heightInBlocks dctSize mcuWidth mcuHeight priorDCValue id qTableIndex dcTableIndex acTableIndex'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Files'!

!JPEGColorComponent commentStamp: '<historical>' prior: 0!
I represent a single component of color in JPEG YCbCr color space.  I can accept a list of blocks in my component from the current MCU, then stream the samples from this block for use in color conversion.  I also store the running DC sample value for my component, used by the Huffman decoder.

The following layout is fixed for the JPEG primitives to work:
	currentX 		<SmallInteger>
	currentY 		<SmallInteger>
	hSampleFactor 	<SmallInteger>
	vSampleFactor 	<SmallInteger>
	mcuBlocks 		<Array of: <IntegerArray of: DCTSize2 * Integer>>
	widthInBlocks 	<SmallInteger>
	heightInBlocks 	<SmallInteger>
	dctSize 			<SmallInteger>
	mcuWidth 		<SmallInteger>
	mcuHeight 		<SmallInteger>
	priorDCValue 	<SmallInteger>
!

!JPEGColorComponent methodsFor: 'accessing' stamp: 'tao 10/23/97 12:21'!
acTableIndex

	^acTableIndex! !

!JPEGColorComponent methodsFor: 'accessing' stamp: 'tao 10/23/97 12:20'!
acTableIndex: anInteger

	acTableIndex := anInteger! !

!JPEGColorComponent methodsFor: 'accessing' stamp: 'tao 10/23/97 12:21'!
dcTableIndex

	^dcTableIndex! !

!JPEGColorComponent methodsFor: 'accessing' stamp: 'tao 10/23/97 12:20'!
dcTableIndex: anInteger

	dcTableIndex := anInteger! !

!JPEGColorComponent methodsFor: 'accessing' stamp: 'tao 10/23/97 12:11'!
heightInBlocks

	^heightInBlocks! !

!JPEGColorComponent methodsFor: 'accessing' stamp: 'tao 10/23/97 12:10'!
heightInBlocks: anInteger

	heightInBlocks := anInteger! !

!JPEGColorComponent methodsFor: 'accessing' stamp: 'tao 10/23/97 12:09'!
id

	^id! !

!JPEGColorComponent methodsFor: 'accessing' stamp: 'tao 10/23/97 12:09'!
id: anObject

	id := anObject! !

!JPEGColorComponent methodsFor: 'sample streaming' stamp: 'tao 10/23/97 12:24'!
initializeSampleStreamBlocks: aCollection

	mcuBlocks := aCollection.
	self resetSampleStream! !

!JPEGColorComponent methodsFor: 'accessing' stamp: 'ar 3/4/2001 01:19'!
mcuWidth: mw mcuHeight: mh dctSize: ds

	mcuWidth := mw.
	mcuHeight := mh.
	dctSize := ds.
	hSampleFactor := mcuWidth // widthInBlocks.
	vSampleFactor := mcuHeight // heightInBlocks! !

!JPEGColorComponent methodsFor: 'sample streaming' stamp: 'ar 3/4/2001 22:16'!
nextSample

	| dx dy blockIndex sampleIndex sample |
	dx := currentX // hSampleFactor.
	dy := currentY // vSampleFactor.
	blockIndex := dy // dctSize * widthInBlocks + (dx // dctSize) + 1.
	sampleIndex := dy \\ dctSize * dctSize + (dx \\ dctSize) + 1.
	sample := (mcuBlocks at: blockIndex) at: sampleIndex.
	currentX := currentX + 1.
	currentX < (mcuWidth * dctSize)
		ifFalse:
			[currentX := 0.
			currentY := currentY + 1].
	^ sample! !

!JPEGColorComponent methodsFor: 'accessing' stamp: 'tao 10/23/97 12:15'!
priorDCValue: aNumber

	priorDCValue := aNumber! !

!JPEGColorComponent methodsFor: 'accessing' stamp: 'tao 10/23/97 12:43'!
qTableIndex
	^qTableIndex! !

!JPEGColorComponent methodsFor: 'accessing' stamp: 'tao 10/23/97 12:11'!
qTableIndex: anInteger

	qTableIndex := anInteger! !

!JPEGColorComponent methodsFor: 'sample streaming' stamp: 'tao 10/23/97 12:24'!
resetSampleStream

	currentX := 0.
	currentY := 0! !

!JPEGColorComponent methodsFor: 'accessing' stamp: 'tao 10/23/97 12:18'!
totalMcuBlocks

	^ heightInBlocks * widthInBlocks! !

!JPEGColorComponent methodsFor: 'accessing' stamp: 'tao 10/23/97 12:16'!
updateDCValue: aNumber

	priorDCValue := priorDCValue + aNumber.
	^priorDCValue! !

!JPEGColorComponent methodsFor: 'accessing' stamp: 'tao 10/23/97 12:11'!
widthInBlocks

	^widthInBlocks! !

!JPEGColorComponent methodsFor: 'accessing' stamp: 'tao 10/23/97 12:10'!
widthInBlocks: anInteger

	widthInBlocks := anInteger! !

Object subclass: #JPEGHuffmanTable
	instanceVariableNames: 'bits values mincode maxcode valptr lookaheadBits lookaheadSymbol'
	classVariableNames: 'BitBufferSize Lookahead'
	poolDictionaries: ''
	category: 'Graphics-Files'!

!JPEGHuffmanTable commentStamp: '<historical>' prior: 0!
I represent the table of values used to decode Huffman entropy-encoded bitstreams.  From the JFIF file header entropy values, I build a derived table of codes and values for faster decoding.!

!JPEGHuffmanTable class methodsFor: 'initialization' stamp: 'tao 10/21/97 11:06'!
initialize

	Lookahead := 8.
	BitBufferSize := 16! !

!JPEGHuffmanTable class methodsFor: 'constants' stamp: 'tao 10/21/97 22:15'!
lookahead

	^ Lookahead! !

!JPEGHuffmanTable methodsFor: 'accessing' stamp: 'tao 10/20/97 14:27'!
bits: anObject

	bits := anObject! !

!JPEGHuffmanTable methodsFor: 'accessing' stamp: 'tao 10/21/97 23:31'!
lookaheadBits
	^lookaheadBits! !

!JPEGHuffmanTable methodsFor: 'accessing' stamp: 'tao 10/21/97 23:38'!
lookaheadSymbol
	^lookaheadSymbol! !

!JPEGHuffmanTable methodsFor: 'computation' stamp: 'tao 10/24/97 12:28'!
makeDerivedTables

	| huffSize huffCode code si index lookbits |
	mincode := Array new: 16.
	maxcode := Array new: 17.
	valptr := Array new: 17.
	huffSize := OrderedCollection new.
	1 to: 16 do: [:l | 1 to: (bits at: l) do: [:i | huffSize add: l]].
	huffSize add: 0.
	code := 0.
	huffCode := Array new: huffSize size.
	si := huffSize at: 1.
	index := 1.
	[(huffSize at: index) ~= 0] whileTrue:
		[[(huffSize at: index) = si] whileTrue:
			[huffCode at: index put: code.
			index := index + 1.
			code := code + 1].
		code := code << 1.
		si := si + 1].

	index := 1.
	1 to: 16 do:
		[:l |
		(bits at: l) ~= 0
			ifTrue:
				[valptr at: l put: index.
				mincode at: l put: (huffCode at: index).
				index := index + (bits at: l).
				maxcode at: l put: (huffCode at: index-1)]
			ifFalse:
				[maxcode at: l put: -1]].
	maxcode at: 17 put: 16rFFFFF.

	lookaheadBits := (Array new: 1 << Lookahead) atAllPut: 0.
	lookaheadSymbol := Array new: 1 << Lookahead.
	index := 1.
	1 to: Lookahead do:
		[:l |
		1 to: (bits at: l) do:
			[:i |
			lookbits := (huffCode at: index) << (Lookahead - l) + 1.
			(1 << (Lookahead - l) to: 1 by: -1) do:
				[:ctr |
				lookaheadBits at: lookbits put: l.
				lookaheadSymbol at: lookbits put: (values at: index).
				lookbits := lookbits + 1].
			index := index + 1]]! !

!JPEGHuffmanTable methodsFor: 'accessing' stamp: 'tao 10/21/97 23:59'!
maxcode
	^maxcode! !

!JPEGHuffmanTable methodsFor: 'computation' stamp: 'tao 10/21/97 22:44'!
valueForCode: code length: length

	^ values at: ((valptr at: length) + code - (mincode at: length))! !

!JPEGHuffmanTable methodsFor: 'accessing' stamp: 'tao 10/20/97 14:27'!
values: anObject

	values := anObject! !

Object subclass: #LayoutFrame
	instanceVariableNames: 'leftFraction leftOffset topFraction topOffset rightFraction rightOffset bottomFraction bottomOffset'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Primitives'!

!LayoutFrame commentStamp: '<historical>' prior: 0!
I define a frame for positioning some morph in a proportional layout.

Instance variables:
	leftFraction 
	topFraction 
	rightFraction 
	bottomFraction 	<Float>		The fractional distance (between 0 and 1) to place the morph in its owner's bounds
	leftOffset 
	topOffset 
	rightOffset 
	bottomOffset 	<Integer>	Fixed pixel offset to apply after fractional positioning (e.g., "10 pixel right of the center of the owner")!

!LayoutFrame class methodsFor: 'accessing' stamp: 'JW 2/1/2001 12:48'!
classVersion
	^1 "changed treatment of bottomOffset and rightOffset"
! !

!LayoutFrame class methodsFor: 'instance creation' stamp: 'ar 2/5/2002 00:07'!
fractions: fractionsOrNil
	^self fractions: fractionsOrNil offsets: nil! !

!LayoutFrame class methodsFor: 'instance creation' stamp: 'RAA 1/8/2001 21:22'!
fractions: fractionsOrNil offsets: offsetsOrNil

	| fractions offsets |

	fractions := fractionsOrNil ifNil: [0@0 extent: 0@0].
	offsets := offsetsOrNil ifNil: [0@0 extent: 0@0].
	^self new
		topFraction: fractions top offset: offsets top;
		leftFraction: fractions left offset: offsets left;
		bottomFraction: fractions bottom offset: offsets bottom;
		rightFraction: fractions right offset: offsets right
! !

!LayoutFrame class methodsFor: 'instance creation' stamp: 'ar 2/5/2002 20:06'!
offsets: offsetsOrNil
	^self fractions: nil offsets: offsetsOrNil! !

!LayoutFrame methodsFor: 'accessing' stamp: 'ar 10/23/2000 19:35'!
bottomFraction
	^bottomFraction! !

!LayoutFrame methodsFor: 'accessing' stamp: 'ar 10/23/2000 19:35'!
bottomFraction: aNumber
	bottomFraction := aNumber! !

!LayoutFrame methodsFor: 'accessing' stamp: 'ar 10/23/2000 19:35'!
bottomFraction: aNumber offset: anInteger

	bottomFraction := aNumber.
	bottomOffset := anInteger! !

!LayoutFrame methodsFor: 'accessing' stamp: 'ar 10/23/2000 19:35'!
bottomOffset
	^bottomOffset! !

!LayoutFrame methodsFor: 'accessing' stamp: 'ar 10/23/2000 19:35'!
bottomOffset: anInteger
	bottomOffset := anInteger! !

!LayoutFrame methodsFor: 'objects from disk' stamp: 'JW 2/1/2001 13:33'!
convertToCurrentVersion: varDict refStream: smartRefStrm
	| className oldClassVersion |

	"JW 2/1/2001"
	"Since class version isn't passed in varDict, look it up through smartRefSrm."
	className := varDict at: #ClassName.
	oldClassVersion := (smartRefStrm structures at: className) first.
	(oldClassVersion = 0) ifTrue: [ self negateBottomRightOffsets ].
	^super convertToCurrentVersion: varDict refStream: smartRefStrm.
! !

!LayoutFrame methodsFor: 'testing' stamp: 'mt 4/28/2015 09:01'!
hasFixedHeight

	^ self topFraction = self bottomFraction! !

!LayoutFrame methodsFor: 'testing' stamp: 'mt 4/28/2015 09:01'!
hasFixedWidth

	^ self leftFraction = self rightFraction! !

!LayoutFrame methodsFor: 'layout' stamp: 'JW 2/1/2001 13:04'!
layout: oldBounds in: newBounds
	"Return the proportional rectangle insetting the given bounds"
	| left right top bottom |
	leftFraction ifNotNil:[
		left := newBounds left + (newBounds width * leftFraction).
		leftOffset ifNotNil:[left := left + leftOffset]].
	rightFraction ifNotNil:[
		right := newBounds right - (newBounds width * (1.0 - rightFraction)).
		rightOffset ifNotNil:[right := right + rightOffset]].
	topFraction ifNotNil:[
		top := newBounds top + (newBounds height * topFraction).
		topOffset ifNotNil:[top := top + topOffset]].
	bottomFraction ifNotNil:[
		bottom := newBounds bottom - (newBounds height * (1.0 - bottomFraction)).
		bottomOffset ifNotNil:[bottom := bottom + bottomOffset]].
	left ifNil:[ right 
			ifNil:[left := oldBounds left. right := oldBounds right]
			ifNotNil:[left := right - oldBounds width]].
	right ifNil:[right := left + oldBounds width].
	top ifNil:[ bottom 
			ifNil:[top := oldBounds top. bottom := oldBounds bottom]
			ifNotNil:[top := bottom - oldBounds height]].
	bottom ifNil:[bottom := top + oldBounds height].
	^(left rounded @ top rounded) corner: (right rounded @ bottom rounded)! !

!LayoutFrame methodsFor: 'accessing' stamp: 'ar 10/23/2000 19:35'!
leftFraction
	^leftFraction! !

!LayoutFrame methodsFor: 'accessing' stamp: 'ar 10/23/2000 19:35'!
leftFraction: aNumber
	leftFraction := aNumber! !

!LayoutFrame methodsFor: 'accessing' stamp: 'ar 10/23/2000 19:35'!
leftFraction: aNumber offset: anInteger

	leftFraction := aNumber.
	leftOffset := anInteger! !

!LayoutFrame methodsFor: 'accessing' stamp: 'ar 10/23/2000 19:35'!
leftOffset
	^leftOffset! !

!LayoutFrame methodsFor: 'accessing' stamp: 'ar 10/23/2000 19:36'!
leftOffset: anInteger
	leftOffset := anInteger! !

!LayoutFrame methodsFor: 'layout' stamp: 'mt 4/28/2015 09:31'!
minExtentFrom: minExtent
	"Return the minimal extent the given bounds can be represented in"
	^ (self minWidthFrom: minExtent x) @ (self minHeightFrom: minExtent y)! !

!LayoutFrame methodsFor: 'layout' stamp: 'mt 4/28/2015 10:10'!
minHeightFrom: minHeight
	"Return the minimal extent the given bounds can be represented in"
	| height top bottom |
	top := topFraction ifNil: [0.0].
	bottom := bottomFraction ifNil: [1.0].
	height := bottom = top
		ifTrue: [0]
		ifFalse: [minHeight / (bottom - top)].
	topOffset ifNotNil:[height := height + topOffset].
	bottomOffset ifNotNil:[height := height + bottomOffset].
	^ height truncated! !

!LayoutFrame methodsFor: 'layout' stamp: 'mt 4/28/2015 09:29'!
minWidthFrom: minWidth
	"Return the minimal extent the given bounds can be represented in"
	| width left right |
	left := leftFraction ifNil: [0.0].
	right := rightFraction ifNil: [1.0].
	width := left = right
		ifTrue: [0]
		ifFalse: [minWidth / (right - left)].
	leftOffset ifNotNil:[width := width + leftOffset].
	rightOffset ifNotNil:[width := width + rightOffset].
	^width truncated! !

!LayoutFrame methodsFor: 'objects from disk' stamp: 'JW 2/1/2001 14:37'!
negateBottomRightOffsets

	bottomOffset ifNotNil: [ bottomOffset := bottomOffset negated ].
	rightOffset ifNotNil: [ rightOffset := rightOffset negated ].

! !

!LayoutFrame methodsFor: 'accessing' stamp: 'ar 10/23/2000 19:36'!
rightFraction
	^rightFraction! !

!LayoutFrame methodsFor: 'accessing' stamp: 'ar 10/23/2000 19:36'!
rightFraction: aNumber
	rightFraction := aNumber! !

!LayoutFrame methodsFor: 'accessing' stamp: 'ar 10/23/2000 19:36'!
rightFraction: aNumber offset: anInteger

	rightFraction := aNumber.
	rightOffset := anInteger! !

!LayoutFrame methodsFor: 'accessing' stamp: 'ar 10/23/2000 19:36'!
rightOffset
	^rightOffset! !

!LayoutFrame methodsFor: 'accessing' stamp: 'ar 10/23/2000 19:36'!
rightOffset: anInteger
	rightOffset := anInteger! !

!LayoutFrame methodsFor: 'accessing' stamp: 'ar 10/23/2000 19:36'!
topFraction
	^topFraction! !

!LayoutFrame methodsFor: 'accessing' stamp: 'ar 10/23/2000 19:36'!
topFraction: aNumber
	topFraction := aNumber! !

!LayoutFrame methodsFor: 'accessing' stamp: 'ar 10/23/2000 19:37'!
topFraction: aNumber offset: anInteger

	topFraction := aNumber.
	topOffset := anInteger! !

!LayoutFrame methodsFor: 'accessing' stamp: 'ar 10/23/2000 19:37'!
topOffset
	^topOffset! !

!LayoutFrame methodsFor: 'accessing' stamp: 'ar 10/23/2000 19:37'!
topOffset: anInteger
	topOffset := anInteger! !

!Object methodsFor: '*Graphics-KernelExtensions' stamp: 'sw 8/15/97 17:25'!
fullScreenSize
	"Answer the size to which a window displaying the receiver should be set"
	| adj |
	adj := (3 * Preferences scrollBarWidth) @ 0.
	^ Rectangle origin: adj extent: (DisplayScreen actualScreenSize - adj)! !

Object subclass: #Point
	instanceVariableNames: 'x y'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Primitives'!

!Point commentStamp: '<historical>' prior: 0!
I represent an x-y pair of numbers usually designating a location on the screen.!

!Point class methodsFor: 'instance creation' stamp: 'sw 9/20/97 15:34'!
fromUser
	Sensor waitNoButton.
	Cursor crossHair show.
	Sensor waitButton.
	Cursor normal show.
	^ Sensor cursorPoint

"Point fromUser"! !

!Point class methodsFor: 'instance creation' stamp: 'wiz 5/4/2006 00:04'!
fromUserWithCursor: aCursor
	Sensor waitNoButton.
	aCursor showWhile:[Sensor waitButton].
	^ Sensor cursorPoint

"Point fromUserWithCursor: Cursor target"! !

!Point class methodsFor: 'instance creation' stamp: 'md 12/2/2004 23:44'!
r: rho degrees: degrees
	"Answer an instance of me with polar coordinates rho and theta."

	^self basicNew setR: rho degrees: degrees! !

!Point class methodsFor: 'instance creation' stamp: 'jrd 5/26/2010 12:31'!
u: xInteger v: yInteger 
	"Answer an instance of me with coordinates xInteger and yInteger."

	^self new setX: xInteger setY: yInteger! !

!Point class methodsFor: 'instance creation' stamp: 'md 12/2/2004 23:44'!
x: xInteger y: yInteger 
	"Answer an instance of me with coordinates xInteger and yInteger."

	^self basicNew setX: xInteger setY: yInteger! !

!Point methodsFor: 'arithmetic' stamp: ''!
abs
	"Answer a Point whose x and y are the absolute values of the receiver's x 
	and y."

	^ x abs @ y abs! !

!Point methodsFor: 'converting' stamp: 'di 11/6/1998 13:45'!
adaptToCollection: rcvr andSend: selector
	"If I am involved in arithmetic with a Collection, return a Collection of
	the results of each element combined with me in that expression."

	^ rcvr collect: [:element | element perform: selector with: self]! !

!Point methodsFor: 'converting' stamp: 'di 11/9/1998 12:44'!
adaptToNumber: rcvr andSend: selector
	"If I am involved in arithmetic with an Integer, convert it to a Point."
	^ rcvr@rcvr perform: selector with: self! !

!Point methodsFor: 'converting' stamp: 'di 11/6/1998 13:47'!
adaptToString: rcvr andSend: selector
	"If I am involved in arithmetic with a String, convert it to a Number."
	^ rcvr asNumber perform: selector with: self! !

!Point methodsFor: 'transforming' stamp: 'di 4/30/1998 11:16'!
adhereTo: aRectangle
	"If the receiver lies outside aRectangle, return the nearest point on the boundary of the rectangle, otherwise return self."

	(aRectangle containsPoint: self) ifTrue: [^ self].
	^ ((x max: aRectangle left) min: aRectangle right)
		@ ((y max: aRectangle top) min: aRectangle bottom)! !

!Point methodsFor: 'point functions' stamp: 'bf 5/29/2012 17:25'!
area
	^ x * y! !

!Point methodsFor: 'converting' stamp: ''!
asFloatPoint
	^ x asFloat @ y asFloat! !

!Point methodsFor: 'converting' stamp: ''!
asIntegerPoint
	^ x asInteger @ y asInteger! !

!Point methodsFor: 'converting' stamp: 'wiz 11/25/2004 12:48'!
asNonFractionalPoint
(x isFraction or: [y isFraction])
	ifTrue:[^ x asFloat @ y asFloat]! !

!Point methodsFor: 'converting' stamp: ''!
asPoint
	"Answer the receiver itself."

	^self! !

!Point methodsFor: 'point functions' stamp: 'FBS 1/5/2004 13:08'!
bearingToPoint: anotherPoint
    "Return the bearing, in degrees, from the receiver to anotherPoint.
     Adapted from Playground, where the ultimate provenance of the algorithm was a wild earlier method of Jay Fenton's which I never checked carefully, but the thing has always seemed to work"

    | deltaX deltaY  |
    deltaX := anotherPoint x -  x.
    deltaY := anotherPoint y - y.

    deltaX abs < 0.001
        ifTrue:
            [^ deltaY > 0 ifTrue: [180] ifFalse: [0]].

    ^ ((deltaX >= 0 ifTrue: [90] ifFalse: [270])
            - ((deltaY / deltaX) arcTan negated radiansToDegrees)) rounded
! !

!Point methodsFor: 'private' stamp: 'ar 4/4/1999 00:40'!
bitShiftPoint: bits
	x := x bitShift: bits.
	y := y bitShift: bits.! !

!Point methodsFor: 'truncation and round off' stamp: 'nice 2/5/2006 16:43'!
ceiling
	"Answer a Point that is the receiver's x and y ceiling. Answer the receiver if its coordinates are already integral."

	(x isInteger and: [y isInteger]) ifTrue: [^ self].
	^ x ceiling @ y ceiling
! !

!Point methodsFor: 'comparing' stamp: 'laza 4/8/2010 11:26'!
closeTo: aPoint
	^(x closeTo: aPoint x) and: [y closeTo: aPoint y]! !

!Point methodsFor: 'converting' stamp: ''!
corner: aPoint 
	"Answer a Rectangle whose origin is the receiver and whose corner is 
	aPoint. This is one of the infix ways of expressing the creation of a 
	rectangle."

	^Rectangle origin: self corner: aPoint! !

!Point methodsFor: 'point functions' stamp: 'ar 10/30/1998 03:05'!
crossProduct: aPoint 
	"Answer a number that is the cross product of the receiver and the 
	argument, aPoint."

	^ (x * aPoint y) - (y * aPoint x)! !

!Point methodsFor: 'copying' stamp: ''!
deepCopy
	"Implemented here for better performance."

	^x deepCopy @ y deepCopy! !

!Point methodsFor: 'polar coordinates' stamp: 'di 6/12/97 12:18'!
degrees
	"Answer the angle the receiver makes with origin in degrees. right is 0; down is 90."
	| tan theta |
	x = 0
		ifTrue: [y >= 0
				ifTrue: [^ 90.0]
				ifFalse: [^ 270.0]]
		ifFalse: 
			[tan := y asFloat / x asFloat.
			theta := tan arcTan.
			x >= 0
				ifTrue: [y >= 0
						ifTrue: [^ theta radiansToDegrees]
						ifFalse: [^ 360.0 + theta radiansToDegrees]]
				ifFalse: [^ 180.0 + theta radiansToDegrees]]! !

!Point methodsFor: 'point functions' stamp: 'spfa 11/6/2004 16:01'!
dist: aPoint 
	"Answer the distance between aPoint and the receiver."

	| dx dy |

	dx := aPoint x - x.
	dy := aPoint y - y.

	^ ((dx * dx) + (dy * dy)) sqrt! !

!Point methodsFor: 'point functions' stamp: 'di 9/11/1998 16:22'!
dotProduct: aPoint 
	"Answer a number that is the dot product of the receiver and the 
	argument, aPoint. That is, the two points are multipled and the 
	coordinates of the result summed."

	^ (x * aPoint x) + (y * aPoint y)! !

!Point methodsFor: 'point functions' stamp: 'nice 12/29/2010 15:07'!
eightNeighbors
	^ (Array with: self + (1 @ 0)
		with: self + (1 @ 1)
		with: self + (0 @ 1)
		with: self + (-1 @ 1)) ,
	(Array with: self + (-1 @ 0)
		with: self + (-1 @ -1)
		with: self + (0 @ -1)
		with: self + (1 @ -1))
! !

!Point methodsFor: 'converting' stamp: ''!
extent: aPoint 
	"Answer a Rectangle whose origin is the receiver and whose extent is 
	aPoint. This is one of the infix ways of expressing the creation of a 
	rectangle."

	^Rectangle origin: self extent: aPoint! !

!Point methodsFor: 'point functions' stamp: 'di 6/11/97 16:08'!
flipBy: direction centerAt: c
	"Answer a Point which is flipped according to the direction about the point c.
	Direction must be #vertical or #horizontal."
	direction == #vertical ifTrue: [^ x @ (c y * 2 - y)].
	direction == #horizontal ifTrue: [^ (c x * 2 - x) @ y].
	self error: 'unrecognizable direction'! !

!Point methodsFor: 'truncation and round off' stamp: 'nice 2/5/2006 16:43'!
floor
	"Answer a Point that is the receiver's x and y floor. Answer the receiver if its coordinates are already integral."

	(x isInteger and: [y isInteger]) ifTrue: [^ self].
	^ x floor @ y floor
! !

!Point methodsFor: 'point functions' stamp: 'wiz 8/6/2007 20:33'!
fourDirections
	"Return vertices for a square centered at 0 asPoint with the receiver as first corner.
	Returns the four rotation of the reciever in counter clockwise order with the reciever 	appearing last. "
	^ Array with: self leftRotated
			with: self negated
			with: self rightRotated
			with: self 
		
! !

!Point methodsFor: 'point functions' stamp: 'nice 12/29/2010 14:57'!
fourNeighbors
	^ Array with: self + (1 @ 0)
		with: self + (0 @ 1)
		with: self + (-1 @ 0)
		with: self + (0 @ -1)
! !

!Point methodsFor: 'point functions' stamp: ''!
grid: aPoint 
	"Answer a Point to the nearest rounded grid modules specified by aPoint."

	| newX newY |
	newX := x + (aPoint x // 2) truncateTo: aPoint x.
	newY := y + (aPoint y // 2) truncateTo: aPoint y.
	^newX @ newY! !

!Point methodsFor: 'extent functions' stamp: 'mt 7/13/2016 12:08'!
guarded
	"Return a positive nonzero extent."
	^ self max: 1@1! !

!Point methodsFor: 'comparing' stamp: 'SqR 11/3/2000 17:08'!
hash
	"Hash is reimplemented because = is implemented."

	^(x hash hashMultiply + y hash) hashMultiply! !

!Point methodsFor: 'point functions' stamp: 'ar 5/22/2001 23:46'!
insideTriangle: p1 with: p2 with: p3
	"Return true if the receiver is within the triangle defined by the three coordinates.
	Note: This method computes the barycentric coordinates for the receiver and tests those coordinates."
	| p0 b0 b1 b2 b3 |
	p0 := self.
	b0 := ((p2 x - p1 x) * (p3 y - p1 y)) - ((p3 x - p1 x) * (p2 y - p1 y)).
	b0 isZero ifTrue:[^false]. "degenerate"
	b0 := 1.0 / b0.
	b1 := (((p2 x - p0 x) * (p3 y - p0 y)) - ((p3 x - p0 x) * (p2 y - p0 y))) * b0.
	b2 := (((p3 x - p0 x) * (p1 y - p0 y)) - ((p1 x - p0 x) * (p3 y - p0 y))) * b0.
	b3 := (((p1 x - p0 x) * (p2 y - p0 y)) - ((p2 x - p0 x) * (p1 y - p0 y))) * b0.
	b1 < 0.0 ifTrue:[^false].
	b2 < 0.0 ifTrue:[^false].
	b3 < 0.0 ifTrue:[^false].
	^true

! !

!Point methodsFor: 'interpolating' stamp: 'jsp 3/22/1999 16:31'!
interpolateTo: end at: amountDone
	"Interpolate between the instance and end after the specified amount has been done (0 - 1)."

	^ self + ((end - self) * amountDone).! !

!Point methodsFor: 'geometry' stamp: 'laza 1/24/2000 03:44'!
isInsideCircle: a with: b with: c 
	"Returns TRUE if self is inside the circle defined by the     
	points a, b, c. See Guibas and Stolfi (1985) p.107"
	^ (a dotProduct: a)
		* (b triangleArea: c with: self) - ((b dotProduct: b)
			* (a triangleArea: c with: self)) + ((c dotProduct: c)
			* (a triangleArea: b with: self)) - ((self dotProduct: self)
			* (a triangleArea: b with: c)) > 0.0! !

!Point methodsFor: 'truncation and round off' stamp: 'wiz 1/11/2006 18:32'!
isIntegerPoint
^ x isInteger and: [ y isInteger ] ! !

!Point methodsFor: 'converting' stamp: 'di 11/6/1998 07:45'!
isPoint
	^ true! !

!Point methodsFor: 'testing' stamp: 'ar 10/29/2000 19:02'!
isZero
	^x isZero and:[y isZero]! !

!Point methodsFor: 'point functions' stamp: 'wiz 7/26/2007 03:32'!
leftRotated
"Return the reciever rotated 90 degrees.
i.e. self rotateBy: #left centerAt: 0 asPoint .
Compare to transposed and normal. "
	^y  @x negated! !

!Point methodsFor: 'comparing' stamp: ''!
max: aPoint 
	"Answer the lower right corner of the rectangle uniquely defined by the 
	receiver and the argument, aPoint."

	^ (x max: aPoint x) @ (y max: aPoint y)! !

!Point methodsFor: 'comparing' stamp: ''!
min: aPoint 
	"Answer the upper left corner of the rectangle uniquely defined by the 
	receiver and the argument, aPoint."

	^ (x min: aPoint x) @ (y min: aPoint y)! !

!Point methodsFor: 'comparing' stamp: ''!
min: aMin max: aMax 

	^ (self min: aMin) max: aMax! !

!Point methodsFor: 'point functions' stamp: 'di 12/1/97 12:37'!
nearestPointAlongLineFrom: p1 to: p2
	"Note this will give points beyond the endpoints.
	Streamlined by Gerardo Richarte 11/3/97"
	| x21 y21 t x1 y1 |
	p1 x = p2 x ifTrue: [^ p1 x @ y].
	p1 y = p2 y ifTrue: [^ x @ p1 y].
	x1 := p1 x asFloat.
	y1 := p1 y asFloat.
	x21 := p2 x asFloat - x1.
	y21 := p2 y asFloat - y1.
	t := ((y asFloat - y1 / x21) + (x asFloat - x1 / y21))
			/ ((x21 / y21) + (y21 / x21)).
	^ (x1 + (t * x21)) @ (y1 + (t * y21))
"
	| old new |
	Pen new place: 200@100; goto: (old := 500@300).
	Display reverse: (old extent: 10@10).
	[Sensor anyButtonPressed] whileFalse:
		[(new := (Sensor cursorPoint nearestPointAlongLineFrom: 200@100 to: 500@300) )
			= old ifFalse:
				[Display reverse: (old extent: 10@10).
				Display reverse: ((old := new) extent: 10@10)]]
"
! !

!Point methodsFor: 'point functions' stamp: 'di 12/1/97 12:40'!
nearestPointOnLineFrom: p1 to: p2
	"This will not give points beyond the endpoints"
	^ (self nearestPointAlongLineFrom: p1 to: p2)
		adhereTo: (p1 rect: p2)! !

!Point methodsFor: 'transforming' stamp: 'ar 8/26/2001 22:14'!
negated
	"Answer a point whose x and y coordinates are the negatives of those of the receiver.  6/6/96 sw"
	"Optimized for speed -- ar 8/26/2001"
	^ (0 - x) @ (0 - y)! !

!Point methodsFor: 'point functions' stamp: 'wiz 7/28/2007 20:50'!
normal
	"Answer a Point representing the unit vector rotated 90 deg clockwise.
	For the zero point return a normal of  -1@0   ."

	| n d |
	
	n := y negated @ x.
	(d := (n x * n x + (n y * n y))) = 0 ifTrue: [ ^  -1 @0  ] .
	^n / d sqrt! !

!Point methodsFor: 'point functions' stamp: 'ar 8/26/2001 22:15'!
normalized
	"Optimized for speed -- ar 8/26/2001"
	| r |
	r := ((x*x) + (y * y)) sqrt.
	^(x / r) @ (y / r)! !

!Point methodsFor: 'point functions' stamp: 'laza 12/13/1999 11:43'!
octantOf: otherPoint 
	"Return 1..8 indicating relative direction to otherPoint.  
	1=ESE, 2=SSE, ... etc. clockwise to 8=ENE"
	"[Sensor anyButtonPressed] whileFalse: [(Display boundingBox center 
	octantOf: Sensor cursorPoint) printString displayAt: 0@0]"
	| quad moreHoriz |
	(x = otherPoint x and: [y > otherPoint y])
		ifTrue: [^ 6].
	"special case"
	(y = otherPoint y and: [x < otherPoint x])
		ifTrue: [^ 8].
	quad := self quadrantOf: otherPoint.
	moreHoriz := (x - otherPoint x) abs >= (y - otherPoint y) abs.
	(quad even eqv: moreHoriz)
		ifTrue: [^ quad * 2]
		ifFalse: [^ quad * 2 - 1]! !

!Point methodsFor: 'point functions' stamp: 'di 12/1/97 12:12'!
onLineFrom: p1 to: p2
	^ self onLineFrom: p1 to: p2 within: 2! !

!Point methodsFor: 'point functions' stamp: 'jm 2/24/98 08:34'!
onLineFrom: p1 to: p2 within: epsilon
	"Answer true if the receiver lies on the given line segment between p1 and p2 within a small epsilon."

	"is this point within the box spanning p1 and p2 expanded by epsilon? (optimized)"
	p1 x < p2 x
		ifTrue: [
			((x < (p1 x - epsilon)) or: [x > (p2 x + epsilon)]) ifTrue: [^ false]]
		ifFalse: [
			((x < (p2 x - epsilon)) or: [x > (p1 x + epsilon)]) ifTrue: [^ false]].
	p1 y < p2 y
		ifTrue: [
			((y < (p1 y - epsilon)) or: [y > (p2 y + epsilon)]) ifTrue: [^ false]]
		ifFalse: [
			((y < (p2 y - epsilon)) or: [y > (p1 y + epsilon)]) ifTrue: [^ false]].

	"it's in the box; is it on the line?"
	^ (self dist: (self nearestPointAlongLineFrom: p1 to: p2)) <= epsilon! !

!Point methodsFor: 'printing' stamp: 'eem 2/21/2013 10:18'!
printOn: aStream 
	"The receiver prints on aStream in terms of infix notation."

	x printOn: aStream.
	aStream nextPut: $@.
	(y isNumber and: [y negative]) ifTrue:
		"Avoid ambiguous @- construct"
		[aStream space].
	y printOn: aStream! !

!Point methodsFor: 'point functions' stamp: '6/9/97 14:51 di'!
quadrantOf: otherPoint
	"Return 1..4 indicating relative direction to otherPoint.
	1 is downRight, 2=downLeft, 3=upLeft, 4=upRight"
	^ x <= otherPoint x
		ifTrue: [y < otherPoint y ifTrue: [1] ifFalse: [4]]
		ifFalse: [y <= otherPoint y ifTrue: [2] ifFalse: [3]]
"
[Sensor anyButtonPressed] whileFalse:
	[(Display boundingBox center quadrantOf: Sensor cursorPoint) printString displayAt: 0@0]
"! !

!Point methodsFor: 'polar coordinates' stamp: ''!
r
	"Answer the receiver's radius in polar coordinate system."

	^(self dotProduct: self) sqrt! !

!Point methodsFor: 'arithmetic' stamp: 'TRee 6/3/2004 11:09'!
reciprocal
    " Answer a Point with coordinates that are the reciprocals of mine. "
    " Method was missing from release. "
    " 20040301 20:50:35 TRee(Squeak3.6-5429-tree07.38) "

    ^ x reciprocal @ y reciprocal.
! !

!Point methodsFor: 'converting' stamp: 'di 12/3/97 19:00'!
rect: aPoint 
	"Answer a Rectangle that encompasses the receiver and aPoint.
	This is the most general infix way to create a rectangle."

	^ Rectangle 
		origin: (self min: aPoint)
		corner: (self max: aPoint)! !

!Point methodsFor: 'point functions' stamp: 'wiz 7/26/2007 02:33'!
rightRotated
"Return the reciever rotated 90 degrees.
i.e. self rotateBy: #right centerAt: 0 asPoint .
Compare to transposed and normal. "
	^y negated @x! !

!Point methodsFor: 'transforming' stamp: ''!
rotateBy: angle about: center
	"Even though Point.theta is measured CW, this rotates with the more conventional CCW interpretateion of angle."

	| p r theta |
	p := self - center.
	r := p r.
	theta := angle asFloat - p theta.
	^ (center x asFloat + (r * theta cos)) @
	  (center y asFloat - (r * theta sin))! !

!Point methodsFor: 'point functions' stamp: 'di 6/11/97 15:12'!
rotateBy: direction centerAt: c
	"Answer a Point which is rotated according to direction, about the point c.
	Direction must be one of #right (CW), #left (CCW) or #pi (180 degrees)."
	| offset |
	offset := self - c.
	direction == #right ifTrue: [^ (offset y negated @ offset x) + c].
	direction == #left ifTrue: [^ (offset y @ offset x negated) + c].
	direction == #pi ifTrue: [^ c - offset].
	self error: 'unrecognizable direction'! !

!Point methodsFor: 'truncation and round off' stamp: 'nice 2/5/2006 16:42'!
roundDownTo: grid
	"Answer a Point that is the receiver's x and y rounded to grid x and 
	grid y by lower value (toward negative infinity)."
	
	| gridPoint |
	gridPoint := grid asPoint.
	^(x roundDownTo: gridPoint x) @ (y roundDownTo: gridPoint y)! !

!Point methodsFor: 'truncation and round off' stamp: 'jm 6/3/1998 12:21'!
rounded
	"Answer a Point that is the receiver's x and y rounded. Answer the receiver if its coordinates are already integral."

	(x isInteger and: [y isInteger]) ifTrue: [^ self].
	^ x rounded @ y rounded
! !

!Point methodsFor: 'truncation and round off' stamp: 'nice 2/5/2006 16:35'!
roundTo: grid
	"Answer a Point that is the receiver's x and y rounded to grid x and 
	grid y."
	
	| gridPoint |
	gridPoint := grid asPoint.
	^(x roundTo: gridPoint x) @ (y roundTo: gridPoint y)! !

!Point methodsFor: 'truncation and round off' stamp: 'nice 2/5/2006 16:41'!
roundUpTo: grid
	"Answer a Point that is the receiver's x and y rounded to grid x and 
	grid y by upper value (toward infinity)."
	
	| gridPoint |
	gridPoint := grid asPoint.
	^(x roundUpTo: gridPoint x) @ (y roundUpTo: gridPoint y)! !

!Point methodsFor: 'transforming' stamp: ''!
scaleBy: factor 
	"Answer a Point scaled by factor (an instance of Point)."

	^(factor x * x) @ (factor y * y)! !

!Point methodsFor: 'transforming' stamp: 'di 12/4/97 14:34'!
scaleFrom: rect1 to: rect2
	"Produce a point stretched according to the stretch from rect1 to rect2"
	^ rect2 topLeft + (((x-rect1 left) * rect2 width // rect1 width)
					@ ((y-rect1 top) * rect2 height // rect1 height))! !

!Point methodsFor: 'extent functions' stamp: 'mt 7/13/2016 12:09'!
scaleTo: anExtent
	"Return a Point scalefactor for shrinking a thumbnail of the receiver's extent to fit within anExtent. self and anExtent are expected to have positive nonZero x and y."

	|  factor  sX sY | 
	factor :=  3.0  reciprocal .
	sX := anExtent x / self  x asFloat  .
	sY :=  anExtent y / self  y asFloat  .
	sX = sY ifTrue: [ ^ sX @ sY ] . "Same aspect ratio"
	^ sX < sY ifTrue: [   sX @ (sX max: sY * factor) ] 
		ifFalse: [  (sY max: sX * factor ) @ sY  ] ! !

!Point methodsFor: 'private' stamp: 'tk 10/4/2001 16:16'!
setR: rho degrees: degrees 

	| radians |
	radians := degrees asFloat degreesToRadians.
	x := rho asFloat * radians cos.
	y := rho asFloat * radians sin.! !

!Point methodsFor: 'private' stamp: 'sw 3/21/2000 13:24'!
setX: xValue setY: yValue

	x := xValue.
	y := yValue! !

!Point methodsFor: 'geometry' stamp: 'laza 1/6/2000 10:30'!
sideOf: otherPoint 
	"Returns #left, #right or #center if the otherPoint lies to the left, right 
	or on the line given by the vector from 0@0 to self"
	| side |
	side := (self crossProduct: otherPoint) sign.
	^ {#right. #center. #left} at: side + 2
! !

!Point methodsFor: 'point functions' stamp: 'wiz 8/1/2007 16:53'!
sign


^ (x sign @ y sign) .! !

!Point methodsFor: 'point functions' stamp: 'ar 4/18/1999 05:17'!
sortsBefore: otherPoint
	"Return true if the receiver sorts before the other point"
	^y = otherPoint y
		ifTrue:[x <= otherPoint x]
		ifFalse:[y <= otherPoint y]! !

!Point methodsFor: 'point functions' stamp: 'ar 5/23/2001 21:29'!
squaredDistanceTo: aPoint
	"Answer the distance between aPoint and the receiver."
	| delta |
	delta := aPoint - self.
	^delta dotProduct: delta! !

!Point methodsFor: 'printing' stamp: 'ar 7/8/2006 19:15'!
storeOn: aStream 
	"x@y printed form is good for storing too"
	aStream nextPut: $(.
	self printOn: aStream.
	aStream nextPut: $).
! !

!Point methodsFor: 'polar coordinates' stamp: 'nice 10/12/2007 23:30'!
theta
	"Answer the angle the receiver makes with origin in radians. right is 0; 
	down is 90. 
	Corrected the constants from single precision to 64 Bit precision 
	and changed the sends in case of overflow to constants HK 2005-07-23"

	| tan theta |
	x = 0
		ifTrue: [y >= 0
				ifTrue: [^ 1.5707963267948966 "90.0 degreesToRadians"]
				ifFalse: [^ 4.71238898038469 "270.0 degreesToRadians"]]
		ifFalse: 
			[tan := y asFloat / x asFloat.
			theta := tan arcTan.
			x >= 0
				ifTrue: [y >= 0
						ifTrue: [^theta]
						ifFalse: [^"360.0 degreesToRadians" 6.283185307179586 + theta]]
				ifFalse: [^"180.0 degreesToRadians" 3.141592653589793 + theta]]! !

!Point methodsFor: 'geometry' stamp: 'ar 4/6/2000 18:37'!
to: end1 intersects: start2 to: end2 
	"Returns true if the linesegment from start1 (=self) to end1 intersects      
	    with the segment from start2 to end2, otherwise false."
	| start1 sideStart sideEnd |
	start1 := self.
	(((start1 = start2 or: [end1 = end2])
		or: [start1 = end2])
		or: [start2 = end1])
		ifTrue: [^ true].
	sideStart := start1 to: end1 sideOf: start2.
	sideEnd := start1 to: end1 sideOf: end2.
	sideStart = sideEnd ifTrue: [^ false].
	sideStart := start2 to: end2 sideOf: start1.
	sideEnd := start2 to: end2 sideOf: end1.
	sideStart = sideEnd ifTrue: [^ false].
	^ true! !

!Point methodsFor: 'geometry' stamp: 'laza 1/5/2000 11:50'!
to: end sideOf: otherPoint 
	"Returns #left, #right, #center if the otherPoint lies to the left, right or on the line given by the vector from self to end"
	^ end - self sideOf: otherPoint - self! !

!Point methodsFor: 'transforming' stamp: 'ar 12/10/2009 00:18'!
transformedBy: aTransform
	"Point transform double dispatch"
	^aTransform transformPoint: self! !

!Point methodsFor: 'transforming' stamp: ''!
translateBy: delta 
	"Answer a Point translated by delta (an instance of Point)."

	^(delta x + x) @ (delta y + y)! !

!Point methodsFor: 'point functions' stamp: 'ar 11/12/1998 01:44'!
transposed
	^y@x! !

!Point methodsFor: 'geometry' stamp: 'laza 1/17/2000 15:47'!
triangleArea: b with: c
	"Returns twice the area of the oriented triangle (a, b, c), i.e., the   
	area is positive if the triangle is oriented counterclockwise"
	^ b x - self x * (c y - self y) - (b y - self y * (c x - self x))! !

!Point methodsFor: 'truncation and round off' stamp: 'jm 5/29/1998 15:53'!
truncated
	"Answer a Point whose x and y coordinates are integers. Answer the receiver if its coordinates are already integral."

	(x isInteger and: [y isInteger]) ifTrue: [^ self].
	^ x truncated @ y truncated
! !

!Point methodsFor: 'truncation and round off' stamp: ''!
truncateTo: grid
	"Answer a Point that is the receiver's x and y truncated to grid x and 
	grid y."
	| gridPoint |
	gridPoint := grid asPoint.
	^(x truncateTo: gridPoint x) @ (y truncateTo: gridPoint y)! !

!Point methodsFor: 'accessing' stamp: 'jrd 5/26/2010 12:32'!
u
	^x! !

!Point methodsFor: 'accessing' stamp: 'jrd 5/26/2010 12:32'!
v
	^y! !

!Point methodsFor: 'copying' stamp: 'tk 8/19/1998 16:05'!
veryDeepCopyWith: deepCopier
	"Return self.  I am immutable in the Morphic world.  Do not record me."! !

!Point methodsFor: 'accessing' stamp: ''!
x
	"Answer the x coordinate."

	^x! !

!Point methodsFor: 'accessing' stamp: ''!
y
	"Answer the y coordinate."

	^y! !

!Point methodsFor: 'arithmetic' stamp: 'di 11/6/1998 14:01'!
* arg 
	"Answer a Point that is the product of the receiver and arg."

	arg isPoint ifTrue: [^ (x * arg x) @ (y * arg y)].
	^ arg adaptToPoint: self andSend: #*! !

!Point methodsFor: 'arithmetic' stamp: 'di 11/6/1998 14:01'!
+ arg 
	"Answer a Point that is the sum of the receiver and arg."

	arg isPoint ifTrue: [^ (x + arg x) @ (y + arg y)].
	^ arg adaptToPoint: self andSend: #+! !

!Point methodsFor: 'arithmetic' stamp: 'di 11/6/1998 14:02'!
- arg 
	"Answer a Point that is the difference of the receiver and arg."

	arg isPoint ifTrue: [^ (x - arg x) @ (y - arg y)].
	^ arg adaptToPoint: self andSend: #-! !

!Point methodsFor: 'arithmetic' stamp: 'di 11/6/1998 14:02'!
/ arg 
	"Answer a Point that is the quotient of the receiver and arg."

	arg isPoint ifTrue: [^ (x / arg x) @ (y / arg y)].
	^ arg adaptToPoint: self andSend: #/! !

!Point methodsFor: 'arithmetic' stamp: 'di 11/6/1998 14:02'!
// arg 
	"Answer a Point that is the quotient of the receiver and arg."

	arg isPoint ifTrue: [^ (x // arg x) @ (y // arg y)].
	^ arg adaptToPoint: self andSend: #//! !

!Point methodsFor: 'comparing' stamp: ''!
< aPoint 
	"Answer whether the receiver is above and to the left of aPoint."

	^x < aPoint x and: [y < aPoint y]! !

!Point methodsFor: 'comparing' stamp: ''!
<= aPoint 
	"Answer whether the receiver is neither below nor to the right of aPoint."

	^x <= aPoint x and: [y <= aPoint y]! !

!Point methodsFor: 'comparing' stamp: ''!
= aPoint

	self species = aPoint species
		ifTrue: [^x = aPoint 
	"Refer to the comment in Object|=." x and: [y = aPoint y]]
		ifFalse: [^false]! !

!Point methodsFor: 'comparing' stamp: ''!
> aPoint 
	"Answer whether the receiver is below and to the right of aPoint."

	^x > aPoint x and: [y > aPoint y]! !

!Point methodsFor: 'comparing' stamp: ''!
>= aPoint 
	"Answer whether the receiver is neither above nor to the left of aPoint."

	^x >= aPoint x and: [y >= aPoint y]! !

!Point methodsFor: 'arithmetic' stamp: 'di 11/6/1998 14:02'!
\\ arg 
	"Answer a Point that is the mod of the receiver and arg."

	arg isPoint ifTrue: [^ (x \\ arg x) @ (y \\ arg y)].
	^ arg adaptToPoint: self andSend: #\\! !

Object subclass: #Rectangle
	instanceVariableNames: 'origin corner'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Primitives'!

!Rectangle commentStamp: 'nice 7/25/2010 14:56' prior: 0!
I represent a rectangular area of the screen. Arithmetic functions take points as arguments and carry out scaling and translating operations to create new instances of me. Rectangle functions create new instances by determining intersections of rectangles with rectangles.

Note 1: only rectangles parallel to reference frame (Screen) can be represented by this class.

Note 2: the Rectangle is represented by two extremities of one diagonal. By convention, it must be the diagonal:
	from rectangle origin (the point having smallest coordinates in reference frame),
	to rectangle corner (the point having largest coordinates in reference frame).

Note 3: Screen coordinates conventions are:
	x is horizontal axis, zero at left border, oriented toward right;
	y is vertical axis, zero at top border, oriented toward bottom.
This corresponds to the latin convention for writing text from left to right and top to bottom.

Note 4: the Rectangle extent is obtained by subtracting rectangle origin to rectangle corner coordinates.
If this leads to a negative width (extent x coordinate) and/or a negative height (extent y coordinate), then the Rectangle is degenerated and considered empty.

Instance variables:
	origin	<Point> the coordinates of corner having smallest coordinates (top left in Screen coordinates)
	corner	<Point> the coordinates of corner having largest coordinates (bottom right in Screen coordinates)
!

Rectangle subclass: #Quadrangle
	instanceVariableNames: 'borderWidth borderColor insideColor'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Primitives'!

!Quadrangle commentStamp: '<historical>' prior: 0!
I represent a particular kind of Rectangle that has a border and inside color.!

!Quadrangle class methodsFor: 'instance creation' stamp: 'sw 5/4/2001 17:12'!
exampleInViewer
	"Create a sample Quadrangle and open a Viewer on it"

	(self region: (100@100 extent: 100@50) borderWidth: (1 + (6 atRandom)) borderColor: Color black insideColor: (Color perform: #(green red blue yellow) atRandom)) beViewed

"Quadrangle exampleInViewer"! !

!Quadrangle class methodsFor: 'instance creation' stamp: 'fc 1/16/2005 21:20'!
origin: originPoint corner: cornerPoint 
	"Override Rectangles origin:corner: in order to get initialized.

	Answer an instance of me whose corners (top left and bottom right) are 
	determined by the arguments."

	^self new setOrigin: originPoint corner: cornerPoint! !

!Quadrangle class methodsFor: 'instance creation' stamp: ''!
region: aRectangle borderWidth: anInteger borderColor: aMask1 insideColor: aMask2
	"Answer an instance of me with rectangle, border width and color, and 
	inside color determined by the arguments."

	^super new
		setRegion: aRectangle
		borderWidth: anInteger
		borderColor: aMask1
		insideColor: aMask2! !

!Quadrangle methodsFor: 'transforming' stamp: ''!
alignedTo: alignPointSelector
	"Return a copy with offset according to alignPointSelector which is one of...
	#(topLeft, topCenter, topRight, leftCenter, center, etc)
	 5/24/96 sw: removed hard-coded class name so subclasses can gain same functionality."

	^ self class
		region: (super translateBy: (0@0) - (self perform: alignPointSelector))
		borderWidth: borderWidth
		borderColor: borderColor
		insideColor: insideColor! !

!Quadrangle methodsFor: 'transforming' stamp: ''!
align: aPoint1 with: aPoint2 
	"Answer a new Quadrangle translated by aPoint2 - aPoint1.
	 5/24/96 sw: removed hard-coded class name so subclasses can gain same functionality."

	^ self class
		region: (super translateBy: aPoint2 - aPoint1)
		borderWidth: borderWidth
		borderColor: borderColor
		insideColor: insideColor! !

!Quadrangle methodsFor: 'bordering' stamp: ''!
borderColor
	"Answer the form that is the borderColor of the receiver."

	^borderColor! !

!Quadrangle methodsFor: 'bordering' stamp: ''!
borderColor: aColor 
	"Set the borderColor of the receiver to aColor, a Form."

	borderColor := aColor! !

!Quadrangle methodsFor: 'bordering' stamp: ''!
borderWidth
	"Answer the borderWidth of the receiver."

	^borderWidth! !

!Quadrangle methodsFor: 'bordering' stamp: ''!
borderWidthLeft: anInteger1 right: anInteger2 top: anInteger3 bottom: anInteger4
	"Set the border width of the receiver to a Rectangle that represents the 
	left, right, top, and bottom border widths."

	borderWidth := anInteger1 @ anInteger3 corner: anInteger2 @ anInteger4! !

!Quadrangle methodsFor: 'bordering' stamp: ''!
borderWidth: anInteger 
	"Set the borderWidth of the receiver to anInteger."

	borderWidth := anInteger! !

!Quadrangle methodsFor: 'displaying-Display' stamp: ''!
display 
	"Display the border and insideRegion of the receiver on the Display."

	self displayOn: Display! !

!Quadrangle methodsFor: 'displaying-Display' stamp: ''!
displayAlign: aPoint1 with: aPoint2 clippingBox: aRectangle 
	"Display the border and region of the receiver on the Display so that its 
	position at aPoint1 is aligned with position aPoint2. The displayed 
	information should be clipped so that only information with the area 
	determined by aRectangle is displayed." 

	self displayOn: Display align: aPoint1 with: aPoint2 clippingBox: aRectangle! !

!Quadrangle methodsFor: 'displaying-generic' stamp: ''!
displayOnPort: aPort at: p
	"Display the border and insideRegion of the receiver."

	(insideColor == nil or: [borderWidth <= 0])
		ifFalse: [aPort fill: (self region translateBy: p) 
			fillColor: borderColor rule: Form over].
	insideColor == nil
		ifFalse: [aPort fill: (self inside translateBy: p) 
			fillColor: insideColor rule: Form over]! !

!Quadrangle methodsFor: 'displaying-generic' stamp: 'ul 11/16/2010 04:50'!
displayOn: aDisplayMedium
	"Display the border and insideRegion of the receiver."

	borderWidth ~= 0 ifTrue: [
		aDisplayMedium
			border: self region
			widthRectangle: borderWidth
			rule: Form over
			fillColor: borderColor ].
	insideColor ifNotNil: [
		aDisplayMedium fill: self inside fillColor: insideColor ]! !

!Quadrangle methodsFor: 'displaying-generic' stamp: ''!
displayOn: aDisplayMedium align: aPoint1 with: aPoint2 clippingBox: aRectangle
	"Display the border and region of the receiver so that its position at 
	aPoint1 is aligned with position aPoint2. The displayed information 
	should be clipped so that only information with the area determined by 
	aRectangle is displayed."

	| savedRegion |
	savedRegion := self region.
	self region: ((savedRegion align: aPoint1 with: aPoint2) intersect: aRectangle).
	self displayOn: aDisplayMedium.
	self region: savedRegion! !

!Quadrangle methodsFor: 'displaying-generic' stamp: 'ul 11/16/2010 04:50'!
displayOn: aDisplayMedium transformation: aWindowingTransformation clippingBox: aRectangle
	"Display the border and region of the receiver so that it is scaled and 
	translated with respect to aWindowingTransformation. The displayed 
	information should be clipped so that only information with the area 
	determined by aRectangle is displayed."

	| screenRectangle |
	screenRectangle := 
		(aWindowingTransformation applyTo: self) intersect: aRectangle.
	(borderWidth ~= 0 and: [ insideColor notNil ])
		ifTrue: 
			[aDisplayMedium fill: screenRectangle fillColor: Color black "borderColor".
			aDisplayMedium
				fill: (screenRectangle insetBy: borderWidth)
				fillColor: insideColor]! !

!Quadrangle methodsFor: 'displaying-Display' stamp: ''!
displayTransformation: aWindowingTransformation clippingBox: aRectangle 
	"Display the border and region of the receiver on the Display so that it 
	is scaled and translated with respect to aWindowingTransformation. The 
	displayed information should be clipped so that only information with 
	the area determined by aRectangle is displayed." 

	self displayOn: Display transformation: aWindowingTransformation clippingBox: aRectangle! !

!Quadrangle methodsFor: 'initialize-release' stamp: ''!
initialize
	"Initialize the region to a null Rectangle, the borderWidth to 1, the 
	borderColor to black, and the insideColor to white."

	origin := 0 @ 0.
	corner := 0 @ 0.
	borderWidth := 1.
	borderColor := Color black.
	insideColor := Color white.
! !

!Quadrangle methodsFor: 'bordering' stamp: ''!
inside
	"Answer a Rectangle that is the receiver inset by the borderWidth."

	^self insetBy: borderWidth! !

!Quadrangle methodsFor: 'bordering' stamp: ''!
insideColor
	"Answer the form that is the insideColor of the receiver."

	^insideColor! !

!Quadrangle methodsFor: 'bordering' stamp: ''!
insideColor: aColor 
	"Set the insideColor of the receiver to aColor, a Form."

	insideColor := aColor! !

!Quadrangle methodsFor: 'rectangle functions' stamp: ''!
intersect: aRectangle 
	"Answer a new Quadrangle whose region is the intersection of the 
	receiver's area and aRectangle.
	 5/24/96 sw: removed hard-coded class name so subclasses can gain same functionality."

	^ self class
	 	region: (super intersect: aRectangle)
		borderWidth: borderWidth
		borderColor: borderColor
		insideColor: insideColor! !

!Quadrangle methodsFor: 'bordering' stamp: ''!
region
	"Answer a Rectangle that defines the area of the receiver."

	^origin corner: corner! !

!Quadrangle methodsFor: 'bordering' stamp: ''!
region: aRectangle 
	"Set the rectangular area of the receiver to aRectangle."

	origin := aRectangle origin.
	corner := aRectangle corner! !

!Quadrangle methodsFor: 'transforming' stamp: ''!
scaleBy: aPoint 
	"Answer a new Quadrangle scaled by aPoint.
	 5/24/96 sw: removed hard-coded class name so subclasses can gain same functionality."

	^ self class
		region: (super scaleBy: aPoint)
		borderWidth: borderWidth
		borderColor: borderColor
		insideColor: insideColor! !

!Quadrangle methodsFor: 'bordering' stamp: 'sw 5/4/2001 18:30'!
setHeight: aNumber 
	"Set the receiver's height"

	self region: (origin extent: (self width @ aNumber))! !

!Quadrangle methodsFor: 'bordering' stamp: 'sw 5/4/2001 17:54'!
setLeft: aNumber 
	"Move the receiver so that its left edge is given by aNumber.  An example of a setter to go with #left"

	self region: ((aNumber @ origin y) extent: self extent)! !

!Quadrangle methodsFor: 'private' stamp: ''!
setRegion: aRectangle borderWidth: anInteger borderColor: aMask1 insideColor: aMask2

	origin := aRectangle origin.
	corner := aRectangle corner.
	borderWidth := anInteger.
	borderColor := aMask1.
	insideColor := aMask2! !

!Quadrangle methodsFor: 'bordering' stamp: 'sw 5/4/2001 18:19'!
setRight: aNumber 
	"Move the receiver so that its right edge is given by aNumber.  An example of a setter to go with #right"

	self region: ((origin x + (aNumber - self right) @ origin y) extent: self extent)! !

!Quadrangle methodsFor: 'bordering' stamp: 'sw 5/4/2001 18:26'!
setWidth: aNumber 
	"Set the receiver's width"

	self region: (origin extent: (aNumber @ self height))! !

!Quadrangle methodsFor: 'transforming' stamp: ''!
translateBy: aPoint 
	"Answer a new Quadrangle translated by aPoint.
	 5/24/96 sw: removed hard-coded class name so subclasses can gain same functionality."

	^ self class
		region: (super translateBy: aPoint)
		borderWidth: borderWidth
		borderColor: borderColor
		insideColor: insideColor! !

!Rectangle class methodsFor: 'instance creation' stamp: 'tk 3/9/97'!
center: centerPoint extent: extentPoint 
	"Answer an instance of me whose center is centerPoint and width 
	by height is extentPoint.  "

	^self origin: centerPoint - (extentPoint//2) extent: extentPoint! !

!Rectangle class methodsFor: 'instance creation' stamp: 'di 12/1/97 10:42'!
encompassing: listOfPoints
	"A number of callers of encompass: should use this method."
	| topLeft bottomRight |
	topLeft := bottomRight := nil.
	listOfPoints do:
		[:p | topLeft == nil
			ifTrue: [topLeft := bottomRight := p]
			ifFalse: [topLeft := topLeft min: p.
					bottomRight := bottomRight max: p]].
	^ topLeft corner: bottomRight! !

!Rectangle class methodsFor: 'instance creation' stamp: ''!
fromUser
	"Answer an instance of me that is determined by having the user 
	designate the top left and bottom right corners. The gridding for user 
	selection is 1@1."

	^self fromUser: 1 @ 1! !

!Rectangle class methodsFor: 'instance creation' stamp: ''!
fromUser: gridPoint
	"Answer a Rectangle that is determined by having the user 
	designate the top left and bottom right corners. 
	The cursor reamins linked with the sensor, but
	the outline is kept gridded."
	| originRect |
	originRect := Cursor origin showWhile: 
		[((Sensor cursorPoint grid: gridPoint) extent: 0@0) newRectFrom:
			[:f | (Sensor cursorPoint grid: gridPoint) extent: 0@0]].
	^ Cursor corner showWhile:
		[originRect newRectFrom:
			[:f | f origin corner: (Sensor cursorPoint grid: gridPoint)]]! !

!Rectangle class methodsFor: 'instance creation' stamp: 'md 12/3/2004 00:02'!
left: leftNumber right: rightNumber top: topNumber bottom: bottomNumber 
	"Answer an instance of me whose left, right, top, and bottom coordinates 
	are determined by the arguments."

	^ self basicNew setOrigin: leftNumber @ topNumber corner: rightNumber @ bottomNumber! !

!Rectangle class methodsFor: 'instance creation' stamp: 'dtl 1/23/2010 18:10'!
locateMagnifiedView: aForm scale: scaleFactor
	"Answer a rectangle at the location where the scaled view of the form,
	aForm, should be displayed."

	^ self originFromUser: (aForm extent * scaleFactor + (0@50))
! !

!Rectangle class methodsFor: 'instance creation' stamp: 'btr 2/14/2003 16:29'!
merging: listOfRects 
	"A number of callers of merge: should use this method."
	| minX minY maxX maxY |
	listOfRects
		do: [:r | minX
				ifNil: [minX := r topLeft x. minY := r topLeft y.
					maxX := r bottomRight x. maxY := r bottomRight y]
				ifNotNil: [minX := minX min: r topLeft x. minY := minY min: r topLeft y.
					maxX := maxX max: r bottomRight x. maxY := maxY max: r bottomRight y]].
	^ minX@minY corner: maxX@maxY! !

!Rectangle class methodsFor: 'instance creation' stamp: ''!
originFromUser: extentPoint 
	"Answer an instance of me that is determined by having the user 
	designate the top left corner. The width and height are determined by 
	extentPoint. The gridding for user selection is 1@1."

	^self originFromUser: extentPoint grid: 1 @ 1! !

!Rectangle class methodsFor: 'instance creation' stamp: ''!
originFromUser: extentPoint grid: gridPoint 
	"Answer an instance of me that is determined by having the user 
	designate the top left corner. The width and height are determined by 
	extentPoint. The gridding for user selection is scaleFactor. Assumes that 
	the sender has determined an extent that is a proper multiple of 
	scaleFactor."

	^ Cursor origin showWhile: 
		[((Sensor cursorPoint grid: gridPoint) extent: extentPoint) newRectFrom:
			[:f | (Sensor cursorPoint grid: gridPoint) extent: extentPoint]].
! !

!Rectangle class methodsFor: 'instance creation' stamp: 'md 12/3/2004 00:04'!
origin: originPoint corner: cornerPoint 
	"Answer an instance of me whose corners (top left and bottom right) are 
	determined by the arguments."

	^self basicNew setOrigin: originPoint corner: cornerPoint! !

!Rectangle class methodsFor: 'instance creation' stamp: 'md 12/3/2004 00:03'!
origin: originPoint extent: extentPoint 
	"Answer an instance of me whose top left corner is originPoint and width 
	by height is extentPoint."

	^self basicNew setOrigin: originPoint corner: originPoint + extentPoint! !

!Rectangle methodsFor: 'accessing' stamp: 'acg 2/23/2000 00:52'!
aboveCenter
	"Answer the point slightly above the center of the receiver."

	^self topLeft + self bottomRight // (2@3)! !

!Rectangle methodsFor: 'rectangle functions' stamp: 'di 10/22/1998 16:11'!
adjustTo: newRect along: side 
	"Return a copy adjusted to fit a neighbor that has changed size."
	side = #left ifTrue: [^ self withRight: newRect left].
	side = #right ifTrue: [^ self withLeft: newRect right].
	side = #top ifTrue: [^ self withBottom: newRect top].
	side = #bottom ifTrue: [^ self withTop: newRect bottom].! !

!Rectangle methodsFor: 'transforming' stamp: ''!
align: aPoint1 with: aPoint2 
	"Answer a Rectangle that is a translated by aPoint2 - aPoint1."

	^self translateBy: aPoint2 - aPoint1! !

!Rectangle methodsFor: 'rectangle functions' stamp: 'ar 1/5/2002 18:04'!
allAreasOutsideList: aCollection do: aBlock
	"Enumerate aBlock with all areas of the receiver not overlapping 
	any rectangle in the given collection"
	^self allAreasOutsideList: aCollection startingAt: 1 do: aBlock! !

!Rectangle methodsFor: 'rectangle functions' stamp: 'ar 1/5/2002 18:03'!
allAreasOutsideList: aCollection startingAt: startIndex do: aBlock
	"Enumerate aBlock with all areas of the receiver not overlapping 
	any rectangle in the given collection"
	| yOrigin yCorner aRectangle index rr |
	index := startIndex.

	"Find the next intersecting rectangle from aCollection"
	[index <= aCollection size ifFalse:[^aBlock value: self].
	aRectangle := aCollection at: index.
	origin <= aRectangle corner and: [aRectangle origin <= corner]] 
		whileFalse:[index := index + 1].

	"aRectangle is intersecting; process it"
	aRectangle origin y > origin y 
		ifTrue: [rr := origin corner: corner x @ (yOrigin := aRectangle origin y).
				rr allAreasOutsideList: aCollection startingAt: index+1 do: aBlock]
		ifFalse: [yOrigin := origin y].
	aRectangle corner y < corner y
		ifTrue: [rr := origin x @ (yCorner := aRectangle corner y) corner: corner.
				rr allAreasOutsideList: aCollection startingAt: index+1 do: aBlock]
		ifFalse: [yCorner := corner y].
	aRectangle origin x > origin x 
		ifTrue: [rr := origin x @ yOrigin corner: aRectangle origin x @ yCorner.
				rr allAreasOutsideList: aCollection startingAt: index+1 do: aBlock].
	aRectangle corner x < corner x 
		ifTrue: [rr := aRectangle corner x @ yOrigin corner: corner x @ yCorner.
				rr allAreasOutsideList: aCollection startingAt: index+1 do: aBlock].! !

!Rectangle methodsFor: 'rectangle functions' stamp: ''!
amountToTranslateWithin: aRectangle
	"Answer a Point, delta, such that self + delta is forced within aRectangle."
	"Altered so as to prefer to keep self topLeft inside when all of self
	cannot be made to fit 7/27/96 di"
	| dx dy |
	dx := 0.  dy := 0.
	self right > aRectangle right ifTrue: [dx := aRectangle right - self right].
	self bottom > aRectangle bottom ifTrue: [dy := aRectangle bottom - self bottom].
	(self left + dx) < aRectangle left ifTrue: [dx := aRectangle left - self left].
	(self top + dy) < aRectangle top ifTrue: [dy := aRectangle top - self top].
	^ dx@dy! !

!Rectangle methodsFor: 'accessing' stamp: 'di 11/17/2001 14:01'!
area
	"Answer the receiver's area, the product of width and height."
	| w |
	(w := self width) <= 0 ifTrue: [^ 0].
	^ w * self height max: 0! !

!Rectangle methodsFor: 'rectangle functions' stamp: 'ar 10/25/2005 17:22'!
areasOutside: aRectangle
	"Answer an Array of Rectangles comprising the parts of the receiver not 
	intersecting aRectangle."

	| areas yOrigin yCorner |
	"Make sure the intersection is non-empty"
     (self intersects: aRectangle)
		ifFalse: [^Array with: self].
	areas := OrderedCollection new.
	aRectangle origin y > origin y
		ifTrue: [areas addLast: (origin corner: corner x @ (yOrigin := aRectangle origin y))]
		ifFalse: [yOrigin := origin y].
	aRectangle corner y < corner y
		ifTrue: [areas addLast: (origin x @ (yCorner := aRectangle corner y) corner: corner)]
		ifFalse: [yCorner := corner y].
	aRectangle origin x > origin x 
		ifTrue: [areas addLast: (origin x @ yOrigin corner: aRectangle origin x @ yCorner)].
	aRectangle corner x < corner x 
		ifTrue: [areas addLast: (aRectangle corner x @ yOrigin corner: corner x @ yCorner)].
	^areas! !

!Rectangle methodsFor: 'rectangle functions' stamp: 'di 10/21/1998 16:00'!
bordersOn: her along: herSide 
	(herSide = #right and: [self left = her right])
	| (herSide = #left and: [self right = her left])
		ifTrue:
		[^ (self top max: her top) < (self bottom min: her bottom)].
	(herSide = #bottom and: [self top = her bottom])
	| (herSide = #top and: [self bottom = her top])
		ifTrue:
		[^ (self left max: her left) < (self right min: her right)].
	^ false! !

!Rectangle methodsFor: 'accessing' stamp: ''!
bottom
	"Answer the position of the receiver's bottom horizontal line."

	^corner y! !

!Rectangle methodsFor: 'accessing' stamp: ''!
bottomCenter
	"Answer the point at the center of the bottom horizontal line of the 
	receiver."

	^self center x @ self bottom! !

!Rectangle methodsFor: 'accessing' stamp: ''!
bottomLeft
	"Answer the point at the left edge of the bottom horizontal line of the 
	receiver."

	^origin x @ corner y! !

!Rectangle methodsFor: 'accessing' stamp: ''!
bottomRight
	"Answer the point at the right edge of the bottom horizontal line of the 
	receiver."

	^corner! !

!Rectangle methodsFor: 'accessing' stamp: 'ar 10/26/2000 22:17'!
bottom: aNumber
	^origin corner: corner x @ aNumber! !

!Rectangle methodsFor: 'accessing' stamp: ''!
boundingBox
	^ self! !

!Rectangle methodsFor: 'truncation and round off' stamp: 'mt 7/13/2016 12:10'!
ceiling
	"Answer the integer rectange to the bottom right of receiver.
	Return reciever if it already and integerRectange."

	self isIntegerRectangle ifTrue: [ ^ self ] .

	^origin ceiling corner: corner ceiling! !

!Rectangle methodsFor: 'accessing' stamp: ''!
center
	"Answer the point at the center of the receiver."

	^self topLeft + self bottomRight // 2! !

!Rectangle methodsFor: 'transforming' stamp: ''!
centeredBeneath: aRectangle
	 "Move the reciever so that its top center point coincides with the bottom center point of aRectangle.  5/20/96 sw:"

	^ self align: self topCenter with: aRectangle bottomCenter! !

!Rectangle methodsFor: 'truncation and round off' stamp: 'wiz 2/12/2006 01:37'!
compressed
	"Answer a Rectangle whose origin and corner are rounded to integers.
	Rounding is done by upper value on origin and lower value on corner so that
	rounded rectangle is inside self."

	^Rectangle origin: origin ceiling corner: corner floor! !

!Rectangle methodsFor: 'truncation and round off' stamp: 'wiz 2/12/2006 01:37'!
compressTo: grid
	"Answer a Rectangle whose origin and corner are rounded to grid x and grid y.
	Rounding is done by upper value on origin and lower value on corner so that
	rounded rectangle is inside self."

	^Rectangle origin: (origin roundUpTo: grid)
				corner: (corner roundDownTo: grid)! !

!Rectangle methodsFor: 'testing' stamp: ''!
containsPoint: aPoint 
	"Answer whether aPoint is within the receiver."

	^origin <= aPoint and: [aPoint < corner]! !

!Rectangle methodsFor: 'testing' stamp: ''!
containsRect: aRect
	"Answer whether aRect is within the receiver (OK to coincide)."

	^ aRect origin >= origin and: [aRect corner <= corner]
! !

!Rectangle methodsFor: 'accessing' stamp: ''!
corner
	"Answer the point at the bottom right corner of the receiver."

	^corner! !

!Rectangle methodsFor: 'accessing' stamp: ''!
corners
	"Return an array of corner points in the order of a quadrilateral spec for WarpBlt."

	^ Array
		with: self topLeft
		with: self bottomLeft
		with: self bottomRight
		with: self topRight
! !

!Rectangle methodsFor: 'FMP' stamp: 'RAA 6/1/1999 17:41'!
deltaToEnsureInOrCentered: r extra: aNumber

	| dX dY halfXDiff halfYDiff |
	dX := dY := 0.
	halfXDiff := (r width - self width * aNumber) truncated.
	halfYDiff := (r height - self height  * aNumber) truncated.
	self left < r left
		ifTrue: [dX := self left - r left - halfXDiff]
		ifFalse: [self right > r right ifTrue: [dX := self right - r right + halfXDiff]].
	self top < r top
		ifTrue: [dY := self top - r top - halfYDiff]
		ifFalse: [self bottom > r bottom ifTrue: [dY := self bottom - r bottom + halfYDiff]].
	^dX @ dY
! !

!Rectangle methodsFor: 'rectangle functions' stamp: ''!
encompass: aPoint 
	"Answer a Rectangle that contains both the receiver and aPoint.  5/30/96 sw"

	^ Rectangle 
		origin: (origin min: aPoint)
		corner: (corner max:  aPoint)! !

!Rectangle methodsFor: 'rectangle functions' stamp: 'md 10/4/2005 14:42'!
expandBy: delta 
	"Answer a Rectangle that is outset from the receiver by delta. delta is a 
	Rectangle, Point, or scalar."

	(delta isRectangle)
		ifTrue: [^Rectangle 
					origin: origin - delta origin 
					corner: corner + delta corner]
		ifFalse: [^Rectangle 
					origin: origin - delta 
					corner: corner + delta]! !

!Rectangle methodsFor: 'truncation and round off' stamp: 'nice 2/5/2006 16:52'!
expanded
	"Answer a Rectangle whose origin and corner are rounded to integers.
	Rounding is done by upper value on origin and lower value on corner so that
	self is inside rounded rectangle."

	^Rectangle origin: origin floor corner: corner ceiling! !

!Rectangle methodsFor: 'truncation and round off' stamp: 'nice 2/5/2006 16:51'!
expandTo: grid
	"Answer a Rectangle whose origin and corner are rounded to grid x and grid y.
	Rounding is done by upper value on origin and lower value on corner so that
	self is inside rounded rectangle."

	^Rectangle origin: (origin roundDownTo: grid)
				corner: (corner roundUpTo: grid)! !

!Rectangle methodsFor: 'rectangle functions' stamp: 'md 10/4/2005 14:42'!
extendBy: delta 
	"Answer a Rectangle with the same origin as the receiver, but whose corner is offset by delta. delta is a 
	Rectangle, Point, or scalar."

	(delta isRectangle)
		ifTrue: [^Rectangle 
					origin: origin
					corner: corner + delta corner]
		ifFalse: [^Rectangle 
					origin: origin
					corner: corner + delta]! !

!Rectangle methodsFor: 'accessing' stamp: 'bp 4/2/2010 21:00'!
extent
	"Answer a point with the receiver's 
	width @ the receiver's height."

	^corner - origin! !

!Rectangle methodsFor: 'transforming' stamp: 'nice 6/20/2010 21:27'!
flipBy: direction centerAt: aPoint 
	"Return a copy flipped #vertical or #horizontal, about aPoint."
	| futureOrigin futureCorner |
	direction == #horizontal
		ifTrue:
			[futureOrigin := self topRight.
			futureCorner := self bottomLeft]
		ifFalse: [direction == #vertical
			ifTrue:
				[futureOrigin := self bottomLeft.
				futureCorner := self topRight]
			ifFalse: [self error: 'unrecognizable direction']].
	^ (futureOrigin flipBy: direction centerAt: aPoint)
		corner: (futureCorner flipBy: direction centerAt: aPoint)! !

!Rectangle methodsFor: 'truncation and round off' stamp: 'mt 7/13/2016 12:10'!
floor
	"Answer the integer rectange to the topleft of receiver.
	Return reciever if it already and integerRectange."

	self isIntegerRectangle ifTrue: [ ^ self ] .

	^origin floor corner: corner floor! !

!Rectangle methodsFor: 'rectangle functions' stamp: 'di 10/21/1998 16:11'!
forPoint: aPoint closestSideDistLen: sideDistLenBlock
	"Evaluate the block with my side (symbol) closest to aPoint,
		the approx distance of aPoint from that side, and
		the length of the side (or 0 if aPoint is beyond the side)"
	| side |
	side := self sideNearestTo: aPoint.
	side == #right ifTrue:
		[^ sideDistLenBlock value: side value: (self right - aPoint x) abs
			value: ((aPoint y between: self top and: self bottom)
						ifTrue: [self height] ifFalse: [0])].
	side == #left ifTrue:
		[^ sideDistLenBlock value: side value: (self left - aPoint x) abs
			value: ((aPoint y between: self top and: self bottom)
						ifTrue: [self height] ifFalse: [0])].
	side == #bottom ifTrue:
		[^ sideDistLenBlock value: side value: (self bottom - aPoint y) abs
			value: ((aPoint x between: self left and: self right)
						ifTrue: [self width] ifFalse: [0])].
	side == #top ifTrue:
		[^ sideDistLenBlock value: side value: (self top - aPoint y) abs
			value: ((aPoint x between: self left and: self right)
						ifTrue: [self width] ifFalse: [0])].! !

!Rectangle methodsFor: 'comparing' stamp: ''!
hash
	"Hash is reimplemented because = is implemented."

	^origin hash bitXor: corner hash! !

!Rectangle methodsFor: 'testing' stamp: ''!
hasPositiveExtent
	^ (corner x > origin x) and: [corner y > origin y]! !

!Rectangle methodsFor: 'accessing' stamp: ''!
height
	"Answer the height of the receiver."

	^corner y - origin y! !

!Rectangle methodsFor: 'accessing' stamp: ''!
innerCorners
	"Return an array of inner corner points,
	ie, the most extreme pixels included,
	in the order of a quadrilateral spec for WarpBlt"
	| r1 |
	r1 := self topLeft corner: self bottomRight - (1@1).
	^ Array with: r1 topLeft with: r1 bottomLeft with: r1 bottomRight with: r1 topRight! !

!Rectangle methodsFor: 'rectangle functions' stamp: 'md 10/2/2005 21:51'!
insetBy: delta 
	"Answer a Rectangle that is inset from the receiver by delta. delta is a 
	Rectangle, Point, or scalar."

	
	(delta isRectangle)
		ifTrue: [^Rectangle 
					origin: origin + delta origin 
					corner: corner - delta corner]
		ifFalse: [^Rectangle 
					origin: origin + delta 
					corner: corner - delta]! !

!Rectangle methodsFor: 'rectangle functions' stamp: ''!
insetOriginBy: originDeltaPoint cornerBy: cornerDeltaPoint 
	"Answer a Rectangle that is inset from the receiver by a given amount in 
	the origin and corner."

	^Rectangle
		origin: origin + originDeltaPoint
		corner: corner - cornerDeltaPoint! !

!Rectangle methodsFor: 'testing' stamp: 'nice 1/15/2013 02:04'!
intersects: aRectangle 
	"Answer whether aRectangle intersects the receiver anywhere."
	"Optimized; old code answered:
		(origin max: aRectangle origin) < (corner min: aRectangle corner)"

	| rOrigin rCorner |
	rOrigin := aRectangle origin.
	rCorner := aRectangle corner.
	rCorner x <= origin x	ifTrue: [^ false].
	rCorner y <= origin y	ifTrue: [^ false].
	rOrigin x >= corner x	ifTrue: [^ false].
	rOrigin y >= corner y	ifTrue: [^ false].
"None of the two rectangle shall be empty"
	corner x < origin x	ifTrue: [^ false].
	corner y < origin y	ifTrue: [^ false].
	rCorner x < rOrigin x	ifTrue: [^ false].
	rCorner y < rOrigin y	ifTrue: [^ false].
	^ true
! !

!Rectangle methodsFor: 'rectangle functions' stamp: 'ar 11/12/2000 19:10'!
intersect: aRectangle 
	"Answer a Rectangle that is the area in which the receiver overlaps with 
	aRectangle. Optimized for speed; old code read:
		^Rectangle 
			origin: (origin max: aRectangle origin)
			corner: (corner min: aRectangle corner)
	"
	| aPoint left right top bottom |
	aPoint := aRectangle origin.
	aPoint x > origin x ifTrue:[left := aPoint x] ifFalse:[left := origin x].
	aPoint y > origin y ifTrue:[top := aPoint y] ifFalse:[top := origin y].
	aPoint := aRectangle corner.
	aPoint x < corner x ifTrue:[right := aPoint x] ifFalse:[right := corner x].
	aPoint y < corner y ifTrue:[bottom := aPoint y] ifFalse:[bottom := corner y].
	^Rectangle
		origin: (left@top)
		corner: (right@bottom)
! !

!Rectangle methodsFor: 'truncation and round off' stamp: 'mt 7/13/2016 12:10'!
isIntegerRectangle
	"Answer true if all component of receiver are integral."

	^origin isIntegerPoint and: [ corner isIntegerPoint ]! !

!Rectangle methodsFor: 'testing' stamp: 'md 10/2/2005 21:51'!
isRectangle
	^true! !

!Rectangle methodsFor: 'testing' stamp: ''!
isTall
	^ self height > self width! !

!Rectangle methodsFor: 'testing' stamp: ''!
isWide
	^ self width > self height! !

!Rectangle methodsFor: 'testing' stamp: 'ar 10/29/2000 19:03'!
isZero
	^origin isZero and:[corner isZero]! !

!Rectangle methodsFor: 'accessing' stamp: ''!
left
	"Answer the position of the receiver's left vertical line."

	^origin x! !

!Rectangle methodsFor: 'accessing' stamp: ''!
leftCenter
	"Answer the point at the center of the receiver's left vertical line."

	^self left @ self center y! !

!Rectangle methodsFor: 'accessing' stamp: 'ar 10/26/2000 22:16'!
left: aNumber
	^aNumber @ origin y corner: corner! !

!Rectangle methodsFor: 'rectangle functions' stamp: ''!
merge: aRectangle 
	"Answer a Rectangle that contains both the receiver and aRectangle."

	^Rectangle 
		origin: (origin min: aRectangle origin)
		corner: (corner max: aRectangle corner)! !

!Rectangle methodsFor: 'transforming' stamp: 'dtl 12/28/2009 13:13'!
newRectButtonPressedDo: newRectBlock 
	"Track the outline of a new rectangle until mouse button 
	changes. newFrameBlock produces each new rectangle from the 
	previous. Only tracks while mouse is down."
	| rect newRect buttonNow delay |
	delay := Delay forMilliseconds: 10.
	buttonNow := Sensor anyButtonPressed.
	rect := self.
	Display
		border: rect
		width: 2
		rule: Form reverse
		fillColor: Color gray.
	[buttonNow]
		whileTrue: [delay wait.
			buttonNow := Sensor anyButtonPressed.
			newRect := newRectBlock value: rect.
			newRect = rect
				ifFalse: [Display
						border: rect
						width: 2
						rule: Form reverse
						fillColor: Color gray.
					Display
						border: newRect
						width: 2
						rule: Form reverse
						fillColor: Color gray.
					rect := newRect]].
	Display
		border: rect
		width: 2
		rule: Form reverse
		fillColor: Color gray.
	Project current pointerMoved. 
	Sensor processEvent: Sensor createMouseEvent.
	^ rect! !

!Rectangle methodsFor: 'transforming' stamp: 'dtl 12/28/2009 13:12'!
newRectFrom: newRectBlock
	"Track the outline of a new rectangle until mouse button changes.
	newFrameBlock produces each new rectangle from the previous"
	| rect newRect buttonStart buttonNow delay |
	delay := Delay forMilliseconds: 10.
	buttonStart := buttonNow := Sensor anyButtonPressed.
	rect := self.
	Display border: rect width: 2 rule: Form reverse fillColor: Color gray.
	[buttonNow == buttonStart] whileTrue: 
		[delay wait.
		buttonNow := Sensor anyButtonPressed.
		newRect := newRectBlock value: rect.
		newRect = rect ifFalse:
			[Display border: rect width: 2 rule: Form reverse fillColor: Color gray.
			Display border: newRect width: 2 rule: Form reverse fillColor: Color gray.
			rect := newRect]].
	Display border: rect width: 2 rule: Form reverse fillColor: Color gray.
	Project current pointerMoved. 
	Sensor processEvent: Sensor createMouseEvent.
	^ rect! !

!Rectangle methodsFor: 'accessing' stamp: ''!
origin
	"Answer the point at the top left corner of the receiver."

	^origin! !

!Rectangle methodsFor: 'rectangle functions' stamp: 'md 10/4/2005 14:41'!
outsetBy: delta 
	"Answer a Rectangle that is outset from the receiver by delta. delta is a 
	Rectangle, Point, or scalar."

	(delta isRectangle)
		ifTrue: [^Rectangle 
					origin: origin - delta origin 
					corner: corner + delta corner]
		ifFalse: [^Rectangle 
					origin: origin - delta 
					corner: corner + delta]! !

!Rectangle methodsFor: 'rectangle functions' stamp: 'di 4/30/1998 11:22'!
pointNearestTo: aPoint
	"Return the point on my border closest to aPoint"
	| side |
	(self containsPoint: aPoint)
		ifTrue:
			[side := self sideNearestTo: aPoint.
			side == #right ifTrue: [^ self right @ aPoint y].
			side == #left ifTrue: [^ self left @ aPoint y].
			side == #bottom ifTrue: [^ aPoint x @ self bottom].
			side == #top ifTrue: [^ aPoint x @ self top]]
		ifFalse:
			[^ aPoint adhereTo: self]! !

!Rectangle methodsFor: 'printing' stamp: ''!
printOn: aStream 
	"Refer to the comment in Object|printOn:."

	origin printOn: aStream.
	aStream nextPutAll: ' corner: '.
	corner printOn: aStream! !

!Rectangle methodsFor: 'rectangle functions' stamp: ''!
quickMerge: aRectangle 
	"Answer the receiver if it encloses the given rectangle or the merge of the two rectangles if it doesn't. THis method is an optimization to reduce extra rectangle creations."

	| useRcvr rOrigin rCorner minX maxX minY maxY |
	useRcvr := true.
	rOrigin := aRectangle topLeft.
	rCorner := aRectangle bottomRight.
	minX := rOrigin x < origin x ifTrue: [useRcvr := false. rOrigin x] ifFalse: [origin x].
	maxX := rCorner x > corner x ifTrue: [useRcvr := false. rCorner x] ifFalse: [corner x].
	minY := rOrigin y < origin y ifTrue: [useRcvr := false. rOrigin y] ifFalse: [origin y].
	maxY := rCorner y > corner y ifTrue: [useRcvr := false. rCorner y] ifFalse: [corner y].

	useRcvr
		ifTrue: [^ self]
		ifFalse: [^ Rectangle origin: minX@minY corner: maxX@maxY].
! !

!Rectangle methodsFor: 'rectangle functions' stamp: 'di 10/20/97 23:01'!
rectanglesAt: y height: ht
	(y+ht) > self bottom ifTrue: [^ Array new].
	^ Array with: (origin x @ y corner: corner x @ (y+ht))! !

!Rectangle methodsFor: 'accessing' stamp: ''!
right
	"Answer the position of the receiver's right vertical line."

	^corner x! !

!Rectangle methodsFor: 'accessing' stamp: ''!
rightCenter
	"Answer the point at the center of the receiver's right vertical line."

	^self right @ self center y! !

!Rectangle methodsFor: 'accessing' stamp: 'ar 10/26/2000 22:17'!
right: aNumber
	^origin corner: aNumber @ corner y! !

!Rectangle methodsFor: 'transforming' stamp: 'nice 6/20/2010 22:01'!
rotateBy: direction centerAt: aPoint
	"Return a copy rotated #right, #left, or #pi about aPoint"
	| futureOrigin futureCorner |
	direction == #pi
		ifTrue:
			[futureOrigin := self corner.
			futureCorner := self origin]
		ifFalse: [direction == #left
			ifTrue:
				[futureOrigin := self topRight.
				futureCorner := self bottomLeft]
			ifFalse: [direction == #right
				ifTrue:
					[futureOrigin := self bottomLeft.
					futureCorner := self topRight]
				ifFalse: [self error: 'unrecognizable direction']]].
	^ (futureOrigin rotateBy: direction centerAt: aPoint)
		corner: (futureCorner rotateBy: direction centerAt: aPoint)! !

!Rectangle methodsFor: 'truncation and round off' stamp: 'fbs 12/17/2010 07:24'!
rounded
	"Answer a Rectangle whose origin and corner are rounded."

	^Rectangle origin: origin rounded extent: self extent rounded! !

!Rectangle methodsFor: 'truncation and round off' stamp: 'nice 2/5/2006 16:53'!
roundTo: grid
	"Answer a Rectangle whose origin and corner are rounded to grid x and grid y."

	^Rectangle origin: (origin roundTo: grid)
				corner: (corner roundTo: grid)! !

!Rectangle methodsFor: 'transforming' stamp: ''!
scaleBy: scale 
	"Answer a Rectangle scaled by scale, a Point or a scalar."

	^Rectangle origin: origin * scale corner: corner * scale! !

!Rectangle methodsFor: 'transforming' stamp: ''!
scaleFrom: rect1 to: rect2
	"Produce a rectangle stretched according to the stretch from rect1 to rect2"
	^ (origin scaleFrom: rect1 to: rect2)
		corner: (corner scaleFrom: rect1 to: rect2)! !

!Rectangle methodsFor: 'private' stamp: ''!
setOrigin: topLeft corner: bottomRight
	origin := topLeft.
	corner := bottomRight! !

!Rectangle methodsFor: 'rectangle functions' stamp: 'di 10/21/1998 15:09'!
sideNearestTo: aPoint
	| distToLeft distToRight distToTop distToBottom closest side |
	distToLeft := aPoint x - self left.
	distToRight := self right - aPoint x.
	distToTop := aPoint y - self top.
	distToBottom := self bottom - aPoint y.
	closest := distToLeft. side := #left.
	distToRight < closest ifTrue: [closest := distToRight. side := #right].
	distToTop < closest ifTrue: [closest := distToTop. side := #top].
	distToBottom < closest ifTrue: [closest := distToBottom. side := #bottom].
	^ side
"
 | r | r := Rectangle fromUser.
Display border: r width: 1.
[Sensor anyButtonPressed] whileFalse:
	[(r sideNearestTo: Sensor cursorPoint) , '      ' displayAt: 0@0]
"! !

!Rectangle methodsFor: 'transforming' stamp: 'sw 5/21/96'!
squishedWithin: aRectangle
	"Return an adjustment of the receiver that fits within aRectangle by reducing its size, not by changing its origin.  "

	^ origin corner: (corner min: aRectangle bottomRight)

"(50 @ 50 corner: 160 @ 100) squishedWithin:  (20 @ 10 corner: 90 @ 85)"
! !

!Rectangle methodsFor: 'printing' stamp: 'nice 11/1/2009 20:27'!
storeOn: aStream 
	"printed form is good for storing too"
	
	aStream nextPut: $(.
	self printOn: aStream.
	aStream nextPut: $).! !

!Rectangle methodsFor: 'rectangle functions' stamp: 'nice 12/27/2009 22:38'!
swallow: aRectangle 
	"Modify the receiver so that it contains aRectangle."

	origin := origin min: aRectangle origin.
	corner := corner max: aRectangle corner! !

!Rectangle methodsFor: 'accessing' stamp: ''!
top
	"Answer the position of the receiver's top horizontal line."

	^origin y! !

!Rectangle methodsFor: 'accessing' stamp: ''!
topCenter
	"Answer the point at the center of the receiver's top horizontal line."

	^self center x @ self top! !

!Rectangle methodsFor: 'accessing' stamp: ''!
topLeft
	"Answer the point at the top left corner of the receiver's top horizontal line."

	^origin
! !

!Rectangle methodsFor: 'accessing' stamp: ''!
topRight
	"Answer the point at the top right corner of the receiver's top horizontal 
	line."

	^corner x @ origin y! !

!Rectangle methodsFor: 'accessing' stamp: 'ar 10/26/2000 22:17'!
top: aNumber
	^origin x @ aNumber corner: corner! !

!Rectangle methodsFor: 'transforming' stamp: ''!
translateBy: factor 
	"Answer a Rectangle translated by factor, a Point or a scalar."

	^Rectangle origin: origin + factor corner: corner + factor! !

!Rectangle methodsFor: 'transforming' stamp: 'nk 7/5/2003 08:31'!
translatedAndSquishedToBeWithin: aRectangle
	"Return an adjustment of the receiver that fits within aRectangle by
		- translating it to be within aRectangle if necessary, then
		- reducing its size, if necessary"

	^ (self translatedToBeWithin: aRectangle) squishedWithin: aRectangle! !

!Rectangle methodsFor: 'rectangle functions' stamp: ''!
translatedToBeWithin: aRectangle
	"Answer a copy of the receiver that does not extend beyond aRectangle.  7/8/96 sw"

	^ self translateBy: (self amountToTranslateWithin: aRectangle)! !

!Rectangle methodsFor: 'truncation and round off' stamp: 'jm 5/29/1998 15:53'!
truncated
	"Answer a Rectangle whose origin and corner have any fractional parts removed. Answer the receiver if its coordinates are already integral."

	(origin x isInteger and:
	[origin y isInteger and:
	[corner x isInteger and:
	[corner y isInteger]]])
		ifTrue: [^ self].

	^ Rectangle origin: origin truncated corner: corner truncated
! !

!Rectangle methodsFor: 'truncation and round off' stamp: ''!
truncateTo: grid
	"Answer a Rectangle whose origin and corner are truncated to grid x and grid y."

	^Rectangle origin: (origin truncateTo: grid)
				corner: (corner truncateTo: grid)! !

!Rectangle methodsFor: 'accessing' stamp: ''!
width
	"Answer the width of the receiver."

	^corner x - origin x! !

!Rectangle methodsFor: 'rectangle functions' stamp: ''!
withBottom: y 
	"Return a copy of me with a different bottom y"
	^ origin x @ origin y corner: corner x @ y! !

!Rectangle methodsFor: 'rectangle functions' stamp: ''!
withHeight: height 
	"Return a copy of me with a different height"
	^ origin corner: corner x @ (origin y + height)! !

!Rectangle methodsFor: 'rectangle functions' stamp: ''!
withLeft: x 
	"Return a copy of me with a different left x"
	^ x @ origin y corner: corner x @ corner y! !

!Rectangle methodsFor: 'rectangle functions' stamp: ''!
withRight: x 
	"Return a copy of me with a different right x"
	^ origin x @ origin y corner: x @ corner y! !

!Rectangle methodsFor: 'rectangle functions' stamp: 'di 9/8/1999 21:25'!
withSideOrCorner: side setToPoint: newPoint
	"Return a copy with side set to newPoint"

	^ self withSideOrCorner: side setToPoint: newPoint minExtent: 0@0! !

!Rectangle methodsFor: 'rectangle functions' stamp: 'bf 9/10/1999 16:16'!
withSideOrCorner: side setToPoint: newPoint minExtent: minExtent
	"Return a copy with side set to newPoint"
	^self withSideOrCorner: side setToPoint: newPoint minExtent: minExtent
		limit: ((#(left top) includes: side) ifTrue: [SmallInteger minVal] ifFalse: [SmallInteger maxVal])! !

!Rectangle methodsFor: 'rectangle functions' stamp: 'bf 9/10/1999 16:07'!
withSideOrCorner: side setToPoint: newPoint minExtent: minExtent limit: limit
	"Return a copy with side set to newPoint"
	side = #top ifTrue: [^ self withTop: (newPoint y min: corner y - minExtent y max: limit + minExtent y)].
	side = #bottom ifTrue: [^ self withBottom: (newPoint y min: limit - minExtent y max: origin y + minExtent y)].
	side = #left ifTrue: [^ self withLeft: (newPoint x min: corner x - minExtent x max: limit + minExtent x)].
	side = #right ifTrue: [^ self withRight: (newPoint x min: limit - minExtent x max: origin x + minExtent x)].
	side = #topLeft ifTrue: [^ (newPoint min: corner - minExtent) corner: self bottomRight].
	side = #bottomRight ifTrue: [^ self topLeft corner: (newPoint max: origin + minExtent)].
	side = #bottomLeft ifTrue: [^ self topRight rect: ((newPoint x min: corner x - minExtent x) @ (newPoint y max: origin y + minExtent y))].
	side = #topRight ifTrue: [^ self bottomLeft rect: ((newPoint x max: origin x + minExtent x) @ (newPoint y min: corner y - minExtent y))].! !

!Rectangle methodsFor: 'rectangle functions' stamp: ''!
withSide: side setTo: value  "return a copy with side set to value"
	^ self perform: (#(withLeft: withRight: withTop: withBottom: )
							at: (#(left right top bottom) indexOf: side))
		with: value! !

!Rectangle methodsFor: 'rectangle functions' stamp: ''!
withTop: y 
	"Return a copy of me with a different top y"
	^ origin x @ y corner: corner x @ corner y! !

!Rectangle methodsFor: 'rectangle functions' stamp: ''!
withWidth: width 
	"Return a copy of me with a different width"
	^ origin corner: (origin x + width) @ corner y! !

!Rectangle methodsFor: 'comparing' stamp: ''!
= aRectangle 
	"Answer true if the receiver's species, origin and corner match aRectangle's."

	self species = aRectangle species
		ifTrue: [^origin = aRectangle origin and: [corner = aRectangle corner]]
		ifFalse: [^false]! !

Object subclass: #TextComposer
	instanceVariableNames: 'lines maxRightX currentY scanner possibleSlide nowSliding prevIndex prevLines currCharIndex startCharIndex stopCharIndex deltaCharIndex theText theContainer isFirstLine theTextStyle defaultLineHeight actualHeight wantsColumnBreaks'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Text'!

!TextComposer class methodsFor: 'as yet unclassified' stamp: 'tpr 9/30/2013 16:04'!
characterForColumnBreak

	^Character characterForColumnBreak! !

!TextComposer methodsFor: 'as yet unclassified' stamp: 'RAA 5/4/2001 18:09'!
addNullLineForIndex: index
"This awful bit is to ensure that if we have scanned all the text and the last character is a CR that there is a null line at the end of lines. Sometimes this was not happening which caused anomalous selections when selecting all the text. This is implemented as a post-composition fixup because I couldn't figure out where to put it in the main logic."

	| oldLastLine r |

	oldLastLine := lines last.
	oldLastLine last - oldLastLine first >= 0 ifFalse: [^self].
	oldLastLine last = (index - 1) ifFalse: [^self].

	r := oldLastLine left @ oldLastLine bottom 
				extent: 0@(oldLastLine bottom - oldLastLine top).
	"Even though we may be below the bottom of the container,
	it is still necessary to compose the last line for consistency..."

	self addNullLineWithIndex: index andRectangle: r.
! !

!TextComposer methodsFor: 'as yet unclassified' stamp: 'RAA 5/5/2001 11:05'!
addNullLineWithIndex: index andRectangle: r

	lines addLast: (
		(
			TextLine 
				start: index 
				stop: index - 1
				internalSpaces: 0 
				paddingWidth: 0
		)
			rectangle: r;
			lineHeight: defaultLineHeight baseline: theTextStyle baseline
	)
! !

!TextComposer methodsFor: 'as yet unclassified' stamp: 'RAA 5/4/2001 11:33'!
checkIfReadyToSlide

	"Check whether we are now in sync with previously composed lines"

	(possibleSlide and: [currCharIndex > stopCharIndex]) ifFalse: [^self].

	[prevIndex < prevLines size
		and: [(prevLines at: prevIndex) first < (currCharIndex - deltaCharIndex)]]
			whileTrue: [prevIndex := prevIndex + 1].

	(prevLines at: prevIndex) first = (currCharIndex - deltaCharIndex) ifTrue: [
		"Yes -- next line will have same start as prior line."
		prevIndex := prevIndex - 1.
		possibleSlide := false.
		nowSliding := true
	] ifFalse: [
		prevIndex = prevLines size ifTrue: [
			"Weve reached the end of prevLines, so no use to keep looking for lines to slide."
			possibleSlide := false
		]
	]! !

!TextComposer methodsFor: 'as yet unclassified' stamp: 'RAA 5/6/2001 14:48'!
composeAllLines

	[currCharIndex <= theText size and: 
			[(currentY + defaultLineHeight) <= theContainer bottom]] whileTrue: [

		nowSliding ifTrue: [
			self slideOneLineDown ifNil: [^nil].
		] ifFalse: [
			self composeOneLine ifNil: [^nil].
		]
	].
! !

!TextComposer methodsFor: 'as yet unclassified' stamp: 'cmm 2/12/2012 17:00'!
composeAllRectangles: rectangles

	| charIndexBeforeLine numberOfLinesBefore reasonForStopping |

	actualHeight := defaultLineHeight.
	charIndexBeforeLine := currCharIndex.
	numberOfLinesBefore := lines size.
	reasonForStopping := self composeEachRectangleIn: rectangles.

	currentY := currentY + actualHeight.
	currentY > theContainer bottom ifTrue: [
		"Oops -- the line is really too high to fit -- back out"
		currCharIndex := charIndexBeforeLine.
		lines size - numberOfLinesBefore timesRepeat: [lines removeLast].
		^self
	].
	
	"It's OK -- the line still fits."
	maxRightX := maxRightX max: scanner rightX.
	1 to: rectangles size - 1 do: [ :i | |lineIndex|
		"Adjust heights across rectangles if necessary"
		lineIndex:=lines size - rectangles size + i.
		(lines size between: 1 and: lineIndex) ifTrue: 
			[(lines at: lineIndex)
				lineHeight: lines last lineHeight
				baseline: lines last baseline] 
	].
	isFirstLine := false.
	reasonForStopping == #columnBreak ifTrue: [^nil].
	currCharIndex > theText size ifTrue: [
		^nil		"we are finished composing"
	].
	! !

!TextComposer methodsFor: 'as yet unclassified' stamp: 'tpr 9/30/2013 16:04'!
composeEachRectangleIn: rectangles

	| myLine lastChar |

	1 to: rectangles size do: [:i | 
		currCharIndex <= theText size ifFalse: [^false].
		myLine := scanner 
			composeFrom: currCharIndex 
			inRectangle: (rectangles at: i)				
			firstLine: isFirstLine 
			leftSide: i=1 
			rightSide: i=rectangles size.
		lines addLast: myLine.
		actualHeight := actualHeight max: myLine lineHeight.  "includes font changes"
		currCharIndex := myLine last + 1.
		lastChar := theText at: myLine last.
		(CharacterSet crlf includes: lastChar) ifTrue: [^#cr].
		wantsColumnBreaks ifTrue: [
			lastChar = Character characterForColumnBreak ifTrue: [^#columnBreak].
		].
	].
	^false! !

!TextComposer methodsFor: 'as yet unclassified' stamp: 'topa 9/16/2014 17:13'!
composeLinesFrom: argStart to: argStop delta: argDelta into: argLinesCollection priorLines: argPriorLines atY: argStartY textStyle: argTextStyle text: argText container: argContainer wantsColumnBreaks: argWantsColumnBreaks

	wantsColumnBreaks := argWantsColumnBreaks.
	lines := argLinesCollection.
	theTextStyle := argTextStyle.
	theText := argText.
	theContainer := argContainer.
	deltaCharIndex := argDelta.
	currCharIndex := startCharIndex := argStart.
	stopCharIndex := argStop.
	prevLines := argPriorLines.
	currentY := argStartY.
	maxRightX := theContainer left.
	possibleSlide := stopCharIndex < theText size and: [theContainer isMemberOf: Rectangle].
	nowSliding := false.
	prevIndex := 1.
	"choose an appropriate scanner - should go away soon, when they can be unified"
	scanner := CompositionScanner new.
	scanner text: theText textStyle: theTextStyle.
	scanner wantsColumnBreaks: wantsColumnBreaks.
	defaultLineHeight := scanner computeDefaultLineHeight.
	isFirstLine := true.
	self composeAllLines.
	isFirstLine ifTrue: ["No space in container or empty text"
		self 
			addNullLineWithIndex: startCharIndex
			andRectangle: (theContainer left @ theContainer top extent: 0@defaultLineHeight)
	] ifFalse: [
		(lines last last = theText size and: [scanner doesTheLineBreaksAfterLastChar])
			ifTrue: [self addNullLineForIndex: theText size + 1]
	].
	^{lines asArray. maxRightX}
! !

!TextComposer methodsFor: 'as yet unclassified' stamp: 'dgd 2/22/2003 13:31'!
composeOneLine
	| rectangles |
	rectangles := theContainer rectanglesAt: currentY height: defaultLineHeight.
	rectangles notEmpty 
		ifTrue: [(self composeAllRectangles: rectangles) ifNil: [^nil]]
		ifFalse: [currentY := currentY + defaultLineHeight].
	self checkIfReadyToSlide! !

!TextComposer methodsFor: 'as yet unclassified' stamp: 'tpr 9/30/2013 16:04'!
slideOneLineDown

	| priorLine |

	"Having detected the end of rippling recoposition, we are only sliding old lines"
	prevIndex < prevLines size ifFalse: [
		"There are no more prevLines to slide."
		^nowSliding := possibleSlide := false
	].

	"Adjust and re-use previously composed line"
	prevIndex := prevIndex + 1.
	priorLine := (prevLines at: prevIndex)
				slideIndexBy: deltaCharIndex andMoveTopTo: currentY.
	lines addLast: priorLine.
	currentY := priorLine bottom.
	currCharIndex := priorLine last + 1.
	wantsColumnBreaks ifTrue: [
		priorLine first to: priorLine last do: [ :i |
			(theText at: i) = Character characterForColumnBreak ifTrue: [
				nowSliding := possibleSlide := false.
				^nil
			].
		].
	].
! !

Object subclass: #TextPrinter
	instanceVariableNames: 'form para paperSize landscape resolution depth offset columns docTitle noHeader noFooter'
	classVariableNames: 'DefaultPaperSize DefaultTextPrinter'
	poolDictionaries: ''
	category: 'Graphics-Text'!

!TextPrinter class methodsFor: 'accessing' stamp: 'ar 4/30/98 18:31'!
defaultPaperSize
	^DefaultPaperSize! !

!TextPrinter class methodsFor: 'accessing' stamp: 'ar 4/30/98 18:31'!
defaultPaperSize: aPoint
	DefaultPaperSize := aPoint! !

!TextPrinter class methodsFor: 'accessing' stamp: 'dew 3/7/2000 20:39'!
defaultTextPrinter
	"This is the global default TextPrinter instance."
	DefaultTextPrinter isNil ifTrue: [DefaultTextPrinter := self new].
	^DefaultTextPrinter! !

!TextPrinter class methodsFor: 'class initialization' stamp: 'ar 4/30/98 18:30'!
initialize
	"TextPrinter initialize"
	self defaultPaperSize: self paperSizeA4.! !

!TextPrinter class methodsFor: 'paper sizes' stamp: 'ar 4/30/98 18:30'!
mm2in: aPoint
	"Convert aPoint from millimeters to inches"
	^aPoint / 25.4! !

!TextPrinter class methodsFor: 'paper sizes' stamp: 'ar 4/30/98 18:27'!
paperSize10x14
	^10.0@14.0! !

!TextPrinter class methodsFor: 'paper sizes' stamp: 'ar 4/30/98 18:27'!
paperSize11x17
	^11.0@17.0! !

!TextPrinter class methodsFor: 'paper sizes' stamp: 'ar 4/30/98 18:27'!
paperSizeA3
	^self mm2in: 297@420! !

!TextPrinter class methodsFor: 'paper sizes' stamp: 'ar 4/30/98 18:27'!
paperSizeA4
	^self mm2in: 210@297! !

!TextPrinter class methodsFor: 'paper sizes' stamp: 'ar 4/30/98 18:27'!
paperSizeA5
	^self mm2in: 148@210! !

!TextPrinter class methodsFor: 'paper sizes' stamp: 'ar 4/30/98 18:27'!
paperSizeB4
	^self mm2in: 250@354! !

!TextPrinter class methodsFor: 'paper sizes' stamp: 'ar 4/30/98 18:27'!
paperSizeB5
	^self mm2in: 182@257! !

!TextPrinter class methodsFor: 'paper sizes' stamp: 'ar 4/30/98 18:28'!
paperSizeCSheet
	^17.0@22.0! !

!TextPrinter class methodsFor: 'paper sizes' stamp: 'ar 4/30/98 18:28'!
paperSizeDSheet
	^22.0@34.0! !

!TextPrinter class methodsFor: 'paper sizes' stamp: 'ar 4/30/98 18:28'!
paperSizeEnvelope10
	^4.125@9.5
! !

!TextPrinter class methodsFor: 'paper sizes' stamp: 'ar 4/30/98 18:28'!
paperSizeEnvelope11
	^4.5@10.375! !

!TextPrinter class methodsFor: 'paper sizes' stamp: 'ar 4/30/98 18:28'!
paperSizeEnvelope12
	^4.75@11! !

!TextPrinter class methodsFor: 'paper sizes' stamp: 'ar 4/30/98 18:28'!
paperSizeEnvelope14
	^5.0@11.5! !

!TextPrinter class methodsFor: 'paper sizes' stamp: 'ar 4/30/98 18:28'!
paperSizeEnvelope9
	^3.875@8.875! !

!TextPrinter class methodsFor: 'paper sizes' stamp: 'ar 4/30/98 18:28'!
paperSizeEnvelopeB4
	^self mm2in: 250@353! !

!TextPrinter class methodsFor: 'paper sizes' stamp: 'ar 4/30/98 18:28'!
paperSizeEnvelopeB5
	^self mm2in: 176@250! !

!TextPrinter class methodsFor: 'paper sizes' stamp: 'ar 4/30/98 18:28'!
paperSizeEnvelopeB6
	^self mm2in: 176@125! !

!TextPrinter class methodsFor: 'paper sizes' stamp: 'ar 4/30/98 18:28'!
paperSizeEnvelopeC3
	^self mm2in: 324@458! !

!TextPrinter class methodsFor: 'paper sizes' stamp: 'ar 4/30/98 18:29'!
paperSizeEnvelopeC4
	^self mm2in: 229@324! !

!TextPrinter class methodsFor: 'paper sizes' stamp: 'ar 4/30/98 18:29'!
paperSizeEnvelopeC5
	^self mm2in: 162@229! !

!TextPrinter class methodsFor: 'paper sizes' stamp: 'ar 4/30/98 18:29'!
paperSizeEnvelopeC6
	^self mm2in: 114@162! !

!TextPrinter class methodsFor: 'paper sizes' stamp: 'ar 4/30/98 18:29'!
paperSizeEnvelopeC65
	^self mm2in: 114@229! !

!TextPrinter class methodsFor: 'paper sizes' stamp: 'ar 4/30/98 18:29'!
paperSizeESheet
	^34.0@44.0! !

!TextPrinter class methodsFor: 'paper sizes' stamp: 'ar 4/30/98 18:29'!
paperSizeFanfoldGerman
	"German standard fanfold"
	^8.5@12.0! !

!TextPrinter class methodsFor: 'paper sizes' stamp: 'ar 4/30/98 18:29'!
paperSizeFanfoldLegalGerman
	"German legal fanfold"
	^8.5@13.0! !

!TextPrinter class methodsFor: 'paper sizes' stamp: 'ar 4/30/98 18:29'!
paperSizeFanfoldUS
	"US standard fanfold"
	^14.875@11.0! !

!TextPrinter class methodsFor: 'paper sizes' stamp: 'ar 4/30/98 18:29'!
paperSizeFolio
	^8.5@13.0! !

!TextPrinter class methodsFor: 'paper sizes' stamp: 'ar 4/30/98 18:29'!
paperSizeLegal
	^8.5@14.0! !

!TextPrinter class methodsFor: 'paper sizes' stamp: 'ar 4/30/98 18:29'!
paperSizeLetter
	^8.5@11.0! !

!TextPrinter class methodsFor: 'paper sizes' stamp: 'ar 4/30/98 18:29'!
paperSizeNote
	^8.5@11.0! !

!TextPrinter class methodsFor: 'paper sizes' stamp: 'ar 4/30/98 18:30'!
paperSizeTabloid
	^11.0@17.0! !

!TextPrinter methodsFor: 'accessing' stamp: 'ar 4/30/98 18:42'!
bestColor
	"Set the reproduction quality to true color"
	depth := 32.! !

!TextPrinter methodsFor: 'accessing' stamp: 'ar 4/30/98 18:42'!
blackAndWhite
	"Set the reproduction quality to black and white"
	depth := 1.! !

!TextPrinter methodsFor: 'formatting' stamp: 'ar 4/30/98 19:25'!
columnRect: n
	"Return a rectangle describing the n-th column"
	| area left right |
	area := self textArea.
	left := area left + ((n-1) * self columnWidth).
	left := left + ((n-1) * self columnSkip).
	right := left + self columnWidth.
	^(self in2pix: left @ area top) corner: 
		(self in2pix: right @ area bottom)! !

!TextPrinter methodsFor: 'formatting' stamp: 'ar 4/30/98 19:20'!
columnSkip
	"Return the separating space between two columns in inches"
	^0.2! !

!TextPrinter methodsFor: 'accessing' stamp: 'ar 4/30/98 18:50'!
columns
	^columns! !

!TextPrinter methodsFor: 'accessing' stamp: 'ar 4/30/98 18:50'!
columns: aNumber
	columns := aNumber asInteger max: 1.! !

!TextPrinter methodsFor: 'formatting' stamp: 'ar 4/30/98 19:21'!
columnWidth
	^(self textWidth - ((self columns-1) * self columnSkip)) / self columns! !

!TextPrinter methodsFor: 'initialize' stamp: 'ar 4/30/98 19:26'!
defaultPaperSize
	"Return the default paper size (inches) for printing"
	^self class defaultPaperSize! !

!TextPrinter methodsFor: 'initialize' stamp: 'nk 4/2/2004 11:32'!
defaultResolution
	"Return the default resolution (DPI) for printing"
	^TextStyle pixelsPerInch asPoint! !

!TextPrinter methodsFor: 'accessing' stamp: 'ar 4/30/98 20:14'!
documentTitle
	^docTitle! !

!TextPrinter methodsFor: 'accessing' stamp: 'ar 4/30/98 20:14'!
documentTitle: aString
	docTitle := aString! !

!TextPrinter methodsFor: 'printing' stamp: 'ar 4/30/98 20:41'!
flushPage
	"The current page has been set up. Send it to the printer."
	form primPrintHScale: self resolution x vScale: self resolution y landscape: self landscape.
	"Uncomment the following for testing"
	"form displayOn: Display. (Delay forSeconds: 5) wait."
! !

!TextPrinter methodsFor: 'footer' stamp: 'ar 4/30/98 19:23'!
footerHeight
	"Return the (additional) height of the footer in inches."
	self noFooter ifTrue:[^0.0].
	^(self pix2in: 0@TextStyle default lineGrid) y * 2! !

!TextPrinter methodsFor: 'footer' stamp: 'dtl 2/12/2010 20:15'!
footerParagraph
	"Return a paragraph for the footer"
	| fPara rect paragraphClass |
	paragraphClass := Smalltalk at: #Paragraph
				ifAbsent: [^ self notify: 'MVC class Paragraph not present'].
	fPara := paragraphClass new.
	fPara destinationForm: form.
	rect := (self in2pix: self textArea bottomLeft) corner: 
				(self in2pix: self textArea bottomRight + (0.0@self footerHeight)).
	fPara clippingRectangle: rect.
	fPara compositionRectangle: rect.
	^fPara! !

!TextPrinter methodsFor: 'formatting' stamp: 'ar 4/30/98 19:29'!
formatColumn: columnNum startingWith: anIndex
	"Format a new column starting at the given string index. Return the string index indicating the start of the next column or nil if no more columns need printing."
	| colRect blk |
	colRect := self columnRect: columnNum.
	anIndex > 1 ifTrue:[para text: (para text copyFrom: anIndex to: para text size)].
	para compositionRectangle: colRect.
	para clippingRectangle: colRect.
	para composeAll.
	para displayOn: form.
	para visibleRectangle corner y <= colRect extent y ifTrue:[^nil].
	"More columns -- find the character block of the last line and adjust clip rect"
	blk := para characterBlockAtPoint: para visibleRectangle bottomLeft.
	para clearVisibleRectangle. "Make sure that the background is clean"
	para clippingRectangle: (colRect topLeft corner: colRect right@blk top).
	para displayOn: form.
	^blk stringIndex.! !

!TextPrinter methodsFor: 'formatting' stamp: 'ar 4/30/98 19:29'!
formatPage: pageNum startingWith: anIndex
	"Format a new page starting at the given string index. Return the string index indicating the start of the next page or nil if no more pages need printing."
	| nextIndex |
	nextIndex := anIndex.
	1 to: self columns do:[:i|
		nextIndex := self formatColumn: i startingWith: nextIndex.
		nextIndex isNil ifTrue:[^nil].
	].
	^nextIndex! !

!TextPrinter methodsFor: 'accessing' stamp: 'ar 4/30/98 18:42'!
goodColor
	"Set the reproduction quality to 8 bit color depth"
	depth := 8.! !

!TextPrinter methodsFor: 'header' stamp: 'ar 4/30/98 19:23'!
headerHeight
	"Return the (additional) height of the header in inches."
	self noHeader ifTrue:[^0.0].
	^(self pix2in: 0@TextStyle default lineGrid) y * 2! !

!TextPrinter methodsFor: 'header' stamp: 'dtl 2/12/2010 20:15'!
headerParagraph
	"Return a paragraph for the footer"
	| hPara rect paragraphClass |
	paragraphClass := Smalltalk at: #Paragraph
				ifAbsent: [^ self notify: 'MVC class Paragraph not present'].
	hPara := paragraphClass new.
	hPara destinationForm: form.
	rect := (self in2pix: self textArea topLeft - (0.0@self headerHeight)) corner: 
				(self in2pix: self textArea topRight).
	hPara clippingRectangle: rect.
	hPara compositionRectangle: rect.
	^hPara! !

!TextPrinter methodsFor: 'other' stamp: 'ar 4/30/98 18:39'!
in2mm: aPoint
	"Convert aPoint from millimeters to inches"
	^aPoint * 25.4! !

!TextPrinter methodsFor: 'other' stamp: 'ar 4/30/98 18:38'!
in2pix: aPoint
	"Convert aPoint from inches to actual pixels"
	^(aPoint * self resolution) rounded! !

!TextPrinter methodsFor: 'initialize' stamp: 'ar 4/30/98 19:39'!
initialize
	self paperSize: self defaultPaperSize.
	self resolution: self defaultResolution.
	self blackAndWhite.
	self landscape: false.
	self offsetRect: (1.0@1.0 corner: 1.0@1.0).
	self columns: 1.
	self noHeader: false.
	self noFooter: false.
	self documentTitle: 'Squeak Document (from ', Date today printString,')'.! !

!TextPrinter methodsFor: 'accessing' stamp: 'ar 4/30/98 18:42'!
landscape
	^landscape! !

!TextPrinter methodsFor: 'accessing' stamp: 'ar 4/30/98 18:42'!
landscape: aBoolean
	landscape := aBoolean! !

!TextPrinter methodsFor: 'other' stamp: 'ar 4/30/98 18:38'!
mm2in: aPoint
	"Convert aPoint from millimeters to inches"
	^aPoint / 25.4! !

!TextPrinter methodsFor: 'other' stamp: 'ar 4/30/98 18:40'!
mm2pix: aPoint
	"Convert aPoint from millimeters to actual pixels"
	^self in2pix: (self mm2in: aPoint)! !

!TextPrinter methodsFor: 'accessing' stamp: 'ar 4/30/98 19:23'!
noFooter
	^noFooter! !

!TextPrinter methodsFor: 'accessing' stamp: 'ar 4/30/98 19:22'!
noFooter: aBoolean
	"Turn off footer printing"
	noFooter := aBoolean.! !

!TextPrinter methodsFor: 'accessing' stamp: 'ar 4/30/98 19:22'!
noHeader
	^noHeader! !

!TextPrinter methodsFor: 'accessing' stamp: 'ar 4/30/98 19:22'!
noHeader: aBoolean
	"Turn off header printing"
	noHeader := aBoolean.! !

!TextPrinter methodsFor: 'accessing' stamp: 'ar 4/30/98 19:27'!
offsetRect
	^offset! !

!TextPrinter methodsFor: 'accessing' stamp: 'ar 4/30/98 19:27'!
offsetRect: aRectangle
	"Set the offset rectangle"
	offset := aRectangle! !

!TextPrinter methodsFor: 'accessing' stamp: 'ar 4/30/98 18:42'!
paperSize
	^paperSize! !

!TextPrinter methodsFor: 'accessing' stamp: 'ar 4/30/98 18:42'!
paperSize: aPoint
	paperSize := aPoint! !

!TextPrinter methodsFor: 'other' stamp: 'ar 4/30/98 18:39'!
pix2in: aPoint
	"Convert aPoint from a pixel value to inches"
	^aPoint / self resolution! !

!TextPrinter methodsFor: 'other' stamp: 'ar 4/30/98 18:40'!
pix2mm: aPoint
	"Convert aPoint from a pixel value to millimeters"
	^self in2mm: (self pix2in: aPoint)! !

!TextPrinter methodsFor: 'private' stamp: 'ar 4/30/98 19:40'!
pixelSize
	"Return the size of the page in pixels"
	^self in2pix: (self realPaperSize)! !

!TextPrinter methodsFor: 'footer' stamp: 'ar 4/30/98 19:24'!
printFooter: pageNumber
	"Print the footer for the given page number"
	| fPara |
	self noFooter ifTrue:[^self].
	fPara := self footerParagraph.
	fPara centered.
	fPara text: ('Page ', pageNumber printString) asText.
	fPara displayOn: form.! !

!TextPrinter methodsFor: 'header' stamp: 'ar 4/30/98 19:23'!
printHeader: pageNumber
	"Print the header for the given page number"
	| fPara |
	self noHeader ifTrue:[^self].
	fPara := self headerParagraph.
	fPara centered.
	fPara text: self documentTitle asText.
	fPara displayOn: form.! !

!TextPrinter methodsFor: 'printing' stamp: 'ar 4/30/98 19:19'!
printParagraph
	| pageNum nextIndex |
	para destinationForm: form.
	pageNum := 1.
	nextIndex := 1.
	[form fillColor: Color white.
	self printHeader: pageNum.
	self printFooter: pageNum.
	nextIndex := self formatPage: pageNum startingWith: nextIndex.
	self flushPage.
	nextIndex isNil] whileFalse:[pageNum := pageNum + 1].! !

!TextPrinter methodsFor: 'printing' stamp: 'dtl 2/12/2010 20:16'!
printText: aText
	"Print aText"
	| paragraphClass |
	form isNil ifTrue:[
		form := Form extent: self pixelSize depth: depth.
	].
	paragraphClass := Smalltalk at: #Paragraph
				ifAbsent: [^ self notify: 'MVC class Paragraph not present'].
	para := paragraphClass withText: aText asText.
	Cursor wait showWhile:[
		self printParagraph.
	].! !

!TextPrinter methodsFor: 'private' stamp: 'ar 4/30/98 19:39'!
realPaperSize
	^self landscape
		ifTrue:[self paperSize y @ self paperSize x]
		ifFalse:[self paperSize]! !

!TextPrinter methodsFor: 'accessing' stamp: 'ar 4/30/98 18:43'!
resolution
	^resolution! !

!TextPrinter methodsFor: 'accessing' stamp: 'ar 4/30/98 18:43'!
resolution: aPoint
	resolution := aPoint! !

!TextPrinter methodsFor: 'formatting' stamp: 'ar 4/30/98 19:58'!
textArea
	^(self offsetRect origin + (0.0@self headerHeight)) corner:
		(self realPaperSize - self offsetRect corner - (0.0@self footerHeight))! !

!TextPrinter methodsFor: 'formatting' stamp: 'ar 4/30/98 19:23'!
textWidth
	^self textArea extent x! !

!ByteSymbol methodsFor: '*Graphics-Text' stamp: 'nice 10/9/2013 01:47'!
scanCharactersFrom: startIndex to: stopIndex with: aCharacterScanner rightX: rightX  font: aFont
	"NB: strongly consider getting almost all these parameters from the scanner"
	"Since I'm a byte char string, I know that we have to scan single-byte characters and don't have to handle encodings etc"
	startIndex > stopIndex
		ifTrue: [^aCharacterScanner handleEndOfRunAt: stopIndex].
	^aFont scanByteCharactersFrom: startIndex to: stopIndex in: self with: aCharacterScanner rightX: rightX! !

Rectangle subclass: #CharacterBlock
	instanceVariableNames: 'stringIndex text textLine'
	classVariableNames: ''
	poolDictionaries: 'TextConstants'
	category: 'Graphics-Text'!

!CharacterBlock commentStamp: 'mtf 5/15/2010 12:44' prior: 0!
I describe the location of one character displayed on the screen. My instances are used to return the results of methods:
	Paragraph characterBlockAtPoint: aPoint and
	Paragraph characterBlockForIndex: stringIndex.
Any recomposition or movement of a Paragraph can make the information I store stale.

text (Text): The text where my character is from
stringIndex (Integer): The index of my character in the text, starting from 1
textLine (TextLine): The displayed line my character is on
origin (Point): The top-left corner of the area allocated for displaying my
		character's glyph, in pixels, counting right then down from the
		top-left corner of the text display area, and starting from 0@0
corner (Point): The bottom-right corner of the area allocated for displaying my
		character's glyph, in pixels, counting right then down from the
		top-left corner of the text display area, and starting from 0@0
!

!CharacterBlock methodsFor: 'accessing' stamp: 'di 6/7/2000 17:33'!
copy
	"Overridden because Rectangle does a deepCopy, which goes nuts with the text"

	^ self clone! !

!CharacterBlock methodsFor: 'comparing' stamp: 'th 9/17/2002 11:54'!
max: aCharacterBlock
	aCharacterBlock ifNil:[^self].
	^aCharacterBlock > self
		ifTrue:[ aCharacterBlock]
		ifFalse:[self].! !

!CharacterBlock methodsFor: 'comparing' stamp: 'th 9/17/2002 11:54'!
min: aCharacterBlock
	aCharacterBlock ifNil:[^self].
	^aCharacterBlock < self
		ifTrue:[ aCharacterBlock]
		ifFalse:[self].! !

!CharacterBlock methodsFor: 'private' stamp: ''!
moveBy: aPoint 
	"Change the corner positions of the receiver so that its area translates by 
	the amount defined by the argument, aPoint."

	origin := origin + aPoint.
	corner := corner + aPoint! !

!CharacterBlock methodsFor: 'printing' stamp: 'di 12/2/97 19:15'!
printOn: aStream

	aStream nextPutAll: 'a CharacterBlock with index '.
	stringIndex printOn: aStream.
	(text ~~ nil and: [text size> 0 and: [stringIndex between: 1 and: text size]])
		ifTrue: [aStream nextPutAll: ' and character '.
				(text at: stringIndex) printOn: aStream].
	aStream nextPutAll: ' and rectangle '.
	super printOn: aStream.
	textLine ifNotNil: [aStream cr; nextPutAll: ' in '.
				textLine printOn: aStream].
! !

!CharacterBlock methodsFor: 'accessing' stamp: ''!
stringIndex
	"Answer the position of the receiver in the string it indexes."

	^stringIndex! !

!CharacterBlock methodsFor: 'private' stamp: 'di 10/23/97 22:33'!
stringIndex: anInteger text: aText topLeft: topLeft extent: extent

	stringIndex := anInteger.
	text := aText.
	super setOrigin: topLeft corner: topLeft + extent ! !

!CharacterBlock methodsFor: 'accessing' stamp: 'di 12/2/97 14:33'!
textLine
	^ textLine! !

!CharacterBlock methodsFor: 'accessing' stamp: 'di 12/2/97 14:33'!
textLine: aLine
	textLine := aLine! !

!CharacterBlock methodsFor: 'comparing' stamp: ''!
< aCharacterBlock 
	"Answer whether the string index of the receiver precedes that of 
	aCharacterBlock."

	^stringIndex < aCharacterBlock stringIndex! !

!CharacterBlock methodsFor: 'comparing' stamp: ''!
<= aCharacterBlock 
	"Answer whether the string index of the receiver does not come after that 
	of aCharacterBlock."

	^(self > aCharacterBlock) not! !

!CharacterBlock methodsFor: 'comparing' stamp: ''!
= aCharacterBlock

	self species = aCharacterBlock species
		ifTrue: [^stringIndex = aCharacterBlock stringIndex]
		ifFalse: [^false]! !

!CharacterBlock methodsFor: 'comparing' stamp: ''!
> aCharacterBlock 
	"Answer whether the string index of the receiver comes after that of 
	aCharacterBlock."

	^aCharacterBlock < self! !

!CharacterBlock methodsFor: 'comparing' stamp: ''!
>= aCharacterBlock 
	"Answer whether the string index of the receiver does not precede that of 
	aCharacterBlock."

	^(self < aCharacterBlock) not! !

Object subclass: #CharacterScanner
	instanceVariableNames: 'destX lastIndex xTable map destY stopConditions text textStyle alignment leftMargin rightMargin font line runStopIndex spaceCount spaceWidth emphasisCode kern indentationLevel wantsColumnBreaks pendingKernX'
	classVariableNames: 'ColumnBreakStopConditions CompositionStopConditions DefaultStopConditions MeasuringStopConditions PaddedSpaceCondition'
	poolDictionaries: 'TextConstants'
	category: 'Graphics-Text'!

!CharacterScanner commentStamp: 'nice 10/22/2013 20:04' prior: 0!
A CharacterScanner holds the state associated with scanning text. Subclasses scan characters for specified purposes, such as computing a CharacterBlock or placing characters into Forms.

Instance Variables
	alignment:		<Integer>
	destX:		<Number>
	destY:		<Number>
	emphasisCode:		<Object>
	font:		<AbstractFont>
	indentationLevel:		<Integer>
	kern:		<Number>
	lastIndex:		<Integer>
	leftMargin:		<Number>
	line:		<TextLine>
	map:		<Array>
	pendingKernX:		<Number>
	rightMargin:		<Number>
	runStopIndex:		<Integer>
	spaceCount:		<Integer>
	spaceWidth:		<Number>
	stopConditions:		<Array>
	text:		<Text>
	textStyle:		<TextStyle>
	wantsColumnBreaks:		<Boolean>
	xTable:		<Array>

alignment
	- an Integer encoding the alignment of text

destX
	- horizontal position for next character (distance from left of composition area)

destY
	- vertical position for next character (distance from top of composition area)

emphasisCode
	- an Integer encoding the current text emphasis to use (bold, italic, ...)

font
	- the current font used for measuring/composing/displaying characters

indentationLevel
	- an Integer specifying a number of leading tabs to be inserted at beginning of new lines

kern
	- a Number specifying additional horizontal spacing to place between characters (spacing is reduced when kern is negative)

lastIndex
	- the Integer index of next character to be processed in the text

leftMargin
	- a Number specifying the distance between left of composition zone and left of first character in the line.

line
	- an object holding information about the line currently being displayed (like first and last index in text).
	Note: this is either a TextLine in Morphic, or TextLineInterval for ST80 compatibility

map
	- an array mapping character code to glyph position.
	This is used by primitive 103 only, in case of ByteString.

pendingKernX
	- a Number to be added to horizontal spacing of next char if ever it is in the same font than previous one.
	The inner scan loop is interrupted by a change of text run.
	But some changes won't change the font, so the kerning must be remembered and applied later.

rightMargin
	- a Number specifying the distance between right of composition zone and right of last character in the line.

runStopIndex
	- the Integer index of last character in current text run.

spaceCount
	- the number of spaces encoutered so far in current line. This is useful for adjusting the spacing in cas of Justified alignment.

spaceWidth
	- the width of space character in current font.

stopConditions
	- an Array mapping a table of characters codes for which special actions are to be taken.
	These are typically control characters like carriage return or horizontal tab.

text
	- the text to be measured/composed/displayed

textStyle
	- an object holding a context for the text style (which set of font to use, which margins, etc...)

wantsColumnBreaks
	- a Boolean indicating whether some special handling for multiple columns is requested.
	THIS ONLY MAKES SENSE IN CompositionScanner AND SHOULD BE MOVED TO THE SUBCLASS
	
xTable
	- an array mapping character code to glyph x coordinate in form.
	This is used by primitive 103 only, in case of ByteString.
	
Implementation note: accelerated Character scanning with primitive 103 requires following order for 5 first instance variables, please don't alter:
destX lastIndex xTable map destY
!

CharacterScanner subclass: #CharacterBlockScanner
	instanceVariableNames: 'characterPoint characterIndex nextLeftMargin specialWidth lastCharacterWidth'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Text'!

!CharacterBlockScanner commentStamp: 'nice 10/6/2013 22:04' prior: 0!
A CharacterScanner does scan text to compute the CharacterBlock for a character specified by its index in the text or its proximity to the cursor location. The CharacterBlock stores information both about character layout and character index in the text.

This class is essential for selecting text with the mouse or with arrow keys.

Instance Variables
	characterIndex:		<Integer | nil>
	characterPoint:		<Point>
	lastCharacterWidth:		<Number | nil>
	nextLeftMargin:		<Number>
	specialWidth:		<Number | nil>

characterIndex
	- the index of character for which the layout information is searched, or nil when the layout is searched by cursor location

characterPoint
	- the cursor location for which nearest character index and layout are searched.

lastCharacterWidth
	- a number indicating the width of last character being processed.
	Note that this variable is left to nil during the inner scan loop, and only set on stopConditions.

nextLeftMargin
	- a number specifying the distance between left of composition zone and left of first character for the next line.

specialWidth
	- a number holding the width of an embedded object if any, or nil if none.
!

!CharacterBlockScanner methodsFor: 'scanning' stamp: 'nice 10/22/2013 20:50'!
characterBlockAtPoint: aPoint index: index in: textLine
	"This method is the Morphic characterBlock finder.  It combines
	MVC's characterBlockAtPoint:, -ForIndex:, and buildCharacterBlockIn:"
	| runLength lineStop stopCondition |
	line := textLine.
	rightMargin := line rightMargin.
	lastIndex := line first.
	self setStopConditions.		"also sets font"
	characterIndex := index.  " == nil means scanning for point"
	characterPoint := aPoint.
	(characterPoint isNil or: [characterPoint y > line bottom])
		ifTrue: [characterPoint := line bottomRight].
	destX := leftMargin := line leftMarginForAlignment: alignment.
	destY := line top.
	(text isEmpty or: [(characterPoint y < destY or: [characterPoint x < destX])
				or: [characterIndex notNil and: [characterIndex < line first]]])
		ifTrue:	[^ (CharacterBlock new stringIndex: line first text: text
					topLeft: destX@destY extent: 0 @ textStyle lineGrid)
					textLine: line].
	runLength := text runLengthFor: line first.
	lineStop := characterIndex	"scanning for index"
		ifNil: [ line last ].			"scanning for point"
	runStopIndex := lastIndex + (runLength - 1) min: lineStop.
	lastCharacterWidth := 0.
	spaceCount := 0.

	[
		stopCondition := self scanCharactersFrom: lastIndex to: runStopIndex
			in: text string rightX: characterPoint x.
		"see setStopConditions for stopping conditions for character block operations."
		self perform: stopCondition
	] whileFalse.
	characterIndex
		ifNil: ["Result for characterBlockAtPoint: "
				^ (CharacterBlock new
					stringIndex: lastIndex
					text: text topLeft: characterPoint + (font descentKern @ 0)
					extent: lastCharacterWidth @ line lineHeight - (font baseKern @ 0))
							textLine: line]
		ifNotNil: ["Result for characterBlockForIndex: "
				^ (CharacterBlock new
					stringIndex: characterIndex
					text: text topLeft: characterPoint + ((font descentKern) - kern @ 0)
					extent: lastCharacterWidth @ line lineHeight)
							textLine: line]! !

!CharacterBlockScanner methodsFor: 'stop conditions' stamp: 'nice 10/1/2013 01:12'!
cr 
	"Answer a CharacterBlock that specifies the current location of the mouse 
	relative to a carriage return stop condition that has just been 
	encountered. The ParagraphEditor convention is to denote selections by 
	CharacterBlocks, sometimes including the carriage return (cursor is at 
	the end) and sometimes not (cursor is in the middle of the text)."

	((characterIndex ~= nil
		and: [characterIndex > text size])
			or: [(line last = text size)
				and: [(destY + line lineHeight) < characterPoint y]])
		ifTrue:	["When off end of string, give data for next character"
				destY := destY +  line lineHeight.
				characterPoint := (nextLeftMargin ifNil: [leftMargin]) @ destY.
				(lastIndex < text size and: [(text at: lastIndex) = CR and: [(text at: lastIndex+1) = Character lf]])
					ifTrue: [lastIndex := lastIndex + 2]
					ifFalse: [lastIndex := lastIndex + 1].
				lastCharacterWidth := 0.
				^ true].
		characterPoint := destX @ destY.
		lastCharacterWidth := rightMargin - destX.
		^true! !

!CharacterBlockScanner methodsFor: 'stop conditions' stamp: 'nice 10/2/2013 02:07'!
crossedX
	"Text display has wrapping. The scanner just found a character past the x 
	location of the cursor. We know that the cursor is pointing at a character 
	or before one."

	self retrieveLastCharacterWidth.
	
	characterPoint x <= (destX + (lastCharacterWidth // 2))
		ifTrue:	[characterPoint := destX @ destY.
				^true].
	lastIndex >= line last 
		ifTrue:	[characterPoint := destX @ destY.
				^true].

	"Pointing past middle of a character, return the next character."
	lastIndex := lastIndex + 1.
	characterPoint := destX + lastCharacterWidth + kern @ destY.
	^ true! !

!CharacterBlockScanner methodsFor: 'stop conditions' stamp: 'nice 10/1/2013 01:45'!
endOfRun
	"Before arriving at the cursor location, the selection has encountered an 
	end of run. Answer false if the selection continues, true otherwise. Set 
	up indexes for building the appropriate CharacterBlock."

	| runLength lineStop |
	
	(((characterIndex ~~ nil and:
		[runStopIndex < characterIndex and: [runStopIndex < text size]])
			or:	[characterIndex == nil and: [lastIndex < line last]]) or: [
				((lastIndex < line last)
				and: [((text at: lastIndex) leadingChar ~= (text at: lastIndex+1) leadingChar)
					and: [lastIndex ~= characterIndex]])])
		ifTrue:	["We're really at the end of a real run."
				runLength := text runLengthFor: (lastIndex := lastIndex + 1).
				lineStop := characterIndex	"scanning for index"
						ifNil: [line last].		"scanning for point".
				(runStopIndex := lastIndex + (runLength - 1)) > lineStop
					ifTrue: [runStopIndex := lineStop].
				self setStopConditions.
				^false].

	self retrieveLastCharacterWidth.
		
	(characterIndex == nil and: [lastIndex = line last])
		ifTrue: [characterPoint x > (destX + (lastCharacterWidth // 2))
			ifTrue:
				[ "Correct for clicking right half of last character in line
				means selecting AFTER the char"
				lastIndex := lastIndex + 1.
				lastCharacterWidth := 0.
				characterPoint := destX + lastCharacterWidth @ destY.
				^true]].

	characterPoint := destX @ destY.
	characterIndex ~~ nil
		ifTrue:	["If scanning for an index and we've stopped on that index,
				then we back destX off by the width of the character stopped on
				(it will be pointing at the right side of the character) and return"
				runStopIndex = characterIndex
					ifTrue:	[characterPoint := destX - lastCharacterWidth @ destY.
							^true].
				"Otherwise the requested index was greater than the length of the
				string.  Return string size + 1 as index, indicate further that off the
				string by setting character to nil and the extent to 0."
				lastIndex :=  lastIndex + 1.
				lastCharacterWidth := 0.
				^true].

	"Scanning for a point and either off the end of the line or off the end of the string."
	runStopIndex = text size
		ifTrue:	["off end of string"
				lastIndex :=  lastIndex + 1.
				lastCharacterWidth := 0.
				^true].
	"just off end of line without crossing x"
	lastIndex := lastIndex + 1.
	^true! !

!CharacterBlockScanner methodsFor: 'text attributes' stamp: 'hmm 2/2/2001 15:07'!
indentationLevel: anInteger
	super indentationLevel: anInteger.
	nextLeftMargin := leftMargin.
	indentationLevel timesRepeat: [
		nextLeftMargin := textStyle nextTabXFrom: nextLeftMargin
					leftMargin: leftMargin
					rightMargin: rightMargin]! !

!CharacterBlockScanner methodsFor: 'stop conditions' stamp: 'nice 10/8/2013 22:40'!
paddedSpace
	"When the line is justified, the spaces will not be the same as the font's 
	space character. A padding of extra space must be considered in trying 
	to find which character the cursor is pointing at. Answer whether the 
	scanning has crossed the cursor."

	| pad |
	spaceCount := spaceCount + 1.
	pad := line justifiedPadFor: spaceCount font: font.
	lastCharacterWidth := spaceWidth + pad.
	(destX + lastCharacterWidth)  >= characterPoint x
		ifTrue:
			[^self crossedX].
	lastIndex := lastIndex + 1.
	destX := destX + lastCharacterWidth + kern.
	pendingKernX := 0.
	^ false
! !

!CharacterBlockScanner methodsFor: 'private' stamp: 'nice 10/6/2013 14:55'!
placeEmbeddedObject: anchoredMorph
	"Workaround: The following should really use #textAnchorType"
	| w |
	anchoredMorph relativeTextAnchorPosition ifNotNil:[^true].
	w := anchoredMorph width.
	specialWidth := w.
	(destX + w > characterPoint x) ifTrue: [^false].
	destX := destX + w + kern.
	^ true! !

!CharacterBlockScanner methodsFor: 'private' stamp: 'nice 10/3/2013 14:57'!
retrieveLastCharacterWidth
	| lastCharacter |
	lastIndex > text size ifTrue: [^lastCharacterWidth := 0].
	specialWidth ifNotNil: [^lastCharacterWidth := specialWidth].
	lastCharacter := text at: lastIndex.
	(lastCharacter charCode >= 256 or: [(stopConditions at: lastCharacter charCode + 1) isNil])
		ifTrue: [lastCharacterWidth := font widthOf: (text at: lastIndex)].
	"if last character was a stop condition, then the width is already set"
	^lastCharacterWidth! !

!CharacterBlockScanner methodsFor: 'stop conditions' stamp: 'ar 1/8/2000 14:32'!
setFont
	specialWidth := nil.
	super setFont! !

!CharacterBlockScanner methodsFor: 'stop conditions' stamp: 'nice 10/13/2013 22:13'!
tab
	| nextDestX |
	nextDestX := self plainTab.
	lastCharacterWidth := nextDestX - destX max: 0.
	nextDestX >= characterPoint x
		ifTrue: 
			[^ self crossedX].
	destX := nextDestX.
	lastIndex := lastIndex + 1.
	^false! !

!CharacterScanner class methodsFor: 'class initialization' stamp: 'nice 10/22/2013 20:02'!
initialize
"
	CharacterScanner initialize
"
	| a |
	a := Array new: 258.
	a at: 1 + 1 put: #embeddedObject.
	a at: Tab asciiValue + 1 put: #tab.
	a at: CR asciiValue + 1 put: #cr.
	a at: Character lf asciiValue + 1 put: #cr.
	"Note: following two codes are used only by primitive 103 for accelerated Character scanning"
	a at: 257 put: #endOfRun.
	a at: 258 put: #crossedX.
	
	DefaultStopConditions := a copy.

	CompositionStopConditions := a copy.
	CompositionStopConditions at: Space asciiValue + 1 put: #space.
	ColumnBreakStopConditions := CompositionStopConditions copy.
	ColumnBreakStopConditions at: Character characterForColumnBreak asciiValue + 1 put: #columnBreak.

	PaddedSpaceCondition := a copy.
	PaddedSpaceCondition at: Space asciiValue + 1 put: #paddedSpace.

	MeasuringStopConditions := (Array new: 258)
		at: 257 put: #endOfRun;
		at: 258 put: #crossedX;
		yourself! !

!CharacterScanner methodsFor: 'text attributes' stamp: 'ar 1/8/2000 14:27'!
addEmphasis: code
	"Set the bold-ital-under-strike emphasis."
	emphasisCode := emphasisCode bitOr: code! !

!CharacterScanner methodsFor: 'text attributes' stamp: 'ar 1/8/2000 14:27'!
addKern: kernDelta
	"Set the current kern amount."
	kern := kern + kernDelta! !

!CharacterScanner methodsFor: 'private' stamp: 'nice 10/8/2013 22:49'!
advanceIfFirstCharOfLine
	lastIndex = line first
		ifTrue:
			[destX := destX + pendingKernX + (font widthOf: (text at: line first)).
			lastIndex := lastIndex + 1.
			pendingKernX := 0].! !

!CharacterScanner methodsFor: 'scanning' stamp: 'nice 10/21/2013 22:38'!
basicScanByteCharactersFrom: startIndex to: stopIndex in: sourceString rightX: rightX 
"this is a scanning method for
single byte characters in a ByteString
a font that does not do character-pair kerning"
	| ascii nextDestX char |
	lastIndex := startIndex.
	[lastIndex <= stopIndex]
		whileTrue: [
			"get the character value"
			char := sourceString at: lastIndex.
			ascii := char asciiValue + 1.
			"if there is an entry in 'stops' for this value, return it"
			(stopConditions at: ascii)
				ifNotNil: [^ stopConditions at: ascii].
			"bump nextDestX by the width of the current character"
			nextDestX := destX + (font widthOf: char).
			"if the next x is past the right edge, return crossedX"
			nextDestX > rightX
				ifTrue: [^#crossedX].
			"update destX and incorporate thr kernDelta"
			destX := nextDestX + kern.
			lastIndex := lastIndex + 1].
	^self handleEndOfRunAt: stopIndex

! !

!CharacterScanner methodsFor: 'stop conditions' stamp: 'tween 4/6/2007 11:16'!
columnBreak

	pendingKernX := 0.
	^true! !

!CharacterScanner methodsFor: 'stop conditions' stamp: 'nice 10/6/2013 15:06'!
embeddedObject
	pendingKernX := 0.
	text attributesAt: lastIndex do:[:attr| 
		attr anchoredMorph ifNotNil:[
			"Try to placeEmbeddedObject: - if it answers false, then there's no place left"
			(self placeEmbeddedObject: attr anchoredMorph) ifFalse:[^self crossedX]]].
	"Note: if ever several objects are embedded on same character, only indent lastIndex once"
	lastIndex := lastIndex + 1.
	^false! !

!CharacterScanner methodsFor: 'scanner methods' stamp: 'nice 10/10/2013 01:49'!
handleEndOfRunAt: stopIndex
	" make sure the lastIndex is set to stopIndex and then return the stopCondition for endOfRun; important for  a couple of outside users"

	lastIndex := stopIndex.
	^#endOfRun! !

!CharacterScanner methodsFor: 'private' stamp: 'nice 10/13/2013 22:10'!
handleIndentation
	self indentationLevel timesRepeat: [
		destX := self plainTab]! !

!CharacterScanner methodsFor: 'private' stamp: 'ar 5/17/2000 18:20'!
indentationLevel
	"return the number of tabs that are currently being placed at the beginning of each line"
	^indentationLevel ifNil:[0]! !

!CharacterScanner methodsFor: 'text attributes' stamp: 'ar 1/8/2000 14:23'!
indentationLevel: anInteger
	"set the number of tabs to put at the beginning of each line"
	indentationLevel := anInteger! !

!CharacterScanner methodsFor: 'initialize' stamp: 'ls 1/14/2002 21:26'!
initialize
	destX := destY := leftMargin := 0.! !

!CharacterScanner methodsFor: 'private' stamp: 'ar 1/8/2000 14:23'!
leadingTab
	"return true if only tabs lie to the left"
	line first to: lastIndex do:
		[:i | (text at: i) == Tab ifFalse: [^ false]].
	^ true! !

!CharacterScanner methodsFor: 'scanning' stamp: 'nice 10/22/2013 20:50'!
measureString: aString inFont: aFont from: startIndex to: stopIndex
	"Measure aString width in given font aFont.
	The string shall not include line breaking, tab or other control character."
	destX := destY := lastIndex := 0.
	pendingKernX := 0.
	font := aFont.
	kern := 0 - font baseKern.
	spaceWidth := font widthOf: Space.
	stopConditions := MeasuringStopConditions.
	self scanCharactersFrom: startIndex to: stopIndex in: aString rightX: 999999.
	^destX! !

!CharacterScanner methodsFor: 'private' stamp: 'nice 10/6/2013 14:46'!
placeEmbeddedObject: anchoredMorph
	"Place the anchoredMorph or return false if it cannot be placed"
	^ true! !

!CharacterScanner methodsFor: 'private' stamp: 'nice 10/13/2013 22:07'!
plainTab
	"This is the basic method of adjusting destX for a tab.
	Answer the next destX"
	pendingKernX := 0.
	^(alignment = Justified and: [self leadingTab not])
		ifTrue:		"embedded tabs in justified text are weird"
			[destX + (textStyle tabWidth - (line justifiedTabDeltaFor: spaceCount)) max: destX]
		ifFalse: 
			[textStyle nextTabXFrom: destX
				leftMargin: leftMargin
				rightMargin: rightMargin].! !

!CharacterScanner methodsFor: 'scanning' stamp: 'nice 10/21/2013 22:39'!
primScanCharactersFrom: startIndex to: stopIndex in: sourceString rightX: rightX stopConditions: stops kern: kernDelta
	"Primitive. This is the inner loop of text display--but see 
	scanCharactersFrom: to:rightX: which would get the string, 
	stopConditions and displaying from the instance. March through source 
	String from startIndex to stopIndex. If any character is flagged with a 
	non-nil entry in stops, then return the corresponding value. Determine 
	width of each character from xTable, indexed by map. 
	If dextX would exceed rightX, then return stops at: 258. 
	Advance destX by the width of the character. If stopIndex has been
	reached, then return stops at: 257. Optional. 
	See Object documentation whatIsAPrimitive.
	Historical note: this primitive has been unusable since about Squeak 2.8 when the shape of the CharracterScanner class changed. It is left here as a reminder that the actual primitive still needs supporting in the VM to keep old images such as Scratch1.4 alive - tpr"
	<primitive: 103>
	^self basicScanByteCharactersFrom: startIndex to: stopIndex in: sourceString rightX: rightX ! !

!CharacterScanner methodsFor: 'scanning' stamp: 'nice 10/21/2013 22:40'!
scanByteCharactersFrom: startIndex to: stopIndex in: sourceString rightX: rightX 
"this is a scanning method for
single byte characters in a ByteString
a font that does not do character-pair kerning"
	^self primScanCharactersFrom: startIndex to: stopIndex in: sourceString rightX: rightX stopConditions: stopConditions kern: kern
! !

!CharacterScanner methodsFor: 'scanning' stamp: 'nice 10/22/2013 20:49'!
scanCharactersFrom: startIndex to: stopIndex in: sourceString rightX: rightX 
	^sourceString scanCharactersFrom: startIndex to: stopIndex with: self rightX: rightX font: font! !

!CharacterScanner methodsFor: 'scanning' stamp: 'tpr 10/3/2013 12:58'!
scanCharactersFrom: startIndex to: stopIndex in: sourceString rightX: rightX stopConditions: stops kern: kernDelta 
	^sourceString scanCharactersFrom: startIndex to: stopIndex with: self rightX: rightX font: font! !

!CharacterScanner methodsFor: 'scanning' stamp: 'nice 10/10/2013 02:19'!
scanKernableByteCharactersFrom: startIndex to: stopIndex in: sourceString rightX: rightX 
"this is a scanning method for
single byte characters in a ByteString
a font that does do character-pair kerning via widthAndKernedWidthOfLeft:right:into:"
	| ascii nextDestX char floatDestX widthAndKernedWidth nextCharOrNil atEndOfRun |
	lastIndex := startIndex.
	floatDestX := destX.
	widthAndKernedWidth := Array new: 2.
	atEndOfRun := false.
	[lastIndex <= stopIndex]
		whileTrue: [
			"get the character value"
			char := sourceString at: lastIndex.
			ascii := char asciiValue + 1.
			"if there is an entry in 'stops' for this value, return it"
			(stopConditions at: ascii)
				ifNotNil: [^ stopConditions at: ascii].
			"get the next character..."
			nextCharOrNil := lastIndex + 1 <= stopIndex
						ifTrue: [sourceString at: lastIndex + 1]
						ifFalse: ["if we're at or past the stopIndex, see if there is anything in the full string"
							atEndOfRun := true.
							lastIndex + 1 <= sourceString size
								ifTrue: [sourceString at: lastIndex + 1]].
			"get the font's kerning info for the pair of current character and next character"
			"for almost all fonts in common use this is a waste of time since they don't support pair kerning and both values are #widthOf: char"
			font
				widthAndKernedWidthOfLeft: char
				right: nextCharOrNil
				into: widthAndKernedWidth.
			"bump nextDestX by the width of the current character"
			nextDestX := floatDestX
						+ (widthAndKernedWidth at: 1).
			"if the next x is past the right edge, return crossedX"
			nextDestX > rightX
				ifTrue: [^ #crossedX].
			"bump floatDestX by the *kerned* width of the current
			character, which is where the *next* char will go"
			floatDestX := floatDestX + kern
						+ (widthAndKernedWidth at: 2).
			"if we are at the end of this run we keep track of the
			character-kern-delta for possible later use and then rather
			insanely remove that character-kern-delta from floatDestX,
			making it equivalent to (old floatDestX) + kernDelta +
			width-of-character - no idea why"
			atEndOfRun
				ifTrue: [pendingKernX := (widthAndKernedWidth at: 2)
								- (widthAndKernedWidth at: 1).
					floatDestX := floatDestX - pendingKernX].
			"save the next x for next time around the loop"
			destX := floatDestX.
			lastIndex := lastIndex + 1].
	^self handleEndOfRunAt: stopIndex
! !

!CharacterScanner methodsFor: 'text attributes' stamp: 'nice 10/21/2013 22:36'!
setActualFont: aFont
	"Set the basal font to an isolated font reference."

	xTable := aFont xTable.
	map := aFont characterToGlyphMap.
	font := aFont.! !

!CharacterScanner methodsFor: 'text attributes' stamp: 'ar 12/15/2001 23:31'!
setAlignment: style
	alignment := style.
	! !

!CharacterScanner methodsFor: 'private' stamp: 'nice 10/22/2013 20:07'!
setFont
	| priorFont |
	"Set the font and other emphasis."
	priorFont := font.
	text ifNotNil:[
		emphasisCode := 0.
		kern := 0.
		indentationLevel := 0.
		alignment := textStyle alignment.
		font := nil.
		(text attributesAt: lastIndex forStyle: textStyle)
			do: [:att | att emphasizeScanner: self]].
	font ifNil: [self setFont: textStyle defaultFontIndex].
	self setActualFont: (font emphasized: emphasisCode).
	priorFont 
		ifNotNil: [
			font = priorFont 
				ifTrue:[
					"font is the same, perhaps the color has changed?
					We still want kerning between chars of the same
					font, but of different color. So add any pending kern to destX"
					destX := destX + (pendingKernX ifNil:[0])].
			destX := destX + priorFont descentKern].
	pendingKernX := 0. "clear any pending kern so there is no danger of it being added twice"
	destX := destX - font descentKern.
	"NOTE: next statement should be removed when clipping works"
	leftMargin ifNotNil: [destX := destX max: leftMargin].
	kern := kern - font baseKern.

	"Install various parameters from the font."
	spaceWidth := font widthOf: Space.! !

!CharacterScanner methodsFor: 'text attributes' stamp: 'ar 1/8/2000 14:28'!
setFont: fontNumber
	"Set the font by number from the textStyle."

	self setActualFont: (textStyle fontAt: fontNumber)! !

!CharacterScanner methodsFor: 'private' stamp: 'nice 10/5/2013 21:03'!
setStopConditions
	"Set the font and the stop conditions for the current run."
	
	self setFont.
	stopConditions := alignment = Justified
		ifTrue: [PaddedSpaceCondition]
		ifFalse: [DefaultStopConditions]! !

!CharacterScanner methodsFor: 'text attributes' stamp: 'ar 1/8/2000 14:28'!
textColor: ignored
	"Overridden in DisplayScanner"! !

!CharacterScanner methodsFor: 'private' stamp: 'ar 1/8/2000 14:28'!
text: t textStyle: ts
	text := t.
	textStyle := ts! !

CharacterScanner subclass: #CompositionScanner
	instanceVariableNames: 'spaceX spaceIndex lineHeight baseline lineHeightAtSpace baselineAtSpace lastBreakIsNotASpace nextIndexAfterLineBreak'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Text'!

!CompositionScanner commentStamp: 'nice 10/6/2013 23:24' prior: 0!
A CompositionScanner measures text and determines where line breaks.
Given a rectangular zone on input, it is used to split text in horizontal lines, and produce information about those lines on output (at which index a line starts/stops, which vertical space does the line require, which horizontal space if left for adjusting inter-word spacing, etc...)

Instance Variables
	baseline:		<Number>
	baselineAtSpace:		<Number>
	lastBreakIsNotASpace:		<Boolean>
	lineHeight:		<Number>
	lineHeightAtSpace:		<Number>
	nextIndexAfterLineBreak:		<Integer>
	spaceIndex:		<Integer>
	spaceX:		<Number>

baseline
	- the distance between top of line and the base line (that is the bottom of latin characters abcdehiklmnorstuvwx in most fonts)

baselineAtSpace
	- memorize the baseline at last encountered space or other breakable character.
	This is necessary because the CompositionScanner wants to break line at a breakable character.
	If a word layout overflows the right margin, the scanner has to roll back and restore the line state to last encountered breakable character.

lastBreakIsNotASpace
	- indicates that the last breakable character was not a space.
	This is necessary because handling a line break at a space differs from non space.
	If line break occurs on space, the space won't be displayed in next line.
	If it's another breakable character, it has to be displayed on next line.

lineHeight
	- the total line height from top to bottom, including inter-line spacing.

lineHeightAtSpace
	- the line height at last encountered space or other breakable character.
	See baselineAtSpace for explanation.

nextIndexAfterLineBreak
	- the index of character after the last line break that was encountered.

spaceIndex
	- the index of last space or other breakable character that was encountered

spaceX
	- the distance from left of composition zone to left of last encountered space or other breakable character 
	See baselineAtSpace for explanation.

Note: if a line breaks on a space, a linefeed or a carriage return, then the space, linefeed or carriage return is integrated in the line.
If there is a carriage return - linefeed pair, the pair is integrated to the line as if it were a single line break for compatibility with legacy software.!

!CompositionScanner methodsFor: 'testing' stamp: 'cmm 6/13/2010 20:50'!
canComputeDefaultLineHeight
	^ rightMargin notNil! !

!CompositionScanner methodsFor: 'stop conditions' stamp: 'nice 9/29/2013 16:12'!
columnBreak

	"Answer true. Set up values for the text line interval currently being 
	composed."

	pendingKernX := 0.
	line stop: lastIndex.
	spaceX := destX.
	lastBreakIsNotASpace := false.
	line paddingWidth: rightMargin - spaceX.
	^true! !

!CompositionScanner methodsFor: 'scanning' stamp: 'nice 10/22/2013 20:50'!
composeFrom: startIndex inRectangle: lineRectangle
	firstLine: firstLine leftSide: leftSide rightSide: rightSide
	"Answer an instance of TextLineInterval that represents the next line in the paragraph."
	| runLength stopCondition |
	"Set up margins"
	leftMargin := lineRectangle left.
	leftSide ifTrue: [leftMargin := leftMargin +
						(firstLine ifTrue: [textStyle firstIndent]
								ifFalse: [textStyle restIndent])].
	destX := spaceX := leftMargin.
	rightMargin := lineRectangle right.
	rightSide ifTrue: [rightMargin := rightMargin - textStyle rightIndent].
	lastIndex := startIndex.	"scanning sets last index"
	destY := lineRectangle top.
	lineHeight := baseline := 0.  "Will be increased by setFont"
	line := (TextLine start: lastIndex stop: 0 internalSpaces: 0 paddingWidth: 0)
				rectangle: lineRectangle.
	self setStopConditions.	"also sets font"
	runLength := text runLengthFor: startIndex.
	runStopIndex := (lastIndex := startIndex) + (runLength - 1).
	nextIndexAfterLineBreak := spaceCount := 0.
	lastBreakIsNotASpace := false.
	self handleIndentation.
	leftMargin := destX.
	line leftMargin: leftMargin.

	[stopCondition := self scanCharactersFrom: lastIndex to: runStopIndex
		in: text string rightX: rightMargin.
	"See setStopConditions for stopping conditions for composing."
	self perform: stopCondition] whileFalse.

	^ line
		lineHeight: lineHeight + textStyle leading
		baseline: baseline + textStyle leading! !

!CompositionScanner methodsFor: 'scanning' stamp: 'tpr 9/25/2013 13:41'!
computeDefaultLineHeight
	"Compute the default line height for a potentially empty text"
	rightMargin notNil
		ifTrue: [lastIndex := 1.
			self setFont.
			^ lineHeight + textStyle leading]
		ifFalse: [^textStyle lineGrid]! !

!CompositionScanner methodsFor: 'stop conditions' stamp: 'nice 10/2/2013 02:21'!
cr
	"Answer true. Set up values for the text line interval currently being 
	composed."

	pendingKernX := 0.
	(lastIndex < text size and: [(text at: lastIndex) = CR and: [(text at: lastIndex+1) = Character lf]]) ifTrue: [lastIndex := lastIndex + 1].
	line stop: lastIndex.
	nextIndexAfterLineBreak := lastIndex + 1.
	spaceX := destX.
	lastBreakIsNotASpace := false.
	line paddingWidth: rightMargin - spaceX.
	^true! !

!CompositionScanner methodsFor: 'stop conditions' stamp: 'nice 10/8/2013 22:42'!
crossedX
	"There is a word that has fallen across the right edge of the composition 
	rectangle. This signals the need for wrapping which is done to the last 
	space that was encountered, as recorded by the space stop condition,
	or any other breakable character if the language permits so."

	pendingKernX := 0.
	
	lastBreakIsNotASpace ifTrue:
		["In some languages line break is possible before a non space."
		^self wrapAtLastBreakable].
	 
	spaceCount >= 1 ifTrue:
		["The common case. there is a space on the line."
		^self wrapAtLastSpace].
	
	"Neither internal nor trailing spaces -- almost never happens."
	self advanceIfFirstCharOfLine.
	^self wrapHere! !

!CompositionScanner methodsFor: 'accessing' stamp: 'nice 10/2/2013 02:23'!
doesTheLineBreaksAfterLastChar
	^nextIndexAfterLineBreak > text size! !

!CompositionScanner methodsFor: 'stop conditions' stamp: 'ar 1/9/2000 13:54'!
endOfRun
	"Answer true if scanning has reached the end of the paragraph. 
	Otherwise step conditions (mostly install potential new font) and answer 
	false."

	| runLength |
	lastIndex = text size
	ifTrue:	[line stop: lastIndex.
			spaceX := destX.
			line paddingWidth: rightMargin - destX.
			^true]
	ifFalse:	[runLength := (text runLengthFor: (lastIndex := lastIndex + 1)).
			runStopIndex := lastIndex + (runLength - 1).
			self setStopConditions.
			^false]
! !

!CompositionScanner methodsFor: 'initialize' stamp: 'nice 10/6/2013 21:41'!
initialize
	wantsColumnBreaks := false.
	super initialize! !

!CompositionScanner methodsFor: 'private' stamp: 'nice 10/21/2013 23:22'!
placeEmbeddedObject: anchoredMorph
	| w descent |
	"Workaround: The following should really use #textAnchorType"
	anchoredMorph relativeTextAnchorPosition ifNotNil:[^true].
	w := anchoredMorph width.
	(destX + w > rightMargin and: [(leftMargin + w) <= rightMargin or: [lastIndex > line first]])
		ifTrue: ["Won't fit, but would on next line"
				^ false].
	destX := destX + w + kern.
	descent := lineHeight - baseline.
	baseline := baseline max: anchoredMorph height.
	lineHeight := baseline + descent.
	^ true! !

!CompositionScanner methodsFor: 'accessing' stamp: 'ar 1/8/2000 14:35'!
rightX
	"Meaningful only when a line has just been composed -- refers to the 
	line most recently composed. This is a subtrefuge to allow for easy 
	resizing of a composition rectangle to the width of the maximum line. 
	Useful only when there is only one line in the form or when each line 
	is terminated by a carriage return. Handy for sizing menus and lists."

	^spaceX! !

!CompositionScanner methodsFor: 'text attributes' stamp: 'ar 1/8/2000 14:36'!
setActualFont: aFont
	"Keep track of max height and ascent for auto lineheight"
	| descent |
	super setActualFont: aFont.
	lineHeight == nil
		ifTrue: [descent := font descent.
				baseline := font ascent.
				lineHeight := baseline + descent]
		ifFalse: [descent := lineHeight - baseline max: font descent.
				baseline := baseline max: font ascent.
				lineHeight := lineHeight max: baseline + descent]! !

!CompositionScanner methodsFor: 'private' stamp: 'nice 10/5/2013 21:02'!
setStopConditions
	"Set the font and the stop conditions for the current run."
	
	self setFont.
	stopConditions := wantsColumnBreaks == true
		ifTrue: [ColumnBreakStopConditions]
		ifFalse: [CompositionStopConditions]! !

!CompositionScanner methodsFor: 'stop conditions' stamp: 'nice 10/6/2013 21:20'!
space
	"Record left x and character index of the space character just encountered. 
	Used for wrap-around. Answer whether the character has crossed the 
	right edge of the composition rectangle of the paragraph."

	spaceX := destX.
	spaceIndex := lastIndex.
	lineHeightAtSpace := lineHeight.
	baselineAtSpace := baseline.
	spaceCount := spaceCount + 1.
	lastBreakIsNotASpace := false.
	destX + spaceWidth > rightMargin ifTrue:[^self crossedX].
	destX := spaceX + spaceWidth + kern.
	lastIndex := lastIndex + 1.
	^false
! !

!CompositionScanner methodsFor: 'stop conditions' stamp: 'tween 4/6/2007 11:15'!
tab
	"Advance destination x according to tab settings in the paragraph's 
	textStyle. Answer whether the character has crossed the right edge of 
	the composition rectangle of the paragraph."

	pendingKernX := 0.
	destX := textStyle
				nextTabXFrom: destX leftMargin: leftMargin rightMargin: rightMargin.
	destX > rightMargin ifTrue:	[^self crossedX].
	lastIndex := lastIndex + 1.
	^false
! !

!CompositionScanner methodsFor: 'initialize' stamp: 'RAA 5/7/2001 10:11'!
wantsColumnBreaks: aBoolean

	wantsColumnBreaks := aBoolean! !

!CompositionScanner methodsFor: 'stop conditions' stamp: 'nice 10/8/2013 22:32'!
wrapAtLastBreakable
	"Wrap the line before last encountered breakable character."
	pendingKernX := 0.
	nextIndexAfterLineBreak := spaceIndex.
	line stop: spaceIndex - 1.
	lineHeight := lineHeightAtSpace.
	baseline := baselineAtSpace.
	line paddingWidth: rightMargin - spaceX.
	line internalSpaces: spaceCount.
	^true! !

!CompositionScanner methodsFor: 'stop conditions' stamp: 'nice 10/8/2013 22:32'!
wrapAtLastSpace
	"Wrap the line before last encountered space"
	
	pendingKernX := 0.
	nextIndexAfterLineBreak := spaceIndex + 1.
	alignment = Justified ifTrue: [
		"gobble all subsequent spaces"
		[nextIndexAfterLineBreak <= text size and: [(text at: nextIndexAfterLineBreak) == Space]]
			whileTrue: [nextIndexAfterLineBreak := nextIndexAfterLineBreak + 1]].
	
	line stop: nextIndexAfterLineBreak - 1.
	lineHeight := lineHeightAtSpace.
	baseline := baselineAtSpace.

	["remove the space at which we break..."
	spaceCount := spaceCount - 1.
	spaceIndex := spaceIndex - 1.

	"...and every other spaces preceding the one at which we wrap.
		Double space after punctuation, most likely."
	spaceCount >= 1 and: [(text at: spaceIndex) = Space]]
		whileTrue:
			["Account for backing over a run which might
				change width of space."
			font := text fontAt: spaceIndex withStyle: textStyle.
			spaceX := spaceX - (font widthOf: Space)].
	line paddingWidth: rightMargin - spaceX.
	line internalSpaces: spaceCount.
	^true! !

!CompositionScanner methodsFor: 'stop conditions' stamp: 'nice 10/8/2013 22:43'!
wrapHere
	"Wrap the line before current character."
	pendingKernX := 0.
	nextIndexAfterLineBreak := lastIndex.
	lastIndex := lastIndex - 1.
	spaceX := destX.
	line paddingWidth: rightMargin - destX.
	line stop: (lastIndex max: line first).
	^true! !

CompositionScanner subclass: #SegmentScanner
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: 'TextConstants'
	category: 'Graphics-Text'!

!SegmentScanner commentStamp: 'nice 10/6/2013 22:39' prior: 0!
A SegmentScanner is a CompositionScanner specialized for composing TextOnCurve.
!

!SegmentScanner methodsFor: 'private' stamp: 'nice 10/5/2013 21:03'!
setStopConditions
	"Set the font and the stop conditions for the current run."
	
	self setFont.
	stopConditions := DefaultStopConditions! !

CharacterScanner subclass: #DisplayScanner
	instanceVariableNames: 'lineY foregroundColor backgroundColor defaultTextColor paragraphColor morphicOffset ignoreColorChanges lastDisplayableIndex stopConditionsMustBeReset'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Text'!

!DisplayScanner commentStamp: 'nice 10/11/2013 23:45' prior: 0!
A DisplayScanner is an abstract class for displaying characters.
It is splitting text into elementary chunks of displayable String/Font pairs (see scanning protocol).
Subclasses responsibility is to handle the effective rendering of these chunks on various backends.

Instance Variables
	backgroundColor:		<Color>
	defaultTextColor:		<Color>
	foregroundColor:		<Color>
	ignoreColorChanges:		<Boolean>
	lastDisplayableIndex:		<Integer>
	lineY:		<Number>
	morphicOffset:		<Point>
	stopConditionsMustBeReset:		<Boolean>

backgroundColor
	- the background color for displaying next chunk of text.
	Note that this can be set to Color transparent, in which case no background is displayed.

defaultTextColor
	- the default foreground color for displaying text in absence of other text attributes specification 

foregroundColor
	- the foreground color for displaying next chunk of text

ignoreColorChanges
	- indicates that any change of color specified in text attributes shall be ignored.
	This is used for displaying text in a shadow mode, when dragging text for example.

lastDisplayableIndex
	- the index of last character to be displayed.
	A different index than lastIndex is required in order to avoid display of control characters.
	This variable must be updated by the stop condition at each inner scan loop.

lineY
	- the distance between destination form top and current line top

morphicOffset
	- an offset for positionning the embedded morphs.
	THE EXACT SPECIFICATION YET REMAINS TO BE WRITTEN

stopConditionsMustBeReset
	- indicates that it's necessary to call setStopConditions in next scan loop.

Notes:
In order to correctly set the lastDisplayableIndex, the display scanner performs the stopCondition BEFORE displaying the string being scanned.
This explains why the stopCondition must not reset the font immediately, but differ this reset AFTER the display, thanks to stopConditionsMustBeReset.
!

DisplayScanner subclass: #BitBltDisplayScanner
	instanceVariableNames: 'bitBlt fillBlt'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Text'!

!BitBltDisplayScanner commentStamp: 'nice 10/12/2013 01:36' prior: 0!
A BitBltDisplayScanner displays characters on Screen or other Form with help of a BitBlt.

Instance Variables
	bitBlt:		<BitBlt>
	fillBlt:		<BitBlt>

bitBlt
	- the object which knows how to copy bits from one Form (the font glyph data) to another (the destination Form)

fillBlt
	- another object for copying form bits, initialized for displaying the background.

!

!BitBltDisplayScanner class methodsFor: 'queries' stamp: 'ar 5/17/2000 17:39'!
defaultFont
	^ TextStyle defaultFont! !

!BitBltDisplayScanner methodsFor: 'displaying' stamp: 'nice 1/10/2014 01:39'!
displayEmbeddedForm: aForm
	aForm 
		displayOn: bitBlt destForm 
		at: destX @ (lineY + line baseline - aForm height)
		clippingBox: bitBlt clipRect
		rule: Form blend
		fillColor: Color white ! !

!BitBltDisplayScanner methodsFor: 'displaying' stamp: 'nice 10/12/2013 01:06'!
displayString: string from: startIndex to: stopIndex at: aPoint
	font displayString: string on: bitBlt 
		from: startIndex 
		to: stopIndex 
		at: aPoint kern: kern! !

!BitBltDisplayScanner methodsFor: 'displaying' stamp: 'nice 10/12/2013 01:08'!
fillTextBackground
	fillBlt == nil ifFalse:
		["Not right"
		fillBlt destX: line left destY: lineY
			width: line width left height: line lineHeight; copyBits].! !

!BitBltDisplayScanner methodsFor: 'stop conditions' stamp: 'nice 10/13/2013 22:10'!
plainTab
	| nextDestX |
 	nextDestX := super plainTab.
	fillBlt == nil ifFalse:
		[fillBlt destX: destX destY: destY width: nextDestX - destX height: font height; copyBits].
	^nextDestX! !

!BitBltDisplayScanner methodsFor: 'private' stamp: 'ar 5/17/2000 19:26'!
setDestForm: df
	bitBlt setDestForm: df.! !

!BitBltDisplayScanner methodsFor: 'private' stamp: 'nice 10/12/2013 01:29'!
setFont 
	super setFont.  "Sets font and emphasis bits, and maybe foregroundColor"
	font installOn: bitBlt foregroundColor: foregroundColor backgroundColor: Color transparent! !

!BitBltDisplayScanner methodsFor: 'private' stamp: 'hmm 9/16/2000 21:29'!
setPort: aBitBlt
	"Install the BitBlt to use"
	bitBlt := aBitBlt.
	bitBlt sourceX: 0; width: 0.	"Init BitBlt so that the first call to a primitive will not fail"
	bitBlt sourceForm: nil. "Make sure font installation won't be confused"
! !

!BitBltDisplayScanner methodsFor: 'private' stamp: 'nice 10/12/2013 01:32'!
text: t textStyle: ts foreground: foreColor background: backColor fillBlt: blt ignoreColorChanges: shadowMode
	text := t.
	textStyle := ts. 
	foregroundColor := defaultTextColor := foreColor.
	(backgroundColor := backColor) isTransparent ifFalse:
		[fillBlt := blt.
		fillBlt fillColor: backgroundColor].
	ignoreColorChanges := shadowMode! !

!DisplayScanner class methodsFor: 'queries' stamp: 'ar 5/17/2000 17:39'!
defaultFont
	^ TextStyle defaultFont! !

!DisplayScanner class methodsFor: 'instance creation' stamp: 'nice 10/12/2013 03:36'!
new
	"Use default concrete class"
	^(self == DisplayScanner
		ifTrue: [BitBltDisplayScanner]
		ifFalse: [self]) basicNew initialize! !

!DisplayScanner methodsFor: 'stop conditions' stamp: 'nice 10/8/2013 23:35'!
cr
	"When a carriage return is encountered, simply increment the pointer 
	into the paragraph."

	pendingKernX := 0.
	lastDisplayableIndex := lastIndex - 1.
	(lastIndex < text size and: [(text at: lastIndex) = CR and: [(text at: lastIndex+1) = Character lf]])
		ifTrue: [lastIndex := lastIndex + 2]
		ifFalse: [lastIndex := lastIndex + 1].
	^false! !

!DisplayScanner methodsFor: 'stop conditions' stamp: 'nice 10/8/2013 23:37'!
crossedX
	"This condition will sometimes be reached 'legally' during display, when, 
	for instance the space that caused the line to wrap actually extends over 
	the right boundary. This character is allowed to display, even though it 
	is technically outside or straddling the clipping rectangle since it is in 
	the normal case not visible and is in any case appropriately clipped by 
	the scanner."

	self advanceIfFirstCharOfLine.
	lastDisplayableIndex := lastIndex - 1.
	^ true ! !

!DisplayScanner methodsFor: 'private' stamp: 'nice 10/11/2013 23:46'!
defaultTextColor
	defaultTextColor ifNil:[defaultTextColor := Color black].
	^defaultTextColor! !

!DisplayScanner methodsFor: 'private' stamp: 'nice 10/11/2013 23:46'!
defaultTextColor: color
	defaultTextColor := color.! !

!DisplayScanner methodsFor: 'displaying' stamp: 'nice 10/19/2013 13:13'!
displayEmbeddedForm: aForm
	self subclassResponsibility! !

!DisplayScanner methodsFor: 'scanning' stamp: 'nice 10/22/2013 20:51'!
displayLine: textLine offset: offset leftInRun: leftInRun
	"The call on the primitive (scanCharactersFrom:to:in:rightX:) will be interrupted according to an array of stop conditions passed to the scanner at which time the code to handle the stop condition is run and the call on the primitive continued until a stop condition returns true (which means the line has terminated).  leftInRun is the # of characters left to scan in the current run; when 0, it is time to call setStopConditions."
	| stopCondition nowLeftInRun startIndex string lastPos lineHeight stop |
	line := textLine.
	morphicOffset := offset.
	lineY := line top + offset y.
	lineHeight := line lineHeight.
	rightMargin := line rightMargin + offset x.
	lastIndex := line first.
	leftInRun <= 0 ifTrue: [self setStopConditions].
	leftMargin := (line leftMarginForAlignment: alignment) + offset x.
	destX := leftMargin.
	self fillTextBackground.
	lastDisplayableIndex := lastIndex := line first.
	leftInRun <= 0
		ifTrue: [nowLeftInRun := text runLengthFor: lastIndex]
		ifFalse: [nowLeftInRun := leftInRun].
	destY := lineY + line baseline - font ascent.
	runStopIndex := lastIndex + (nowLeftInRun - 1) min: line last.
	spaceCount := 0.
	string := text string.
	[
		"reset the stopping conditions of this displaying loop, and also the font."
		stopConditionsMustBeReset
			ifTrue:[self setStopConditions].
		
		"remember where this portion of the line starts"
		startIndex := lastIndex.
		lastPos := destX@destY.
		
		"find the end of this portion of the line"
		stopCondition := self scanCharactersFrom: lastIndex to: runStopIndex
						in: string rightX: rightMargin.
		"handle the stop condition - this will also set lastDisplayableIndex"
		stop := self perform: stopCondition.
		
		"display that portion of the line"
		lastDisplayableIndex >= startIndex ifTrue:[
			self displayString: string
				from: startIndex 
				to: lastDisplayableIndex 
				at: lastPos].
		
		"if the stop condition were true, stop the loop"
		stop
	] whileFalse.
	^ runStopIndex - lastIndex   "Number of characters remaining in the current run"! !

!DisplayScanner methodsFor: 'displaying' stamp: 'nice 10/12/2013 01:05'!
displayString: string from: startIndex  to: stopIndex at: aPoint
	self subclassResponsibility! !

!DisplayScanner methodsFor: 'stop conditions' stamp: 'nice 10/10/2013 00:13'!
endOfRun
	"The end of a run in the display case either means that there is actually 
	a change in the style (run code) to be associated with the string or the 
	end of this line has been reached."
	| runLength |
	lastDisplayableIndex := lastIndex.
	lastIndex = line last ifTrue: [^true].
	runLength := text runLengthFor: (lastIndex := lastIndex + 1).
	runStopIndex := lastIndex + (runLength - 1) min: line last.
	"differ reset of stopConditions and font AFTER the dispaly of last scanned string"
	stopConditionsMustBeReset := true.
	^ false! !

!DisplayScanner methodsFor: 'displaying' stamp: 'nice 10/12/2013 00:53'!
fillTextBackground
	self subclassResponsibility! !

!DisplayScanner methodsFor: 'displaying' stamp: 'nice 10/12/2013 03:39'!
initialize
	super initialize.
	ignoreColorChanges := false.! !

!DisplayScanner methodsFor: 'stop conditions' stamp: 'nice 10/8/2013 23:36'!
paddedSpace
	"Each space is a stop condition when the alignment is right justified. 
	Padding must be added to the base width of the space according to 
	which space in the line this space is and according to the amount of 
	space that remained at the end of the line when it was composed."

	lastDisplayableIndex := lastIndex - 1.
	spaceCount := spaceCount + 1.
	destX := destX + spaceWidth + kern + (line justifiedPadFor: spaceCount font: font).
	lastIndex := lastIndex + 1.
	pendingKernX := 0.
	^ false! !

!DisplayScanner methodsFor: 'private' stamp: 'nice 10/19/2013 16:21'!
placeEmbeddedObject: anchoredMorphOrForm
	anchoredMorphOrForm relativeTextAnchorPosition ifNotNil:[:relativeTextAnchorPosition |
		anchoredMorphOrForm position: 
			relativeTextAnchorPosition +
			(anchoredMorphOrForm owner textBounds origin x @ (lineY - morphicOffset y)).
		^true
	].
	(anchoredMorphOrForm isMorph or: [anchoredMorphOrForm isPrimitiveCostume]) ifTrue: [
		anchoredMorphOrForm position: (destX@(lineY + line baseline - anchoredMorphOrForm height)) - morphicOffset
	] ifFalse: [
		self displayEmbeddedForm: anchoredMorphOrForm
	].
	destX := destX + anchoredMorphOrForm width + kern.
	^ true! !

!DisplayScanner methodsFor: 'private' stamp: 'nice 10/11/2013 23:47'!
setFont 
	foregroundColor := self defaultTextColor.
	super setFont.  "Sets font and emphasis bits, and maybe foregroundColor"
	text ifNotNil:[destY := lineY + line baseline - font ascent]! !

!DisplayScanner methodsFor: 'private' stamp: 'nice 10/9/2013 23:39'!
setStopConditions
	super setStopConditions.
	stopConditionsMustBeReset := false! !

!DisplayScanner methodsFor: 'stop conditions' stamp: 'nice 10/13/2013 22:10'!
tab
	lastDisplayableIndex := lastIndex - 1.
	destX := self plainTab.
	lastIndex := lastIndex + 1.
	^ false! !

!DisplayScanner methodsFor: 'text attributes' stamp: 'ar 1/8/2000 14:51'!
textColor: textColor
	ignoreColorChanges ifTrue: [^ self].
	foregroundColor := textColor! !

!DisplayScanner methodsFor: 'private' stamp: 'nice 10/12/2013 01:33'!
text: t textStyle: ts foreground: foreColor background: backColor fillBlt: blt ignoreColorChanges: shadowMode
	text := t.
	textStyle := ts. 
	foregroundColor := defaultTextColor := foreColor.
	backgroundColor := backColor.
	ignoreColorChanges := shadowMode! !

DisplayObject subclass: #DisplayText
	instanceVariableNames: 'text textStyle offset form foreColor backColor'
	classVariableNames: ''
	poolDictionaries: 'TextConstants'
	category: 'Graphics-Display Objects'!

!DisplayText commentStamp: '<historical>' prior: 0!
I represent Text whose emphasis changes are mapped to a set of fonts. My instances have an offset used in determining screen placement for displaying. They get used two different ways in the system. In the user interface, they mainly hold onto some text which is viewed by some form of ParagraphEditor. However, as a DisplayObject, they may need to display efficiently, so my instances have a cache for the bits.!

!DisplayText class methodsFor: 'examples' stamp: 'tk 11/28/2001 16:03'!
example
	"Continually prints two lines of text wherever you point with the cursor.  Terminate by pressing any button on the
	mouse."
	| tx |
	tx := 'this is a line of characters and
this is the second line.' asDisplayText.
	tx foregroundColor: Color black backgroundColor: Color transparent.
	tx := tx alignedTo: #center.
	[Sensor anyButtonPressed]
		whileFalse:
			[tx displayOn: Display at: Sensor cursorPoint]

	"DisplayText example."! !

!DisplayText class methodsFor: 'instance creation' stamp: ''!
text: aText 
	"Answer an instance of me such that the text displayed is aText 
	according to the system's default text style."

	^self new
		setText: aText
		textStyle: DefaultTextStyle copy
		offset: 0 @ 0! !

!DisplayText class methodsFor: 'instance creation' stamp: ''!
text: aText textStyle: aTextStyle 
	"Answer an instance of me such that the text displayed is aText 
	according to the style specified by aTextStyle."

	^self new
		setText: aText
		textStyle: aTextStyle
		offset: 0 @ 0! !

!DisplayText class methodsFor: 'instance creation' stamp: ''!
text: aText textStyle: aTextStyle offset: aPoint 
	"Answer an instance of me such that the text displayed is aText 
	according to the style specified by aTextStyle. The display of the 
	information should be offset by the amount given as the argument, 
	aPoint."

	^self new
		setText: aText
		textStyle: aTextStyle
		offset: aPoint! !

!DisplayText methodsFor: 'accessing' stamp: ''!
alignedTo: alignPointSelector
	"Return a copy with offset according to alignPointSelector which is one of...
	#(topLeft, topCenter, topRight, leftCenter, center, etc)"
	| boundingBox |
	boundingBox := 0@0 corner: self form extent.
	^ self shallowCopy offset: (0@0) - (boundingBox perform: alignPointSelector)! !

!DisplayText methodsFor: 'color' stamp: ''!
backgroundColor
	backColor == nil ifTrue: [^ Color transparent].
	^ backColor! !

!DisplayText methodsFor: 'display box access' stamp: ''!
boundingBox 
	"Refer to the comment in DisplayObject|boundingBox."

	^self form boundingBox! !

!DisplayText methodsFor: 'private' stamp: 'mt 5/4/2016 15:38'!
composeForm

	form := Project current composeDisplayTextIntoForm: self.! !

!DisplayText methodsFor: 'display box access' stamp: ''!
computeBoundingBox 
	"Compute minimum enclosing rectangle around characters."

	| character font width carriageReturn lineWidth lineHeight |
	carriageReturn := Character cr.
	width := lineWidth := 0.
	font := textStyle defaultFont.
	lineHeight := textStyle lineGrid.
	1 to: text size do: 
		[:i | 
		character := text at: i.
		character = carriageReturn
		  ifTrue: 
			[lineWidth := lineWidth max: width.
			lineHeight := lineHeight + textStyle lineGrid.
			width := 0]
		  ifFalse: [width := width + (font widthOf: character)]].
	lineWidth := lineWidth max: width.
	^offset extent: lineWidth @ lineHeight! !

!DisplayText methodsFor: 'displaying' stamp: ''!
displayOnPort: aPort at: location
	self form displayOnPort: aPort at: location + offset! !

!DisplayText methodsFor: 'displaying' stamp: 'yo 6/23/2003 20:05'!
displayOn: aDisplayMedium at: aDisplayPoint clippingBox: clipRectangle rule: ruleInteger fillColor: aForm
	"For TT font, rule 34 is used if possible."
	"Refer to the comment in 
	DisplayObject|displayOn:at:clippingBox:rule:mask:."

	| form1 rule |
	form1 := self form.
	rule := (ruleInteger = Form over and: [backColor isTransparent])
				ifTrue: [form1 depth = 32 ifTrue: [rule := 34] ifFalse: [Form paint]]
				ifFalse: [ruleInteger].
	form1 depth = 32 ifTrue: [rule := 34].
	form1
		displayOn: aDisplayMedium
		at: aDisplayPoint + offset
		clippingBox: clipRectangle
		rule: rule
		fillColor: aForm! !

!DisplayText methodsFor: 'displaying' stamp: ''!
displayOn: aDisplayMedium transformation: displayTransformation clippingBox: clipRectangle align: alignmentPoint with: relativePoint rule: ruleInteger fillColor: aForm 
	"Refer to the comment in 
	DisplayObject|displayOn:transformation:clippingBox:align:with:rule:mask:."

	| absolutePoint |
	absolutePoint := displayTransformation applyTo: relativePoint.
	absolutePoint := absolutePoint x asInteger @ absolutePoint y asInteger.
	self displayOn: aDisplayMedium
		at: absolutePoint - alignmentPoint
		clippingBox: clipRectangle
		rule: ruleInteger
		fillColor: aForm! !

!DisplayText methodsFor: 'accessing' stamp: ''!
fontsUsed
	"Return a list of all fonts used currently in this text.  8/19/96 tk"

	^ text runs values asSet collect: [:each | textStyle fontAt: each]! !

!DisplayText methodsFor: 'color' stamp: ''!
foregroundColor
	foreColor == nil ifTrue: [^ Color black].
	^ foreColor! !

!DisplayText methodsFor: 'color' stamp: ''!
foregroundColor: cf backgroundColor: cb
	foreColor := cf.
	backColor := cb! !

!DisplayText methodsFor: 'accessing' stamp: ''!
form 
	"Answer the form into which the receiver's display bits are cached."

	form == nil ifTrue: [self composeForm].
	^form! !

!DisplayText methodsFor: 'accessing' stamp: ''!
lineGrid
	"Answer the relative space between lines of the receiver's text."

	^textStyle lineGrid! !

!DisplayText methodsFor: 'accessing' stamp: ''!
numberOfLines 
	"Answer the number of lines of text in the receiver."

	^self height // text lineGrid! !

!DisplayText methodsFor: 'accessing' stamp: ''!
offset 
	"Refer to the comment in DisplayObject|offset."

	^offset! !

!DisplayText methodsFor: 'accessing' stamp: ''!
offset: aPoint 
	"Refer to the comment in DisplayObject|offset:."

	offset := aPoint! !

!DisplayText methodsFor: 'private' stamp: ''!
setText: aText textStyle: aTextStyle offset: aPoint

	text := aText.
	textStyle := aTextStyle.
	offset := aPoint.
	form := nil! !

!DisplayText methodsFor: 'accessing' stamp: ''!
string
	"Answer the string of the characters displayed by the receiver."

	^text string! !

!DisplayText methodsFor: 'accessing' stamp: ''!
text 
	"Answer the text displayed by the receiver."

	^text! !

!DisplayText methodsFor: 'accessing' stamp: ''!
textStyle 
	"Answer the style by which the receiver displays its text."

	^textStyle! !

!DisplayText methodsFor: 'accessing' stamp: ''!
textStyle: aTextStyle 
	"Set the style by which the receiver should display its text."

	textStyle := aTextStyle.
	form := nil.
	self changed.
	! !

!DisplayText methodsFor: 'accessing' stamp: ''!
text: aText 
	"Set the receiver to display the argument, aText."
	
	text := aText.
	form := nil.
	self changed.
	! !

CompositionScanner subclass: #SegmentScanner
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: 'TextConstants'
	category: 'Graphics-Text'!

!SegmentScanner commentStamp: 'nice 10/6/2013 22:39' prior: 0!
A SegmentScanner is a CompositionScanner specialized for composing TextOnCurve.
!

AbstractFont subclass: #StrikeFont
	instanceVariableNames: 'characterToGlyphMap xTable glyphs name type minAscii maxAscii maxWidth strikeLength ascent descent xOffset raster subscript superscript emphasis derivativeFonts pointSize fallbackFont charIndexCompatibilitySlot'
	classVariableNames: 'DefaultStringScanner'
	poolDictionaries: 'TextConstants'
	category: 'Graphics-Fonts'!

!StrikeFont commentStamp: 'fbs 11/28/2013 08:50' prior: 0!
I represent a compact encoding of a set of Forms corresponding to characters in the ASCII character set. All the forms are placed side by side in a large form whose height is the font height, and whose width is the sum of all the character widths. The xTable variable gives the left-x coordinates of the subforms corresponding to the glyphs. Characters are mapped to glyphs by using the characterToGyphMap.

Subclasses can have non-trivial mapping rules as well as different representations for glyphs sizes (e.g., not using an xTable). If so, these classes should return nil when queried for xTable and/or the characterToGlyphMap. This will cause the CharacterScanner primitive to fail and query the font for the width of a character (so that a more programatical approach can be implemented).

For display, fonts need to implement two messages:
	#installOn: aDisplayContext foregroundColor: foregroundColor backgroundColor: backgroundColor
This method installs the receiver (a font) on the given DisplayContext (which may be an instance of BitBlt or Canvas (or any of its subclasses). The font should take the appropriate action to initialize the display context so that further display operations can be optimized.
	#displayString: aString on: aDisplayContext from: startIndex to: stopIndex at: aPoint kern: kernDelta
This method is called for each subsequent run of characters in aString which is to be displayed with the (previously installed) settings.
!

StrikeFont subclass: #FormSetFont
	instanceVariableNames: 'tintable combinationRule'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Fonts'!

!FormSetFont commentStamp: '<historical>' prior: 0!
FormSetFonts are designed to capture individual images as character forms for imbedding in normal text.  While most often used to insert an isolated glyph in some text, the code is actually desinged to support an entire user-defined font.  The TextAttribute subclass TextFontReference is specifically designed for such in-line insertion of exceptional fonts in normal text.!

!FormSetFont class methodsFor: 'examples' stamp: 'ar 1/15/2001 18:38'!
copy: charForm toClipBoardAs: char ascent: ascent
	Clipboard clipboardText:
		(Text string: char asString
			attribute: (TextFontReference toFont: 
				(FormSetFont new
					fromFormArray: (Array with: charForm)
					asciiStart: char asciiValue
					ascent: ascent)))
"
	The S in the Squeak welcome window was installed by doing the following
	in a workspace (where the value of, eg, charForm will persist through BitEdit...
	f := TextStyle default fontAt: 4.
	oldS := f characterFormAt: $S.
	charForm := Form extent: oldS extent depth: 8.
	oldS displayOn: charForm.
	charForm bitEdit.
	...Play around with the BitEditor, then accept and close...
	FormSetFont copy: charForm toClipBoardAs: $S ascent: f ascent.
	...Then do a paste into the Welcome window
"! !

!FormSetFont class methodsFor: 'examples' stamp: ''!
example    "FormSetFont example"
	"Lets the user select a (small) area of the screen to represent the
	character A, then copies 'A' to the clipboard with that as the letter form.
	Thereafter, a paste operation will imbed that character in any text."
	| charForm |
	charForm := Form fromUser.
	self copy: charForm toClipBoardAs: $A ascent: charForm height! !

!FormSetFont methodsFor: 'accessing' stamp: 'mt 8/11/2016 10:08'!
combinationRule

	^ combinationRule! !

!FormSetFont methodsFor: 'accessing' stamp: 'mt 8/11/2016 10:08'!
combinationRule: anObject

	combinationRule := anObject! !

!FormSetFont methodsFor: 'as yet unclassified' stamp: 'mt 8/11/2016 10:09'!
displayString: aString on: aBitBlt from: startIndex to: stopIndex at: aPoint kern: kernDelta
	"Draw the given string from startIndex to stopIndex "

	combinationRule ifNotNil: [:r | aBitBlt combinationRule: r].
	tintable == false ifTrue: [aBitBlt colorMap: nil].
	
	^ super displayString: aString on: aBitBlt from: startIndex to: stopIndex at: aPoint kern: kernDelta! !

!FormSetFont methodsFor: 'as yet unclassified' stamp: 'ar 5/23/2000 12:49'!
fromFormArray: formArray asciiStart: asciiStart ascent: ascentVal
	| height width x badChar |
	type := 2.
	name := 'aFormFont'.
	minAscii := asciiStart.
	maxAscii := minAscii + formArray size - 1.
	ascent := ascentVal.
	subscript := superscript := emphasis := 0.
	height := width := 0.
	maxWidth := 0.
	formArray do:
		[:f | width := width + f width.
		maxWidth := maxWidth max: f width.
		height := height max: f height + f offset y].
	badChar := (Form extent: 7@height) borderWidth: 1.
	width := width + badChar width.
	descent := height - ascent.
	pointSize := height.
	glyphs := Form extent: width @ height depth: formArray first depth.
	xTable := Array new: maxAscii + 3 withAll: 0.
	x := 0.
	formArray doWithIndex:
		[:f :i | f displayOn: glyphs at: x@0.
		xTable at: minAscii + i+1 put: (x := x + f width)].
	badChar displayOn: glyphs at: x@0.
	xTable at: maxAscii + 3 put: x + badChar width.
	characterToGlyphMap := nil.! !

!FormSetFont methodsFor: 'as yet unclassified' stamp: 'mt 8/11/2016 10:16'!
initialize

	super initialize.
	self preserveColors.! !

!FormSetFont methodsFor: 'as yet unclassified' stamp: 'mt 8/11/2016 10:13'!
makeTintable
	"Default."
	
	self tintable: true.
	self combinationRule: Form over.! !

!FormSetFont methodsFor: 'as yet unclassified' stamp: 'mt 8/11/2016 10:12'!
preserveColors

	self tintable: false.
	self combinationRule: Form paint.! !

!FormSetFont methodsFor: 'as yet unclassified' stamp: 'mt 8/11/2016 10:14'!
preserveColorsWithAlpha
	"Useful for rendering Emojis."
	
	self tintable: false.
	self combinationRule: Form blend.! !

!FormSetFont methodsFor: 'as yet unclassified' stamp: ''!
reset  "Ignored by FormSetFonts"! !

!FormSetFont methodsFor: 'accessing' stamp: 'mt 8/11/2016 10:08'!
tintable

	^ tintable! !

!FormSetFont methodsFor: 'accessing' stamp: 'mt 8/11/2016 10:08'!
tintable: anObject

	tintable := anObject! !

StrikeFont subclass: #HostFont
	instanceVariableNames: 'fullWidth kernPairs ranges'
	classVariableNames: 'IsoToSqueakMap'
	poolDictionaries: 'TextConstants'
	category: 'Graphics-Fonts'!

!HostFont class methodsFor: 'accessing' stamp: 'yo 2/14/2004 01:50'!
defaultRanges

	^ Array with: (Array with: 0 with: 16r2AFF).
! !

!HostFont class methodsFor: 'accessing' stamp: 'rbb 2/18/2005 13:23'!
fontNameFromUser
	"HostFont fontNameFromUser"
	| fontNames index labels |
	fontNames := self listFontNames asSortedCollection.
	labels := WriteStream on: (String new: 100).
	fontNames do:[:fn| labels nextPutAll: fn] separatedBy:[labels cr].
	index := (UIManager default chooseFrom: (labels contents substrings) title: 'Choose your font').
	index = 0 ifTrue:[^nil].
	^fontNames at: index! !

!HostFont class methodsFor: 'instance creation' stamp: 'ar 6/4/2000 23:13'!
fontName: fontName size: ptSize emphasis: emphasisCode
	"
		^HostFont fontName: (HostFont fontNameFromUser) size: 12 emphasis: 0.
	"
	^self new fontName: fontName size: ptSize emphasis: emphasisCode! !

!HostFont class methodsFor: 'instance creation' stamp: 'yo 2/14/2004 01:17'!
fontName: fontName size: ptSize emphasis: emphasisCode rangesArray: ranges
	"
		^HostFont fontName: (HostFont fontNameFromUser) size: 12 emphasis: 0.
	"
	^self new fontName: fontName size: ptSize emphasis: emphasisCode rangesArray: ranges! !

!HostFont class methodsFor: 'system defaults' stamp: 'yo 2/13/2004 23:25'!
initWin32
	"HostFont initWin32"
	#(
			"Basic fonts"
			('Arial'				"menu/text serifless"
				(10 11 12 13 14 16 18 20 22 24 26 28 30 36 48 60 72 90))
			('Times New Roman'	"menu/text serifs"
				(10 11 12 13 14 16 18 20 22 24 26 28 30 36 48 60 72 90))
			('Courier New'			"menu/text fixed"
				(10 11 12 13 14 16 18 20 22 24 26 28 30 36 48 60 72 90))
			('Wingdings'			"deco"
				(10 11 12 13 14 16 18 20 22 24 26 28 30 36 48 60 72 90))
			('Symbol'				"deco"
				(10 11 12 13 14 16 18 20 22 24 26 28 30 36 48 60 72 90))

			"Nice fonts"
			('Verdana'			"menu/text serifless"
				(10 11 12 13 14 16 18 20 22 24 26 28 30 36 48 60 72 90))

			('Tahoma'			"menu/text serifless"
				(10 11 12 13 14 16 18 20 22 24 26 28 30 36 48 60 72 90))

			('Garamond'			"menu/text serifs"
				(10 11 12 13 14 16 18 20 22 24 26 28 30 36 48 60 72 90))
			('Georgia'			"menu/text serifs"
				(10 11 12 13 14 16 18 20 22 24 26 28 30 36 48 60 72 90))

			('Comic Sans MS'	"eToy"
				(10 11 12 13 14 16 18 20 22 24 26 28 30 36 48 60 72 90))

			"Optional fonts"
			('Impact'			"flaps"
				(10 11 12 13 14 16 18 20 22 24 26 28 30 36 48 60 72 90))

			('Webdings'			"deco"
				(10 11 12 13 14 16 18 20 22 24 26 28 30 36 48 60 72 90))

			('System'		"12pt only"
				(12))
			('Fixedsys'		"12pt only"
				(12))
		) do:[:spec| HostFont textStyleFrom: spec first sizes: spec last].

	TextConstants removeKey: #Atlanta ifAbsent: [].
	TextConstants removeKey: #ComicPlain ifAbsent: [].
	TextConstants removeKey: #ComicBold ifAbsent: [].
	TextConstants removeKey: #Courier ifAbsent: [].
	TextConstants removeKey: #Palatino ifAbsent: [].

	TextConstants at: #DefaultFixedTextStyle put: (TextConstants at: #'Courier New').
	TextConstants at: #Helvetica put:  (TextConstants at: #'Arial').

! !

!HostFont class methodsFor: 'accessing' stamp: 'ar 6/4/2000 23:18'!
listFontNames
	"HostFont listFontNames"
	"List all the OS font names"
	| font fontNames index |
	fontNames := WriteStream on: Array new.
	index := 0.
	[font := self listFontName: index.
	font == nil] whileFalse:[
		fontNames nextPut: font.
		index := index + 1].
	^fontNames contents! !

!HostFont class methodsFor: 'accessing' stamp: 'ar 6/4/2000 23:18'!
listFontName: index
	<primitive:'primitiveListFont' module:'FontPlugin'>
	^nil! !

!HostFont class methodsFor: 'accessing' stamp: 'yo 2/14/2004 01:57'!
rangesForJapanese

	| basics etc |
	basics := {
		Array with: 0 with: 255
	}.
	etc := {
		Array with: 16r370 with: 16r3FF. "greek"
		Array with: 16r400 with: 16r52F. "cyrillic"
		Array with: 16r1D00 with: 16r1D7F. "phonetic"
		Array with: 16r1E00 with: 16r1EFF. "latin extended additional"
		Array with: 16r2000 with: 16r206F. "general punctuation"
		Array with: 16r20A0 with: 16r20CF. "currency symbols"
		Array with: 16r2100 with: 16r214F. "letterlike"
		Array with: 16r2150 with: 16r218F. "number form"
		Array with: 16r2190 with: 16r21FF. "arrows"
		Array with: 16r2200 with: 16r22FF. "math operators"
		Array with: 16r2300 with: 16r23FF. "misc tech"
		Array with: 16r2460 with: 16r24FF. "enclosed alnum"
		Array with: 16r2500 with: 16r257F. "box drawing"
		Array with: 16r2580 with: 16r259F. "box elem"
		Array with: 16r25A0 with: 16r25FF. "geometric shapes"
		Array with: 16r2600 with: 16r26FF. "misc symbols"
		Array with: 16r2700 with: 16r27BF. "dingbats"
		Array with: 16r27C0 with: 16r27EF. "misc math A"
		Array with: 16r27F0 with: 16r27FF. "supplimental arrow A"
		Array with: 16r2900 with: 16r297F. "supplimental arrow B"
		Array with: 16r2980 with: 16r29FF. "misc math B"
		Array with: 16r2A00 with: 16r2AFF. "supplimental math op"
		Array with: 16r2900 with: 16r297F. "supplimental arrow B"
		Array with: 16r2E80 with: 16r2EFF. "cjk radicals suppliment"
		Array with: 16r2F00 with: 16r2FDF. "kangxi radicals"
		Array with: 16r3000 with: 16r303F. "cjk symbols"
		Array with: 16r3040 with: 16r309F. "hiragana"
		Array with: 16r30A0 with: 16r30FF. "katakana"
		Array with: 16r3190 with: 16r319F. "kanbun"
		Array with: 16r31F0 with: 16r31FF. "katakana extension"
		Array with: 16r3200 with: 16r32FF. "enclosed CJK"
		Array with: 16r3300 with: 16r33FF. "CJK compatibility"
		Array with: 16r3400 with: 16r4DBF. "CJK unified extension A"
		Array with: 16r4E00 with: 16r9FAF. "CJK ideograph"
		Array with: 16rF900 with: 16rFAFF. "CJK compatiblity ideograph"
		Array with: 16rFE30 with: 16rFE4F. "CJK compatiblity forms"
		Array with: 16rFF00 with: 16rFFEF. "half and full"
	}.

	^ basics, etc.
! !

!HostFont class methodsFor: 'accessing' stamp: 'cmm 6/15/2011 10:59'!
textStyleFromUser
	"HostFont textStyleFromUser"
	| styleName fonts |
	styleName := self fontNameFromUser ifNil:[^self].
	styleName := styleName asSymbol.
	(TextConstants includesKey: styleName)
		ifTrue:[(self confirm: 
styleName , ' is already defined in TextConstants.
Do you want to replace that definition?')
			ifFalse: [^ self]].
	fonts := #(10 12 14 16 18 20 22 24 26 28 30 36 48 60 72 90).
	('Rendering ', styleName) displayProgressFrom: 1 to: fonts size during:[:bar|
			fonts := fonts
				collect:[:ptSize| bar value: (fonts indexOf: ptSize).
							   self fontName: styleName 
									size: ptSize
									emphasis: 0]
				thenSelect:[:font| font notNil]]. "reject those that failed"
	fonts size = 0 ifTrue:[^self error:'Could not create font style', styleName].
	TextConstants
		at: styleName
		put: (TextStyle fontArray: fonts).! !

!HostFont class methodsFor: 'accessing' stamp: 'cmm 6/15/2011 10:59'!
textStyleFrom: fontName
	"HostFont textStyleFromUser"
	| styleName fonts |
	styleName := fontName asSymbol.
	"(TextConstants includesKey: styleName)
		ifTrue:[(self confirm: 
styleName , ' is already defined in TextConstants.
Do you want to replace that definition?')
			ifFalse: [^ self]]."
	fonts := #(10 11 12 13 14 16 18 20 22 24 26 28 30 36 48 60 72 90).
	('Rendering ', styleName) displayProgressFrom: 1 to: fonts size during:[:bar|
			fonts := fonts
				collect:[:ptSize| bar value: (fonts indexOf: ptSize).
							   self fontName: styleName 
									size: ptSize
									emphasis: 0]
				thenSelect:[:font| font notNil]]. "reject those that failed"
	fonts size = 0 ifTrue:[^self error:'Could not create font style', styleName].
	TextConstants
		at: styleName
		put: (TextStyle fontArray: fonts).! !

!HostFont class methodsFor: 'accessing' stamp: 'cmm 6/15/2011 10:59'!
textStyleFrom: fontName sizes: ptSizes
	| styleName fonts |
	styleName := fontName asSymbol.
	(TextConstants includesKey: styleName)
		ifTrue:[(self confirm: 
styleName , ' is already defined in TextConstants.
Do you want to replace that definition?')
			ifFalse: [^ self]].
	('Rendering ', styleName) displayProgressFrom: 1 to: ptSizes size during:[:bar|
			fonts := ptSizes
				collect:[:ptSize| bar value: (ptSizes indexOf: ptSize).
							   self fontName: styleName 
									size: ptSize
									emphasis: 0]
				thenSelect:[:font| font notNil]]. "reject those that failed"
	fonts size = 0 ifTrue:[^self error:'Could not create font style', styleName].
	TextConstants
		at: styleName
		put: (TextStyle fontArray: fonts).! !

!HostFont class methodsFor: 'accessing' stamp: 'cmm 6/15/2011 10:59'!
textStyleFrom: fontName sizes: ptSizes ranges: ranges
	| styleName fonts |
	styleName := fontName asSymbol.
	(TextConstants includesKey: styleName)
		ifTrue:[(self confirm: 
styleName , ' is already defined in TextConstants.
Do you want to replace that definition?')
			ifFalse: [^ self]].
	('Rendering ', styleName) displayProgressFrom: 1 to: ptSizes size during:[:bar|
			fonts := ptSizes
				collect:[:ptSize| bar value: (ptSizes indexOf: ptSize).
							   self fontName: styleName 
									size: ptSize
									emphasis: 0 rangesArray: ranges
				]
				thenSelect:[:font| font notNil]]. "reject those that failed"
	fonts size = 0 ifTrue:[^self error:'Could not create font style', styleName].
	TextConstants
		at: styleName
		put: (TextStyle fontArray: fonts).! !

!HostFont methodsFor: 'accessing' stamp: 'ar 2/2/2002 18:49'!
baseKern
	^0! !

!HostFont methodsFor: 'accessing' stamp: 'yo 2/13/2004 04:06'!
createCharacterToGlyphMap

	^ IdentityGlyphMap new.
! !

!HostFont methodsFor: 'accessing' stamp: 'ar 2/2/2002 18:49'!
descentKern
	^0! !

!HostFont methodsFor: 'accessing' stamp: 'yo 1/7/2005 12:03'!
displayString: aString on: aBitBlt from: startIndex to: stopIndex at: aPoint kern: kernDelta 

	^ self displayString: aString on: aBitBlt from: startIndex to: stopIndex at: aPoint kern: kernDelta baselineY: aPoint y + self ascent.
! !

!HostFont methodsFor: 'accessing' stamp: 'yo 1/7/2005 15:14'!
displayString: aString on: aBitBlt from: startIndex to: stopIndex at: aPoint kern: kernDelta baselineY: baselineY

 	^ super displayMultiString: aString on: aBitBlt from: startIndex to: stopIndex at: aPoint kern: kernDelta baselineY: baselineY.
! !

!HostFont methodsFor: 'emphasis' stamp: 'ar 8/29/2000 21:18'!
emphasized: code
	| derivative addedEmphasis base safeCode |
	code = 0 ifTrue: [^ self].
	derivativeFonts == nil ifTrue:[derivativeFonts := Array new: 32].
	derivative := derivativeFonts at: (safeCode := code min: derivativeFonts size).
	derivative == nil ifFalse: [^ derivative].  "Already have this style"

	"Dont have it -- derive from another with one with less emphasis"
	addedEmphasis := 1 bitShift: safeCode highBit - 1.
	base := self emphasized: safeCode - addedEmphasis.  "Order is Bold, Ital, Under, Narrow"
	addedEmphasis = 1 ifTrue:   "Compute synthetic bold version of the font"
		[derivative := (base copy name: base name) makeBoldGlyphs].
	addedEmphasis = 2 ifTrue:   "Compute synthetic italic version of the font"
		[ derivative := (base copy name: base name) makeItalicGlyphs].
	addedEmphasis = 4 ifTrue:   "Compute underlined version of the font"
		[derivative := (base copy name: base name) makeUnderlinedGlyphs].
	addedEmphasis = 8 ifTrue:   "Compute narrow version of the font"
		[derivative := (base copy name: base name) makeCondensedGlyphs].
	addedEmphasis = 16 ifTrue:   "Compute struck-out version of the font"
		[derivative := (base copy name: base name) makeStruckOutGlyphs].
	derivative emphasis: safeCode.
	derivativeFonts at: safeCode put: derivative.
	^ derivative! !

!HostFont methodsFor: 'private-creation' stamp: 'yo 2/14/2004 01:38'!
fontName: fontName size: ptSize emphasis: emphasisCode

	^ self fontName: fontName size: ptSize emphasis: emphasisCode rangesArray: (Array with: (Array with: 0 with: 255)).
! !

!HostFont methodsFor: 'private-creation' stamp: 'yo 2/14/2004 01:41'!
fontName: fontName size: ptSize emphasis: emphasisCode rangesArray: rangesArray
	"
		^HostFont fontName: ('MS UI Gothic') size: 12 emphasis: 0 rangesArray: EFontBDFFontReaderForRanges basicNew rangesForJapanese.
	"
	| fontHandle xStart w glyphForm fontHeight fw enc rangesStream currentRange |
	fontHandle := self primitiveCreateFont: fontName size: ptSize emphasis: emphasisCode.
	fontHandle ifNil:[^nil].
	ranges := rangesArray.
	ranges ifNil: [ranges := Array with: (Array with: 0 with: 255)].
	pointSize := ptSize.
	name := fontName.
	emphasis := emphasisCode.
	minAscii := 0.
	maxAscii := ranges last last.
	ascent := self primitiveFontAscent: fontHandle.
	descent := self primitiveFontDescent: fontHandle.
	kernPairs := Array new: (self primitiveFontNumKernPairs: fontHandle).
	1 to: kernPairs size do:[:i|
		kernPairs at: i put: (self primitiveFont: fontHandle getKernPair: i)].
	fontHeight := ascent + descent.
	xTable := Array new: maxAscii + 3.
	fullWidth := Array new: maxAscii + 1.
	xStart := maxWidth := 0.
	rangesStream := ReadStream on: (ranges collect: [:e | (e first to: e second)]).
	currentRange := rangesStream next.
	0 to: maxAscii do:[:i|
		xTable at: i+1 put: xStart.
		i > currentRange last ifTrue: [
			[rangesStream atEnd not and: [currentRange := rangesStream next. currentRange last < i]] whileTrue.
			rangesStream atEnd ifTrue: [].
		].
		(currentRange includes: i) ifTrue: [
			xTable at: i+1 put: xStart.
			fw := self primitiveFont: fontHandle fullWidthOfChar: i.
			(#(	1 "anchored morph"
				9 "tab"
				10 "LF"
				13 "CR"
			) includes: i) ifTrue:[fw := {0. 0. 0}].
			fullWidth at: i+1 put: fw.
			w := fw at: 2.
			(fw at: 1) > 0 ifTrue:[w := w + (fw at: 1)].
			(fw at: 3) > 0 ifTrue:[w := w + (fw at: 3)].
			w > maxWidth ifTrue:[maxWidth := w].
			xStart := xStart + w].
		].
	xStart = 0 ifTrue:[^nil].
	strikeLength := xStart.
	xTable at: maxAscii+1 put: xStart.
	xTable at: maxAscii+2 put: xStart.
	xTable at: maxAscii+3 put: xStart.
	glyphs := Form extent: xTable last @ fontHeight depth: 1.
	glyphForm := Form extent: maxWidth @ fontHeight depth: 1.
	0 to: maxAscii do:[:i|
		glyphForm fillWhite.
		self primitiveFont: fontHandle glyphOfChar: i into: glyphForm.
		xStart := xTable at: i+1.
		glyphForm displayOn: glyphs at: xStart@0.
		"glyphForm displayOn: Display at: xStart@0."
	].
	enc := self primitiveFontEncoding: fontHandle.
	enc = 1 ifTrue:[characterToGlyphMap := self isoToSqueakMap].
	self primitiveDestroyFont: fontHandle.
	^self! !

!HostFont methodsFor: 'accessing' stamp: 'ar 2/18/2001 20:01'!
getFontData
	| fontHandle bufSize buffer |
	fontHandle := self primitiveCreateFont: name size: pointSize emphasis: emphasis.
	fontHandle ifNil:[^nil].
	bufSize := self primitiveFontDataSize: fontHandle.
	buffer := ByteArray new: bufSize.
	self primitiveFont: fontHandle getData: buffer.
	^buffer! !

!HostFont methodsFor: 'private-creation' stamp: 'yo 2/13/2004 02:53'!
isoToSqueakMap
	^nil
! !

!HostFont methodsFor: 'emphasis' stamp: 'yo 2/14/2004 01:38'!
makeBoldGlyphs
	"First check if we can use some OS support for this"
	(self class listFontNames includes: name) ifFalse:[^super makeBoldGlyphs].
	"Now attempt a direct creation through the appropriate primitives"
	(self fontName: name size: pointSize emphasis: (emphasis bitOr: 1) rangesArray: ranges) 
		ifNil:[^super makeBoldGlyphs]. "nil means we failed"! !

!HostFont methodsFor: 'emphasis' stamp: 'yo 2/14/2004 01:39'!
makeItalicGlyphs
	"First check if we can use some OS support for this"
	(self class listFontNames includes: name) ifFalse:[^super makeItalicGlyphs].
	"Now attempt a direct creation through the appropriate primitives"
	(self fontName: name size: pointSize emphasis: (emphasis bitOr: 2) rangesArray: ranges)
		ifNil:[^super makeItalicGlyphs]. "nil means we failed"! !

!HostFont methodsFor: 'emphasis' stamp: 'yo 2/14/2004 01:39'!
makeStruckOutGlyphs
	"First check if we can use some OS support for this"
	(self class listFontNames includes: name) ifFalse:[^super makeStruckOutGlyphs].
	"Now attempt a direct creation through the appropriate primitives"
	(self fontName: name size: pointSize emphasis: (emphasis bitOr: 8) rangesArray: ranges)
		ifNil:[^super makeStruckOutGlyphs]. "nil means we failed"! !

!HostFont methodsFor: 'emphasis' stamp: 'yo 2/14/2004 01:40'!
makeUnderlinedGlyphs
	"First check if we can use some OS support for this"
	(self class listFontNames includes: name) ifFalse:[^super makeUnderlinedGlyphs].
	"Now attempt a direct creation through the appropriate primitives"
	(self fontName: name size: pointSize emphasis: (emphasis bitOr: 4) rangesArray: ranges)
		ifNil:[^super makeUnderlinedGlyphs]. "nil means we failed"! !

!HostFont methodsFor: 'primitives' stamp: 'ar 6/4/2000 23:11'!
primitiveCreateFont: fontName size: fontSize emphasis: fontFlags
	<primitive:'primitiveCreateFont' module:'FontPlugin'>
	^nil! !

!HostFont methodsFor: 'primitives' stamp: 'ar 6/4/2000 23:01'!
primitiveDestroyFont: fontHandle
	<primitive:'primitiveDestroyFont' module:'FontPlugin'>
	^self primitiveFailed! !

!HostFont methodsFor: 'primitives' stamp: 'ar 6/4/2000 23:01'!
primitiveFontAscent: fontHandle
	<primitive:'primitiveFontAscent' module:'FontPlugin'>
	^self primitiveFailed! !

!HostFont methodsFor: 'primitives' stamp: 'ar 2/18/2001 19:45'!
primitiveFontDataSize: fontHandle
	<primitive:'primitiveFontDataSize' module:'FontPlugin'>
	^self primitiveFailed! !

!HostFont methodsFor: 'primitives' stamp: 'ar 6/4/2000 23:01'!
primitiveFontDescent: fontHandle
	<primitive:'primitiveFontDescent' module:'FontPlugin'>
	^self primitiveFailed! !

!HostFont methodsFor: 'primitives' stamp: 'ar 2/18/2001 20:00'!
primitiveFontEmbeddingFlags: fontHandle
	<primitive:'primitiveFontEmbeddingFlags' module:'FontPlugin'>
	^self primitiveFailed! !

!HostFont methodsFor: 'primitives' stamp: 'ar 6/4/2000 23:02'!
primitiveFontEncoding: fontHandle
	<primitive:'primitiveFontEncoding' module:'FontPlugin'>
	^self primitiveFailed! !

!HostFont methodsFor: 'primitives' stamp: 'ar 8/28/2000 16:04'!
primitiveFontNumKernPairs: fontHandle
	<primitive:'primitiveFontNumKernPairs' module:'FontPlugin'>
	^0! !

!HostFont methodsFor: 'primitives' stamp: 'nk 8/31/2004 09:19'!
primitiveFont: fontHandle fullWidthOfChar: aCharIndex 
	<primitive:'primitiveFontFullWidthOfChar' module:'FontPlugin'>
	^Array 
		with: 0
		with: (self primitiveFont: fontHandle widthOfChar: aCharIndex)
		with: 0! !

!HostFont methodsFor: 'primitives' stamp: 'ar 2/18/2001 19:46'!
primitiveFont: fontHandle getData: buffer
	<primitive:'primitiveGetFontData' module:'FontPlugin'>
	^self primitiveFailed! !

!HostFont methodsFor: 'primitives' stamp: 'ar 8/28/2000 16:05'!
primitiveFont: fontHandle getKernPair: kernIndex
	<primitive:'primitiveFontGetKernPair' module:'FontPlugin'>
	^0! !

!HostFont methodsFor: 'primitives' stamp: 'nk 8/31/2004 09:19'!
primitiveFont: fontHandle glyphOfChar: aCharIndex into: glyphForm 
	<primitive:'primitiveFontGlyphOfChar' module:'FontPlugin'>
	^self primitiveFailed! !

!HostFont methodsFor: 'primitives' stamp: 'nk 8/31/2004 09:19'!
primitiveFont: fontHandle widthOfChar: aCharIndex 
	<primitive:'primitiveFontWidthOfChar' module:'FontPlugin'>
	^self primitiveFailed! !

!HostFont methodsFor: 'accessing' stamp: 'nice 12/27/2009 03:11'!
testEmbeddingFlags
	"HostFont basicNew testEmbeddingFlags"
	| list |
	list := self class listFontNames.
	list do:[:fName| | fontHandle |
		fontHandle := self primitiveCreateFont: fName size: 12 emphasis: 0.
		fontHandle ifNotNil:[
			type := self primitiveFontEmbeddingFlags: fontHandle.
			Transcript cr; show: fName,': ', type printString.
			self primitiveDestroyFont: fontHandle.
		].
	].! !

!StrikeFont class methodsFor: 'accessing' stamp: 'nk 9/1/2004 11:00'!
actualFamilyNames
	"Answer a sorted list of actual family names, without the Default aliases"

	^(self familyNames copyWithoutAll: TextStyle defaultFamilyNames) asOrderedCollection! !

!StrikeFont class methodsFor: 'class initialization' stamp: 'ar 2/26/2010 23:05'!
cleanUp
	"Flush synthesized strike fonts"

	self allInstancesDo:[:sf| sf reset].! !

!StrikeFont class methodsFor: 'examples' stamp: 'nice 12/26/2009 22:07'!
convertFontsNamed: familyName  " StrikeFont convertFontsNamed: 'NewYork' "
	"This utility is for use after you have used BitFont to produce data files 
	for the fonts you wish to use.  It will read the BitFont files and then 
	write them out in strike2 (*.sf2) format which is much more compact,
	and which can be read in again very quickly."
	"For this utility to work as is, the BitFont data files must be named
	'familyNN.BF', and must reside in the same directory as the image."
	(FileDirectory default fileNamesMatching: familyName , '*.BF') do:
		[:fname |
		| f |
		Transcript cr; show: fname.
		f := StrikeFont new readFromBitFont: fname.
		f writeAsStrike2named: f name , '.sf2']! !

!StrikeFont class methodsFor: 'font creation' stamp: 'topa 6/10/2016 10:53'!
createDejaVuDark: pointSize
	
	| base bold oblique boldOblique point |
	point := pointSize asString.
	base := (StrikeFont new
		buildFromForm: (self perform: ('dejaVuSansBookDark', point, 'Form') asSymbol)
		data: (self perform: ('dejaVuSansBookDark', point, 'Data') asSymbol)
		name: 'Darkmap DejaVu Sans', point)
			pointSize: pointSize.
	bold := (StrikeFont new
		buildFromForm:  (self perform: ('dejaVuSansBoldDark', point, 'Form') asSymbol)
		data: (self perform: ('dejaVuSansBoldDark', point, 'Data') asSymbol)
		name: 'Darkmap DejaVu Sans', point, 'B')
			emphasis: 1;
			pointSize: pointSize.
	oblique := (StrikeFont new
		buildFromForm: (self perform: ('dejaVuSansObliqueDark', point, 'Form') asSymbol)
		data: (self perform: ('dejaVuSansObliqueDark', point, 'Data') asSymbol)
		name: 'Darkmap DejaVu Sans', point, 'I')
			emphasis: 2;
			pointSize: pointSize.
	boldOblique := (StrikeFont new
		buildFromForm: (self perform: ('dejaVuSansBoldObliqueDark', point, 'Form') asSymbol)
		data: (self perform: ('dejaVuSansBoldObliqueDark', point, 'Data') asSymbol)
		name: 'Darkmap DejaVu Sans', point, 'BI')
			emphasis: 3;
			pointSize: pointSize.
		
	base derivativeFont: bold at: 1.
	base derivativeFont: oblique at: 2.
	base derivativeFont: boldOblique at: 3.
	
	^base! !

!StrikeFont class methodsFor: 'font creation' stamp: 'jmv 8/4/2009 09:55'!
createDejaVu: pointSize
	"Warning: Uses the methods in 'dejaVu font data' category, that will be removed soon (or are already removed) to save space."
	
	| base bold oblique boldOblique point |
	point := pointSize asString.
	base := (StrikeFont new
		buildFromForm: (self perform: ('dejaVuSansBook', point, 'Form') asSymbol)
		data: (self perform: ('dejaVuSansBook', point, 'Data') asSymbol)
		name: 'Bitmap DejaVu Sans ', point)
			pointSize: pointSize.
	bold := (StrikeFont new
		buildFromForm:  (self perform: ('dejaVuSansBold', point, 'Form') asSymbol)
		data: (self perform: ('dejaVuSansBold', point, 'Data') asSymbol)
		name: 'Bitmap DejaVu Sans ', point, 'B')
			emphasis: 1;
			pointSize: pointSize.
	oblique := (StrikeFont new
		buildFromForm: (self perform: ('dejaVuSansOblique', point, 'Form') asSymbol)
		data: (self perform: ('dejaVuSansOblique', point, 'Data') asSymbol)
		name: 'Bitmap DejaVu Sans ', point, 'I')
			emphasis: 2;
			pointSize: pointSize.
	boldOblique := (StrikeFont new
		buildFromForm: (self perform: ('dejaVuSansBoldOblique', point, 'Form') asSymbol)
		data: (self perform: ('dejaVuSansBoldOblique', point, 'Data') asSymbol)
		name: 'Bitmap DejaVu Sans ', point, 'BI')
			emphasis: 3;
			pointSize: pointSize.
		
	base derivativeFont: bold at: 1.
	base derivativeFont: oblique at: 2.
	base derivativeFont: boldOblique at: 3.
	
	^base! !

!StrikeFont class methodsFor: 'accessing' stamp: 'ar 9/6/2010 11:33'!
defaultSized: aNumber
	| fonts f |
	"This used to be the default textstyle, but it needs to be a StrikeFont and not a TTCFont and sometimes the default textstyle is a TTCFont.  So, we use a typical StrikeFont as the default fallback font."
	fonts := (TextConstants at: #Accuny ifAbsent:[TextStyle default]) fontArray.
	f := fonts first.
	1 to: fonts size do: [:i |
		aNumber > (fonts at: i) height ifTrue: [f := fonts at: i].
	].
	^f
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBold12Data
	<generated>
	" Font meta data for DejaVu Sans Bold 12. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 12 15 4 0 255 18 0 0 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 16 23 31 44 55 71 85 90 97 104 112 125 131 138 144 150 161 172 183 194 205 216 227 238 249 260 266 272 285 298 311 320 336 348 360 372 385 396 407 420 433 439 445 457 467 483 496 510 522 536 548 560 571 584 596 614 626 638 650 657 663 670 683 691 699 710 721 730 741 752 759 770 781 786 791 802 807 824 835 846 857 868 876 886 894 905 915 930 940 950 959 970 976 987 1000 1000 1013 1021 1034 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1053 1060 1071 1082 1092 1103 1109 1117 1125 1141 1150 1160 1173 1180 1196 1204 1212 1225 1232 1239 1247 1259 1269 1275 1283 1290 1299 1309 1326 1343 1360 1369 1381 1393 1405 1417 1429 1441 1458 1470 1481 1492 1503 1514 1520 1526 1532 1538 1551 1564 1578 1592 1606 1620 1634 1647 1661 1674 1687 1700 1713 1725 1737 1749 1760 1771 1782 1793 1804 1815 1832 1841 1852 1863 1874 1885 1890 1895 1901 1906 1917 1928 1939 1950 1961 1972 1983 1996 2007 2018 2029 2040 2051 2061 2072 2082
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:34'!
dejaVuSansBold12Form
	<generated>
	" Form data for DejaVu Sans Bold 12. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAACCIAAAATCAIAAADAwKnYAAA51klEQVR4Aexaq6K0LBSdJ5p3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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/10/2016 10:48'!
dejaVuSansBold13Data
	<generated>
	" Font meta data for DejaVu Sans Bold 13. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 13 16 4 0 128576 42 0 0 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 16 24 33 47 59 76 91 96 104 112 121 135 142 149 156 162 174 186 198 210 222 234 246 258 270 282 289 296 310 324 338 348 365 378 391 404 418 430 442 456 470 476 483 496 507 524 538 553 566 581 594 606 618 632 645 664 677 690 702 710 716 724 738 747 756 768 780 790 802 814 821 833 845 851 857 868 874 892 904 916 928 940 948 958 966 978 989 1005 1016 1027 1037 1049 1055 1067 1081 1081 1095 1104 1118 1132 1132 1132 1132 1132 1132 1132 1132 1132 1132 1132 1132 1132 1132 1132 1132 1132 1132 1132 1132 1132 1132 1132 1132 1132 1132 1132 1132 1132 1138 1146 1158 1170 1181 1193 1199 1208 1217 1234 1244 1255 1269 1276 1293 1302 1311 1325 1333 1341 1350 1363 1374 1381 1390 1398 1408 1419 1437 1455 1473 1483 1496 1509 1522 1535 1548 1561 1580 1593 1605 1617 1629 1641 1647 1653 1659 1665 1679 1693 1708 1723 1738 1753 1768 1782 1797 1811 1825 1839 1853 1866 1879 1891 1903 1915 1927 1939 1951 1963 1981 1991 2003 2015 2027 2039 2045 2051 2058 2064 2076 2088 2100 2112 2124 2136 2148 2162 2174 2186 2198 2210 2222 2233 2245 2256 2269 2281 2294 2306 2319 2331 2344 2354 2367 2377 2390 2400 2413 2423 2437 2451 2465 2477 2489 2501 2513 2525 2537 2549 2561 2573 2585 2597 2611 2623 2637 2649 2663 2675 2689 2701 2715 2727 2744 2758 2764 2770 2776 2782 2788 2794 2800 2806 2812 2818 2831 2843 2851 2858 2871 2882 2893 2904 2910 2921 2927 2938 2946 2957 2967 2979 2986 3000 3012 3026 3038 3052 3064 3081 3095 3107 3122 3134 3149 3161 3176 3188 3208 3227 3240 3248 3261 3269 3282 3290 3302 3312 3324 3334 3346 3356 3368 3378 3390 3398 3410 3418 3430 3438 3452 3464 3478 3490 3504 3516 3530 3542 3556 3568 3582 3594 3613 3629 3642 3653 3666 3678 3688 3700 3710 3722 3732 3739 3751 3765 3778 3790 3803 3815 3828 3841 3851 3865 3881 3894 3906 3918 3930 3945 3957 3969 3979 3993 4007 4025 4032 4039 4052 4063 4069 4079 4097 4112 4124 4139 4154 4166 4185 4201 4215 4227 4240 4252 4262 4274 4285 4293 4305 4313 4325 4339 4351 4366 4380 4394 4407 4419 4429 4442 4455 4466 4476 4488 4501 4512 4522 4534 4540 4551 4560 4566 4593 4617 4639 4656 4673 4685 4706 4726 4744 4757 4769 4775 4781 4796 4808 4822 4834 4848 4860 4874 4886 4900 4912 4926 4938 4950 4963 4975 4988 5000 5019 5037 5051 5063 5077 5089 5102 5114 5129 5141 5156 5168 5181 5191 5198 5225 5249 5271 5285 5297 5319 5333 5347 5359 5372 5384 5403 5421 5436 5448 5461 5473 5486 5498 5510 5522 5534 5546 5554 5561 5567 5573 5588 5600 5615 5627 5640 5648 5661 5669 5683 5695 5709 5721 5733 5743 5755 5763 5775 5785 5799 5811 5825 5840 5854 5865 5877 5887 5900 5912 5924 5936 5951 5963 5978 5990 6005 6017 6032 6044 6057 6068 6076 6091 6100 6106 6125 6144 6158 6172 6183 6194 6208 6218 6228 6241 6252 6265 6279 6292 6304 6316 6324 6331 6346 6360 6373 6382 6395 6406 6418 6430 6442 6454 6464 6474 6486 6500 6512 6524 6539 6549 6558 6572 6585 6592 6606 6618 6629 6640 6651 6663 6675 6687 6696 6704 6713 6723 6735 6741 6755 6773 6791 6809 6821 6835 6847 6859 6875 6887 6901 6910 6919 6930 6938 6946 6956 6966 6977 6988 6998 7007 7015 7025 7036 7044 7052 7068 7081 7093 7104 7120 7131 7143 7155 7167 7178 7189 7199 7209 7219 7229 7244 7255 7268 7280 7292 7303 7316 7325 7339 7349 7359 7379 7400 7420 7437 7450 7466 7484 7499 7512 7522 7529 7542 7558 7566 7574 7578 7583 7588 7594 7601 7611 7618 7623 7632 7639 7646 7653 7659 7665 7671 7677 7686 7695 7704 7713 7722 7731 7736 7745 7754 7763 7768 7777 7786 7795 7801 7807 7813 7819 7828 7837 7844 7850 7859 7868 7877 7886 7895 7904 7910 7919 7926 7930 7937 7944 7950 7959 7968 7977 7986 7995 7995 7995 8004 8013 8024 8024 8024 8024 8024 8033 8033 8033 8033 8042 8042 8042 8042 8042 8042 8042 8042 8042 8054 8063 8076 8088 8099 8115 8127 8135 8146 8156 8166 8179 8192 8198 8208 8222 8234 8246 8253 8259 8265 8269 8281 8290 8298 8305 8313 8318 8325 8335 8345 8354 8364 8376 8388 8396 8407 8416 8424 8433 8441 8447 8458 8472 8485 8498 8510 8522 8534 8545 8561 8577 8597 8611 8637 8658 8685 8691 8702 8711 8725 8735 8741 8757 8769 8778 8790 8796 8808 8814 8825 8834 8844 8853 8865 8877 8889 8903 8912 8912 8912 8919 8931 8940 8940 8940 8940 8947 8950 8950 8963 8963 8985 9007 9029 9051 9069 9091 9113 9113 9113 9113 9113 9113 9113 9113 9113 9113 9113 9113 9113 9113 9125 9135 9153 9167 9172 9177 9191 9203 9203 9203 9212 9222 9231 9240 9247 9247 9247 9247 9247 9247 9255 9264 9278 9285 9300 9317 9327 9327 9342 9342 9360 9376 9383 9396 9409 9420 9433 9445 9457 9471 9486 9492 9505 9518 9535 9549 9560 9575 9589 9602 9602 9614 9626 9639 9654 9667 9682 9697 9703 9716 9728 9738 9750 9757 9769 9781 9793 9805 9817 9827 9837 9849 9861 9868 9880 9891 9904 9916 9926 9938 9952 9964 9974 9987 9998 10010 10023 10034 10048 10063 10070 10082 10094 10106 10121 10134 10145 10156 10169 10186 10199 10213 10228 10241 10256 10268 10281 10291 10303 10312 10324 10335 10351 10362 10381 10395 10409 10421 10437 10450 10463 10474 10488 10500 10513 10525 10537 10547 10560 10572 10582 10588 10603 10614 10625 10638 10650 10663 10680 10693 10705 10717 10730 10742 10754 10766 10781 10792 10805 10817 10823 10829 10836 10856 10875 10890 10904 10918 10931 10945 10958 10971 10984 10995 11010 11022 11043 11055 11069 11083 11097 11111 11128 11142 11157 11171 11184 11197 11209 11222 11239 11252 11268 11282 11303 11326 11342 11360 11373 11386 11406 11419 11431 11443 11454 11463 11477 11489 11506 11516 11528 11540 11552 11565 11579 11591 11603 11615 11627 11637 11647 11658 11675 11686 11699 11711 11729 11748 11761 11777 11788 11798 11815 11826 11838 11850 11862 11871 11881 11891 11897 11903 11909 11926 11942 11955 11967 11979 11990 12002 12021 12036 12050 12063 12080 12094 12111 12125 12148 12167 12182 12194 12215 12232 12244 12254 12272 12290 12305 12317 12332 12344 12359 12371 12391 12409 12427 12442 12466 12486 12505 12520 12533 12543 12554 12572 12585 12593 12601 12627 12669 12707 12723 12737 12750 12761 12774 12786 12797 12806 12817 12826 12840 12851 12872 12889 12901 12911 12924 12936 12950 12962 12976 12988 13005 13019 13035 13049 13068 13083 13105 13122 13138 13153 13166 13176 13188 13198 13211 13222 13235 13246 13259 13270 13289 13306 13320 13332 13346 13358 13372 13384 13402 13416 13434 13448 13454 13475 13492 13505 13516 13532 13546 13560 13572 13588 13602 13616 13628 13647 13663 13669 13682 13694 13707 13719 13738 13756 13768 13780 13795 13807 13822 13834 13855 13872 13884 13894 13907 13918 13932 13944 13958 13970 13985 13997 14012 14024 14039 14051 14064 14074 14087 14098 14111 14122 14135 14146 14160 14172 14183 14192 14210 14226 14237 14246 14259 14270 14283 14294 14307 14317 14337 14352 14371 14387 14401 14413 14434 14451 14473 14490 14504 14515 14531 14545 14557 14567 14581 14594 14616 14634 14652 14669 14688 14705 14720 14732 14751 14767 14781 14793 14815 14833 14855 14872 14888 14902 14902 14902 14902 14902 14902 14902 14902 14902 14902 14902 14902 14916 14929 14942 14955 14968 14981 14992 15004 15020 15033 15044 15054 15071 15085 15097 15108 15121 15133 15145 15158 15170 15182 15194 15207 15219 15234 15246 15259 15272 15284 15296 15307 15319 15329 15343 15355 15368 15383 15383 15383 15389 15395 15400 15406 15411 15419 15427 15427 15443 15454 15466 15478 15489 15500 15510 15521 15534 15546 15557 15563 15580 15591 15602 15613 15623 15634 15645 15656 15661 15672 15680 15691 15697 15713 15723 15734 15745 15756 15772 15783 15794 15802 15818 15830 15841 15855 15869 15869 15875 15881 15881 15881 15881 15881 15881 15881 15881 15881 15881 15881 15881 15881 15881 15881 15881 15881 15881 15881 15881 15881 15881 15881 15881 15881 15881 15881 15881 15881 15881 15881 15881 15881 15881 15881 15881 15881 15881 15883 15889 15895 15901 15903 15907 15911 15917 15922 15924 15926 15932 15934 15936 15943 15948 15954 15956 15958 15964 15964 15964 15973 15978 15978 15978 15978 15978 15978 15978 15978 15978 15991 16001 16009 16019 16031 16037 16044 16056 16068 16073 16083 16093 16103 16115 16127 16133 16141 16153 16164 16176 16187 16198 16209 16222 16232 16245 16257 16257 16257 16257 16257 16257 16268 16278 16287 16295 16307 16307 16307 16307 16307 16307 16307 16307 16307 16307 16307 16307 16307 16307 16307 16307 16307 16307 16318 16329 16329 16344 16364 16364 16371 16371 16371 16371 16371 16371 16371 16371 16371 16375 16375 16375 16375 16375 16375 16382 16382 16382 16382 16392 16392 16401 16408 16414 16425 16431 16447 16453 16470 16480 16497 16514 16526 16538 16550 16559 16568 16578 16588 16612 16636 16659 16682 16700 16718 16730 16742 16742 16742 16742 16742 16742 16748 16768 16783 16799 16814 16827 16842 16852 16863 16879 16895 16900 16905 16910 16915 16920 16925 16931 16936 16943 16946 16949 16949 16954 16954 16954 16963 16963 16963 16963 16963 16963 16973 16983 16993 17003 17013 17023 17033 17043 17053 17063 17073 17079 17086 17095 17112 17127 17128 17128 17128 17128 17133 17133 17133 17133 17133 17150 17167 17184 17201 17218 17235 17252 17269 17281 17293 17305 17317 17329 17341 17353 17361 17369 17377 17385 17393 17401 17409 17417 17425 17435 17446 17458 17468 17482 17492 17502 17512 17522 17546 17570 17594 17617 17640 17658 17670 17690 17710 17730 17750 17770 17790 17805 17820 17838 17860 17878 17894 17910 17926 17944 17962 17980 17998 18016 18034 18049 18064 18079 18094 18109 18124 18139 18154 18169 18185 18197 18197 18197 18197 18197 18197 18197 18208 18219 18230 18230 18230 18241 18257 18257 18273 18273 18289 18289 18289 18289 18289 18299 18299 18299 18299 18299 18299 18299 18299 18299 18299 18299 18299 18299 18299 18299 18299 18299 18299 18299 18299 18299 18299 18299 18299 18299 18299 18299 18309 18319 18329 18339 18349 18359 18369 18379 18389 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18399 18411 18423 18435 18447 18459 18471 18483 18495 18507 18519 18525 18534 18543 18554 18566 18578 18588 18600 18616 18625 18634 18645 18657 18665 18683 18692 18706 18718 18729 18745 18756 18768 18777 18788 18798 18809 18820 18831 18841 18851 18851 18851 18851 18856 18862 18864 18870 18877 18883 18890 18892 18897 18904 18911 18911 18911 18923 18935 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18943 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18955 18969 18982 18982 18995 18995 18995 19005 19018 19018 19031 19031 19031 19044 19044 19044 19044 19044 19044 19044 19056 19068 19081 19095 19095 19108 19120 19132 19148 19162 19177 19192 19192 19206 19219 19232 19232 19245 19245 19257 19257 19257 19271 19289 19289 19301 19314 19330 19342 19363 19373 19398 19418 19440 19460 19482 19493 19505 19505 19526 19549 19561 19561 19561 19570 19585 19594 19605 19616 19616 19629 19629 19637 19657 19680 19694 19717 19729 19729 19729 19742 19755 19767 19782 19795 19808 19823 19837 19850 19866 19866 19866 19889 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19912 19927 19940 19952 19966 19977 19990 20003 20019 20027 20038 20052 20067 20078 20093 20106 20117 20133 20144 20155 20170 20185 20197 20208 20219 20230 20241 20255 20270 20281 20292 20303 20315 20330 20340 20352 20362 20372 20385 20385 20385 20385 20385 20385 20385 20385 20385 20385 20385 20395 20405 20416 20430 20440 20450 20459 20473 20483 20493 20511 20521 20531 20545 20555 20565 20579 20589 20601 20611 20626 20636 20650 20660 20669 20679 20690 20700 20710 20720 20730 20739 20749 20759 20769 20779 20789 20799 20814 20824 20834 20845 20855 20863 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20869 20882 20895 20908 20921 20937 20953 20969 20969 20985 21001 21017 21034 21051 21068 21085 21102 21119 21139 21159 21179 21199 21215 21235 21255 21275 21295 21311 21311 21316 21325 21332 21339 21346 21353 21360 21367 21377 21385 21390 21397 21404 21411 21432 21449 21470 21492 21505 21518 21531 21544 21559 21574 21589 21589 21604 21619 21634 21651 21668 21685 21702 21719 21736 21756 21776 21796 21816 21836 21856 21876 21896 21911 21921 21925 21925 21939 21953 21967 21981 21995 22009 22023 22023 22037 22051 22065 22083 22101 22119 22137 22155 22173 22191 22209 22227 22245 22263 22281 22299 22317 22335 22343 22360 22377 22395 22412 22425 22438 22451 22464 22477 22490 22503 22516 22529 22547 22564 22581 22598 22615 22632 22650 22667 22685 22702 22719 22736 22753 22770 22787 22796 22805 22821 22837 22853 22869 22882 22895 22908 22921 22934 22947 22960 22973 22986 23004 23021 23039 23056 23074 23091 23109 23126 23144 23161 23179 23196 23214 23231 23249 23258 23267 23278 23289 23300 23311 23322 23333 23344 23355 23366 23381 23396 23411 23426 23441 23456 23471 23486 23501 23516 23531 23546 23561 23576 23591 23598 23607 23614 23614 23614 23631 23648 23665 23682 23698 23714 23730 23746 23762 23783 23804 23825 23846 23867 23888 23904 23915 23924 23935 23952 23969 23986 24003 24019 24035 24051 24067 24083 24104 24125 24147 24168 24190 24211 24232 24253 24274 24295 24317 24338 24360 24381 24392 24392 24407 24420 24433 24446 24459 24472 24485 24498 24511 24524 24541 24557 24574 24591 24608 24625 24642 24658 24675 24691 24708 24725 24742 24759 24776 24784 24792 24800 24800 24800 24800 24800 24800 24800 24800 24800 24816 24832 24848 24868 24888 24908 24928 24949 24970 24991 25012 25033 25054 25079 25103 25128 25152 25177 25201 25226 25250 25263 25276 25289 25302 25315 25328 25341 25354 25367 25380 25397 25414 25431 25448 25465 25482 25499 25516 25533 25550 25567 25584 25601 25618 25635 25643 25643 25650 25659 25677 25695 25712 25729 25746 25763 25776 25789 25802 25815 25828 25841 25858 25874 25882 25882 25897 25910 25923 25936 25949 25965 25981 25997 26013 26033 26053 26063 26077 26091 26105 26119 26133 26147 26161 26175 26189 26203 26221 26239 26248 26248 26248 26248 26248 26248 26248 26248 26248 26248 26265 26282 26299 26316 26333 26350 26367 26378 26392 26401 26422 26443 26464 26485 26506 26527 26548 26565 26565 26565 26565 26565 26582 26599 26616 26633 26660 26687 26714 26736 26758 26785 26812 26827 26849 26849 26849 26849 26849 26849 26849 26849 26849 26849 26866 26883 26899 26915 26931 26947 26958 26971 26984 26997 27010 27023 27036 27049 27057 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27070 27084 27084 27084 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27098 27107 27116 27116 27116 27116 27116 27116 27116 27116 27116 27116 27116 27116 27116 27116 27116 27116 27116 27116 27116 27116 27116 27116 27116 27116 27116 27116 27116 27116 27116 27116 27116 27116 27116 27116 27116 27116 27116 27116 27116 27123 27144 27171 27206 27241 27271 27300 27335 27370 27370 27370 27370 27370 27370 27370 27370 27370 27370 27380 27391 27408 27430 27457 27490 27501 27518 27540 27567 27600 27610 27626 27647 27673 27705 27716 27733 27755 27782 27815 27825 27842 27856 27878 27905 27918 27929 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27940 27951 27965 27983 27993 28003 28015 28027 28037 28047 28053 28061 28072 28081 28095 28107 28119 28129 28140 28151 28162 28181 28181 28193 28205 28215 28226 28237 28247 28258 28271 28287 28299 28310 28326 28336 28347 28347 28347 28356 28367 28379 28389 28402 28415 28423 28435 28443 28443 28452 28459 28466 28475 28484 28488 28492 28500 28507 28518 28527 28536 28545 28554 28562 28570 28577 28586 28598 28606 28614 28622 28634 28642 28650 28658 28666 28673 28680 28688 28692 28700 28711 28719 28727 28734 28742 28750 28758 28765 28773 28781 28792 28801 28801 28809 28816 28823 28831 28838 28842 28847 28855 28864 28872 28879 28887 28895 28902 28902 28902 28902 28902 28902 28902 28902 28902 28902 28902 28902 28902 28914 28923 28923 28923 28932 28932 28945 28945 28945 28945 28945 28945 28945 28945 28954 28954 28954 28954 28954 28954 28954 28954 28954 28954 28954 28954 28954 28954 28954 28954 28954 28954 28954 28954 28954 28954 28962 28969 28976 28984 28991 28997 29003 29011 29019 29025 29030 29036 29042 29049 29055 29061 29067 29078 29089 29099 29109 29117 29125 29134 29141 29148 29155 29165 29173 29180 29188 29197 29204 29213 29221 29229 29236 29236 29236 29236 29236 29250 29264 29278 29292 29309 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29326 29339 29351 29364 29376 29389 29401 29414 29426 29439 29449 29463 29475 29489 29501 29515 29527 29541 29553 29567 29579 29591 29603 29615 29627 29639 29651 29663 29675 29687 29699 29711 29718 29732 29744 29758 29770 29784 29796 29810 29822 29836 29848 29862 29874 29880 29886 29892 29898 29911 29922 29935 29946 29959 29970 29981 29987 29998 30004 30015 30021 30032 30039 30056 30074 30091 30109 30126 30144 30158 30170 30184 30196 30210 30222 30236 30248 30263 30275 30290 30302 30317 30329 30344 30356 30369 30381 30394 30406 30419 30427 30440 30448 30461 30469 30482 30490 30502 30512 30524 30534 30546 30556 30568 30578 30590 30600 30612 30620 30632 30640 30652 30660 30672 30680 30694 30706 30720 30732 30746 30758 30772 30784 30798 30810 30823 30834 30847 30858 30877 30893 30912 30928 30947 30963 30982 30998 31017 31033 31046 31057 31070 31081 31094 31105 31117 31127 31139 31149 31161 31171 31183 31191 31207 31218 31230 31237 31245 31252 31267 31279 31292 31304 31317 31329 31342 31354 31367 31379 31392 31404 31417 31429 31442 31454 31467 31479 31492 31504 31517 31529 31542 31554 31567 31579 31591 31603 31615 31627 31639 31651 31663 31675 31687 31699 31711 31723 31735 31747 31759 31771 31777 31783 31789 31795 31810 31822 31837 31849 31864 31876 31891 31903 31918 31930 31945 31957 31972 31984 31999 32011 32026 32038 32053 32065 32080 32092 32107 32119 32133 32145 32159 32171 32185 32197 32211 32223 32237 32249 32263 32275 32289 32301 32314 32325 32338 32349 32362 32373 32386 32397 32413 32424 32424 32424 32424 32424 32436 32448 32460 32472 32484 32496 32508 32520 32533 32546 32564 32582 32598 32615 32629 32644 32654 32664 32674 32684 32694 32704 32704 32704 32718 32732 32751 32770 32788 32806 32806 32806 32818 32830 32842 32854 32866 32878 32890 32902 32918 32934 32955 32976 32996 33017 33035 33053 33060 33067 33075 33083 33090 33098 33105 33112 33120 33128 33141 33154 33166 33179 33189 33199 33211 33223 33235 33247 33259 33271 33271 33271 33286 33302 33323 33344 33362 33381 33381 33381 33393 33405 33417 33429 33441 33453 33465 33477 33477 33493 33493 33513 33513 33534 33534 33552 33567 33582 33597 33612 33627 33642 33657 33672 33688 33704 33725 33747 33765 33784 33802 33820 33832 33844 33854 33864 33876 33888 33895 33902 33914 33926 33938 33950 33965 33980 33980 33980 33992 34004 34016 34028 34040 34052 34064 34076 34089 34102 34120 34138 34154 34171 34185 34200 34212 34224 34236 34248 34260 34272 34284 34296 34312 34328 34349 34370 34390 34411 34429 34447 34462 34477 34492 34507 34522 34537 34552 34567 34583 34599 34620 34642 34660 34679 34697 34715 34727 34739 34751 34763 34775 34775 34787 34799 34812 34825 34840 34854 34867 34876 34885 34894 34903 34912 34924 34936 34948 34948 34960 34972 34988 35003 35022 35039 35053 35062 35071 35080 35087 35094 35101 35108 35108 35108 35115 35122 35128 35134 35145 35155 35155 35164 35173 35182 35194 35206 35218 35230 35242 35254 35266 35278 35291 35304 35322 35340 35354 35363 35372 35381 35381 35381 35396 35411 35426 35426 35441 35456 35474 35489 35508 35524 35539 35548 35557 35557 35566 35583 35592 35609 35615 35619 35622 35634 35641 35644 35646 35646 35646 35646 35646 35646 35653 35660 35672 35681 35698 35715 35724 35733 35740 35747 35754 35761 35772 35783 35794 35805 35814 35823 35834 35845 35851 35862 35879 35885 35885 35885 35885 35885 35885 35885 35885 35888 35913 35945 35950 35958 35969 35974 35982 35993 36006 36013 36020 36037 36048 36058 36067 36083 36099 36106 36124 36133 36145 36153 36161 36179 36193 36207 36216 36227 36236 36245 36254 36261 36277 36286 36296 36313 36329 36343 36355 36369 36383 36397 36404 36419 36433 36440 36447 36451 36451 36451 36451 36451 36451 36451 36451 36451 36451 36451 36451 36451 36451 36451 36451 36451 36459 36463 36463 36463 36471 36479 36487 36495 36503 36511 36520 36529 36538 36543 36548 36556 36564 36572 36580 36588 36596 36604 36612 36620 36628 36636 36645 36654 36663 36668 36673 36673 36681 36689 36697 36704 36712 36720 36728 36732 36743 36751 36759 36766 36773 36773 36773 36773 36789 36801 36813 36825 36837 36855 36867 36893 36914 36933 36949 36961 36973 36985 36997 37021 37033 37045 37057 37069 37084 37096 37096 37096 37108 37120 37132 37132 37132 37144 37144 37144 37144 37144 37144 37144 37144 37144 37144 37144 37144 37144 37144 37144 37144 37144 37144 37144 37160 37175 37175 37175 37175 37175 37190 37205 37205 37205 37205 37221 37242 37242 37242 37242 37242 37257 37257 37257 37257 37257 37257 37257 37257 37257 37257 37257 37257 37257 37257 37257 37257 37257 37257 37257 37257 37257 37257 37257 37257 37257 37257 37257 37257 37257 37257 37257 37276 37296 37309 37330 37345 37364 37384 37395 37407 37426 37426 37444 37460 37475 37487 37499 37509 37521 37536 37544 37561 37575 37596 37613 37625 37638 37653 37669 37683 37697 37712 37724 37742 37764 37781 37794 37807 37817 37832 37847 37860 37866 37879 37892 37908 37922 37937 37948 37961 37975 37987 38007 38015 38029 38042 38050 38062 38069 38085 38108 38122 38135 38146 38161 38175 38188 38198 38209 38222 38236 38248 38260 38266 38276 38276 38291 38291 38291 38300 38300 38318 38336 38361 38379 38397 38415 38433 38451 38469 38487 38505 38523 38541 38559 38577 38590 38596 38607 38623 38642 38655 38674 38698 38727 38746 38759 38778 38802 38813 38826 38840 38857 38863 38873 38888 38905 38916 38933 38954 38980 38997 39008 39025 39046 39052 39062 39074 39092 39114 39128 39150 39163 39173 39186 39186 39186 39186 39204 39204 39204 39204 39204 39204 39204 39218 39232 39246 39260 39274 39288 39302 39316 39330 39344 39358 39372 39386 39400 39414 39428 39442 39456 39470 39484 39498 39512 39526 39540 39554 39568 39582 39596 39610 39624 39638 39652 39666 39680 39694 39708 39722 39736 39750 39764 39778 39792 39806 39820 39834 39848 39862 39876 39890 39904 39918 39932 39946 39960 39974 39988 40002 40016 40030 40044 40058 40072 40086 40100 40114 40128 40142 40156 40170 40184 40198 40212 40226 40240 40254 40268 40282 40296 40310 40324 40338 40352 40366 40380 40394 40408 40422 40436 40450 40464 40478 40492 40506 40520 40534 40548 40562 40576 40590 40604 40618 40632 40646 40660 40674 40688 40702 40716 40730 40744 40758 40772 40785 40797 40806 40818 40830 40845 40857 40869 40884 40899 40912 40927 40942 40955 40966 40980 40994 41006 41020 41034 41046 41052 41064 41078 41089 41096 41107 41118 41129 41141 41155 41169 41184 41199 41213 41222 41231 41240 41249 41263 41277 41291 41305 41315 41331 41353 41363 41380 41403 41413 41423 41433 41445 41457 41462 41474 41488 41502 41516 41530 41544 41558 41572 41586 41592 41606 41620 41634 41648 41662 41676 41690 41704 41718 41732 41746 41760 41774 41788 41802 41816 41830 41844 41858 41876 41894 41908 41922 41936 41950 41964 41978 41992 42006 42020 42034 42048 42062 42076 42090 42104 42118 42132 42146 42160 42174 42192 42210 42219 42233 42247 42261 42275 42289 42303 42317 42331 42345 42359 42373 42387 42401 42415 42429 42443 42457 42471 42485 42499 42513 42527 42541 42555 42569 42583 42597 42611 42625 42639 42653 42667 42681 42695 42709 42723 42737 42751 42765 42779 42793 42807 42821 42835 42849 42863 42877 42891 42905 42919 42933 42947 42961 42977 42993 43009 43025 43034 43043 43059 43075 43091 43107 43123 43139 43155 43171 43185 43199 43213 43227 43241 43255 43272 43289 43303 43317 43326 43340 43354 43368 43382 43396 43410 43424 43438 43452 43463 43470 43481 43495 43512 43529 43546 43563 43580 43594 43608 43622 43636 43650 43664 43678 43692 43706 43720 43734 43758 43782 43796 43810 43824 43838 43852 43866 43880 43894 43908 43922 43936 43950 43964 43978 43992 44006 44020 44034 44048 44062 44079 44096 44113 44130 44150 44165 44178 44193 44208 44221 44236 44251 44271 44286 44299 44314 44327 44342 44352 44362 44374 44388 44402 44416 44430 44438 44446 44454 44462 44470 44484 44498 44512 44526 44540 44549 44549 44549 44549 44549 44549 44549 44565 44579 44579 44579 44587 44595 44603 44611 44621 44631 44631 44631 44651 44671 44695 44715 44740 44740 44740 44764 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44779 44786 44798 44813 44813 44813 44813 44813 44825 44825 44825 44840 44840 44840 44840 44840 44840 44840 44840 44840 44840 44860 44860 44860 44860 44860 44860 44860 44860 44860 44860 44860 44860 44860 44875 44875 44875 44875 44875 44875 44875 44884 44893 44902 44911 44920 44929 44938 44947 44956 44965 44974 44983 44996 45009 45022 45035 45048 45061 45074 45084 45084 45084 45084 45084 45084 45084 45084 45084 45084 45084 45084 45084 45084 45084 45084 45084 45084 45084 45084 45084 45084 45084 45084 45084 45084 45084 45084 45084 45084 45084 45084 45098 45114 45114 45114 45114 45114 45114 45114 45114 45114 45114 45114 45114 45114 45114 45114 45114 45114 45114 45114 45114 45129 45129 45142 45142 45142 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45154 45167 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45179 45194 45209 45224 45239 45254 45269 45284 45299 45314 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45329 45340 45351 45361 45371 45381 45391 45401 45411 45421 45431 45441 45451 45461 45471 45481 45491 45501 45511 45521 45531 45541 45551 45561 45571 45581 45591 45601 45611 45621 45631 45641 45651 45661 45671 45681 45691 45701 45711 45721 45731 45741 45751 45761 45771 45782 45793 45804 45815 45826 45837 45848 45859 45870 45881 45892 45903 45914 45925 45936 45947 45958 45969 45980 45991 46002 46013 46024 46035 46046 46057 46068 46079 46090 46101 46112 46123 46133 46143 46153 46163 46174 46184 46194 46204 46214 46224 46234 46244 46254 46264 46274 46284 46294 46304 46314 46324 46334 46344 46354 46364 46375 46386 46397 46408 46419 46430 46441 46452 46463 46473 46483 46493 46503 46516 46529 46542 46552 46562 46572 46582 46592 46602 46612 46622 46633 46643 46654 46664 46678 46692 46706 46720 46734 46748 46762 46776 46790 46803 46816 46829 46842 46855 46868 46881 46894 46907 46921 46935 46949 46962 46975 46988 47001 47015 47029 47043 47057 47070 47084 47098 47114 47130 47146 47162 47178 47194 47210 47226 47242 47258 47270 47282 47298 47314 47323 47332 47345 47358 47371 47384 47393 47402 47415 47428 47437 47446 47459 47472 47485 47498 47507 47516 47529 47542 47551 47560 47573 47586 47599 47612 47625 47640 47648 47663 47678 47693 47708 47723 47738 47753 47768 47783 47798 47813 47822 47831 47845 47862 47879 47896 47903 47910 47917 47924 47937 47950 47963 47976 47989 48002 48013 48029 48045 48061 48077 48093 48106 48119 48132 48151 48167 48183 48199 48215 48230 48245 48260 48275 48288 48301 48314 48328 48342 48355 48368 48381 48396 48413 48428 48443 48458 48473 48488 48498 48513 48528 48543 48558 48570 48587 48608 48629 48644 48659 48674 48683 48698 48713 48728 48743 48758 48773 48788 48803 48818 48828 48843 48853 48868 48883 48898 48913 48924 48937 48948 48961 48970 48985 49000 49015 49027 49042 49057 49072 49087 49102 49117 49132 49147 49162 49177 49192 49207 49225 49243 49261 49276 49291 49306 49317 49330 49343 49358 49373 49388 49403 49418 49433 49448 49463 49478 49493 49508 49523 49538 49553 49568 49583 49598 49613 49628 49643 49658 49673 49688 49703 49718 49733 49748 49763 49778 49793 49808 49823 49838 49853 49868 49883 49898 49913 49928 49936 49947 49962 49977 49985 49991 49999 50012 50025 50040 50055 50070 50085 50100 50115 50130 50145 50160 50175 50190 50205 50220 50235 50250 50265 50280 50295 50310 50325 50340 50355 50370 50385 50400 50415 50430 50445 50460 50475 50490 50505 50520 50535 50550 50559 50574 50589 50604 50619 50634 50649 50664 50664 50679 50694 50709 50721 50738 50757 50777 50793 50807 50821 50835 50849 50863 50877 50891 50905 50919 50933 50947 50961 50974 50987 51000 51013 51028 51041 51054 51054 51054 51054 51054 51054 51054 51054 51068 51082 51096 51110 51110 51110 51110 51110 51110 51110 51110 51110 51110 51110 51110 51110 51110 51110 51110 51110 51110 51110 51110 51110 51110 51110 51110 51110 51110 51110 51110 51110 51110 51110 51123 51123 51123 51123 51123 51123 51123 51123 51123 51123 51123 51123 51123 51123 51123 51123 51123 51123 51123 51123 51123 51123 51123 51123 51123 51123 51123 51123 51123 51123 51123 51137 51151 51165 51179 51179 51193 51207 51221 51235 51235 51235 51249 51263 51277 51291 51305 51319 51333 51347 51361 51375 51389 51403 51417 51431 51445 51459 51473 51487 51501 51515 51529 51543 51557 51571 51585 51599 51613 51627 51627 51641 51655 51669 51683 51697 51711 51725 51739 51753 51767 51781 51795 51809 51823 51837 51851 51865 51879 51893 51907 51921 51935 51949 51963 51977 51991 52005 52019 52033 52047 52061 52075 52089 52103 52117 52117 52132 52132 52147 52162 52177 52192 52192 52192 52192 52207 52207 52221 52235 52249 52255 52261 52271 52281 52281 52281 52295 52309 52323 52337 52351 52365 52379 52393 52407 52421 52435 52449 52463 52477 52491 52505 52519 52533 52547 52561 52575 52590 52605 52620 52635 52650 52665 52680 52695 52710 52725 52739 52753 52767 52781 52795 52809 52823 52837 52851 52865 52879 52893 52907 52921 52935 52949 52963 52977 52991 53005 53019 53019 53019 53019 53033 53047 53061 53075 53089 53103 53117 53131 53145 53159 53173 53187 53201 53215 53229 53243 53257 53271 53285 53299 53313 53327 53341 53355 53355 53369 53383 53397 53411 53425 53439 53453 53467 53481 53495 53509 53523 53537 53551 53551 53551 53551 53551 53551 53551 53559 53567 53567 53567 53567 53567 53567 53567 53567 53567 53567 53567 53567 53567 53567 53567 53567 53567 53567 53567 53567 53567 53567 53567 53567 53567 53567 53575 53575 53575 53575 53575 53575 53583 53591 53599 53607 53619 53631 53631 53631 53631 53631 53645 53659 53673 53687 53707 53732 53757 53782 53807 53832 53857 53882 53907 53932 53957 53982 53995 54008 54021 54034 54047 54060 54073 54086 54099 54112 54125 54138 54151 54164 54177 54190 54203 54216 54229 54242 54255 54268 54281 54294 54307 54320 54333 54346 54359 54372 54385 54398 54411 54424 54437 54450 54463 54476 54489 54502 54515 54528 54541 54554 54567 54580 54593 54606 54619 54632 54645 54658 54671 54684 54697 54710 54723 54736 54749 54762 54775 54788 54801 54814 54827 54840 54853 54866 54879 54892 54905 54918 54931 54944 54957 54970 54983 54996 55009 55022 55035 55048 55061 55074 55087 55100 55113 55126 55139 55152 55165 55178 55191 55204 55217 55230 55243 55256 55269 55282 55295 55308 55321 55334 55347 55360 55373 55386 55399 55412 55425 55438 55451 55464 55477 55490 55503 55516 55529 55542 55555 55568 55581 55594 55607 55620 55633 55646 55659 55672 55685 55698 55711 55724 55737 55750 55763 55776 55789 55802 55815 55828 55841 55854 55867 55880 55893 55906 55919 55932 55945 55958 55971 55984 55997 56010 56023 56036 56049 56062 56075 56088 56101 56114 56127 56140 56153 56166 56179 56192 56205 56218 56231 56244 56257 56270 56283 56296 56309 56322 56335 56348 56361 56374 56387 56400 56413 56426 56439 56452 56465 56478 56491 56504 56517 56530 56543 56556 56569 56582 56595 56608 56621 56634 56647 56660 56673 56686 56699 56712 56725 56738 56751 56764 56777 56790 56803 56816 56829 56842 56855 56868 56881 56894 56907 56920 56933 56946 56959 56972 56985 56998 57011 57024 57037 57050 57063 57076 57089 57102 57115 57128 57141 57154 57167 57180 57193 57206 57219 57232 57245 57258 57271 57284 57297 57310 57310 57310 57310 57310 57310 57310 57324 57338 57338 57338 57352 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57366 57380 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57394 57407 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57420 57434 57452 57470 57487 57504 57521 57538 57555 57555 57555 57555 57555 57555 57555 57555 57555 57555 57555 57555 57555 57555 57555 57555 57555 57555 57555 57555 57555 57555 57563 57563 57563 57563 57563 57563 57563 57563 57563 57563 57563 57563 57563 57563 57563 57577 57591 57591 57591 57591 57591 57608 57625 57642 57642 57642 57642 57642 57642 57642 57642 57642 57642 57671 57681 57691 57701 57711 57721 57731 57741 57752 57762 57772 57783 57793 57803 57813 57823 57833 57833 57833 57833 57833 57833 57833 57833 57833 57833 57833 57833 57833 57833 57833 57833 57833 57833 57833 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57847 57861 57875 57875 57875 57875 57875 57875 57875 57875 57875 57875 57875 57875 57875 57875 57875 57875 57875 57875 57889 57903 57917 57931 57945 57959 57973 57987 58001 58015 58029 58043 58057 58071 58085 58099 58113 58127 58141 58155 58169 58183 58197 58211 58225 58239 58253 58267 58281 58295 58309 58323 58337 58351 58365 58379 58379 58379 58379 58379 58379 58379 58379 58379 58379 58379 58379 58379 58379 58393 58407 58421 58435 58449 58463 58477 58491 58505 58519 58533 58547 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58561 58575 58589 58589 58589 58589 58589 58589 58603 58617 58631 58645 58659 58673 58687 58701 58715 58729 58743 58757 58771 58785 58799 58813 58827 58841 58857 58873 58889 58905 58918 58931 58944 58957 58973 58973 58973 58973 58973 58988 59003 59018 59033 59048 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59067 59082 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59097 59108 59114 59125 59138 59151 59163 59171 59187 59199 59212 59223 59235 59245 59260 59277 59290 59305 59318 59339 59357 59368 59380 59390 59403 59403 59412 59424 59434 59438 59446 59458 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59470 59481 59493 59504 59515 59526 59544 59556 59574 59585 59596 59614 59626 59638 59656 59668 59683 59701 59713 59725 59743 59761 59779 59791 59803 59814 59825 59836 59848 59866 59878 59890 59901 59919 59930 59941 59953 59966 59983 59983 59983 59983 59983 59983 59983 59983 59983 59983 59983 59995 60011 60027 60039 60051 60063 60075 60088 60101 60113 60125 60139 60156 60169 60180 60193 60209 60225 60231 60244 60258 60275 60287 60300 60312 60324 60334 60352 60365 60379 60391 60397 60410 60416 60428 60440 60456 60472 60486 60492 60506 60522 60538 60551 60566 60579 60592 60604 60617 60631 60643 60658 60670 60685 60685 60685 60685 60685 60685 60685 60685 60685 60685 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60697 60707 60707 60707 60707 60707 60707 60707 60721 60721 60721 60729 60737 60745 60753 60753 60753 60753 60753 60753 60753 60753 60753 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60763 60778 60793 60808 60823 60838 60853 60868 60883 60898 60913 60928 60943 60958 60973 60988 61003 61018 61033 61048 61063 61078 61093 61108 61123 61138 61153 61168 61183 61198 61213 61228 61243 61258 61273 61288 61303 61318 61333 61348 61363 61378 61393 61408 61423 61438 61453 61468 61483 61498 61513 61528 61543 61558 61573 61588 61603 61618 61633 61648 61663 61678 61693 61708 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61723 61736 61749 61762 61776 61788 61800 61814 61827 61840 61849 61862 61875 61887 61899 61911 61928 61942 61953 61965 61978 61991 62004 62017 62031 62044 62053 62072 62085 62098 62111 62124 62137 62149 62161 62167 62182 62196 62210 62220 62234 62240 62246 62258 62270 62276 62282 62292 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62302 62314 62324 62331 62339 62339 62339 62339 62339 62363 62383 62383 62383 62404 62422 62422 62422 62442 62459 62478 62494 62494 62494 62494 62494 62494 62494 62494 62494 62494 62494 62513 62529 62548 62564 62586 62603 62618 62630 62648 62663 62687 62706 62723 62723 62723 62723 62723 62723 62723 62723 62723 62723 62723 62723 62723 62723 62723 62723 62723 62723 62723 62723 62723 62723 62723 62723 62723 62723 62723 62723 62740 62754 62766 62776 62776 62776 62776 62776 62776 62776 62790 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62802 62811 62820 62829 62838 62847 62856 62865 62874 62883 62892 62901 62910 62919 62928 62937 62937 62937 62937 62937 62944 62951 62956 62961 62966 62966 62966 62974 62981 62990 62999 63013 63025 63043 63058 63070 63080 63080 63080 63080 63080 63090 63100 63123 63141 63163 63181 63202 63220 63239 63255 63274 63290 63308 63324 63336 63345 63359 63371 63371 63371 63371 63371 63386 63395 63407 63416 63432 63446 63446 63446 63470 63489 63502 63514 63530 63546 63546 63546 63561 63573 63573 63573 63573 63573 63573 63573 63573 63573 63573 63573 63573 63573 63586 63598 63611 63623 63623 63623 63623 63623 63623 63623 63623 63623 63623 63623 63623 63623 63623 63623 63623 63623 63623 63623 63623 63623 63623 63623 63623 63623 63634 63640 63654 63666 63666 63666 63666 63666 63666 63673 63680 63688 63693 63707 63719 63719 63735 63748 63748 63748 63748 63748 63748 63748 63748 63748 63748 63748 63748 63748 63748 63748 63763 63776 63790 63802 63817 63830 63844 63853 63866 63877 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63892 63903 63915 63933 63945 63958 63975 63981 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64004 64008 64013 64019 64025 64031 64036 64040 64045 64051 64057 64063 64068 64072 64077 64083 64089 64095 64100 64104 64109 64115 64121 64127 64132 64136 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64141 64152 64163 64174 64189 64200 64211 64222 64237 64247 64258 64278 64289 64300 64315 64326 64337 64353 64364 64377 64388 64403 64414 64430 64441 64452 64463 64475 64486 64497 64508 64519 64529 64540 64551 64562 64573 64584 64596 64613 64613 64631 64646 64656 64666 64676 64686 64696 64706 64716 64726 64736 64746 64756 64766 64776 64790 64804 64818 64832 64846 64856 64866 64876 64886 64896 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64906 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64918 64932 64945 64958 64977 64996 65010 65028 65028 65028 65028 65028 65028 65028 65028 65028 65028 65028 65028 65028 65052 65076 65100 65124 65153 65153 65153 65153 65153 65153 65158 65164 65173 65184 65200 65214 65230 65243 65258 65273 65287 65302 65316 65329 65342 65355 65368 65381 65394 65407 65417 65425 65435 65447 65455 65463 65463 65475 65482 65492 65502 65512 65512 65524 65524 65532 65544 65544 65556 65567 65567 65578 65591 65601 65614 65626 65632 65642 65652 65663 65675 65675 65675 65692 65710 65716 65724 65741 65759 65765 65773 65790 65808 65814 65822 65839 65857 65863 65871 65888 65906 65912 65920 65937 65955 65961 65969 65989 66009 66020 66033 66053 66073 66084 66097 66109 66121 66133 66146 66158 66170 66182 66195 66207 66219 66231 66244 66256 66268 66280 66293 66302 66312 66321 66331 66340 66350 66359 66369 66379 66391 66401 66413 66431 66449 66459 66469 66487 66505 66515 66525 66543 66561 66571 66581 66599 66617 66627 66637 66652 66667 66682 66697 66703 66711 66711 66711 66711 66711 66711 66711 66727 66742 66754 66766 66766 66766 66766 66766 66766 66766 66766 66766 66766 66766 66766 66766 66766 66766 66766 66766 66766 66766 66766 66766 66766 66766 66766 66766 66766 66766 66766 66766 66766 66766 66766 66766 66766 66766 66766 66766 66766 66780 66795 66805 66815 66826 66838 66849 66861 66872 66884 66884 66895 66907 66907 66907 66907 66907 66923 66940 66946 66954 66960 66968 66968 66968 66968 66968 66968 66968 66968 66968 66968 66968 66968 66968 66968 66968 66968 66968 66968 66968 66984 67001 67007 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67015 67028 67035 67046 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67052 67058 67064 67070 67076 67082 67082 67088 67094 67100 67106 67112 67118 67124 67130 67136 67142 67151 67158 67165 67171 67177 67188 67200 67206 67212 67228 67244 67250 67258 67264 67270 67287 67305 67311 67319 67329 67339 67356 67374 67380 67388 67405 67423 67429 67437 67449 67461 67473 67486 67498 67510 67522 67535 67547 67559 67571 67584 67593 67603 67612 67622 67632 67644 67654 67666 67690 67714 67731 67749 67773 67797 67814 67832 67855 67878 67895 67912 67935 67958 67975 67992 68010 68028 68044 68061 68079 68097 68113 68130 68142 68154 68166 68176 68188 68200 68212 68222 68242 68262 68273 68286 68301 68316 68327 68340 68356 68372 68382 68392 68407 68422 68428 68436 68449 68462 68473 68485 68500 68515 68521 68529 68539 68549 68561 68573 68584 68596 68612 68629 68645 68662 68668 68676 68688 68702 68715 68728 68741 68754 68767 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68780 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68799 68813 68824 68834 68845 68855 68865 68874 68886 68902 68908 68920 68930 68953 68968 68984 69000 69013 69029 69040 69051 69060 69072 69084 69097 69111 69126 69137 69148 69159 69168 69182 69182 69188 69202 69215 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69230 69245 69260 69275 69290 69305 69320 69335 69350 69365 69380 69395 69410 69425 69440 69455 69470 69485 69500 69515 69530 69545 69560 69575 69590 69605 69620 69635 69650 69665 69680 69695 69710 69725 69740 69755 69770 69785 69800 69815 69830 69845 69860 69875 69890 69905 69920 69935 69950 69965 69980 69995 70010 70025 70040 70055 70070 70085 70100 70115 70130 70145 70160 70175 70190 70205 70220 70235 70250 70265 70280 70295 70310 70325 70340 70355 70370 70385 70400 70415 70430 70445 70460 70475 70490 70505 70520 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70535 70548 70561 70561 70575 70587 70599 70613 70613 70621 70628 70642 70653 70671 70671 70686 70686 70686 70686 70698 70710 70724 70737 70756 70770 70783 70783 70795 70807 70817 70829 70841 70850 70862 70874 70880 70886 70898 70904 70923 70935 70947 70959 70971 70980 70990 70999 71011 71021 71037 71049 71060 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71070 71083 71096 71109 71123 71135 71147 71161 71175 71184 71191 71204 71215 71232 71246 71261 71274 71289 71302 71314 71326 71340 71353 71372 71385 71398 71410 71422 71434 71444 71456 71468 71475 71487 71499 71505 71511 71522 71528 71546 71558 71570 71582 71594 71602 71612 71620 71632 71643 71659 71670 71681 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71691 71704 71717 71728 71741 71753 71765 71779 71794 71800 71813 71826 71843 71857 71868 71883 71897 71910 71925 71937 71949 71962 71977 71990 72005 72020 72032 72044 72056 72068 72080 72090 72100 72112 72124 72131 72143 72154 72167 72179 72189 72201 72215 72227 72237 72250 72261 72273 72286 72297 72311 72326 72335 72346 72357 72370 72384 72396 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72411 72423 72435 72447 72459 72471 72483 72495 72507 72519 72531 72531 72531 72531 72531 72531 72531 72531 72531 72531 72531 72543 72555 72567 72579 72591 72603 72615 72627 72639 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72651 72674 72697 72720 72743 72766 72789 72812 72835 72858 72881 72904 72927 72950 72973 72996 73019 73042 73065 73088 73111 73134 73157 73180 73203 73226 73249 73272 73295 73318 73341 73364 73387 73410 73433 73456 73479 73502 73525 73548 73571 73594 73617 73640 73663 73686 73709 73732 73755 73778 73801 73815 73829 73843 73857 73871 73885 73899 73913 73927 73941 73955 73969 73983 73997 74011 74025 74039 74053 74067 74081 74095 74109 74123 74137 74151 74165 74179 74193 74207 74221 74235 74249 74263 74277 74291 74305 74319 74333 74347 74361 74375 74389 74403 74417 74431 74445 74459 74473 74487 74501 74501 74501 74501 74501 74501 74501 74501 74501 74501 74501 74501 74501 74519 74537 74555 74573 74591 74609 74627 74645 74663 74681 74699 74717 74735 74753 74771 74771 74771 74789 74807 74825 74843 74861 74879 74897 74915 74933 74951 74969 74987 75005 75023 75023 75023 75041 75059 75077 75095 75113 75131 75149 75167 75185 75203 75221 75239 75257 75275 75293 75293 75311 75329 75347 75365 75383 75401 75419 75437 75455 75473 75491 75509 75527 75545 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75563 75581 75601 75601 75601 75619 75619 75619 75619 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75639 75657 75675 75695 75713 75731 75749 75767 75785 75803 75821 75839 75857 75875 75893 75911 75929 75947 75965 75983 76001 76019 76037 76055 76073 76091 76109 76127 76145 76163 76181 76199 76217 76235 76253 76271 76289 76289 76307 76325 76343 76361 76379 76397 76415 76415 76435 76453 76471 76489 76507 76525 76543 76571 76589 76607 76625 76643 76663 76681 76699 76717 76735 76753 76771 76789
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBold14Data
	<generated>
	" Font meta data for DejaVu Sans Bold 14. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 14 18 4 0 255 21 0 0 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 18 27 37 53 66 85 102 108 117 126 136 152 159 167 174 181 194 207 220 233 246 259 272 285 298 311 319 327 343 359 375 386 405 420 434 448 464 477 490 506 522 529 535 550 562 581 597 613 627 643 658 672 685 700 715 736 751 765 779 788 795 804 820 830 840 853 867 878 892 905 913 927 941 948 955 968 975 995 1009 1022 1036 1050 1059 1070 1079 1093 1105 1123 1135 1147 1158 1172 1179 1193 1209 1209 1225 1235 1251 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1274 1283 1296 1309 1321 1334 1341 1351 1361 1380 1391 1403 1419 1427 1446 1456 1466 1482 1490 1498 1508 1522 1534 1541 1551 1559 1570 1582 1602 1622 1642 1653 1668 1683 1698 1713 1728 1743 1764 1778 1791 1804 1817 1830 1837 1844 1851 1858 1874 1890 1906 1922 1938 1954 1970 1986 2002 2017 2032 2047 2062 2076 2090 2104 2117 2130 2143 2156 2169 2182 2202 2213 2226 2239 2252 2265 2272 2279 2286 2293 2306 2320 2333 2346 2359 2372 2385 2401 2414 2428 2442 2456 2470 2482 2496 2508
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:34'!
dejaVuSansBold14Form
	<generated>
	" Form data for DejaVu Sans Bold 14. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAACcwAAAAWCAIAAAB4qNppAABCkUlEQVR4AezBMQEAAAABMP1L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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBold17Data
	<generated>
	" Font meta data for DejaVu Sans Bold 17. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 17 21 5 0 255 25 0 0 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 22 32 44 63 79 102 122 129 140 151 163 182 191 201 210 218 234 250 266 282 298 314 330 346 362 378 387 396 415 434 453 466 489 507 525 542 561 577 593 612 631 640 648 666 681 704 723 743 760 780 798 815 831 850 868 893 911 928 945 956 964 975 994 1006 1018 1034 1050 1064 1080 1096 1106 1122 1138 1146 1154 1169 1177 1201 1217 1233 1249 1265 1276 1290 1301 1317 1332 1353 1368 1383 1396 1412 1420 1436 1455 1455 1474 1486 1505 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1532 1542 1558 1574 1589 1605 1613 1625 1637 1660 1673 1688 1707 1717 1740 1752 1764 1783 1793 1803 1815 1832 1847 1856 1868 1878 1891 1906 1930 1954 1978 1991 2009 2027 2045 2063 2081 2099 2124 2141 2157 2173 2189 2205 2214 2223 2232 2241 2260 2279 2299 2319 2339 2359 2379 2398 2418 2437 2456 2475 2494 2511 2528 2545 2561 2577 2593 2609 2625 2641 2665 2679 2695 2711 2727 2743 2751 2759 2768 2776 2792 2808 2824 2840 2856 2872 2888 2907 2923 2939 2955 2971 2987 3002 3018 3033
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:34'!
dejaVuSansBold17Form
	<generated>
	" Form data for DejaVu Sans Bold 17. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAAC9kAAAAbCAIAAABd3TraAABQyElEQVR4AeydrZ7rLBPAc0W9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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBold20Data
	<generated>
	" Font meta data for DejaVu Sans Bold 20. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 20 25 6 0 255 30 0 0 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 25 37 51 74 93 120 144 152 164 176 190 213 223 234 244 254 273 292 311 330 349 368 387 406 425 444 455 466 489 512 535 551 578 599 620 640 662 680 698 720 743 753 763 784 801 828 851 874 894 917 938 957 975 997 1018 1048 1069 1089 1109 1121 1131 1143 1166 1180 1194 1212 1231 1247 1266 1284 1296 1315 1334 1343 1352 1370 1379 1407 1426 1445 1464 1483 1496 1512 1525 1544 1562 1587 1604 1622 1638 1657 1667 1686 1709 1709 1732 1746 1769 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1801 1813 1832 1851 1868 1887 1897 1911 1925 1952 1967 1984 2007 2018 2045 2059 2073 2096 2108 2120 2134 2154 2171 2181 2195 2207 2222 2239 2267 2295 2323 2339 2360 2381 2402 2423 2444 2465 2494 2514 2532 2550 2568 2586 2596 2606 2616 2626 2649 2672 2695 2718 2741 2764 2787 2810 2833 2855 2877 2899 2921 2941 2961 2980 2998 3016 3034 3052 3070 3088 3116 3132 3150 3168 3186 3204 3213 3222 3232 3241 3260 3279 3298 3317 3336 3355 3374 3397 3416 3435 3454 3473 3492 3510 3529 3547
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:34'!
dejaVuSansBold20Form
	<generated>
	" Form data for DejaVu Sans Bold 20. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAADdsAAAAgCAIAAADfINfKAABdy0lEQVR4Aezcq4KzOhAAYJ6o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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBold7Data
	<generated>
	" Font meta data for DejaVu Sans Bold 7. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 7 8 2 0 255 10 0 0 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 10 15 20 28 35 45 53 56 61 66 71 79 83 87 91 95 102 109 116 123 130 137 144 151 158 165 169 173 181 189 197 203 212 219 226 233 241 248 255 263 271 275 279 286 292 301 309 317 324 332 339 346 353 361 368 378 385 392 399 404 408 413 421 426 431 438 445 451 458 465 469 476 483 487 491 497 501 511 518 525 532 539 544 550 555 562 568 577 583 589 595 602 606 613 621 621 629 634 642 650 650 650 650 650 650 650 650 650 650 650 650 650 650 650 650 650 650 650 650 650 650 650 650 650 650 650 650 650 654 659 666 673 679 686 690 695 700 709 715 721 729 733 742 747 752 760 764 768 773 780 786 790 795 799 805 811 821 831 841 847 854 861 868 875 882 889 899 906 913 920 927 934 938 942 946 950 958 966 974 982 990 998 1006 1014 1022 1030 1038 1046 1054 1061 1068 1075 1082 1089 1096 1103 1110 1117 1127 1133 1140 1147 1154 1161 1165 1169 1173 1177 1184 1191 1198 1205 1212 1219 1226 1234 1241 1248 1255 1262 1269 1275 1282 1288
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:34'!
dejaVuSansBold7Form
	<generated>
	" Form data for DejaVu Sans Bold 7. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAABQgAAAAKCAIAAAB38iSVAAAfOklEQVR4Ae1dIbutqtP3E/Ed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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBold9Data
	<generated>
	" Font meta data for DejaVu Sans Bold 9. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 9 11 3 0 255 13 0 0 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 11 16 22 32 40 52 62 66 71 76 82 92 97 102 107 111 119 127 135 143 151 159 167 175 183 191 196 201 211 221 231 238 250 259 268 277 287 295 303 313 323 327 332 341 349 361 371 381 390 400 409 418 426 436 445 458 467 476 485 490 494 499 509 515 521 529 538 545 554 562 567 576 585 589 593 601 605 618 627 635 644 653 659 666 672 681 689 700 708 716 723 732 736 745 755 755 765 771 781 791 791 791 791 791 791 791 791 791 791 791 791 791 791 791 791 791 791 791 791 791 791 791 791 791 791 791 791 791 795 800 808 816 824 832 836 842 848 860 867 875 885 890 902 908 914 924 929 934 940 949 957 962 968 973 980 988 1000 1012 1024 1031 1040 1049 1058 1067 1076 1085 1098 1107 1115 1123 1131 1139 1143 1147 1151 1155 1165 1175 1185 1195 1205 1215 1225 1235 1245 1255 1265 1275 1285 1294 1303 1312 1320 1328 1336 1344 1352 1360 1373 1380 1388 1396 1404 1412 1416 1420 1425 1429 1437 1446 1454 1462 1470 1478 1486 1496 1504 1513 1522 1531 1540 1548 1557 1565
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:34'!
dejaVuSansBold9Form
	<generated>
	" Form data for DejaVu Sans Bold 9. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAABh0AAAAOCAIAAAC0BkouAAApmUlEQVR4AexcqZ6sPtPuK8o9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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBoldDark12Data
	<generated>
	" Font meta data for DejaVu Sans Bold Dark 12. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 12 15 4 0 255 18 0 0 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 16 23 31 44 55 71 85 90 97 104 112 125 131 138 144 150 161 172 183 194 205 216 227 238 249 260 266 272 285 298 311 320 336 348 360 372 385 396 407 420 433 439 445 457 467 483 496 510 522 536 548 560 571 584 596 614 626 638 650 657 663 670 683 691 699 710 721 730 741 752 759 770 781 786 791 802 807 824 835 846 857 868 876 886 894 905 915 930 940 950 959 970 976 987 1000 1000 1013 1021 1034 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1047 1053 1060 1071 1082 1092 1103 1109 1117 1125 1141 1150 1160 1173 1180 1196 1204 1212 1225 1232 1239 1247 1259 1269 1275 1283 1290 1299 1309 1326 1343 1360 1369 1381 1393 1405 1417 1429 1441 1458 1470 1481 1492 1503 1514 1520 1526 1532 1538 1551 1564 1578 1592 1606 1620 1634 1647 1661 1674 1687 1700 1713 1725 1737 1749 1760 1771 1782 1793 1804 1815 1832 1841 1852 1863 1874 1885 1890 1895 1901 1906 1917 1928 1939 1950 1961 1972 1983 1996 2007 2018 2029 2040 2051 2061 2072 2082
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'mt 6/15/2016 10:13'!
dejaVuSansBoldDark12Form
	<generated>
	" Form data for DejaVu Sans Bold Dark 12. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAACCIAAAATCAYAAABPoj6PAAAABGdBTUEAALGPC/xhBQAAACBj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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBoldDark14Data
	<generated>
	" Font meta data for DejaVu Sans Bold Dark 14. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 14 18 4 0 255 21 0 0 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 18 27 37 53 66 85 102 108 117 126 136 152 159 167 174 181 194 207 220 233 246 259 272 285 298 311 319 327 343 359 375 386 405 420 434 448 464 477 490 506 522 529 535 550 562 581 597 613 627 643 658 672 685 700 715 736 751 765 779 788 795 804 820 830 840 853 867 878 892 905 913 927 941 948 955 968 975 995 1009 1022 1036 1050 1059 1070 1079 1093 1105 1123 1135 1147 1158 1172 1179 1193 1209 1209 1225 1235 1251 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1267 1274 1283 1296 1309 1321 1334 1341 1351 1361 1380 1391 1403 1419 1427 1446 1456 1466 1482 1490 1498 1508 1522 1534 1541 1551 1559 1570 1582 1602 1622 1642 1653 1668 1683 1698 1713 1728 1743 1764 1778 1791 1804 1817 1830 1837 1844 1851 1858 1874 1890 1906 1922 1938 1954 1970 1986 2002 2017 2032 2047 2062 2076 2090 2104 2117 2130 2143 2156 2169 2182 2202 2213 2226 2239 2252 2265 2272 2279 2286 2293 2306 2320 2333 2346 2359 2372 2385 2401 2414 2428 2442 2456 2470 2482 2496 2508
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'mt 6/15/2016 10:13'!
dejaVuSansBoldDark14Form
	<generated>
	" Form data for DejaVu Sans Bold Dark 14. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAACcwAAAAWCAYAAAD3yk0+AAAABGdBTUEAALGPC/xhBQAAACBj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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBoldDark17Data
	<generated>
	" Font meta data for DejaVu Sans Bold Dark 17. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 17 21 5 0 255 25 0 0 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 22 32 44 63 79 102 122 129 140 151 163 182 191 201 210 218 234 250 266 282 298 314 330 346 362 378 387 396 415 434 453 466 489 507 525 542 561 577 593 612 631 640 648 666 681 704 723 743 760 780 798 815 831 850 868 893 911 928 945 956 964 975 994 1006 1018 1034 1050 1064 1080 1096 1106 1122 1138 1146 1154 1169 1177 1201 1217 1233 1249 1265 1276 1290 1301 1317 1332 1353 1368 1383 1396 1412 1420 1436 1455 1455 1474 1486 1505 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1524 1532 1542 1558 1574 1589 1605 1613 1625 1637 1660 1673 1688 1707 1717 1740 1752 1764 1783 1793 1803 1815 1832 1847 1856 1868 1878 1891 1906 1930 1954 1978 1991 2009 2027 2045 2063 2081 2099 2124 2141 2157 2173 2189 2205 2214 2223 2232 2241 2260 2279 2299 2319 2339 2359 2379 2398 2418 2437 2456 2475 2494 2511 2528 2545 2561 2577 2593 2609 2625 2641 2665 2679 2695 2711 2727 2743 2751 2759 2768 2776 2792 2808 2824 2840 2856 2872 2888 2907 2923 2939 2955 2971 2987 3002 3018 3033
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'mt 6/15/2016 10:13'!
dejaVuSansBoldDark17Form
	<generated>
	" Form data for DejaVu Sans Bold Dark 17. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAAC9kAAAAbCAYAAADSv62NAAAABGdBTUEAALGPC/xhBQAAACBj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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBoldDark20Data
	<generated>
	" Font meta data for DejaVu Sans Bold Dark 20. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 20 25 6 0 255 30 0 0 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 25 37 51 74 93 120 144 152 164 176 190 213 223 234 244 254 273 292 311 330 349 368 387 406 425 444 455 466 489 512 535 551 578 599 620 640 662 680 698 720 743 753 763 784 801 828 851 874 894 917 938 957 975 997 1018 1048 1069 1089 1109 1121 1131 1143 1166 1180 1194 1212 1231 1247 1266 1284 1296 1315 1334 1343 1352 1370 1379 1407 1426 1445 1464 1483 1496 1512 1525 1544 1562 1587 1604 1622 1638 1657 1667 1686 1709 1709 1732 1746 1769 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1792 1801 1813 1832 1851 1868 1887 1897 1911 1925 1952 1967 1984 2007 2018 2045 2059 2073 2096 2108 2120 2134 2154 2171 2181 2195 2207 2222 2239 2267 2295 2323 2339 2360 2381 2402 2423 2444 2465 2494 2514 2532 2550 2568 2586 2596 2606 2616 2626 2649 2672 2695 2718 2741 2764 2787 2810 2833 2855 2877 2899 2921 2941 2961 2980 2998 3016 3034 3052 3070 3088 3116 3132 3150 3168 3186 3204 3213 3222 3232 3241 3260 3279 3298 3317 3336 3355 3374 3397 3416 3435 3454 3473 3492 3510 3529 3547
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'mt 6/15/2016 10:13'!
dejaVuSansBoldDark20Form
	<generated>
	" Form data for DejaVu Sans Bold Dark 20. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAADdsAAAAgCAYAAABQQkCdAAAABGdBTUEAALGPC/xhBQAAACBj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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBoldDark7Data
	<generated>
	" Font meta data for DejaVu Sans Bold Dark 7. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 7 8 2 0 255 10 0 0 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 10 15 20 28 35 45 53 56 61 66 71 79 83 87 91 95 102 109 116 123 130 137 144 151 158 165 169 173 181 189 197 203 212 219 226 233 241 248 255 263 271 275 279 286 292 301 309 317 324 332 339 346 353 361 368 378 385 392 399 404 408 413 421 426 431 438 445 451 458 465 469 476 483 487 491 497 501 511 518 525 532 539 544 550 555 562 568 577 583 589 595 602 606 613 621 621 629 634 642 650 650 650 650 650 650 650 650 650 650 650 650 650 650 650 650 650 650 650 650 650 650 650 650 650 650 650 650 650 654 659 666 673 679 686 690 695 700 709 715 721 729 733 742 747 752 760 764 768 773 780 786 790 795 799 805 811 821 831 841 847 854 861 868 875 882 889 899 906 913 920 927 934 938 942 946 950 958 966 974 982 990 998 1006 1014 1022 1030 1038 1046 1054 1061 1068 1075 1082 1089 1096 1103 1110 1117 1127 1133 1140 1147 1154 1161 1165 1169 1173 1177 1184 1191 1198 1205 1212 1219 1226 1234 1241 1248 1255 1262 1269 1275 1282 1288
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'mt 6/15/2016 10:13'!
dejaVuSansBoldDark7Form
	<generated>
	" Form data for DejaVu Sans Bold Dark 7. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAABQgAAAAKCAYAAAD4kLPCAAAABGdBTUEAALGPC/xhBQAAACBj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=='
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBoldDark9Data
	<generated>
	" Font meta data for DejaVu Sans Bold Dark 9. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 9 11 3 0 255 13 0 0 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 11 16 22 32 40 52 62 66 71 76 82 92 97 102 107 111 119 127 135 143 151 159 167 175 183 191 196 201 211 221 231 238 250 259 268 277 287 295 303 313 323 327 332 341 349 361 371 381 390 400 409 418 426 436 445 458 467 476 485 490 494 499 509 515 521 529 538 545 554 562 567 576 585 589 593 601 605 618 627 635 644 653 659 666 672 681 689 700 708 716 723 732 736 745 755 755 765 771 781 791 791 791 791 791 791 791 791 791 791 791 791 791 791 791 791 791 791 791 791 791 791 791 791 791 791 791 791 791 795 800 808 816 824 832 836 842 848 860 867 875 885 890 902 908 914 924 929 934 940 949 957 962 968 973 980 988 1000 1012 1024 1031 1040 1049 1058 1067 1076 1085 1098 1107 1115 1123 1131 1139 1143 1147 1151 1155 1165 1175 1185 1195 1205 1215 1225 1235 1245 1255 1265 1275 1285 1294 1303 1312 1320 1328 1336 1344 1352 1360 1373 1380 1388 1396 1404 1412 1416 1420 1425 1429 1437 1446 1454 1462 1470 1478 1486 1496 1504 1513 1522 1531 1540 1548 1557 1565
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'mt 6/15/2016 10:13'!
dejaVuSansBoldDark9Form
	<generated>
	" Form data for DejaVu Sans Bold Dark 9. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAABh0AAAAOCAYAAAA7ZN15AAAABGdBTUEAALGPC/xhBQAAACBj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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBoldOblique12Data
	<generated>
	" Font meta data for DejaVu Sans Bold Oblique 12. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 12 15 4 0 255 19 0 0 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 16 23 31 42 53 69 83 88 95 102 110 123 129 136 142 151 162 173 184 195 206 217 228 239 250 261 267 273 286 299 312 321 337 349 361 373 386 397 408 421 434 440 450 463 473 489 502 516 528 542 554 566 577 590 602 620 635 647 660 668 674 682 695 703 711 722 733 742 753 764 772 783 794 799 808 819 824 841 852 863 874 885 893 903 911 922 932 947 959 970 980 991 997 1008 1021 1021 1034 1042 1055 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1074 1081 1092 1103 1113 1125 1131 1140 1148 1164 1173 1183 1196 1203 1219 1227 1235 1248 1255 1262 1270 1282 1292 1298 1306 1313 1322 1332 1349 1366 1383 1392 1404 1416 1428 1440 1452 1464 1483 1495 1506 1517 1528 1539 1545 1552 1559 1566 1580 1593 1607 1621 1635 1649 1663 1676 1692 1705 1718 1731 1744 1756 1768 1780 1791 1802 1813 1824 1835 1846 1863 1872 1883 1894 1905 1916 1921 1928 1934 1940 1951 1962 1973 1984 1995 2006 2017 2030 2042 2053 2064 2075 2086 2097 2108 2119
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:34'!
dejaVuSansBoldOblique12Form
	<generated>
	" Form data for DejaVu Sans Bold Oblique 12. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAACEcAAAATCAIAAAD3DmbsAAA84UlEQVR4AeybL+OzKhTHfUV7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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBoldOblique14Data
	<generated>
	" Font meta data for DejaVu Sans Bold Oblique 14. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 14 18 4 0 255 22 0 0 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 18 27 37 51 64 83 100 106 115 124 134 150 157 165 172 183 196 209 222 235 248 261 274 287 300 313 321 329 345 361 377 388 407 422 436 450 466 479 492 508 524 531 543 559 571 590 606 622 636 652 667 681 694 709 724 745 762 776 791 800 807 817 833 843 853 866 880 891 905 918 927 941 955 962 973 986 993 1013 1027 1040 1054 1068 1078 1089 1098 1112 1124 1142 1156 1169 1180 1194 1201 1215 1231 1231 1247 1257 1273 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1296 1305 1318 1331 1343 1357 1364 1375 1385 1404 1415 1427 1443 1451 1470 1480 1490 1506 1514 1522 1532 1546 1558 1565 1575 1583 1594 1606 1626 1646 1666 1677 1692 1707 1722 1737 1752 1767 1789 1803 1816 1829 1842 1855 1862 1870 1878 1886 1902 1918 1934 1950 1966 1982 1998 2014 2033 2048 2063 2078 2093 2107 2121 2135 2148 2161 2174 2187 2200 2213 2233 2244 2257 2270 2283 2296 2303 2311 2318 2325 2338 2352 2365 2378 2391 2404 2417 2433 2447 2461 2475 2489 2503 2516 2530 2543
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:34'!
dejaVuSansBoldOblique14Form
	<generated>
	" Form data for DejaVu Sans Bold Oblique 14. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAACe8AAAAWCAIAAADcwmK6AABG9klEQVR4Aeybq7qsLBjH54rW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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBoldOblique17Data
	<generated>
	" Font meta data for DejaVu Sans Bold Oblique 17. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 17 21 5 0 255 27 0 0 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 22 32 44 60 76 99 119 126 137 148 160 179 188 198 207 220 236 252 268 284 300 316 332 348 364 380 389 398 417 436 455 468 491 509 527 544 563 579 595 614 633 642 657 676 691 714 733 753 770 790 808 825 841 860 878 903 923 940 958 969 977 989 1008 1020 1032 1048 1064 1078 1094 1110 1121 1137 1153 1161 1174 1190 1198 1222 1238 1254 1270 1286 1298 1312 1323 1339 1354 1375 1392 1408 1422 1438 1446 1462 1481 1481 1500 1512 1531 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1558 1568 1584 1600 1615 1632 1640 1653 1665 1688 1701 1716 1735 1745 1768 1780 1792 1811 1821 1831 1843 1860 1875 1884 1896 1906 1919 1934 1958 1982 2006 2019 2037 2055 2073 2091 2109 2127 2154 2171 2187 2203 2219 2235 2244 2254 2264 2274 2293 2312 2332 2352 2372 2392 2412 2431 2453 2472 2491 2510 2529 2546 2563 2580 2596 2612 2628 2644 2660 2676 2700 2714 2730 2746 2762 2778 2786 2796 2805 2814 2830 2846 2862 2878 2894 2910 2926 2945 2962 2978 2994 3010 3026 3042 3058 3074
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:34'!
dejaVuSansBoldOblique17Form
	<generated>
	" Form data for DejaVu Sans Bold Oblique 17. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAADAIAAAAbCAIAAADTF1vnAABWkElEQVR4AezdrbbjrNcA8FxR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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBoldOblique20Data
	<generated>
	" Font meta data for DejaVu Sans Bold Oblique 20. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 20 25 6 0 255 32 0 0 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 25 37 51 70 89 116 140 148 160 172 186 209 219 230 240 256 275 294 313 332 351 370 389 408 427 446 457 468 491 514 537 553 580 601 622 642 664 682 700 722 745 755 772 794 811 838 861 884 904 927 948 967 986 1008 1029 1059 1083 1103 1124 1137 1147 1161 1184 1198 1212 1230 1249 1265 1284 1302 1315 1334 1353 1362 1377 1395 1404 1432 1451 1470 1489 1508 1522 1538 1551 1570 1588 1613 1632 1651 1667 1686 1696 1715 1738 1738 1761 1775 1798 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1830 1842 1861 1880 1897 1917 1927 1942 1956 1983 1998 2016 2039 2050 2077 2091 2105 2128 2140 2152 2166 2186 2203 2213 2227 2239 2254 2272 2300 2328 2356 2372 2393 2414 2435 2456 2477 2498 2530 2550 2568 2586 2604 2622 2632 2644 2655 2666 2689 2712 2735 2758 2781 2804 2827 2850 2876 2898 2920 2942 2964 2984 3004 3023 3041 3059 3077 3095 3113 3131 3159 3175 3193 3211 3229 3247 3256 3268 3278 3288 3307 3326 3345 3364 3383 3402 3421 3444 3464 3483 3502 3521 3540 3559 3578 3597
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:34'!
dejaVuSansBoldOblique20Form
	<generated>
	" Form data for DejaVu Sans Bold Oblique 20. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAADg0AAAAgCAIAAAAUzU7FAABnaklEQVR4AezcK37rOhMAcK/I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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBoldOblique7Data
	<generated>
	" Font meta data for DejaVu Sans Bold Oblique 7. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 7 8 2 0 255 12 0 0 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 10 15 20 27 34 44 52 55 60 65 70 78 82 86 90 96 103 110 117 124 131 138 145 152 159 166 170 174 182 190 198 204 213 221 228 235 243 250 257 265 273 277 283 291 297 306 314 322 329 337 344 351 358 366 373 383 392 399 407 412 416 421 429 434 439 446 453 459 466 473 478 485 492 496 501 508 512 522 529 536 543 550 555 561 566 573 579 588 595 602 608 615 619 626 634 634 642 647 655 663 663 663 663 663 663 663 663 663 663 663 663 663 663 663 663 663 663 663 663 663 663 663 663 663 663 663 663 663 667 672 679 686 692 699 703 709 714 723 729 735 743 747 756 761 766 774 778 782 787 794 800 804 809 813 819 825 835 845 855 861 869 877 885 893 901 909 921 928 935 942 949 956 960 964 968 972 980 988 996 1004 1012 1020 1028 1036 1045 1053 1061 1069 1077 1084 1091 1098 1105 1112 1119 1126 1133 1140 1150 1156 1163 1170 1177 1184 1188 1192 1196 1200 1207 1214 1221 1228 1235 1242 1249 1257 1264 1271 1278 1285 1292 1299 1306 1313
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:34'!
dejaVuSansBoldOblique7Form
	<generated>
	" Form data for DejaVu Sans Bold Oblique 7. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAABSEAAAAKCAIAAADEugyPAAAgrUlEQVR4Ae1doYKtuLLli/IP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=='
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBoldOblique9Data
	<generated>
	" Font meta data for DejaVu Sans Bold Oblique 9. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 9 11 3 0 255 15 0 0 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 11 16 22 31 39 51 61 65 70 75 81 91 96 101 106 113 121 129 137 145 153 161 169 177 185 193 198 203 213 223 233 240 252 262 271 280 290 298 306 316 326 330 337 347 355 367 377 387 396 406 415 424 432 442 451 464 475 484 494 500 504 510 520 526 532 540 549 556 565 573 579 588 597 601 607 615 619 632 641 649 658 667 673 680 686 695 703 714 723 731 738 747 751 760 770 770 780 786 796 806 806 806 806 806 806 806 806 806 806 806 806 806 806 806 806 806 806 806 806 806 806 806 806 806 806 806 806 806 810 815 823 831 839 848 852 859 865 877 884 892 902 907 919 925 931 941 946 951 957 966 974 979 985 990 997 1005 1017 1029 1041 1048 1058 1068 1078 1088 1098 1108 1123 1132 1140 1148 1156 1164 1168 1173 1178 1183 1193 1203 1213 1223 1233 1243 1253 1263 1275 1285 1295 1305 1315 1324 1333 1342 1350 1358 1366 1374 1382 1390 1403 1410 1418 1426 1434 1442 1446 1451 1456 1461 1469 1478 1486 1494 1502 1510 1518 1528 1537 1546 1555 1564 1573 1581 1590 1598
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:34'!
dejaVuSansBoldOblique9Form
	<generated>
	" Form data for DejaVu Sans Bold Oblique 9. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAABj4AAAAOCAIAAAAQbPL9AAAr9UlEQVR4Aexbq6LkqhLNF/EP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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBoldObliqueDark12Data
	<generated>
	" Font meta data for DejaVu Sans Bold Oblique Dark 12. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 12 15 4 0 255 19 0 0 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 16 23 31 42 53 69 83 88 95 102 110 123 129 136 142 151 162 173 184 195 206 217 228 239 250 261 267 273 286 299 312 321 337 349 361 373 386 397 408 421 434 440 450 463 473 489 502 516 528 542 554 566 577 590 602 620 635 647 660 668 674 682 695 703 711 722 733 742 753 764 772 783 794 799 808 819 824 841 852 863 874 885 893 903 911 922 932 947 959 970 980 991 997 1008 1021 1021 1034 1042 1055 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1068 1074 1081 1092 1103 1113 1125 1131 1140 1148 1164 1173 1183 1196 1203 1219 1227 1235 1248 1255 1262 1270 1282 1292 1298 1306 1313 1322 1332 1349 1366 1383 1392 1404 1416 1428 1440 1452 1464 1483 1495 1506 1517 1528 1539 1545 1552 1559 1566 1580 1593 1607 1621 1635 1649 1663 1676 1692 1705 1718 1731 1744 1756 1768 1780 1791 1802 1813 1824 1835 1846 1863 1872 1883 1894 1905 1916 1921 1928 1934 1940 1951 1962 1973 1984 1995 2006 2017 2030 2042 2053 2064 2075 2086 2097 2108 2119
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'mt 6/15/2016 10:13'!
dejaVuSansBoldObliqueDark12Form
	<generated>
	" Form data for DejaVu Sans Bold Oblique Dark 12. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAACEcAAAATCAYAAAB4bPG7AAAABGdBTUEAALGPC/xhBQAAACBj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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBoldObliqueDark14Data
	<generated>
	" Font meta data for DejaVu Sans Bold Oblique Dark 14. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 14 18 4 0 255 22 0 0 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 18 27 37 51 64 83 100 106 115 124 134 150 157 165 172 183 196 209 222 235 248 261 274 287 300 313 321 329 345 361 377 388 407 422 436 450 466 479 492 508 524 531 543 559 571 590 606 622 636 652 667 681 694 709 724 745 762 776 791 800 807 817 833 843 853 866 880 891 905 918 927 941 955 962 973 986 993 1013 1027 1040 1054 1068 1078 1089 1098 1112 1124 1142 1156 1169 1180 1194 1201 1215 1231 1231 1247 1257 1273 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1289 1296 1305 1318 1331 1343 1357 1364 1375 1385 1404 1415 1427 1443 1451 1470 1480 1490 1506 1514 1522 1532 1546 1558 1565 1575 1583 1594 1606 1626 1646 1666 1677 1692 1707 1722 1737 1752 1767 1789 1803 1816 1829 1842 1855 1862 1870 1878 1886 1902 1918 1934 1950 1966 1982 1998 2014 2033 2048 2063 2078 2093 2107 2121 2135 2148 2161 2174 2187 2200 2213 2233 2244 2257 2270 2283 2296 2303 2311 2318 2325 2338 2352 2365 2378 2391 2404 2417 2433 2447 2461 2475 2489 2503 2516 2530 2543
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'mt 6/15/2016 10:13'!
dejaVuSansBoldObliqueDark14Form
	<generated>
	" Form data for DejaVu Sans Bold Oblique Dark 14. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAACe8AAAAWCAYAAABToPXtAAAABGdBTUEAALGPC/xhBQAAACBj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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBoldObliqueDark17Data
	<generated>
	" Font meta data for DejaVu Sans Bold Oblique Dark 17. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 17 21 5 0 255 27 0 0 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 22 32 44 60 76 99 119 126 137 148 160 179 188 198 207 220 236 252 268 284 300 316 332 348 364 380 389 398 417 436 455 468 491 509 527 544 563 579 595 614 633 642 657 676 691 714 733 753 770 790 808 825 841 860 878 903 923 940 958 969 977 989 1008 1020 1032 1048 1064 1078 1094 1110 1121 1137 1153 1161 1174 1190 1198 1222 1238 1254 1270 1286 1298 1312 1323 1339 1354 1375 1392 1408 1422 1438 1446 1462 1481 1481 1500 1512 1531 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1550 1558 1568 1584 1600 1615 1632 1640 1653 1665 1688 1701 1716 1735 1745 1768 1780 1792 1811 1821 1831 1843 1860 1875 1884 1896 1906 1919 1934 1958 1982 2006 2019 2037 2055 2073 2091 2109 2127 2154 2171 2187 2203 2219 2235 2244 2254 2264 2274 2293 2312 2332 2352 2372 2392 2412 2431 2453 2472 2491 2510 2529 2546 2563 2580 2596 2612 2628 2644 2660 2676 2700 2714 2730 2746 2762 2778 2786 2796 2805 2814 2830 2846 2862 2878 2894 2910 2926 2945 2962 2978 2994 3010 3026 3042 3058 3074
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'mt 6/15/2016 10:13'!
dejaVuSansBoldObliqueDark17Form
	<generated>
	" Form data for DejaVu Sans Bold Oblique Dark 17. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAADAIAAAAbCAYAAABcdcywAAAABGdBTUEAALGPC/xhBQAAACBj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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBoldObliqueDark20Data
	<generated>
	" Font meta data for DejaVu Sans Bold Oblique Dark 20. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 20 25 6 0 255 32 0 0 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 25 37 51 70 89 116 140 148 160 172 186 209 219 230 240 256 275 294 313 332 351 370 389 408 427 446 457 468 491 514 537 553 580 601 622 642 664 682 700 722 745 755 772 794 811 838 861 884 904 927 948 967 986 1008 1029 1059 1083 1103 1124 1137 1147 1161 1184 1198 1212 1230 1249 1265 1284 1302 1315 1334 1353 1362 1377 1395 1404 1432 1451 1470 1489 1508 1522 1538 1551 1570 1588 1613 1632 1651 1667 1686 1696 1715 1738 1738 1761 1775 1798 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1821 1830 1842 1861 1880 1897 1917 1927 1942 1956 1983 1998 2016 2039 2050 2077 2091 2105 2128 2140 2152 2166 2186 2203 2213 2227 2239 2254 2272 2300 2328 2356 2372 2393 2414 2435 2456 2477 2498 2530 2550 2568 2586 2604 2622 2632 2644 2655 2666 2689 2712 2735 2758 2781 2804 2827 2850 2876 2898 2920 2942 2964 2984 3004 3023 3041 3059 3077 3095 3113 3131 3159 3175 3193 3211 3229 3247 3256 3268 3278 3288 3307 3326 3345 3364 3383 3402 3421 3444 3464 3483 3502 3521 3540 3559 3578 3597
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'mt 6/15/2016 10:13'!
dejaVuSansBoldObliqueDark20Form
	<generated>
	" Form data for DejaVu Sans Bold Oblique Dark 20. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAADg0AAAAgCAYAAACbr9mSAAAABGdBTUEAALGPC/xhBQAAACBj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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBoldObliqueDark7Data
	<generated>
	" Font meta data for DejaVu Sans Bold Oblique Dark 7. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 7 8 2 0 255 12 0 0 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 10 15 20 27 34 44 52 55 60 65 70 78 82 86 90 96 103 110 117 124 131 138 145 152 159 166 170 174 182 190 198 204 213 221 228 235 243 250 257 265 273 277 283 291 297 306 314 322 329 337 344 351 358 366 373 383 392 399 407 412 416 421 429 434 439 446 453 459 466 473 478 485 492 496 501 508 512 522 529 536 543 550 555 561 566 573 579 588 595 602 608 615 619 626 634 634 642 647 655 663 663 663 663 663 663 663 663 663 663 663 663 663 663 663 663 663 663 663 663 663 663 663 663 663 663 663 663 663 667 672 679 686 692 699 703 709 714 723 729 735 743 747 756 761 766 774 778 782 787 794 800 804 809 813 819 825 835 845 855 861 869 877 885 893 901 909 921 928 935 942 949 956 960 964 968 972 980 988 996 1004 1012 1020 1028 1036 1045 1053 1061 1069 1077 1084 1091 1098 1105 1112 1119 1126 1133 1140 1150 1156 1163 1170 1177 1184 1188 1192 1196 1200 1207 1214 1221 1228 1235 1242 1249 1257 1264 1271 1278 1285 1292 1299 1306 1313
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'mt 6/15/2016 10:13'!
dejaVuSansBoldObliqueDark7Form
	<generated>
	" Form data for DejaVu Sans Bold Oblique Dark 7. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAABSEAAAAKCAYAAABL2JvYAAAABGdBTUEAALGPC/xhBQAAACBj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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBoldObliqueDark9Data
	<generated>
	" Font meta data for DejaVu Sans Bold Oblique Dark 9. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 9 11 3 0 255 15 0 0 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 11 16 22 31 39 51 61 65 70 75 81 91 96 101 106 113 121 129 137 145 153 161 169 177 185 193 198 203 213 223 233 240 252 262 271 280 290 298 306 316 326 330 337 347 355 367 377 387 396 406 415 424 432 442 451 464 475 484 494 500 504 510 520 526 532 540 549 556 565 573 579 588 597 601 607 615 619 632 641 649 658 667 673 680 686 695 703 714 723 731 738 747 751 760 770 770 780 786 796 806 806 806 806 806 806 806 806 806 806 806 806 806 806 806 806 806 806 806 806 806 806 806 806 806 806 806 806 806 810 815 823 831 839 848 852 859 865 877 884 892 902 907 919 925 931 941 946 951 957 966 974 979 985 990 997 1005 1017 1029 1041 1048 1058 1068 1078 1088 1098 1108 1123 1132 1140 1148 1156 1164 1168 1173 1178 1183 1193 1203 1213 1223 1233 1243 1253 1263 1275 1285 1295 1305 1315 1324 1333 1342 1350 1358 1366 1374 1382 1390 1403 1410 1418 1426 1434 1442 1446 1451 1456 1461 1469 1478 1486 1494 1502 1510 1518 1528 1537 1546 1555 1564 1573 1581 1590 1598
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'mt 6/15/2016 10:13'!
dejaVuSansBoldObliqueDark9Form
	<generated>
	" Form data for DejaVu Sans Bold Oblique Dark 9. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAABj4AAAAOCAYAAACfDmWqAAAABGdBTUEAALGPC/xhBQAAACBj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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBook12Data
	<generated>
	" Font meta data for DejaVu Sans Book 12. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 12 15 4 0 255 16 0 0 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 15 21 28 41 51 66 78 82 88 94 102 115 120 126 131 136 146 156 166 176 186 196 206 216 226 236 241 246 259 272 285 293 309 320 331 342 354 364 373 385 397 402 407 417 426 440 452 465 475 488 499 509 519 531 542 558 569 579 590 596 601 607 620 628 636 646 656 665 675 685 691 701 711 715 719 728 732 748 758 768 778 788 795 803 809 819 828 841 850 859 867 877 882 892 905 905 918 926 939 952 952 952 952 952 952 952 952 952 952 952 952 952 952 952 952 952 952 952 952 952 952 952 952 952 952 952 952 952 957 963 973 983 993 1003 1008 1016 1024 1040 1048 1058 1071 1077 1093 1101 1109 1122 1128 1134 1142 1152 1162 1167 1175 1181 1189 1199 1215 1231 1247 1255 1266 1277 1288 1299 1310 1321 1337 1348 1358 1368 1378 1388 1393 1398 1403 1408 1420 1432 1445 1458 1471 1484 1497 1510 1523 1535 1547 1559 1571 1581 1591 1601 1611 1621 1631 1641 1651 1661 1677 1686 1696 1706 1716 1726 1730 1734 1739 1744 1754 1764 1774 1784 1794 1804 1814 1827 1837 1847 1857 1867 1877 1886 1896 1905
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:34'!
dejaVuSansBook12Form
	<generated>
	" Form data for DejaVu Sans Book 12. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAAB3EAAAATCAIAAAABG2BVAAA4dklEQVR4Aeybq4KrvBaAeSLe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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBook14Data
	<generated>
	" Font meta data for DejaVu Sans Book 14. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 14 18 4 0 255 19 0 0 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 17 25 34 50 62 80 95 100 107 114 124 140 146 153 159 165 177 189 201 213 225 237 249 261 273 285 291 297 313 329 345 355 374 387 400 413 428 440 451 466 480 486 492 504 515 531 545 560 571 586 599 611 623 637 650 669 682 694 707 714 720 727 743 753 763 775 787 797 809 821 828 840 852 857 862 873 878 897 909 921 933 945 953 963 970 982 993 1009 1020 1031 1041 1053 1059 1071 1087 1087 1103 1113 1129 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1151 1159 1171 1183 1195 1207 1213 1223 1233 1252 1261 1273 1289 1296 1315 1325 1335 1351 1359 1367 1377 1389 1401 1407 1417 1425 1434 1446 1464 1482 1500 1510 1523 1536 1549 1562 1575 1588 1607 1620 1632 1644 1656 1668 1674 1680 1686 1692 1707 1721 1736 1751 1766 1781 1796 1812 1827 1841 1855 1869 1883 1895 1906 1918 1930 1942 1954 1966 1978 1990 2009 2019 2031 2043 2055 2067 2072 2077 2083 2089 2101 2113 2125 2137 2149 2161 2173 2189 2201 2213 2225 2237 2249 2260 2272 2283
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:34'!
dejaVuSansBook14Form
	<generated>
	" Form data for DejaVu Sans Book 14. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAACOsAAAAWCAIAAAAUpx0AAABBEUlEQVR4Aeyaq4LkrrPH54n6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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBook17Data
	<generated>
	" Font meta data for DejaVu Sans Book 17. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 17 21 5 0 255 23 0 0 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 21 30 41 60 75 97 115 121 130 139 151 170 177 185 192 200 215 230 245 260 275 290 305 320 335 350 358 366 385 404 423 435 458 474 490 506 524 539 552 570 587 594 600 615 628 648 665 683 697 715 731 746 760 777 793 816 832 846 862 871 879 888 907 919 931 945 960 973 988 1002 1010 1025 1040 1046 1052 1065 1071 1093 1108 1122 1137 1152 1161 1173 1182 1197 1211 1230 1244 1258 1270 1285 1293 1308 1327 1327 1346 1358 1377 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1403 1412 1427 1442 1457 1472 1480 1492 1504 1527 1538 1552 1571 1579 1602 1614 1626 1645 1654 1663 1675 1690 1705 1712 1724 1733 1744 1758 1780 1802 1824 1836 1852 1868 1884 1900 1916 1932 1954 1970 1985 2000 2015 2030 2037 2044 2051 2058 2076 2093 2111 2129 2147 2165 2183 2202 2220 2237 2254 2271 2288 2302 2316 2330 2344 2358 2372 2386 2400 2414 2437 2450 2464 2478 2492 2506 2512 2518 2526 2533 2547 2562 2576 2590 2604 2618 2632 2651 2665 2680 2695 2710 2725 2739 2754 2768
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:34'!
dejaVuSansBook17Form
	<generated>
	" Form data for DejaVu Sans Book 17. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAACtAAAAAbCAIAAABgRs7QAABPSElEQVR4Aeycq57rrhPA94n6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=='
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBook20Data
	<generated>
	" Font meta data for DejaVu Sans Book 20. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 20 25 6 0 255 27 0 0 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 25 36 48 71 88 114 135 142 153 164 178 201 210 220 229 238 255 272 289 306 323 340 357 374 391 408 417 426 449 472 495 509 536 554 573 592 613 630 646 667 687 695 702 720 735 758 778 799 815 836 855 872 889 909 927 954 972 989 1007 1018 1027 1038 1061 1075 1089 1106 1123 1138 1155 1172 1182 1199 1216 1224 1232 1248 1256 1282 1299 1316 1333 1350 1361 1375 1386 1403 1419 1441 1457 1473 1487 1504 1513 1530 1553 1553 1576 1590 1613 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1645 1656 1673 1690 1707 1724 1733 1747 1761 1788 1801 1818 1841 1851 1878 1892 1906 1929 1940 1951 1965 1982 1999 2008 2022 2033 2046 2063 2089 2115 2141 2155 2173 2191 2209 2227 2245 2263 2289 2308 2325 2342 2359 2376 2384 2392 2400 2408 2429 2449 2470 2491 2512 2533 2554 2577 2598 2618 2638 2658 2678 2695 2711 2728 2745 2762 2779 2796 2813 2830 2857 2872 2889 2906 2923 2940 2948 2956 2965 2973 2990 3007 3024 3041 3058 3075 3092 3115 3132 3149 3166 3183 3200 3216 3233 3249
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:34'!
dejaVuSansBook20Form
	<generated>
	" Form data for DejaVu Sans Book 20. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAADLEAAAAgCAIAAADYa5yzAABcaElEQVR4AezdoX6zPBcAcK6I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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBook7Data
	<generated>
	" Font meta data for DejaVu Sans Book 7. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 7 8 2 0 255 9 0 0 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 9 13 18 26 32 41 49 52 56 60 65 73 76 80 83 87 93 99 105 111 117 123 129 135 141 147 151 155 163 171 179 184 193 200 207 214 221 227 233 240 247 250 253 259 265 273 280 288 294 302 309 315 321 328 335 344 351 357 364 368 372 376 384 389 394 400 406 411 417 423 427 433 439 442 445 451 454 463 469 475 481 487 491 496 500 506 512 520 526 532 537 543 547 553 561 561 569 574 582 590 590 590 590 590 590 590 590 590 590 590 590 590 590 590 590 590 590 590 590 590 590 590 590 590 590 590 590 590 593 597 603 609 615 621 625 630 635 644 649 655 663 667 676 681 686 694 698 702 707 713 719 722 727 731 736 742 751 760 769 774 781 788 795 802 809 816 825 832 838 844 850 856 859 862 865 868 875 882 890 898 906 914 922 930 938 945 952 959 966 972 978 984 990 996 1002 1008 1014 1020 1029 1034 1040 1046 1052 1058 1061 1064 1067 1070 1076 1082 1088 1094 1100 1106 1112 1120 1126 1132 1138 1144 1150 1156 1162 1168
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:34'!
dejaVuSansBook7Form
	<generated>
	" Form data for DejaVu Sans Book 7. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAABJAAAAAKCAIAAABkADNIAAAdjUlEQVR4AexareKluA7vE/Ud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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBook9Data
	<generated>
	" Font meta data for DejaVu Sans Book 9. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 9 11 3 0 255 12 0 0 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 11 16 22 32 40 51 60 63 68 73 79 89 93 97 101 105 113 121 129 137 145 153 161 169 177 185 189 193 203 213 223 229 241 249 257 265 274 282 289 298 307 311 315 323 330 340 349 358 365 374 382 390 397 406 414 426 434 441 449 454 458 463 473 479 485 492 500 507 515 522 526 534 542 545 548 555 558 570 578 585 593 601 606 612 617 625 632 642 649 656 662 670 674 682 692 692 702 708 718 728 728 728 728 728 728 728 728 728 728 728 728 728 728 728 728 728 728 728 728 728 728 728 728 728 728 728 728 728 732 737 745 753 761 769 773 779 785 797 803 810 820 824 836 842 848 858 863 868 874 882 890 894 900 905 911 918 930 942 954 960 968 976 984 992 1000 1008 1020 1028 1036 1044 1052 1060 1064 1068 1072 1076 1085 1094 1103 1112 1121 1130 1139 1149 1158 1167 1176 1185 1194 1201 1208 1216 1223 1230 1237 1244 1251 1258 1270 1277 1284 1291 1298 1305 1308 1311 1315 1319 1326 1334 1341 1348 1355 1362 1369 1379 1386 1394 1402 1410 1418 1425 1433 1440
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:34'!
dejaVuSansBook9Form
	<generated>
	" Form data for DejaVu Sans Book 9. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAABaAAAAAOCAIAAABW7CymAAAo50lEQVR4AexarZrkrBKuK+Ie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=='
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBookDark12Data
	<generated>
	" Font meta data for DejaVu Sans Book Dark 12. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 12 15 4 0 255 16 0 0 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 15 21 28 41 51 66 78 82 88 94 102 115 120 126 131 136 146 156 166 176 186 196 206 216 226 236 241 246 259 272 285 293 309 320 331 342 354 364 373 385 397 402 407 417 426 440 452 465 475 488 499 509 519 531 542 558 569 579 590 596 601 607 620 628 636 646 656 665 675 685 691 701 711 715 719 728 732 748 758 768 778 788 795 803 809 819 828 841 850 859 867 877 882 892 905 905 918 926 939 952 952 952 952 952 952 952 952 952 952 952 952 952 952 952 952 952 952 952 952 952 952 952 952 952 952 952 952 952 957 963 973 983 993 1003 1008 1016 1024 1040 1048 1058 1071 1077 1093 1101 1109 1122 1128 1134 1142 1152 1162 1167 1175 1181 1189 1199 1215 1231 1247 1255 1266 1277 1288 1299 1310 1321 1337 1348 1358 1368 1378 1388 1393 1398 1403 1408 1420 1432 1445 1458 1471 1484 1497 1510 1523 1535 1547 1559 1571 1581 1591 1601 1611 1621 1631 1641 1651 1661 1677 1686 1696 1706 1716 1726 1730 1734 1739 1744 1754 1764 1774 1784 1794 1804 1814 1827 1837 1847 1857 1867 1877 1886 1896 1905
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'mt 6/15/2016 10:13'!
dejaVuSansBookDark12Form
	<generated>
	" Form data for DejaVu Sans Book Dark 12. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAAB3EAAAATCAYAAACOefcCAAAABGdBTUEAALGPC/xhBQAAACBj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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBookDark14Data
	<generated>
	" Font meta data for DejaVu Sans Book Dark 14. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 14 18 4 0 255 19 0 0 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 17 25 34 50 62 80 95 100 107 114 124 140 146 153 159 165 177 189 201 213 225 237 249 261 273 285 291 297 313 329 345 355 374 387 400 413 428 440 451 466 480 486 492 504 515 531 545 560 571 586 599 611 623 637 650 669 682 694 707 714 720 727 743 753 763 775 787 797 809 821 828 840 852 857 862 873 878 897 909 921 933 945 953 963 970 982 993 1009 1020 1031 1041 1053 1059 1071 1087 1087 1103 1113 1129 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1145 1151 1159 1171 1183 1195 1207 1213 1223 1233 1252 1261 1273 1289 1296 1315 1325 1335 1351 1359 1367 1377 1389 1401 1407 1417 1425 1434 1446 1464 1482 1500 1510 1523 1536 1549 1562 1575 1588 1607 1620 1632 1644 1656 1668 1674 1680 1686 1692 1707 1721 1736 1751 1766 1781 1796 1812 1827 1841 1855 1869 1883 1895 1906 1918 1930 1942 1954 1966 1978 1990 2009 2019 2031 2043 2055 2067 2072 2077 2083 2089 2101 2113 2125 2137 2149 2161 2173 2189 2201 2213 2225 2237 2249 2260 2272 2283
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'mt 6/15/2016 10:13'!
dejaVuSansBookDark14Form
	<generated>
	" Form data for DejaVu Sans Book Dark 14. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAACOsAAAAWCAYAAACbxYpXAAAABGdBTUEAALGPC/xhBQAAACBj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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBookDark17Data
	<generated>
	" Font meta data for DejaVu Sans Book Dark 17. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 17 21 5 0 255 23 0 0 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 21 30 41 60 75 97 115 121 130 139 151 170 177 185 192 200 215 230 245 260 275 290 305 320 335 350 358 366 385 404 423 435 458 474 490 506 524 539 552 570 587 594 600 615 628 648 665 683 697 715 731 746 760 777 793 816 832 846 862 871 879 888 907 919 931 945 960 973 988 1002 1010 1025 1040 1046 1052 1065 1071 1093 1108 1122 1137 1152 1161 1173 1182 1197 1211 1230 1244 1258 1270 1285 1293 1308 1327 1327 1346 1358 1377 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1396 1403 1412 1427 1442 1457 1472 1480 1492 1504 1527 1538 1552 1571 1579 1602 1614 1626 1645 1654 1663 1675 1690 1705 1712 1724 1733 1744 1758 1780 1802 1824 1836 1852 1868 1884 1900 1916 1932 1954 1970 1985 2000 2015 2030 2037 2044 2051 2058 2076 2093 2111 2129 2147 2165 2183 2202 2220 2237 2254 2271 2288 2302 2316 2330 2344 2358 2372 2386 2400 2414 2437 2450 2464 2478 2492 2506 2512 2518 2526 2533 2547 2562 2576 2590 2604 2618 2632 2651 2665 2680 2695 2710 2725 2739 2754 2768
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'mt 6/15/2016 10:13'!
dejaVuSansBookDark17Form
	<generated>
	" Form data for DejaVu Sans Book Dark 17. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAACtAAAAAbCAYAAADvJFmHAAAABGdBTUEAALGPC/xhBQAAACBj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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBookDark20Data
	<generated>
	" Font meta data for DejaVu Sans Book Dark 20. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 20 25 6 0 255 27 0 0 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 25 36 48 71 88 114 135 142 153 164 178 201 210 220 229 238 255 272 289 306 323 340 357 374 391 408 417 426 449 472 495 509 536 554 573 592 613 630 646 667 687 695 702 720 735 758 778 799 815 836 855 872 889 909 927 954 972 989 1007 1018 1027 1038 1061 1075 1089 1106 1123 1138 1155 1172 1182 1199 1216 1224 1232 1248 1256 1282 1299 1316 1333 1350 1361 1375 1386 1403 1419 1441 1457 1473 1487 1504 1513 1530 1553 1553 1576 1590 1613 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1636 1645 1656 1673 1690 1707 1724 1733 1747 1761 1788 1801 1818 1841 1851 1878 1892 1906 1929 1940 1951 1965 1982 1999 2008 2022 2033 2046 2063 2089 2115 2141 2155 2173 2191 2209 2227 2245 2263 2289 2308 2325 2342 2359 2376 2384 2392 2400 2408 2429 2449 2470 2491 2512 2533 2554 2577 2598 2618 2638 2658 2678 2695 2711 2728 2745 2762 2779 2796 2813 2830 2857 2872 2889 2906 2923 2940 2948 2956 2965 2973 2990 3007 3024 3041 3058 3075 3092 3115 3132 3149 3166 3183 3200 3216 3233 3249
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'mt 6/15/2016 10:13'!
dejaVuSansBookDark20Form
	<generated>
	" Form data for DejaVu Sans Book Dark 20. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAADLEAAAAgCAYAAABXCQvkAAAABGdBTUEAALGPC/xhBQAAACBj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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBookDark7Data
	<generated>
	" Font meta data for DejaVu Sans Book Dark 7. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 7 8 2 0 255 9 0 0 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 9 13 18 26 32 41 49 52 56 60 65 73 76 80 83 87 93 99 105 111 117 123 129 135 141 147 151 155 163 171 179 184 193 200 207 214 221 227 233 240 247 250 253 259 265 273 280 288 294 302 309 315 321 328 335 344 351 357 364 368 372 376 384 389 394 400 406 411 417 423 427 433 439 442 445 451 454 463 469 475 481 487 491 496 500 506 512 520 526 532 537 543 547 553 561 561 569 574 582 590 590 590 590 590 590 590 590 590 590 590 590 590 590 590 590 590 590 590 590 590 590 590 590 590 590 590 590 590 593 597 603 609 615 621 625 630 635 644 649 655 663 667 676 681 686 694 698 702 707 713 719 722 727 731 736 742 751 760 769 774 781 788 795 802 809 816 825 832 838 844 850 856 859 862 865 868 875 882 890 898 906 914 922 930 938 945 952 959 966 972 978 984 990 996 1002 1008 1014 1020 1029 1034 1040 1046 1052 1058 1061 1064 1067 1070 1076 1082 1088 1094 1100 1106 1112 1120 1126 1132 1138 1144 1150 1156 1162 1168
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'mt 6/15/2016 10:13'!
dejaVuSansBookDark7Form
	<generated>
	" Form data for DejaVu Sans Book Dark 7. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAABJAAAAAKCAYAAADrYqQfAAAABGdBTUEAALGPC/xhBQAAACBj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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansBookDark9Data
	<generated>
	" Font meta data for DejaVu Sans Book Dark 9. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 9 11 3 0 255 12 0 0 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 11 16 22 32 40 51 60 63 68 73 79 89 93 97 101 105 113 121 129 137 145 153 161 169 177 185 189 193 203 213 223 229 241 249 257 265 274 282 289 298 307 311 315 323 330 340 349 358 365 374 382 390 397 406 414 426 434 441 449 454 458 463 473 479 485 492 500 507 515 522 526 534 542 545 548 555 558 570 578 585 593 601 606 612 617 625 632 642 649 656 662 670 674 682 692 692 702 708 718 728 728 728 728 728 728 728 728 728 728 728 728 728 728 728 728 728 728 728 728 728 728 728 728 728 728 728 728 728 732 737 745 753 761 769 773 779 785 797 803 810 820 824 836 842 848 858 863 868 874 882 890 894 900 905 911 918 930 942 954 960 968 976 984 992 1000 1008 1020 1028 1036 1044 1052 1060 1064 1068 1072 1076 1085 1094 1103 1112 1121 1130 1139 1149 1158 1167 1176 1185 1194 1201 1208 1216 1223 1230 1237 1244 1251 1258 1270 1277 1284 1291 1298 1305 1308 1311 1315 1319 1326 1334 1341 1348 1355 1362 1369 1379 1386 1394 1402 1410 1418 1425 1433 1440
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'mt 6/15/2016 10:13'!
dejaVuSansBookDark9Form
	<generated>
	" Form data for DejaVu Sans Book Dark 9. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAABaAAAAAOCAYAAADZjrvxAAAABGdBTUEAALGPC/xhBQAAACBj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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansOblique12Data
	<generated>
	" Font meta data for DejaVu Sans Oblique 12. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 12 15 4 0 255 17 0 0 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 15 21 28 41 51 66 78 82 88 95 103 116 121 127 132 140 150 160 170 180 190 200 210 220 230 240 245 250 263 276 289 297 313 325 336 347 359 369 378 390 402 407 416 427 436 450 462 475 485 498 509 519 529 541 552 568 581 591 603 609 614 621 634 642 650 660 670 679 689 699 706 716 726 730 737 746 750 766 776 786 796 806 813 821 827 837 846 859 869 879 888 898 903 913 926 926 939 947 960 973 973 973 973 973 973 973 973 973 973 973 973 973 973 973 973 973 973 973 973 973 973 973 973 973 973 973 973 973 978 984 994 1004 1014 1024 1029 1037 1045 1061 1069 1079 1092 1098 1114 1122 1130 1143 1149 1155 1163 1173 1183 1188 1196 1202 1210 1220 1236 1252 1268 1276 1288 1300 1312 1324 1336 1348 1365 1376 1386 1396 1406 1416 1421 1427 1433 1439 1451 1463 1476 1489 1502 1515 1528 1541 1555 1567 1579 1591 1603 1613 1623 1633 1643 1653 1663 1673 1683 1693 1709 1718 1728 1738 1748 1758 1762 1768 1773 1778 1788 1798 1808 1818 1828 1838 1848 1861 1871 1881 1891 1901 1911 1921 1931 1941
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:34'!
dejaVuSansOblique12Form
	<generated>
	" Form data for DejaVu Sans Oblique 12. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAAB5UAAAATCAIAAAA/Es1eAAA8j0lEQVR4AexbL6OkKhSfT+R3
8BPMFzCbrVab0WYzmUwmE4VEoVAoBAqFQKAQDPfJGa/LDMzsvft/9/l7+3YZOZxz+B3AA+rl
7cSJEydOnDhx4sSJEydOnPi/YEX1ZUM5iddyGncXj2ziNlVvpyq73JD3JiXBp2oXuJZl7v9h
ayQzFl5BxzRuvGSDEx7LGSwBitH+EprUAs5X8/qMR4Wu4FE984cqNlaHu/TeXcf6G2NaLcBu
Z94NNtBg5O4QJl0B1ypoyeuD75Zsv6fSlzfmSOsr3j4J94XVvCpzUJWkdn1nQn6dNNTexsws
nkXJjOVlx3V4JsQOoevNtVKsKbH+ClwyCS5mnpZfAfU+hdzXptAev4kl6/lUH1wQk4qRGIHO
XmsMwWpUmlRy46sc2Ns/D6eWoW/bbiby7cSJ/w3O8+sTJ06cOHHit8NySiiT68nEiRMnTvyP
YSUjhPwSUycUHHgWzD0PBxvg4Kym5u3VmeaIyehLNVKxjuHqT9QIGooMjhmxihXxodzqGqTk
XHufBvbkmLJAyhBfyIn9RTQtcGA8Jo9OLYXD63ziNnnwndcTw0N8qOr4uCm9dsTKaStkVXAG
qhEc8g/hyX5Wjdr/kjXEYyB0BOY3D8ZyU5AvyizVt5xfc39GXM5kaa4wGjq0Ph8wjRepYiYS
Y+baACVJrDM438yUDL7UkuTwMluc82aieChy38eB6CddqPzhLrMKBk81ibdfBQSM9OmuAhwr
biGjaefVAiEtB4qBtxoldPABxhIycoIgjS5BqigvHj1RP/aYmBLChPmqoGKbIFUu8ksLQog0
PzbBN31+OdDAsvNTsGpGCOVf16+FF0x000hCiNDuQ9aM9GxLG+k4botwiwSefwpW47WzD/aX
iLi/1veXK/fnpRY8ClASBgaycHGXuQ+O/Q5yJajW7jecXzslpVTmoWyUVHZNubrhveSeUibm
th5ZYgxhtCwL4fpRnqAFMZcadpxihBAmTGqbdjuAFUtdlu/xok1ZttHTY8MJBgd+MYx6cHhV
nGJCMcIiNfic0ck+gipBMEYbZ5g9DJrVWSk4JbdaCkFMw+7qXWjRXzngHdYucotT4iOCCZd6
3a+BqruWcCUMmdOMYOSBhbJRnBXFfnAgwu1f8ZBUMIy8v5SrH6TSSIhHELAoKCBhXXINsZLT
nV/KIO73gYb2j0GJZQ6AM3HtURdZZ7t1QsOpCs291WS/jIt/xrNGr1/RZpX0SKqKjSZqVxNe
DyS1i2KkItVacoIRzLgjoUlHMM3/ayVREMEFEEiuloufnJTxm59raD2K8BeSpXKpAQmG0gLH
OgzxjzhfIShBq0PsWKpUxAaE8oivC8p3WgLPk+P2bmVbNa7Lqqrryt8anI4iqPBQllXtBWoU
0wDMx0FLI0672SdasrEpyoZAj78Pbmmrouo/nt6Rqa+rDeVHxCn4Sc36ovYhHyiKGqs1bp5u
e+JvgiXz0MD8uh3i8KnO8iocxnxq/RRrOsTN91qLp+Tn23Mu3Z+SSmifFcf3zSSOlXZNrNUv
TNwyA0LZl6VvFX7CN5N2amy2wpA0ZuwGY9fn/jgj2K4e3PqFiN2LsWo0B1jIl+0oJpSyz2xI
oy5jduuxVYIQuJDaH1o+ZRePj1vYc/8jDfssL1oJzrnQ9ztzv90gmMgPTxxnjRSCMREzbCVd
5iWk77Pyq1WM7qwp+1r+c70XjGAi3Ct+BUaYyZDYaPMlhFRaa7XBuKe2vIR+Ne5hd6ReyNAu
v1yu0fl1euKrFCCj+dR2ABRJBps4eVNw1MIFTrY6JjQIh7V+5GMigBlPM+VKB23DLHMvmMP/
TZ69R9oIihBRazDghddqrFFKB5lz4DskouFeJmA1zre1ixLLJ6k7Xsa+G2YZWIrF8Dx2XTcu
VD8VWwVZhmFE2IOw+BYTGgW8mowghvYQfv/S6ozaN+A+6Obmb1dBtpnYBTgg8NgFxDJOKwVU
JGW0hTi694GxIZJJ7zi0W+8zf6eP2bPa9C4vCafQ2NWVRzugh5x6ldPF40pfLoZirtPvj1ta
XgDVskbLfZNDzcgU6bYZjYO2TqLa32yps6zdCj1292rz/VMAWWxWe/b2k6AR3JKyRb+SUu8f
qSD1QJ+o3z8ycNFznq6q6g67VfZ1Vbez2cJNWpCu5R1P4wXg9aklg3LeUQeHeN0inEJ1WQXc
ia4qS78/gh+UsPC2YWidg42JK9w+RtZgqLzMan3Fio8XiD3OXdns/vU2IqkvfN21RVrMW2Hg
9s5nT8JigY2qnfTbD4aYyuTXHunPiYrhYSAb0l8A8TNaifqqrEaqNRm2woDV08dsHiW1d5s4
8nzJctJHth2Z1RhyT7KJXhyfrlmewLXhz+a5wdAtePZoSQ5fc9iVXz0jY9RINe8hNBDpjpqk
e+PWvqXxNyAHqlmEX+Ukv5wydMwuIQ5zh6vdnXlLrmGa6DhYLPlx4H4jd7PWkP3S26/BsV5U
x7MQmGwHsuELk3Zuiuzo+X1Cs8rlenlANjITPDZ/RItk6mHyuFeX80ECqrOodYYD62xqwrpj
rqL68gTtPseW9kF10eHDLhvre5sVkPGHYlWPIcjqJRKyHM99W5dFcd1QlE03vczF3VTs4aah
VBwUQD3S0BgZm1ioaBFU8iJunxU92qdFLBOgeVF7tOZzl8fVeTkzEzTPiE30q1pU8DP66tOx
a9g2qc1BugB4VxV/DxgajRfrdXm/nnc0kLw/fzxuw+Uc3IOXMk9EZ30dwWvLwzvvpiRLKHkd
oKqHGRREIR4D9SKHyL0oiKaFlgN38deL8H6NboFzFM1KCZ/Q7nuw+/dNxFhEy5ftwZnw5Ytj
fQa4ucpuF4/70YZRhI7ZsTyUyOryHPlwFzXArrPB0Q04WNCiHAtQfvYJtaX9bUjpz718kSH9
/YsUB5KKD3q6xwrwET+7p34ewykL9YP8ZZJr3Dyp+e3fBemrLK+wXv+dHrV5uOAcS0dHzJd5
/WUNvFL3Hca+b0oC1G005i3+RQQ50RT7aX68QwgX7Y9MWAreFyN/eBV0w+1B0fVah5ttTR5M
NPcb+EpoAgL/tXe9irHqXrdPlHfIE/ACaDQWi0PicCgUCoXCoDAYDAaBwSAQGATifgdY0DXd
M3zMbeecnt/tVh0S0pA/O2v/jfHBPSuwDX7NsP3yzicM3huTzl/sGXK9e6Au+QB9ttwCmsb8
yc04+tye9j+czsrNbkW1VAOlX1qsdRoIDP/clqkOFz7lDUdaA1txg/k5wBZDR0cwxMatkzE9
f7Z+QcIEJNCT+hcJQPp80JCb4rTOfNSppidB+/U6In+IsqJB1oDofUZu3j8vDjC5rywFDGZY
nrsE+PkJKtwVCnpXNq8MP8HQfi10//7VrtLUhsQtN9Kmbeo3HCUXpIBP1qmfaecC8j/WhpTy
MN8fV6NyP8RCVuFSRUMWOEkXI9URHUEenfV34JBWRwWXu9hv0qkZd5W/JdgZhVe7ssMij/Si
vy7/eRm1iXOeQWgoA5yP3fyhZBm5B6x+LDdhMWwh33k9idjWjlumJlFH+qaxIt2gVW7yg1/W
K+tkTrnzUqjHlF/yrr8ZduX1IiDgPCvOUG0dNjJaKLTw7kuIzVqmsR4Q9yNGI2ib6A0Zcr6c
hg0x+EX/0JnJXcUqOx6FLmvvuBRU58TaDDRN6as3aU1hA49y6umaeMjKATvrFrYMVfPbuGwJ
7QVMobeoRoxHRt1xy1dlBEv5VJqbIn+uTZn2C0YMaOtK37gDU+Y+DT3TwJgYpuVFxURj4Sb1
0GZr4/5AhzeYC9MAZbTpRkWRx4HDxqK9q8EoQIlBazpfp83Le6xvvejxm9DQQf3P3Cx8Rmge
xybzXT//au+czNV7BBAbc+ykyANb36zsqdS3+HgQxhZl2mGc5llkoarTvucs044fJmmW54sa
XGiIMI/msdveF+W4bQPb8w/yvKidiN1jRsJssVh7+k3Fa3GdBK63kx/4Nhq34no9jEOsByfM
yyL2LIYXfe6hWS8uyxSDAa76DQmnrLUMQhY4hhQ7mzTQDK8M4/hhh8V8X9XlH/WjZpLxRKbj
B0Hg++6GOci6OKUOHinTjbO8yBIfYMV5N2wqA2zBQ23eKajzZrjLjB/kekH2qNTd3bUK39i/
04mSrMizOHA1Zr/B61I+wWLDYYDPFM6q8xZWprA1ZGtzd6xkq+hZO/YWoinJ6D9yibmBexQ0
sOgPJ+MDVYGJLUPWWtgD4jTLUt9Shx5HzKC3Dr95aHouNiIm0ceuJ/zXZy56a/tpXuRZ4jvm
pqYvY3/dm77v2buov8+k624Mx+AVxapkhLBBv+mjBoOthY6RCfYKCAi9bXbCEW59mA4n7Xbm
ZiO9IA6DOVtXq6LYwzIwaccNie8xBeH71rOihjYsYvFg4ZNH29zYBD5AXXbLir0nwce8gSrv
1MdDjKddf5L3UazuxcoKO2iCkfeUcPi+Oc39umMWuI4X8wtF5Dlu2E43r2OSZcvqf9X/GnwP
Ljl/PbGlRCfNyHwS3gayJrDoU/RlWxJsDfS7IrL77Nf/kmj+kNK1HeQLxLWvrHyY/YyNgxHb
1D54HU4xHvM3J8zqps4i17CivajPl3C3Zv5nKNY/hL+wDtKyW5zfuioLjQ2ciOi4tiyqph3G
oYxsGC1eSdQ9I1y694u6EogL3RPO+kT9uI+SjoqmLSJNRuuLgkBXlXU37ie7Xp0BhxnyESYC
NFfGLqVfTXpA5GeZI0+rC8HaiNm3k4mgu+Gl4z9zHTuw018Z6arYzCXlJNQ3OFL/ff15GscJ
WxJ2bln/SZJA+i+oU4VHnbidzxaGNhRDOILqWTtdFwfOof4rShnhy59XnwCpascPFvJdLY1G
XwTdv3u16zRW9nHe+VFe5GkEZzIy4l6QAn5rnTPkz7NsJfU0Dn3fT/cSuWgnWnzqJ3jICm/L
3lv/yV0wNiM3ty3kSDhIuVn/TxcLXjrnvmWHv550oWOblksnCEK/sjQtmvGfqV3+EOFoZfCe
QB1ez6+icdPoxNxDErQfGXerYNdljfmdnP4jvgsAo2zx/rQpqU3ySwNoDA0I7OOqzRy7Kk2X
yJu5r9M03ZXLqWvT4aj8Zhh5XDPPsqP6n9XN2bLdopMfNW1MNGymx0KQKce8Dg1o3sd887m7
VeC6hpPO/4yJ55imDac9Go08TfOqx2jk9UtmFPoBsoWI/isnEaWNvRuzm8iU6pe+XoBhM87D
+kctI8vrgJXX18XYaZ3ZJUvLUGO1QH+tgumjfBEutt/xIWACoxf6a2iHxWHsJN2vqqEBLZKM
KSBCHbSst/HtnaPxqd74jFw0OPiN98+ZN7TzQH89bPXRJTa6QldVgC9ovQGB3QtYuLcY4HRf
73ztNHBTsOGrMtyX67p6CfhqUxccnGhq8yhr2AHy7UQm7BNZCu05CF/Ky6599AkQ+Wqe8gca
XpMsYBhSdaiksXiMrJ8PbaPhF4cTh/q0Emca2jTwwucSZo2xawdpOUz/L6jP0oNJzdugGXck
EGUlB++ehwzLD9YUkX9NJL2iSYGfCOEMTBzCIHgA2c7hrRUQ3DBzSIvBt2rIOkSyVMjSG3Oc
bjGTCbUdXkd4i/yukX6KZdznLptMubV5+Sexxnd4DY0PtSz0g+KeHDivgXTazVQT39ayhQwj
T3W0zxOWOJoXv5xB4DDtX29ETAEEPCdp6RPYXI8IzdvsQq0t4jmgVpbWVySRhANUFexHOIhM
F9CbmIDXPHF0ww8s8Gw5gO0KJrqpjuQGmVviYITso/qRuBgqrIh8PlCLiQ/ZuZ/UCEDhy88P
pwDlpOPUuIqWzXWax7uJuDbM3W+8huwomy16XjjYUjw/anQtnUTx+nzENUpSSYFWR7EtAmAA
QWOPBsWC2VYjuiJ7Ikm+Pj0qsmI5Xj1iVUHTcBa1PZ30ah7FyMsx6u8Wj3JSZD/7nv4XBnz+
qMO1m/+Z24aamMIqhf5a6O4/ob/+/JYE72UKXh/q1WUuuK50CNq5Hz81DWbFALfqfb80wMw9
iS6w+YmRH0sDfrjXqXXQ/tQVkW2apmX7UdbUiYarBNOQBrYIkXwpoXtBnMRxHEVRGMZVD90x
unfFQ1mHmwU80nDjeloQANKwt8RdSRw5phKMlNNVnZP0YDWrYRGpFBQE1wmmEThMAWPvIzOt
RZf018Dqt0t0TnCOF5+tP/d5koSuxYKbrH+dJJD+++oA/AhwAtjTbmAmfCAdPS8OML2wlBC+
/Hn1CcQNHUykZguh21UvgO7fthoUuDzLeGh8VKcmNsZiA8AUvL6lU7guBfy+OufIn0aJycza
SVjKoUJ0DZp9sp91yx01zfxAh1DkSHcjYXFdNf2wkgTiO8gcp4f5p7bXHpQOZRqHEZbzieBA
iPVpYQH8d0k5XU+PupHfzbCEdLH4/OM7JVQeRvkiHq75go7ysT/y1M5bOkpJhac218nIt+FN
fx+ALynFHg1739ZIAC1p6tfvHe8bhOumG4YlWdn9iZvEMDDNeOszNEFsgbymA7EkYZsXhCxM
8t9j5IcZgmr3fEwoEgcJIQ4qmjNhShD8r/1Relg/0l/DzAW9A8Cu1F9PfVM3bbtYGrbbZrs6
MTaPrbZtmnacCY4r096YRRz7tl4FGyjdlJvNCB7ZDqEpMh/6vY+PhWrpRgeIJpIGTPWNqDx1
BWFtm000UvT6eufrpGWvQ/Nd2TT66g57zT0tMiqcwwJBQ8oukHyQu1HsapKC4Agv8Qc7X0OZ
LklqYeAcSkOqw5rOVAVrD1K+mOXEfeYvGpuqqpqDmU9tXVUPk1dOTZG61tLk8/c1I7nB5ltd
NP01gTritDCHDs700/FhqAWHkJD/lBUVCbnGEC8AaiG8C3kVVmjyxuK1XzbQPMpApBHRVX4x
oM4DkeakFGpT6QSHeaqaYcbr/FG82LTfi8+UMqQZVtQZPOn2tE3aiUe55fXRlFTUGqbGLAB2
g2A1IRWb41qKokxaR72HSNeheTcUdyaTEn8ahohQOFk7zhuRUzBvatqg6PkqlUROgxxzcfB3
sJOls8jFBH9kKJpvI+77VNE2p1kGiwPBKRv6BWY47KYdZKn9RlxRRNVYSXekMHPTBya2fBfe
vGy+61iNRQuWKMylFEs4tyv3RcgV34+vcYr9S2qy0DY0JfLx65H1XG/K8gLH2Is/pB2YqjQw
FYVEJjUKusLdC7QTRq5xKwyPRey9z4nhlGh2CC1D6/1FQ5tuergfHr3QdhD5tlLG5kXYpg4e
eubRYrIUIb2DXjrWsIpTvylnM3zidSxmpEIzDa3e3ouCCgOulWEHSeS+gfSSKWus4Y60TkY1
vLNirbQbJpF7p1dS16at4DhFtsRrThCH7jFIJhyKxfAq0w0829DmNhqyn3f1enZQDGWolXqP
ytFqZf6OesPAblSGtlJm2k5TkxhK2eB+oDKwldLbP7WC4hhzQ/8ip9q1A46htBVs7iFKKdPL
KTG6pbUy3GxZ5KZWhsc+f+MyFMpwki37oVba2Mk0TcPQWxGrVuH+dg6iwKawE5+kz29JtrYe
c6BkvCc2S/a8F/FcO4bWhttMt7kgaLdSxifY8yTAi4zt+Mr6oavK5RaDfgtYpPCXwttweAvc
C8uiGHmS87H7TomPAy9vytB6IzKiZptrCAsAcijV4Gky7Gkap3n/C0WfIXSv6GqAD5BX9EOB
7l3LwWLmi4dXYQmgeDuS4yOk6RnbyFeICt8pPV86Q2FrZeKEAns03pQT1VMVvjHpoOszJYSa
y6mrsAwgK1nRRBkj95N67rt+F7KloIkcjIwN6sjmNJqfqj8W75sjqC+1j4PS10q5vHHOgfTf
U0fCbEAgCF/1mbh3XRy415NXlhLClz8vPwHwcDMZ1oOgky+D7t+92qrqgT+ZCC0iWym8wcBD
9hBtEPjbZSngN9Y5R/6YZUFWNVG4qg7GFf+gEGfTGQinUnVWamqCkX5z4d3L/5dbPi8N6mGo
ONmUsvN2OhcWzsUBLqX/JEv99080gMDPW4ZcoLS3zeBcu4Y2SHKfSGoQQgQyhqULJbGP5gGc
Pof8r5U66ii1Q6Dlz7fM/lVnFuWeGzGdTSzT57LD1VJCq1XkXHr3XGo4drflB1KYOn33ef01
DjxE8eMksJJ5rgxyDGkT6+2EkBN9itcDw6/nMXfe3tx+v+4REGpPPDI128XEURZarJwSilmf
zYZM6CoU0+x87bSilfdEKPNYpqFmeJiWw/xi/TU5X7fk6n+rQOlt4boig6dOUqeLD8flKIGl
D9mS/Y+0V8xjoSkGnE33lm2ZpuUGaTd99BEwvcB3fpUu5UnZPU6NyppuIJs3K1yV0HOT+Wo7
ZYd1cS7k9EftMdes/kMFtyPIi6zcRGNXJ4Gj35iUt592i5W1KMo7tDyv2uGIQPmQISyI85ML
MLs9s6SFq0obB1Gf3ZbU2LWtZaicYPEycYJ2hstqwLtxLE2kkfpnrgNyVSabkIkn89hn4GV2
g61NrgcgwRw5oFj6I6AOBL8ZhAbvl9Kmo2wPJx1Avnu8DXM6EAw+Ex76Qj+OTlJrRFbITB8Y
V2IjHkzTTyJbYYFhYesg8tQ28lRT+0WbHUIFeXjNkNOEwQwLeN/gMusWh3sHe/TJeSNiEuFE
TE8mLCE7zE9cYeHsjJ4II0FUS10POCfwIhAhm6CUnc6k/90GCu8aXuxbmD7wVdQX8htI9o2j
axU7FgnqYc+AMks6Vo+E8jGwwj53TERqk6aMThNHifl6jnp3z6xl29DC7qcYmANiNwBTOGNa
tw4hXrfMDe3HN0Nk2o6N97AxofjDE9txTMX5RrvAOpTXpmloy8+P7YkGLTSIwwjqs6MccB0j
vE80Z2ZoIj7o8bq3bL+5jJzD4IciGNWQO2jnxBZEBpCyLHyH9is+uGWvSNeJxjBGJOfXocUj
v72LJOw8vAaPBhY291Np01BvlB9QW45jb11VfpcH7/V+kaE3PiyCpsHSjz04fgxH0Lv93h+I
T4KnwSqGIxhWKyQfnzNgykV5dxzrWCfEWDZu36au1nrTXVsmpZUXagsnac9BFKRK8Njn6Wu2
5JQHblT124IM676K3CDvxEU3Gsqm68TppGe0kzAegbKc/aB7T905Pfs9gkTeWNHNW6aKoV55
prLCDPDPxJ1iYuTHOqY949fDhZhivWZ0KgOIxE0/jkv8aFYNUFhjQeLc2ZNUdJ5MHDFUrn5T
6w4tYwdiyCcI3bOTIwdI1k1IML36+6TUvRPiYeHkHtM4bDRO4+Z0suRlGPH0UMQPdWJuO6Ho
2KUuD+0z2YEOSsBjykNqBOVSRKTdvK8CWIifImjBdD6QEGTFM04ZEzm7kKsQm73y1ZvaBUu2
UiMTF3NCm3p0rf78YDSGoc2BHM7bl7eYmHCIuQSk/9o6kMvA25voPZPvfBBqXhcHJNR/cSkh
fPnz8pPS3+12TABOWEJfBt2/c7WFhuN88VZ5M99RmRNX7DnHi2pqEr27OISOhuHzihTwe+uc
I38KXfKaYWHOTR4Z5I8Fbxu/nLp4O8XSupsvgPC/rJQgq6kp2vVMWDgXB15WSnIBwBI7yFKp
/ImsLNB7MLntp5H/HytljZna1FUCcH5sBH9usORcdnhl6bnUwGKsFKbO3n1afy1j7edp2kDa
NOEv5FMr6yrzNq1E2dSbQtKNi7qqfhWNbEbwotBWuBVQTJI2TXjMeCsEX7Dv1NRVXTf9xNVL
mBKPPYmeNFmypE3hrmK4sdylyyGW8pb63QrSxbRgR2lob14l0owMs+QXUeZoPpCqUOpxxtCE
JHPJsZoy78jANALBMFmOfB3BvoWmrRoFcZeefmTP/OAYgpkBCJZ3AmDKeJkp0XLWjNRb55AD
Ms/gFvrM5XTYU31rk5+HKotgDj3SMPtx2fSzuGLoIbkFq/2bMvMdizts2n4m7pJGOhqCC7n3
Dgjq2AHX0UdLOgcAhYTDKdqxX4Zc83kAhY4ko+hnvLuupRNneJvTYoCgf0RPUIeIz05Zig2F
ncI7fYnPOajpZ/k6EcaKPhMCicisCjHsY2vKl/fhoim0LIu2zVKvrCps5i2Tj/bzmpxftppY
3mOu9/U2lcExLKPIViSymoKpYgbtZFiCiNp8cdIEQh2r4FIj+1cbflKWRZYEu+oO0iZ4LynR
HC8Sl4UCNe4xxdJIMEq1snY/ZMez6oMhYGr4lMEAJrbaRm8ZJbTcWPKuD26ZHMMFDZzTenxK
eY2ZkpkQ2U8QJwhfzTGvuTnvB/BxwfPEXm5Y4XA5GQMD31CPjF3Qq9zTKB1mvN03VTOgkYXT
NxznAe69yzDajvr320iw98niyBmKKvMASdwgljT6qczd8WRICZlhKdJEz+kebcNJJJKy3Nex
EVc9Fems373R4Ukx7NZBbIONFw+5B9se/u9Zr+DCZkX9ketMoZ9ghqtUVw0EqraRn2tbDi+O
Zu6nCrL21pPI7jjicpgO7yo36xm9YWBlbnHedNiqYJucP+04naE9nDm/BDb+WuhHPjJIFj2f
PsCdMG9jSImgjTX4mgE2bEM5fqq/Fpo7kQ+vWm3JzQ3bmvu6qPuv3pInrrX9bnhA3MNz10oG
fhAVE0ZyH66u8dRyUc3iQdTgW/q2bUokv4rKpm2aphveu7cptg03q+o89qC2mNirQxKydZWA
rwNMdxvIzlPXuJZSc14YddBMzbrU4maWuYYgihysW5legIXF2ofdTUGFeRFaitDmGFv6TSl9
l9SbFVan3cPEYRLTIos8hca5eycEUSJPf1HeDEftwb8AFOsYJ3iQVW3TdOOcxFnT9X1Xh7Y+
9TgB/id7D/jzNmUw8NAV93VkMnMYq9i2LC96PD5IWFJvtzVG5RbbC+5nuoFva/JuJt/VvGsT
+xZUjG3blom7Vs/7cd7ZGnsUzUXk27Zb9PNZ/XZe7sBxHdPQ2jAdP/lVvUziom6HoS/X8dTB
wtPO2idq89j3Aw6fPQfSf2sdIF44G8I5QxBOseviwDnUf0GpRPj88+ITyzzEPMO2TMtLJ+bn
iDH9Muj+natRzt+drZuaFFsM5BABiWsDKDwxtXGf3hUp4DfXOUf+mGXYmOm2VXwOAI9b9HBm
d/JrIPyvKoWCMOjmI5xLQ4N/IiyciwOvKyW5AJiZxG0uFT/Zv8SMy9VyN5TIDzN8Evn/mVJx
nUaRZXktACc1EvZHAnFg+3PZ4ZWl51IDhLgHwtTpu0/rrwGYLl0PAk9YO1lGbl0xdiuVCEzK
jPKG8GIVuI7jOrYb5Zu5TLl5EZN+TicQTEsYIYMFEHL0fRVuWUOq+zk0hrPbKeehqbsR4oFX
LqXdpmQbQ1O9qYUObaM66AhplxLXOzXDmT8C+0fjrHXznvsv7zWampgVtYLGdD+6jqgQFNSJ
YzvOYaMz/G5vUG2p1mc4aHyAC1NXl1U7zfMqNqbmDpvYNdv0s22NZp4JQCC9CaCs50BL6Nss
28J5hJ0AUX8TgpIs8fZyXpOw4/PPmTJ+gAw/Sustl4+goW3qxyQ9rPfxKCIfeBGHpfCJSJqR
ThQkxMCk77HtUx0rTCWSq0C8pKCwfPiQevLmkkNt2q6zkImRxD1FvpYJtWXiPImHoLRCT1BH
W8472bblJTVagPXPPcq8uNqZAP/3KTJE4nu8rizbAS1/QNpllRZgluBOvHfQGkiBXTChKbR8
tyhq5s1448axDdXAnDsau/KoCb8npMJI+n/ayNpRMnYxtKLSZobtjKYkWX42YQ9eaIS+msgb
P8DbJLAMVGS/DDaSyfu1oJ4jTTQZY2ARpAWj8x5/k0ct6a+DevcTsZv9yAjqecgcdgMhmqFZ
gYPYqee4un9h4FAeyutULghOzM0Z6nmF8IH9Ypq7Kgs8x1oDM36RhuIepwCk/Vvbp1cMx3qg
aWLvZkit0mqLv5epLMp8paIIHWhMDg7MB00tUkVBrNL+cJy2fJcy+wLLazCh4sTphs+kcDzg
b7SMo4EMUQ2nmuH/u2cYyyGZw/VM9gqDgHuMOXsDIhg6VyDL0ocGFsPrpPdCodFPsAVxL5/l
hUUFbEC4HJcewy8MnZQZz7DRYH0E6EfioyN/2vTPvLVpGHrTI/epw9PH0Bka1YF3lovK5NyN
MaTXvcOycnS8Sn3PM7WQLU+C2Lp0twe7YVofrVfwwadF4YVpluHwhXX5K+i8e3BxABlaK0E4
pB4lGTx00JzQaSoUcnqeG9Td4ZD6TJgiaD+SS/XqHZzvTi5+3k7T8mwmB4KgHMAHgPE2xLgd
N+V54gkN/bUJpbmUAig+vckCy1zc813fdyzLx7QOsQPUEIQe1kiQjYdUZhtKSzK0RiDtA4CN
7vnVob8+SBWj6N7TNFdJ6PkLBUHgmLBpBUGwPPL8ZDWzueqNycl77oYTyQu6pUTKrKbHwTqw
0n+r0yXWYqYfbnOAnqfD7lL7DcQRWm3k2saiPrb8uLg1ERUWXBebIrQgMshr5C3XMT4k75oy
Xx8Ov2f1AZhNPww9C9489odTYOp8fdY+u6S5hmE6EYblEpD+W+uUvsFee+WmtjNvoLplextb
viwOnEP9F5QSwpc/Lz5Z2qdAMdNJJhmm+XXQ/TtXY+IsT0HJU39YRKxmvRiG3K0Q/QMl8gUp
4HfWuYD8McsckOocn4P1oNa8Iy6+OirnCyD8bypVmwiWlQVQfewBJ5wIC+fiwOtKWS4AZubp
41L5cygMMEbhflcMn0H+f6oUmn0F2kIctb5RORIgt5oV/Rv77X1o5Fx2eFnpudQAPdgDYer0
3ef112OJOIvTuMjMNk3LPpxcDcc23/WRpp2yFmnsy/RAYNLawLzGyOrShitu32QeHTBbNFC+
DZWxeyOMUI+C8dEHcuCJcHYQLodtFsJVCjSlrqkN0J6hUpnm9lsjC88pTHSxFU+cr0HS9jgU
HunoQV0mUkSRivowu8b1cGJwsGkK7D2nxurnlHmm2uB2Wbf3E177Bo5SoCgYSXjlYIlTWJ98
mGw6QjfZH/ahpTh6qMsDJXy7tZtfvz8XbwRRUWMtSgNXXjygPC+b4e4VC3WRBi7AAa+igxM5
WfcBK5hhTQLn7a3ZdgplE8G4I4WjG/jeIjlhUfE1I/uCZ2dG7NnU0WjtLFhV6A0BndEy6uhg
Om1BlmauAT0g3Veb5UXsanZ2EI0Dqcu7XPCZ4kKY6WNn3BCJdw1g9XNTlrxHsUUYHdbhpidC
AATVpGB8Ky5SF8pEgGBaEhKH4VYxNKXcELdNJVnRrkaWC41g4vDVyimatqmr2DU5QEEu3LZK
bS3ScZBXphRphO8z0C0ml3PW19OYu2yCOhJuIrwlMHfVNjSMTpz5BDdBFMt8elhAg/MoQdhQ
ho+V16QvqCdWwXD2NKlGfBn1h8pFacPcECqWCiudmb9Bej+5DQLzQtuQKuNvSXhlr8AHDceO
0eSCJ898Xx8FfiLOd7eI8/GmSduL10GBvDjhUN0evtggYWvHxoxqKvUH2StoTyj+FLwXqmQx
++QAUk9yeCceMfSTNCzQvFgf7FUjJDeAWpl1nb2QTPCEOXP1fpTUFs0aWJYZddug2Wm/atXD
svS16A9Z0eJWbH/c7zcGwiiFSDis0qATyGqjqJ2vKIj73c4EqwMrc7UVZUVZZKFnq9vQ2KQe
fpv+OrFvEtQYgrRGxkBBc7KaOXIkHMYKQaJSkWJ7HDokkXKStmubX9RSjiyLjjDgYZzyibNq
flecyonUDWhzRL5vkt671L2QaGXwV2/x9T56uEIL3Otx1h2102pWn/j/ZsOUIP12du06oMoA
n78LsNE9K2n3YTGqaUptBb0nde9zhEPnau6OeUsxMp5XhSWJJHO6YNPtqNJqnDDKoXEh6YGa
NHAc99kdAXskiLkZTgsb+7uosQF2O+4M+lUJdypyGv0N5gEJnNUXFwkCOdOoQVA6aZ+GMBLi
3jmQ/jvrABJsZK02FJj6A+ImRJfFAaDx31dKCF/+vPykSxSOKnmE4d6/L4Tu37ka0ZwThEZA
Kk0KTvQCDDlABWCYFV/NV6SA31nnHPmzX7mbLhEwVZE4BrZJOUKDtkcfzoiThkLpFIT/TaUP
ySuHE2HhXBx4XSnJBWfYfpQ/oQcAYmTmCcXIJ5D/nypdr2M1tAEyrZU2hSOpHNFIUE3w5DOL
vo8t8Lpz2eF1pedSA86sB8LUybtP66/hFF2W7TifXnoTqTel1bF9jP2vhZQyPwQkzm309qar
GTYWeQd9ZG3W/nGug3cX4LkyoZWDhtfOBuoASMhXJK7fud66JgXuc2hPQgQZfnjoRPO86O4O
r3AgxdeBTdOyFtf4FL5MgwD3amNX2KCNhzRycvM3QcLxR+aXQGaSMuDMA5TWw0pmISx9EPCk
a3nhilva57Hvuq4f56l2tYhHPqN58ZL2HM0irxtkVTPOz+YPQUfKLHYtjgowvcWz+zbbgL3e
/zN8wArAjqVv8CdU4QrZ0x5bV/s92ZYFYZFDyyzWT+6o40RHGp+8PxfUYaCSF2G52bk/wnkp
/nvWS4fQbbXQ67k0AkOlhc+ECMdUiVW3t1aS6cLGTj1rCkXChxRjCwMDEA/VxArbOLJhkC8k
sjk7qeSWdGmhmEHBas4b8YtBToG8q1YQ/E1YxpOe+Gf2CXTbqieRITqIHC1XHdx4QdjvjJbE
pGBfwI++iUQ8h9BBk2ORUF47UnnNjtVwZmR7J2Fi1uG+kNrERpjbMN+g86B8cENmpqHs2J0N
rezRNkx7lmORv+VYPFZYTvN4SxNrgfn0CQ5oyGcBfNjB+ZkhNKRH3rFmIcY2uzk4lKHp9iEq
wrxgh9LG4ZapV8gDM+TeSa9gf7VStlgYUCWjhzD2oPR95AMDekmO9z8cw2U/+Shp6nJ1isGJ
Br5nhJz1D4esdCUj4GhFVUnp46kmgFnUIn2qZXM11IxJJyyCyXABgOtacpNObWpgfyV3/R/S
3b/mgoJ487hUQS5S7DbNeKsN7NZ4qZajqV6tvwYN+1hZeffMP4d10CiJ720n13LNoArGB/hK
8jQs3U0CK8o0cN7ogus6jYIgjCI4pppuEIVhGARhUs3wBog8LzoGtEkZYyA7xCnN2bIgrLJD
YnFlOr7nmluGh39qc93LMxJMlEmSpDslSVL10+EVCJtrnVns93dOY2kArkiAzd0zf31tHWi4
Xc+IX8yb0kb3voBKX39pIkFi6UYw8vkLYZt9FNZ0+X2hwZk/QafT1GT+7i3tHf7mnJeDuBDl
7oR62sjbJli6mJzVl1Y9K+z/dfsQEHax8RqQ/ivrgMMLgmVL0HVxwCt+cynBcvHz8pNOXmzD
GZ/sZP5S6P6Nq4HoigXDQ6Aw3dMrMHnSjIyKEclxWQr4nXXOkD9mWZC2s9V7TaKsNvV2s9w5
CP/bSv1imqePsH4+ExZOxIGXlhJ6J8w8C2x/72eXbzeEFzKwoJo+g/z/WOkHaossSZJcmKXR
yJtSR9zkWGg0ci47vK70RGrAuXYiTJ2/+6z+eizTJMmuAbQhV5BCST1HlIdB3g647HHB633A
38z3B0KIgpdKUE2wB7JWDnVA5SbzImpefsbxLoglc4DFz8s2U5fFcZKKkEq6IDWJ47RoyR8Z
Yr9clIdjSxXZgnFjxUg1ep24gDjevUj5pufuwvC4r5umqmpQUwG2WmlVb44/XdszgC7RK9zX
3OK+oH1RDoX1Mf915ynyqyKy1W1Ku/HmwqV53AJfATdCSwGj8JCW3YHE0zhOMuYAJGtXeeje
eG85O/Qf2hofL6lC0pHNJsZ5tN0gqVoJFdGNlHLjICMwFI7HeeMVdZ0GFho0LH2TgLJ1dg3O
PE+geW4SB/IMeMF2WxGor2KD8rrAJq9sXq3z2CWeHa6PYuuD3+vU5JFJyc1R5zHqRWnWPdgp
IiPq3Pm08cXrUFThGwXLe3jzpOzM3LoKMjlaF9nSZSTarkebEnexdgZFT/cNBiPVJDG49/Rt
UhS6/3ppgWZHQ1Wb8qc9UMueN4JUzmIMsR85HiIMs56V+EPpqLsZb/CKWLdLAa2R1jcY3crE
+sKjn+6QJDBBpkcRGNgkDr6dQg2Evxv5rIlbiYbq3fNaTPepY/WEy4Rn6cn7SsLtQ0m39z8+
YsFQylE48LmANIvcETx9E3L+BhpmJA5n4UxznPBUpNKbEkvBxkliMGmWccUiDJPoJ/6dTG+9
l3ZspKHZRwWvGOFGB8dJLur3rcE8QbbcccoXLpW9gm3gmPG5C0ws1KOHPPLhfiE4DS8KWwT4
o2Xu50Ftwyu1MfbVy3ecikTMrG2E8QCsSWouyKUa7IVsRUhBw5qgzehXxkpEYEAdD6JlQBcJ
2lH1FFiSz+FcD77xJ+mk2+T4SXbTS4RlAD4DVokDJTG3fHfzNMsYRMVzgYJ8fVeS4QFDcYYr
tkbyJuKRH5rQxhRneHxGuENMuWXb5HHg2JZl254fplnqasCGK1QE5p5RqjAJiJ7R3LiG9tL2
QvecNM+LstmBYp0ElPT/K2hsqzyvvnK54hTm8JTON6QpunNXF+W+CsFnXkQQhs2sHavAQJjI
w/uTMbDQL2yPTLpB7mF9nHaeqYQZ47n2hyo2UIDj7CKQ/hvrdKkLl9IexT3i8B6GF5yLA+dQ
/6WlhPDFz2tPKL9E+45Ty8RSdDJ+KXT/xtXA8kJ8PDwIu9zfN0exV2shfNJBM4+1b2BA6um6
FPBb65wjf6wNw8sKJKqo255KdwcLBvzwqjkH4X9TKeWGBU0DkmydCAsn4sBLSxmfn2N78RMp
0bSbHeYL3wA+/wzy/4OlMuINCnqp2DzcDpYH3MiZ7PDK0hOpAXN3Ikydv/uU/hrw5Vq2OBg/
naxHoIfw4zOg9MMlCyAz6CXfQUzEIdJ4eRHv6QJnqP/Qmu37nm1qeVf4+b32bHuM6unTsg2r
b9z+bIhEEITwzBrKw+XBdy2NWayG3SfR3jzb1b5ytVJ2VGOCQUhusmYMVMZ+qu2Zkj3fcw28
TxtbpDJnE6jahttxfc/FeBMqpSzVbuA7aBv8EQqgR8JDspTge33PPvrVzkfGSW05rutYKNLv
TLmCKiVFL4Brz+NDp+0CRuRJf/Zq+zft+BGuf5TE8Fr5o1CK7Ux5WNIbCTKcsBnJm5V8kDnm
F8/pItdlVyH0EyM/UMJxDK/jrZvF4CBE5wgyXgm/KLk+1XkzDH2Q0k49oRSJNSRRKttl2Xmu
baE78FjE65TvVV7Mgs+k4BTQhl10ekyFbG0oTHx8NFBTcLk4EgJpu5pQJLyZ4P5DRwvVJJ4g
9LZTsq9lva5sax9dZceog6ZOVCGiEb034qCR+2PYZ4rMS+jaugLcxQFTeqZjK/EpwtIyOr6+
rx65+XSpfgPFJ9cwkoIMWmn1kTN0ubdzp5b9u3E6XMvhblKEhKGZlDKDnkNz3Ex6+ZFz+kw5
Il5IXea8Hank36fJ2IYrNIhNhL7JthnMOM5E13UdG1HYvDhtP/Qdk6/y21/ECvPDMMBCPWKS
Woe0wIwXBWEGA4MYgkhvHe6l4mJMTD+/3u8Sl1/0KIKsgi1JsVbjx5aHnGNZwse9QmWsFMfz
XIyt2s8gS4mRR3wrDa9ygpvhXVrmfhLhpPSDpTX8Y78n6dQwLdN08n7es3Bo1/cdVF1+dR/W
KtksBevA2EINdBsUtftn2dUI4AjJQaIyhOMwogM5nrfnM7UjZNiUk3ICooCOwAm/t/4ah3D5
HGrsUrbI0rms9/kna6KjFd/qbNweuImNa7jmaWjqumn7eepCE1yX8Bi27bVPa00K6Dknzols
+1FeVlWZ7xeBWPkz11rmnoVM3F1mWp82XcjueWGaF0Wehp79fPckjbGtlQYZhrGgbHmx5GcX
Ho77AOkgFlLafvf3H+B2XccWONiLaKw8B9cPFIGLrU1EEEvxiT91RRRFcYLYEtMJ8mY4q98k
GqwpyIssK9r5+fbHOjru4EHVy0D6b6xjsvhGLBQ8g8DO4qYjxQF3OX0gO4MhnEH915VKhM8/
rz/xNcu+JMso3LX7tdD9O1fDUoHzkIxHNDaolroGX+rueh5gJ168KAX8kTpnyP9cqsK9KY6l
lOF4QRh4GEI7mc9B+HcsZe2KtlAKAs70XM+DlswrR2B+FDq+77kOhIVzceClpQQURTIKLpU/
0TK+3/OwpiEZfQL5/8lSEKUv1toHq5c+XhBM8OF7Iyeyw0tLz6UGeEdKYer83Wf11xRnEQxX
gZfOeiT6kKHWZRra4LVgl35STrfMCEa/maM19fFGkHd06zQORJC247wINjlT+QJnNTa5MJNK
Au7Az0PMOyJZ6pw1iGyAxFVT4XwtvJvBY+JquPkvgqxb/TUUmcLbEU8JEycCkrKGwghKKawe
loOkunl3qBOuY7pxz2ZSAbbYMTq0b5o3naid2BRDSMRPB3EU2cg/DkUDHPNPiU2O12meZAbD
S6MH4ce6cSfs20X87MbVFz5Jyu6mbZvCwYQfKxYzoAyRNqwwvbURjHVgGx8mfrvhfU/ewiWG
/ausIFkBdQQpp0ULvGcFjQ39d7xpOX5e99S4DApjdSE+k4eCUvujG7K1o5qmK0PliB26PKmj
ZBGIV6+sObeL66KY9CkPnQ9gIkhrFHJTDxUlaORDpz1q5MEYDny5jWMZHzmGF3eTuOkeikKp
Dihh79rJJEOLNFcQD5TrFkcDP5R71hC5I6h9MvPKuyOItGCGIBxqQH4cJsKjR9Lj4BHieSFN
Lc5zmHwsPtp9veFXiw69oGWlf4HrUSkgFK4PoUXNWuaHqKO+jE2Ug7QVtPNhYJAYYC5C51CX
e47B4+9pMASaNXieilKRv0VUaFN3DxLiImxJ4gkdleI6YrZMnPUKgxDpW1PiwVhctY2bweND
LLILeHhNteujRT95ZRIZdri3NmY+OBTWOTRxeOI4lkgm0PukAScS9p6plJoguOON70Z9Uzg0
9dl9x1UltxdH8sITFsN+qkUF/8GTP02E8aYvaY3uGq3pWE550+HKZRjeJPEwDnXT30lX147n
0F2OfOLaflK0fV/nkZas9ZzmIY88U78jQi9CrtRX0h/sHu4bOCEr/GyATsTtI40SaJc4YHMN
6y61cUid0NwVgQ8FwgsIrmFSiiFXR11Mp/UR0E2k/OH59pFlMQSQeApI/411EPAqBExJgDfX
xQEJ9V9ZKhE+/7z+xFEfZRnL8eIcp9aXQ/fvXQ1pB6pB7Ng6L3bsvh7+YZFHH04i24u7+aIU
8MfqSOR/sjaY4qXUiBL/pn0v6c9B+LctJQgKWoyd01gLVG96zUTCgpLCwpk48NLSM2xPpeIn
qC8eoPdPIP8/VXqdIOB+aATTeCI7vLj0VGqw306FKfGu0F+rYPqYBTok/fWLaSr1Q0e2qe+6
gTt3XKc+9PI5ciJ3/ZVrUQpPw7uEFPzY/19ECrlanlp8jqzPH9f3X5vhcR6HYWv3Wd3tdptK
3/enAz5hRtD4cz3rVpLvTuPQX2uVxfjvSH2u98Oy3Rf02DeJb69PAUZfQRjevkda299HPLl9
j2Qwn6cpdTQMdN+c5rHrwKc+00jfDX0dK3JHfY7mCXu/6//dHIxD3y8tYIf+/QSkiws/Iw6d
H/2Vm+fjP3GweNVSNvaX0wAeO5/vpn6cHnDgvh/6Qbw/9N1ps/PQd8NC4mQQNFGNzSeRhOQn
qaPbPP48jcsSHz6eNHq/eGraDyL5Jkpm+D0hDdHpYbpOdHeBI044sv/AtoOBAQlhniV4AZtZ
O8zzQy3qNE1DkxrkYPU/R8jmIXFvk9iLF1U7/hHXchafoPv7o/RDm59NMy9ST48tPy9MeZxp
BvWitO0bF7EUp9SnMN6/hsb1sPoO9S0Equ6xu1kYZo+++ofm0lecR+iHzqH7X1rtnPI0Hwj6
jNM0DMA+T0oBr6/zApqnTaEh25cg/PuXArwOt+sBupMH09rl6xmStufiwOtKv5QmQu+fQP5/
uvQ6eU7QLO9Nw7JP0Mi57PD60nOp4VyYOn8X/tfK9X3fA/m+75oKzmWvp60D5fTbT6Iu4cjZ
TayCq9CX6a+N9BkDShrHyMj+RfRDSPX1jWlq881QKixnZlRcUgD9UOgiZgXBR/8hQmgVLnn4
oU9TgIUErcFBbZkm6WLSpXKcHT/kqeUO3ChJ0zgwFeWOfFp8imzNedi/KT0Vp1VxOu+/nLI0
cU0lXJyuU+9r4VMptKiogIT+/4uE3P1aaucrX8mAyNcn2cfID11TZGkSr3eGdH8+8fgPqQv3
8QxNvlpbpzKJjgBKSVOTul4Yh866fev/zFGuTBtZ1pRXyGo/1KTBsi48E9lF/0P0Qz/0Qzgd
PD+KAwdg4Id+6LVSgxSmnn93qmNDa0OS6TXzbwrrq+v2j0gpM+WLmEb8/UM/9NtprLLItW3L
smzb8fwwK5/Qwv7QkQ3tv6nxn6dp/uFdXzeY4zgux8E0P6yw1Xl+zN/UHXp7M//uIRP5DbTl
/zs77BFEXH1vIfoZB8YpNtnT9i8mnqB6+veX3GVx6Pt+EBfTAy1q4C+JwJP83/6T778lp2oN
WfZ7WdKVeUWPX09DGVumlTTfcX3+EK5p+jzxfa3a/i8oKMYmMTlJnRvWwjfsh3DTCQ7usP8Z
jh/6j9EPwc1iI8MFVv2hH3q91EDC1PPv/gzuD/3QD/3VNPQ98ur80A99YzKtO2Ta4f+A1r/v
luT9VVW3/b/XOjZV1bT9/P2xflVdd06d+rau27/fHokPr5uXfMtQRqY2+artny35Qz9UV1Xz
dY7w8zz9ov9Wxofxkq35x2w//YcH6Yd+6Ifm+YcJ/NDvlhqkMHX93f8DITgfODO4jx0AAAAA
SUVORK5CYII='
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansOblique14Data
	<generated>
	" Font meta data for DejaVu Sans Oblique 14. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 14 18 4 0 255 21 0 0 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 17 25 34 50 62 80 95 100 107 114 124 140 146 153 159 169 181 193 205 217 229 241 253 265 277 289 295 301 317 333 349 359 378 391 404 417 432 444 455 470 484 490 500 513 524 540 554 569 580 595 608 620 632 646 659 678 693 705 719 726 732 740 756 766 776 788 800 810 822 834 842 854 866 871 880 891 896 915 927 939 951 963 971 981 988 1000 1011 1027 1039 1051 1061 1073 1079 1091 1107 1107 1123 1133 1149 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1171 1179 1191 1203 1215 1227 1233 1243 1253 1272 1281 1293 1309 1316 1335 1345 1355 1371 1379 1387 1397 1409 1421 1427 1437 1445 1454 1466 1484 1502 1520 1530 1543 1556 1569 1582 1595 1608 1629 1642 1654 1666 1678 1690 1696 1703 1710 1717 1732 1746 1761 1776 1791 1806 1821 1837 1854 1868 1882 1896 1910 1922 1934 1946 1958 1970 1982 1994 2006 2018 2037 2047 2059 2071 2083 2095 2100 2107 2113 2119 2131 2143 2155 2167 2179 2191 2203 2219 2231 2243 2255 2267 2279 2291 2303 2315
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:34'!
dejaVuSansOblique14Form
	<generated>
	" Form data for DejaVu Sans Oblique 14. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAACQsAAAAWCAIAAADiy8+xAABGtklEQVR4AeyaqaK0LBzGzxV5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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansOblique17Data
	<generated>
	" Font meta data for DejaVu Sans Oblique 17. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 17 21 5 0 255 24 0 0 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 21 30 41 60 75 97 115 121 130 138 150 169 176 184 191 203 218 233 248 263 278 293 308 323 338 353 361 369 388 407 426 438 461 477 493 509 527 542 555 573 590 597 610 626 639 659 676 694 708 726 742 757 772 789 805 828 846 860 877 886 894 904 923 935 947 961 976 989 1004 1018 1027 1042 1057 1063 1074 1087 1093 1115 1130 1144 1159 1174 1184 1196 1205 1220 1234 1253 1268 1283 1296 1311 1319 1334 1353 1353 1372 1384 1403 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1429 1438 1453 1468 1483 1498 1506 1518 1530 1553 1564 1578 1597 1605 1628 1640 1652 1671 1680 1689 1701 1716 1731 1738 1750 1759 1770 1784 1806 1828 1850 1862 1878 1894 1910 1926 1942 1958 1982 1998 2013 2028 2043 2058 2065 2073 2081 2089 2107 2124 2142 2160 2178 2196 2214 2233 2253 2270 2287 2304 2321 2335 2349 2363 2377 2391 2405 2419 2433 2447 2470 2483 2497 2511 2525 2539 2545 2553 2560 2568 2582 2597 2611 2625 2639 2653 2667 2686 2701 2716 2731 2746 2761 2776 2791 2806
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:34'!
dejaVuSansOblique17Form
	<generated>
	" Form data for DejaVu Sans Oblique 17. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAACvYAAAAbCAIAAAAiBb1HAABWLUlEQVR4Aezcq57rLBAA8D5R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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansOblique20Data
	<generated>
	" Font meta data for DejaVu Sans Oblique 20. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 20 25 6 0 255 28 0 0 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 25 36 48 71 88 114 135 142 153 163 177 200 209 219 228 242 259 276 293 310 327 344 361 378 395 412 421 430 453 476 499 513 540 558 577 596 617 634 650 671 691 699 714 733 748 771 791 812 828 849 868 885 902 922 940 967 987 1004 1024 1035 1044 1054 1077 1091 1105 1122 1139 1154 1171 1188 1199 1216 1233 1241 1254 1270 1278 1304 1321 1338 1355 1372 1384 1398 1409 1426 1442 1464 1482 1500 1515 1532 1541 1558 1581 1581 1604 1618 1641 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1673 1684 1701 1718 1735 1752 1761 1775 1789 1816 1829 1846 1869 1879 1906 1920 1934 1957 1968 1979 1993 2010 2027 2036 2050 2061 2074 2091 2117 2143 2169 2183 2201 2219 2237 2256 2274 2292 2320 2339 2356 2373 2390 2407 2415 2425 2435 2445 2466 2486 2507 2528 2549 2570 2591 2614 2638 2658 2678 2698 2718 2735 2751 2768 2785 2802 2819 2836 2853 2870 2897 2912 2929 2946 2963 2980 2988 2998 3007 3016 3033 3050 3067 3084 3101 3118 3135 3158 3176 3193 3210 3227 3244 3262 3279 3297
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:34'!
dejaVuSansOblique20Form
	<generated>
	" Form data for DejaVu Sans Oblique 20. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAADOEAAAAgCAIAAABhfxr7AABm50lEQVR4AezdLbarPBQG4IyI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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansOblique7Data
	<generated>
	" Font meta data for DejaVu Sans Oblique 7. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 7 8 2 0 255 10 0 0 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 9 13 18 26 32 41 49 52 56 60 65 73 76 80 83 89 95 101 107 113 119 125 131 137 143 149 153 157 165 173 181 186 195 202 209 216 223 229 235 242 249 252 257 264 270 278 285 293 299 307 314 320 326 333 340 349 357 363 370 374 378 382 390 395 400 406 412 417 423 429 433 439 445 448 452 458 461 470 476 482 488 494 498 503 507 513 519 527 533 539 544 550 554 560 568 568 576 581 589 597 597 597 597 597 597 597 597 597 597 597 597 597 597 597 597 597 597 597 597 597 597 597 597 597 597 597 597 597 600 604 610 616 622 628 632 637 642 651 656 662 670 674 683 688 693 701 705 709 714 720 726 729 734 738 743 749 758 767 776 781 788 795 802 809 816 823 833 840 846 852 858 864 867 871 875 879 886 893 901 909 917 925 933 941 949 956 963 970 977 983 989 995 1001 1007 1013 1019 1025 1031 1040 1045 1051 1057 1063 1069 1072 1076 1079 1082 1088 1094 1100 1106 1112 1118 1124 1132 1138 1144 1150 1156 1162 1168 1174 1180
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:34'!
dejaVuSansOblique7Form
	<generated>
	" Form data for DejaVu Sans Oblique 7. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAABJwAAAAKCAIAAAB+PNPGAAAfT0lEQVR4AexZq8Ksug7OE/Ud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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansOblique9Data
	<generated>
	" Font meta data for DejaVu Sans Oblique 9. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 9 11 3 0 255 13 0 0 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 11 16 22 32 40 51 60 63 68 73 79 89 93 97 101 108 116 124 132 140 148 156 164 172 180 188 192 196 206 216 226 232 244 253 261 269 278 286 293 302 311 315 321 329 336 346 355 364 371 380 388 396 404 413 421 433 442 449 458 463 467 472 482 488 494 501 509 516 524 531 536 544 552 555 560 567 570 582 590 597 605 613 618 624 629 637 644 654 662 670 677 685 689 697 707 707 717 723 733 743 743 743 743 743 743 743 743 743 743 743 743 743 743 743 743 743 743 743 743 743 743 743 743 743 743 743 743 743 747 752 760 768 776 784 788 794 800 812 818 825 835 839 851 857 863 873 878 883 889 897 905 909 915 920 926 933 945 957 969 975 984 993 1002 1011 1020 1029 1042 1050 1058 1066 1074 1082 1086 1090 1094 1098 1107 1116 1125 1134 1143 1152 1161 1171 1182 1191 1200 1209 1218 1225 1232 1240 1247 1254 1261 1268 1275 1282 1294 1301 1308 1315 1322 1329 1332 1336 1340 1344 1351 1359 1366 1373 1380 1387 1394 1404 1412 1420 1428 1436 1444 1452 1460 1468
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:34'!
dejaVuSansOblique9Form
	<generated>
	" Form data for DejaVu Sans Oblique 9. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAABbwAAAAOCAIAAABrfk3AAAArCElEQVR4AexbrZ70Kg/niriH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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansObliqueDark12Data
	<generated>
	" Font meta data for DejaVu Sans Oblique Dark 12. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 12 15 4 0 255 17 0 0 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 10 15 21 28 41 51 66 78 82 88 95 103 116 121 127 132 140 150 160 170 180 190 200 210 220 230 240 245 250 263 276 289 297 313 325 336 347 359 369 378 390 402 407 416 427 436 450 462 475 485 498 509 519 529 541 552 568 581 591 603 609 614 621 634 642 650 660 670 679 689 699 706 716 726 730 737 746 750 766 776 786 796 806 813 821 827 837 846 859 869 879 888 898 903 913 926 926 939 947 960 973 973 973 973 973 973 973 973 973 973 973 973 973 973 973 973 973 973 973 973 973 973 973 973 973 973 973 973 973 978 984 994 1004 1014 1024 1029 1037 1045 1061 1069 1079 1092 1098 1114 1122 1130 1143 1149 1155 1163 1173 1183 1188 1196 1202 1210 1220 1236 1252 1268 1276 1288 1300 1312 1324 1336 1348 1365 1376 1386 1396 1406 1416 1421 1427 1433 1439 1451 1463 1476 1489 1502 1515 1528 1541 1555 1567 1579 1591 1603 1613 1623 1633 1643 1653 1663 1673 1683 1693 1709 1718 1728 1738 1748 1758 1762 1768 1773 1778 1788 1798 1808 1818 1828 1838 1848 1861 1871 1881 1891 1901 1911 1921 1931 1941
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'mt 6/15/2016 10:13'!
dejaVuSansObliqueDark12Form
	<generated>
	" Form data for DejaVu Sans Oblique Dark 12. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAAB5UAAAATCAYAAACwcFoJAAAABGdBTUEAALGPC/xhBQAAACBj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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansObliqueDark14Data
	<generated>
	" Font meta data for DejaVu Sans Oblique Dark 14. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 14 18 4 0 255 21 0 0 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 11 17 25 34 50 62 80 95 100 107 114 124 140 146 153 159 169 181 193 205 217 229 241 253 265 277 289 295 301 317 333 349 359 378 391 404 417 432 444 455 470 484 490 500 513 524 540 554 569 580 595 608 620 632 646 659 678 693 705 719 726 732 740 756 766 776 788 800 810 822 834 842 854 866 871 880 891 896 915 927 939 951 963 971 981 988 1000 1011 1027 1039 1051 1061 1073 1079 1091 1107 1107 1123 1133 1149 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1165 1171 1179 1191 1203 1215 1227 1233 1243 1253 1272 1281 1293 1309 1316 1335 1345 1355 1371 1379 1387 1397 1409 1421 1427 1437 1445 1454 1466 1484 1502 1520 1530 1543 1556 1569 1582 1595 1608 1629 1642 1654 1666 1678 1690 1696 1703 1710 1717 1732 1746 1761 1776 1791 1806 1821 1837 1854 1868 1882 1896 1910 1922 1934 1946 1958 1970 1982 1994 2006 2018 2037 2047 2059 2071 2083 2095 2100 2107 2113 2119 2131 2143 2155 2167 2179 2191 2203 2219 2231 2243 2255 2267 2279 2291 2303 2315
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'mt 6/15/2016 10:13'!
dejaVuSansObliqueDark14Form
	<generated>
	" Form data for DejaVu Sans Oblique Dark 14. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAACQsAAAAWCAYAAABtqVjmAAAABGdBTUEAALGPC/xhBQAAACBj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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansObliqueDark17Data
	<generated>
	" Font meta data for DejaVu Sans Oblique Dark 17. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 17 21 5 0 255 24 0 0 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 14 21 30 41 60 75 97 115 121 130 138 150 169 176 184 191 203 218 233 248 263 278 293 308 323 338 353 361 369 388 407 426 438 461 477 493 509 527 542 555 573 590 597 610 626 639 659 676 694 708 726 742 757 772 789 805 828 846 860 877 886 894 904 923 935 947 961 976 989 1004 1018 1027 1042 1057 1063 1074 1087 1093 1115 1130 1144 1159 1174 1184 1196 1205 1220 1234 1253 1268 1283 1296 1311 1319 1334 1353 1353 1372 1384 1403 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1422 1429 1438 1453 1468 1483 1498 1506 1518 1530 1553 1564 1578 1597 1605 1628 1640 1652 1671 1680 1689 1701 1716 1731 1738 1750 1759 1770 1784 1806 1828 1850 1862 1878 1894 1910 1926 1942 1958 1982 1998 2013 2028 2043 2058 2065 2073 2081 2089 2107 2124 2142 2160 2178 2196 2214 2233 2253 2270 2287 2304 2321 2335 2349 2363 2377 2391 2405 2419 2433 2447 2470 2483 2497 2511 2525 2539 2545 2553 2560 2568 2582 2597 2611 2625 2639 2653 2667 2686 2701 2716 2731 2746 2761 2776 2791 2806
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'mt 6/15/2016 10:13'!
dejaVuSansObliqueDark17Form
	<generated>
	" Form data for DejaVu Sans Oblique Dark 17. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAACvYAAAAbCAYAAACtZyoQAAAABGdBTUEAALGPC/xhBQAAACBj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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansObliqueDark20Data
	<generated>
	" Font meta data for DejaVu Sans Oblique Dark 20. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 20 25 6 0 255 28 0 0 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 16 25 36 48 71 88 114 135 142 153 163 177 200 209 219 228 242 259 276 293 310 327 344 361 378 395 412 421 430 453 476 499 513 540 558 577 596 617 634 650 671 691 699 714 733 748 771 791 812 828 849 868 885 902 922 940 967 987 1004 1024 1035 1044 1054 1077 1091 1105 1122 1139 1154 1171 1188 1199 1216 1233 1241 1254 1270 1278 1304 1321 1338 1355 1372 1384 1398 1409 1426 1442 1464 1482 1500 1515 1532 1541 1558 1581 1581 1604 1618 1641 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1664 1673 1684 1701 1718 1735 1752 1761 1775 1789 1816 1829 1846 1869 1879 1906 1920 1934 1957 1968 1979 1993 2010 2027 2036 2050 2061 2074 2091 2117 2143 2169 2183 2201 2219 2237 2256 2274 2292 2320 2339 2356 2373 2390 2407 2415 2425 2435 2445 2466 2486 2507 2528 2549 2570 2591 2614 2638 2658 2678 2698 2718 2735 2751 2768 2785 2802 2819 2836 2853 2870 2897 2912 2929 2946 2963 2980 2988 2998 3007 3016 3033 3050 3067 3084 3101 3118 3135 3158 3176 3193 3210 3227 3244 3262 3279 3297
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'mt 6/15/2016 10:13'!
dejaVuSansObliqueDark20Form
	<generated>
	" Form data for DejaVu Sans Oblique Dark 20. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAADOEAAAAgCAYAAADuHY2sAAAABGdBTUEAALGPC/xhBQAAACBj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='
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansObliqueDark7Data
	<generated>
	" Font meta data for DejaVu Sans Oblique Dark 7. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 7 8 2 0 255 10 0 0 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 9 13 18 26 32 41 49 52 56 60 65 73 76 80 83 89 95 101 107 113 119 125 131 137 143 149 153 157 165 173 181 186 195 202 209 216 223 229 235 242 249 252 257 264 270 278 285 293 299 307 314 320 326 333 340 349 357 363 370 374 378 382 390 395 400 406 412 417 423 429 433 439 445 448 452 458 461 470 476 482 488 494 498 503 507 513 519 527 533 539 544 550 554 560 568 568 576 581 589 597 597 597 597 597 597 597 597 597 597 597 597 597 597 597 597 597 597 597 597 597 597 597 597 597 597 597 597 597 600 604 610 616 622 628 632 637 642 651 656 662 670 674 683 688 693 701 705 709 714 720 726 729 734 738 743 749 758 767 776 781 788 795 802 809 816 823 833 840 846 852 858 864 867 871 875 879 886 893 901 909 917 925 933 941 949 956 963 970 977 983 989 995 1001 1007 1013 1019 1025 1031 1040 1045 1051 1057 1063 1069 1072 1076 1079 1082 1088 1094 1100 1106 1112 1118 1124 1132 1138 1144 1150 1156 1162 1168 1174 1180
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'mt 6/15/2016 10:13'!
dejaVuSansObliqueDark7Form
	<generated>
	" Form data for DejaVu Sans Oblique Dark 7. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAABJwAAAAKCAYAAADxXkSRAAAABGdBTUEAALGPC/xhBQAAACBj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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'topa 6/13/2016 15:30'!
dejaVuSansObliqueDark9Data
	<generated>
	" Font meta data for DejaVu Sans Oblique Dark 9. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^ #(0 9 11 3 0 255 13 0 0 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 11 16 22 32 40 51 60 63 68 73 79 89 93 97 101 108 116 124 132 140 148 156 164 172 180 188 192 196 206 216 226 232 244 253 261 269 278 286 293 302 311 315 321 329 336 346 355 364 371 380 388 396 404 413 421 433 442 449 458 463 467 472 482 488 494 501 509 516 524 531 536 544 552 555 560 567 570 582 590 597 605 613 618 624 629 637 644 654 662 670 677 685 689 697 707 707 717 723 733 743 743 743 743 743 743 743 743 743 743 743 743 743 743 743 743 743 743 743 743 743 743 743 743 743 743 743 743 743 747 752 760 768 776 784 788 794 800 812 818 825 835 839 851 857 863 873 878 883 889 897 905 909 915 920 926 933 945 957 969 975 984 993 1002 1011 1020 1029 1042 1050 1058 1066 1074 1082 1086 1090 1094 1098 1107 1116 1125 1134 1143 1152 1161 1171 1182 1191 1200 1209 1218 1225 1232 1240 1247 1254 1261 1268 1275 1282 1294 1301 1308 1315 1322 1329 1332 1336 1340 1344 1351 1359 1366 1373 1380 1387 1394 1404 1412 1420 1428 1436 1444 1452 1460 1468
)
! !

!StrikeFont class methodsFor: 'dejaVu font data' stamp: 'mt 6/15/2016 10:13'!
dejaVuSansObliqueDark9Form
	<generated>
	" Form data for DejaVu Sans Oblique Dark 9. Generated with StrikeFont generateDejaVuMethods: 'DejaVu'"
	^Form fromBinaryStream: (
'iVBORw0KGgoAAAANSUhEUgAABbwAAAAOCAYAAADkHNqXAAAABGdBTUEAALGPC/xhBQAAACBj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'
	) base64Decoded asByteArray readStream
! !

!StrikeFont class methodsFor: 'examples' stamp: ''!
example
	"Displays a line of text on the display screen at the location of the cursor.
	Example depends on the strike font file, 'TimesRoman10.strike'. existing."

	(StrikeFont new readFromStrike2: 'NewYork12.sf2')
		displayLine: 'A line of 12-pt text in New York style' at: Sensor cursorPoint
	 
	"StrikeFont example."! !

!StrikeFont class methodsFor: 'accessing' stamp: 'nice 10/21/2009 00:14'!
familyNames
	^ (TextConstants select: [:each | each isKindOf: TextStyle]) keys asArray sort! !

!StrikeFont class methodsFor: 'accessing' stamp: 'ar 2/3/2002 23:04'!
familyName: aName pointSize: aSize
	"Answer a font (or the default font if the name is unknown) in the specified size."

	^ ((TextStyle named: aName asSymbol) ifNil: [TextStyle default]) fontOfPointSize: aSize! !

!StrikeFont class methodsFor: 'instance creation' stamp: 'ar 2/3/2002 23:06'!
familyName: aName pointSize: aSize emphasized: emphasisCode
	"Create the font with this emphasis"

	^ (self familyName: aName pointSize: aSize) emphasized: emphasisCode! !

!StrikeFont class methodsFor: 'accessing' stamp: 'fbs 11/28/2013 18:38'!
familyName: aName size: aSize
	"Answer a font (or the default font if the name is unknown) in the specified size."
	| style |
	style := TextStyle named: aName asSymbol.
	style ifNil: [^(MissingFont forFamilyName: aName pixelSize: aSize)
			signal: 'missing font' ].
	^style fontOfSize: aSize! !

!StrikeFont class methodsFor: 'instance creation' stamp: 'tk 1/28/1999 11:31'!
familyName: aName size: aSize emphasized: emphasisCode
	"Create the font with this emphasis"

	^ (self familyName: aName size: aSize) emphasized: emphasisCode! !

!StrikeFont class methodsFor: 'instance creation' stamp: 'yo 3/18/2004 00:10'!
fixAccuISO8859From: aStrikeFont

	^aStrikeFont copy fixAccuISO8859From: aStrikeFont.
! !

!StrikeFont class methodsFor: 'font creation' stamp: 'ar 6/4/2000 22:27'!
fromHostFont: fontName size: fontSize flags: fontFlags weight: fontWeight
	"
		^StrikeFont fromHostFont: (StrikeFont hostFontFromUser)
					size: 12 flags: 0 weight: 4.
	"
	| fontHandle glyphs xTable xStart maxWidth w glyphForm ascent descent fontHeight |
	fontHandle := self primitiveCreateFont: fontName size: fontSize flags: fontFlags weight: fontWeight.
	ascent := self primitiveFontAscent: fontHandle.
	descent := self primitiveFontDescent: fontHandle.
	fontHeight := ascent + descent.
	xTable := Array new: 258.
	xStart := maxWidth := 0.
	0 to: 255 do:[:i|
		xTable at: i+1 put: xStart.
		w := self primitiveFont: fontHandle widthOfChar: i.
		w > maxWidth ifTrue:[maxWidth := w].
		xStart := xStart + w].
	xTable at: 256 put: xStart.
	xTable at: 257 put: xStart.
	xTable at: 258 put: xStart.
	glyphs := Form extent: xTable last @ fontHeight depth: 1.
	glyphForm := Form extent: maxWidth @ fontHeight depth: 1.
	0 to: 255 do:[:i|
		glyphForm fillWhite.
		self primitiveFont: fontHandle glyphOfChar: i into: glyphForm.
		xStart := xTable at: i+1.
		glyphForm displayOn: glyphs at: xStart@0.
		glyphForm displayOn: Display at: xStart@0.
	].
	self primitiveDestroyFont: fontHandle.
	^Array with: glyphs with: xTable! !

!StrikeFont class methodsFor: 'instance creation' stamp: ''!
fromStrike: fileName 
	"Read a font from disk in the old ST-80 'strike' format.
	Note: this is an old format; use strike2 format instead"

	^self new newFromStrike: fileName! !

!StrikeFont class methodsFor: 'font creation' stamp: 'topa 6/10/2016 10:40'!
generateDejaVuMethods: directory
	"StrikeFont generateDejaVuMethods: 'DejaVu'."
	| dir formTemplate dataTemplate methodCategory |
	methodCategory := #'dejaVu font data'.
	formTemplate := '{1}
	<generated>
	" Form data for {2}. Generated with StrikeFont generateDejaVuMethods: ''{3}''"
	^Form fromBinaryStream: (
''{4}''
	) base64Decoded asByteArray readStream
'.
	dataTemplate := '{1}
	<generated>
	" Font meta data for {2}. Generated with StrikeFont generateDejaVuMethods: ''{3}''"
	^ #({4})
'.
	dir := FileDirectory default / directory.
	#('*.txt' 'Data' '*.png' 'Form') pairsDo: 
		[:match :suffix | (dir fileNamesMatching: match)
			do: 
				[:local | | selector source stringContent|
					" .txt and .png have both length 4"
					selector := (local allButLast: 4) asLegalSelector, suffix.
					stringContent := dir readOnlyFileNamed: local do:
						[:stream | suffix = 'Data'
							ifTrue: [stream contentsOfEntireFile]
							ifFalse: [(stream binary; contentsOfEntireFile) base64Encoded]].
					source := (suffix = 'Data' ifTrue: [dataTemplate] ifFalse: [formTemplate])
						format: {selector . (local allButLast: 4) . directory . stringContent }.
					self class compile: source classified: methodCategory]
			displayingProgress: [:local | 'Generating ', local]].! !

!StrikeFont class methodsFor: 'font creation' stamp: 'rbb 2/18/2005 13:21'!
hostFontFromUser
	"StrikeFont hostFontFromUser"
	| fontNames index labels |
	fontNames := self listFontNames asSortedCollection.
	labels := WriteStream on: (String new: 100).
	fontNames do:[:fn| labels nextPutAll: fn] separatedBy:[labels cr].
	index := (UIManager default chooseFrom: (labels contents substrings) 
				title: 'Choose your font').
	index = 0 ifTrue:[^nil].
	^fontNames at: index! !

!StrikeFont class methodsFor: 'class initialization' stamp: 'topa 6/10/2016 11:24'!
initialize
	StrikeFont
		installDejaVuDark;
		installDejaVu! !

!StrikeFont class methodsFor: 'font creation' stamp: 'topa 6/10/2016 10:50'!
installDejaVu
	"
	StrikeFont installDejaVu
	"

	TextConstants
		at: 'Bitmap DejaVu Sans' 
		put: (TextStyle fontArray: (#(7 9 12 14 17 20) collect: [:size | self createDejaVu: size])).
	Preferences restoreDefaultFonts.
! !

!StrikeFont class methodsFor: 'font creation' stamp: 'topa 6/10/2016 10:54'!
installDejaVuDark
	" This is a Version of dejaVu renderd for light text on dark background.
	StrikeFont installDejaVuDark
	"

	TextConstants
		at: 'Darkmap DejaVu Sans' 
		put: (TextStyle fontArray: (#(7 9 12 14 17 20) collect: [:size | self createDejaVuDark: size])).
! !

!StrikeFont class methodsFor: 'removing' stamp: 'jmv 3/31/2009 08:20'!
limitTo16Bits
	"Limit glyph depth to 16 bits (it is usually 16 or 32).
	
	StrikeFont limitTo16Bits
	"
	StrikeFont allInstances do: [ :f | f
		setGlyphsDepthAtMost: 16 ].! !

!StrikeFont class methodsFor: 'font creation' stamp: 'ar 6/4/2000 21:12'!
listFontNames
	"StrikeFont listFontNames"
	"List all the OS font names"
	| font fontNames index |
	fontNames := WriteStream on: Array new.
	index := 0.
	[font := self listFont: index.
	font == nil] whileFalse:[
		fontNames nextPut: font.
		index := index + 1].
	^fontNames contents! !

!StrikeFont class methodsFor: 'font creation' stamp: 'ar 6/4/2000 21:12'!
listFont: index
	<primitive:'primitiveListFont' module:'FontPlugin'>
	^nil! !

!StrikeFont class methodsFor: 'font creation' stamp: 'tak 8/3/2005 21:11'!
localeChanged
	self setupDefaultFallbackFont! !

!StrikeFont class methodsFor: 'character shapes' stamp: 'jmv 3/27/2009 09:28'!
makeControlCharsVisible
	"
	Make normally not visible characters, visible
	StrikeFont makeControlCharsVisible
	"
	self allInstances do: [ :font | font makeControlCharsVisible ]! !

!StrikeFont class methodsFor: 'character shapes' stamp: 'jmv 3/26/2009 14:51'!
makeLfInvisible
	"
	Make line feed characters invisible
	StrikeFont makeLfInvisible
	"
	self allInstances do: [ :font | font makeLfInvisible ]! !

!StrikeFont class methodsFor: 'character shapes' stamp: 'jmv 3/26/2009 14:51'!
makeLfVisible
	"
	Make line feed characters visible
	StrikeFont makeLfVisible
	"
	self allInstances do: [ :font | font makeLfVisible ]! !

!StrikeFont class methodsFor: 'character shapes' stamp: 'jmv 3/26/2009 14:53'!
makeTabInvisible
	"
	Make tab characters invisible
	StrikeFont makeTabInvisible
	"
	self allInstances do: [ :font | font makeTabInvisible ]! !

!StrikeFont class methodsFor: 'character shapes' stamp: 'jmv 3/26/2009 14:53'!
makeTabVisible
	"
	Make tab characters visible
	StrikeFont makeTabVisible
	"
	self allInstances do: [ :font | font makeTabVisible ]! !

!StrikeFont class methodsFor: 'instance creation' stamp: 'nop 1/23/2000 19:21'!
newFromBDFFile: aFileName name: aString  "StrikeFont newFromBDFFile: 'helvR12.bdf' name: 'Helvetica12'"
	"Read a font from disk in the X11 Bitmap Distribution Format."

	| n |
	n := self new.
	n readBDFFromFile: aFileName name: aString.
	^n.

	"TextConstants at: #Helvetica put: (TextStyle fontArray: {StrikeFont newFromBDFFile: 'helvR12.bdf' name: 'Helvetica12'})"
	"TextConstants at: #Lucida put: (TextStyle fontArray: {StrikeFont newFromBDFFile: 'luRS12.bdf' name: 'Lucida'})"
	"TextStyle default fontAt: 5 put: (StrikeFont new readFromStrike2: 'helv12.sf2')."

! !

!StrikeFont class methodsFor: 'instance creation' stamp: 'tak 12/20/2004 10:23'!
passwordFontSize: aSize 
	^ FixedFaceFont new passwordFont fontSize: aSize! !

!StrikeFont class methodsFor: 'font creation' stamp: 'ar 6/4/2000 21:13'!
primitiveCreateFont: fontName size: fontSize flags: fontFlags weight: fontWeight
	<primitive:'primitiveCreateFont' module:'FontPlugin'>
	^self primitiveFailed! !

!StrikeFont class methodsFor: 'font creation' stamp: 'ar 6/4/2000 21:13'!
primitiveDestroyFont: fontHandle
	<primitive:'primitiveDestroyFont' module:'FontPlugin'>
	^self primitiveFailed! !

!StrikeFont class methodsFor: 'font creation' stamp: 'ar 6/4/2000 22:25'!
primitiveFontAscent: fontHandle
	<primitive:'primitiveFontAscent' module:'FontPlugin'>
	^self primitiveFailed! !

!StrikeFont class methodsFor: 'font creation' stamp: 'ar 6/4/2000 22:25'!
primitiveFontDescent: fontHandle
	<primitive:'primitiveFontDescent' module:'FontPlugin'>
	^self primitiveFailed! !

!StrikeFont class methodsFor: 'font creation' stamp: 'ar 6/4/2000 21:14'!
primitiveFontEncoding: fontHandle
	<primitive:'primitiveFontEncoding' module:'FontPlugin'>
	^self primitiveFailed! !

!StrikeFont class methodsFor: 'font creation' stamp: 'ar 6/4/2000 21:14'!
primitiveFont: fontHandle glyphOfChar: charIndex into: glyphForm
	<primitive:'primitiveFontGlyphOfChar' module:'FontPlugin'>
	^self primitiveFailed! !

!StrikeFont class methodsFor: 'font creation' stamp: 'ar 6/4/2000 21:15'!
primitiveFont: fontHandle widthOfChar: charIndex
	<primitive:'primitiveFontWidthOfChar' module:'FontPlugin'>
	^self primitiveFailed! !

!StrikeFont class methodsFor: 'examples' stamp: 'tpr 11/13/2015 15:38'!
readStrikeFont2Family: familyName 
	"StrikeFont readStrikeFont2Family: 'Lucida'"

	^self readStrikeFont2Family: familyName fromDirectory: FileDirectory default! !

!StrikeFont class methodsFor: 'examples' stamp: 'tpr 11/13/2015 15:39'!
readStrikeFont2Family: familyName fromDirectory: aDirectory
	"StrikeFont readStrikeFont2Family: 'Lucida' fromDirectory: FileDirectory default"
	"This utility reads all available .sf2 StrikeFont files for a given family from  
	the current directory. It returns an Array, sorted by size, suitable for handing 
	to TextStyle newFontArray: ."
	"For this utility to work as is, the .sf2 files must be named 'familyNN.sf2'."
	| fileNames strikeFonts |
	fileNames := aDirectory fileNamesMatching: familyName , '##.sf2'.
	strikeFonts := fileNames collect: [:fname | StrikeFont new readFromStrike2: (aDirectory fullNameFor: fname)].
	strikeFonts do: [ :font | font reset ].
	^strikeFonts asArray sort: [:a :b | a height < b height].

	"TextConstants at: #Lucida put: (TextStyle fontArray: (StrikeFont  readStrikeFont2Family: 'Lucida' fromDirectory: FileDirectory default))."! !

!StrikeFont class methodsFor: 'removing' stamp: 'jmv 3/31/2009 08:19'!
saveSpace
	"Removes glyphs over 128, leaving only lower ascii.
	Also limit glyph depth to 4 bits (it is usually 16 or 32).
	This effectively turns off subpixel rendering, as glyphs will only have 16 shades of gray.
	
	StrikeFont saveSpace
	"
	StrikeFont allInstances do: [ :f | f
		stripHighGlyphs;
		setGlyphsDepthAtMost: 4 ].! !

!StrikeFont class methodsFor: 'derivative font caching' stamp: 'nice 10/12/2013 02:35'!
shutDown  "StrikeFont shutDown"
	"Deallocate synthetically derived copies of base fonts to save space"
	self allSubInstancesDo: [:sf | sf reset].
	DefaultStringScanner := nil.
! !

!StrikeFont class methodsFor: 'class initialization' stamp: 'nice 10/12/2013 02:28'!
unload
	Smalltalk removeFromShutDownList: self.
! !

!StrikeFont class methodsFor: 'character shapes' stamp: 'jmv 8/6/2009 14:31'!
useUnderscoreIfOver1bpp
	"Sets underscore and caret glyphs for chars 95 and 94. 
	Only for enhanced StrikeFonts, i.e. those with glyphs of more than 1bpp.
	ASCII standard glyphs"
	"
	StrikeFont useUnderscoreIfOver1bpp
	"
	self allInstances do: [ :font | font useUnderscoreIfOver1bpp ]! !

!StrikeFont methodsFor: 'Mac reader' stamp: ''!
aComment
	"To read Mac font resources.  
1) Use ResEdit in the Fonts folder in the System Folder.  Open the file of the Font you want.  (A screen font, not a TrueType outline font).
2) Open the FOND resource and scroll down to the list of sizes and resource numbers. Note the resource number of the size you want.
3) Open the NFNT resource.  Click on the number you have noted.
4) Choose 'Open Using Hex Editor' from the resource editor.
5) Copy all of the hex numbers and paste into a text editor.  Save the file into the Smalltalk folder under the name 'FontName 12 hex' (or other size).
6) Enter the fileName below and execute: 

TextStyle default fontAt: 8 put: (StrikeFont new readMacFontHex: 'fileName').

Select text and type Command-7 to change it to your new font.

(There is some problem in the ParagraphEditor with the large size of Cairo 18.  Its line heights are not the right.)
	"! !

!StrikeFont methodsFor: 'character shapes' stamp: ''!
alter: char formBlock: formBlock
	self characterFormAt: char 
		put: (formBlock value: (self characterFormAt: char))! !

!StrikeFont methodsFor: 'accessing' stamp: ''!
ascent
	"Answer the receiver's maximum extent of characters above the baseline."

	^ascent! !

!StrikeFont methodsFor: 'accessing' stamp: 'mt 6/16/2016 13:44'!
ascentKern
	"Return the kern delta for ascenders."
	
	self depth > 1 ifTrue: [^ 0].
	
	"Optimization for traditional 1-bit fonts."
	^ (emphasis allMask: 2)
		ifFalse: [0]
		ifTrue: [(self ascent-5+4)//4 max: 0]  "See makeItalicGlyphs"

! !

!StrikeFont methodsFor: 'accessing' stamp: 'yo 1/6/2005 04:19'!
ascentOf: aCharacter

	(self hasGlyphOf: aCharacter) ifFalse: [
		fallbackFont ifNotNil: [
			^ fallbackFont ascentOf: aCharacter.
		].
	].
	^ self ascent.
! !

!StrikeFont methodsFor: 'accessing' stamp: 'mt 6/16/2016 13:43'!
baseKern
	"Return the base kern value to be used for all characters."
	
	self depth > 1 ifTrue: [^ 0].
	
	"Optimization for traditional 1-bit fonts."
	^ (emphasis allMask: 2)
		ifFalse: [0]
		ifTrue: [((self height-1-self ascent+4)//4 max: 0)  "See makeItalicGlyphs"
			+ (((self ascent-5+4)//4 max: 0))]! !

!StrikeFont methodsFor: 'multibyte character methods' stamp: 'topa 6/1/2016 10:46'!
basicHasGlyphOf: aCharacter

	^ self hasGlyphForCode: (self codeForCharacter: aCharacter)
! !

!StrikeFont methodsFor: 'emphasis' stamp: 'tpr 3/15/2013 12:38'!
bonk: glyphForm with: bonkForm
	"Bonking means to run through the glyphs clearing out black pixels
	between characters to prevent them from straying into an adjacent
	character as a result of, eg, bolding or italicizing"
	"Uses the bonkForm to erase at every character boundary in glyphs."
	| bb offset x |
	offset := bonkForm offset x.
	bb := BitBlt toForm: glyphForm.
	bb sourceForm: bonkForm; sourceRect: bonkForm boundingBox;
		combinationRule: Form erase; destY: 0.
	x := self xTable.
	(x isMemberOf: SparseLargeTable) ifTrue: [
		x base to: x size-1 do: [:i | bb destX: (x at: i) + offset; copyBits].
	] ifFalse: [
		1 to: x size-1 do: [:i | bb destX: (x at: i) + offset; copyBits].
	].
! !

!StrikeFont methodsFor: 'building' stamp: 'topa 6/9/2016 17:58'!
buildFromForm: allGlyphs data: data name: aString

	| x formMetadata glyphsXStart |
	data first = 0 ifFalse: [^ self buildLimitedFromForm: allGlyphs data: data name: aString].
	formMetadata := data readStream.
	type := formMetadata next.
	pointSize := formMetadata next.
	ascent := formMetadata next.
	descent := formMetadata next.
	
	minAscii := formMetadata next.
	maxAscii := formMetadata next.
	maxWidth := formMetadata next.
	emphasis := formMetadata next.
	glyphsXStart := formMetadata upToEnd.
	name := aString.

	superscript := ascent - descent // 3.	
	subscript := descent - ascent // 3.	

	xTable := maxAscii > 1024
		ifFalse: [Array new: maxAscii + 3 withAll: 0]
		ifTrue: [ | mostCommon |
			mostCommon := glyphsXStart asBag sortedCounts first value.
			SparseLargeTable new: maxAscii + 3
			chunkSize: 256 arrayClass: Array base: 1
			defaultValue: mostCommon].
	glyphs := allGlyphs.
	x := 0.
	minAscii to: maxAscii + 1 do: [ :i |
		x := (glyphsXStart at: i - minAscii + 1).
		xTable at: i + 1 put: x].
	self reset.
	derivativeFonts := Array new: 32! !

!StrikeFont methodsFor: 'file in/out' stamp: 'ar 5/23/2000 12:50'!
buildfontNamed: nm fromForms: forms startingAtAscii: startAscii
	ascent: a descent: d maxWid: m
	"This builds a StrikeFont instance from existing forms."

	| lastAscii width ascii charForm missingForm tempGlyphs |
	name := nm.
	ascent := 11.
	descent := 3.
	maxWidth := 16.
	pointSize := 8.
	name := (name copyWithout: Character space) ,
				(pointSize < 10
					ifTrue: ['0' , pointSize printString]
					ifFalse: [pointSize printString]).
	minAscii := 258.
	maxAscii := 0.
	superscript := ascent - descent // 3.	
	subscript := descent - ascent // 3.	
	emphasis := 0.
	type := 0.  "ignored for now"

	tempGlyphs := Form extent: (maxWidth*257) @ self height.
	xTable := (Array new: 258) atAllPut: 0.
	xTable at: 1 put: 0.

	"Read character forms and blt into tempGlyphs"
	lastAscii := -1.
	1 to: forms size do:
		[:i | charForm := forms at: i. width := charForm width.
		ascii := startAscii-1+i.
		self displayChar: ascii form: charForm.
		ascii = 256
			ifTrue: [missingForm := charForm deepCopy]
			ifFalse:
			[minAscii := minAscii min: ascii.
			maxAscii := maxAscii max: ascii.
			lastAscii+1 to: ascii-1 do: [:as | xTable at: as+2 put: (xTable at: as+1)].
			tempGlyphs copy: ((xTable at: ascii+1)@0
									extent: charForm extent)
						from: 0@0 in: charForm rule: Form over.
			xTable at: ascii+2 put: (xTable at: ascii+1) + width.
			lastAscii := ascii]].
	lastAscii+1 to: maxAscii+1 do: [:as | xTable at: as+2 put: (xTable at: as+1)].
	missingForm == nil ifFalse:
		[tempGlyphs copy: missingForm boundingBox from: missingForm
				to: (xTable at: maxAscii+2)@0 rule: Form over.
		xTable at: maxAscii+3 put: (xTable at: maxAscii+2) + missingForm width].
	glyphs := Form extent: (xTable at: maxAscii+3) @ self height.
	glyphs copy: glyphs boundingBox from: 0@0 in: tempGlyphs rule: Form over.
	xTable := xTable copyFrom: 1 to: maxAscii+3.
	characterToGlyphMap := nil.! !

!StrikeFont methodsFor: 'building' stamp: 'topa 6/7/2016 18:56'!
buildLimitedFromForm: allGlyphs data: data name: aString

	| x |
	pointSize := data first.
	ascent := data second.
	descent := data third.
	
	minAscii := 32.
	maxAscii := 255.
	name := aString.
	type := 0.  "ignored for now"
	superscript := ascent - descent // 3.	
	subscript := descent - ascent // 3.	
	emphasis := 0.

	xTable := (Array new: 258) atAllPut: 0.
	maxWidth := 0.
	glyphs := allGlyphs.
	x := 0.
	minAscii to: maxAscii+1 do: [ :i |
		x := (data at: i-minAscii+4).
		xTable at: i+1 put: x].
	xTable at: 258 put: x.
	self reset.
	derivativeFonts := Array new: 32! !

!StrikeFont methodsFor: 'character shapes' stamp: 'nice 2/17/2014 23:12'!
characterFormAt: character 
	"Answer a Form copied out of the glyphs for the argument, character."
	| ascii leftX rightX |
	ascii := self codeForCharacter: character.
	(ascii between: minAscii and: maxAscii) ifFalse: [ascii := maxAscii + 1].
	leftX := xTable at: ascii + 1.
	rightX := xTable at: ascii + 2.
	leftX < 0 ifTrue: [^ glyphs copy: (0@0 corner: 0@self height)].
	^ glyphs copy: (leftX @ 0 corner: rightX @ self height)! !

!StrikeFont methodsFor: 'character shapes' stamp: 'jmv 4/22/2007 20:47'!
characterFormAt: character put: characterForm
	"Copy characterForm over the glyph for the argument, character."
	| ascii leftX rightX widthDif newGlyphs |
	ascii := character asciiValue.
	ascii < minAscii ifTrue: [^ self error: 'Cant store characters below min ascii'].
	ascii > maxAscii ifTrue:
		[(self confirm:
'This font does not accomodate ascii values higher than ' , maxAscii printString , '.
Do you wish to extend it permanently to handle values up to ' , ascii printString)
			ifTrue: [self extendMaxAsciiTo: ascii]
			ifFalse: [^ self error: 'No change made']].
	leftX := xTable at: ascii + 1.
	rightX := xTable at: ascii + 2.
	widthDif := characterForm width - (rightX - leftX).
	widthDif ~= 0 ifTrue:
		["Make new glyphs with more or less space for this char"
		newGlyphs := Form extent: (glyphs width + widthDif) @ glyphs height depth: glyphs depth.
		newGlyphs copy: (0@0 corner: leftX@glyphs height)
			from: 0@0 in: glyphs rule: Form over.
		newGlyphs copy: ((rightX+widthDif)@0 corner: newGlyphs width@glyphs height)
			from: rightX@0 in: glyphs rule: Form over.
		glyphs := newGlyphs.
		"adjust further entries on xTable"
		xTable := xTable copy.
		ascii+2 to: xTable size
			do: [:i | xTable at: i put: (xTable at: i) + widthDif]].
	glyphs copy: (leftX @ 0 extent: characterForm extent)
		from: 0@0 in: characterForm rule: Form over
"
| f |  f := TextStyle defaultFont.
f characterFormAt: $  put: (Form extent: (f widthOf: $ )+10@f height)
"! !

!StrikeFont methodsFor: 'character shapes' stamp: ''!
characterForm: char pixelValueAt: pt put: val
	| f |
	f := self characterFormAt: char.
	f pixelAt: pt put: val.
	self characterFormAt: char put: val! !

!StrikeFont methodsFor: 'displaying' stamp: 'nice 2/17/2014 23:13'!
characters: anInterval in: sourceString displayAt: aPoint clippedBy: clippingRectangle rule: ruleInteger fillColor: aForm kernDelta: kernDelta on: aBitBlt
	"Simple, slow, primitive method for displaying a line of characters.
	No wrap-around is provided."
	| destPoint |
	destPoint := aPoint.
	anInterval do: 
		[:i | | sourceRect leftX ascii rightX |
		self flag: #yoDisplay.
		"if the char is not supported, fall back to the specified fontset."
		ascii := self codeForCharacter: (sourceString at: i).
		(ascii < minAscii or: [ascii > maxAscii])
			ifTrue: [ascii := maxAscii].
		leftX := xTable at: ascii + 1.
		rightX := xTable at: ascii + 2.
		sourceRect := leftX@0 extent: (rightX-leftX) @ self height.
		aBitBlt copyFrom: sourceRect in: glyphs to: destPoint.
		destPoint := destPoint + ((rightX-leftX+kernDelta)@0).
		"destPoint printString displayAt: 0@(i*20)"].
	^ destPoint! !

!StrikeFont methodsFor: 'accessing' stamp: 'ar 5/23/2000 12:52'!
characterToGlyphMap
	^characterToGlyphMap ifNil:[characterToGlyphMap := self createCharacterToGlyphMap].! !

!StrikeFont methodsFor: 'accessing' stamp: 'ar 5/23/2000 12:52'!
characterToGlyphMap: anArray
	characterToGlyphMap := anArray.! !

!StrikeFont methodsFor: 'testing' stamp: ''!
checkCharacter: character 
	"Answer a Character that is within the ascii range of the receiver--either 
	character or the last character in the receiver."

	| ascii |  
	ascii := character asciiValue.
	((ascii < minAscii) or: [ascii > maxAscii])
			ifTrue: [^maxAscii asCharacter]
			ifFalse:	[^character]
! !

!StrikeFont methodsFor: 'private' stamp: 'nice 2/17/2014 23:08'!
codeForCharacter: aCharacter
	| code |
	code := aCharacter charCode.
	(self characterToGlyphMap isNil
		or: [	characterToGlyphMap size <= code ])
			ifTrue: [^code].
	^characterToGlyphMap at: code + 1! !

!StrikeFont methodsFor: 'private' stamp: 'yo 3/11/2005 07:38'!
createCharacterToGlyphMap
        "Private. Create the character to glyph mapping for a font that didn't have any before. This is basically equivalent to what the former setStopCondition did, only based on indexes."

        maxAscii < 256 ifTrue: [^ (1 to: 256) collect: [:i | i - 1]].
        ^ nil.
! !

!StrikeFont methodsFor: 'copying' stamp: 'BG 12/9/2004 17:27'!
deepCopy
 " there is a circular reference from the derivative fonts back to the receiver. It is therefore not possible to make a deep copy. We make a sahllow copy. The method postCopy can be used to modify the shallow copy. " 
  ^self copy! !

!StrikeFont methodsFor: 'accessing' stamp: 'mt 5/9/2016 16:58'!
depth

	^ self glyphs depth! !

!StrikeFont methodsFor: 'accessing' stamp: 'bf 2/26/2007 12:39'!
derivativeFonts
	derivativeFonts ifNil: [^#()].
	^derivativeFonts copyWithout: nil! !

!StrikeFont methodsFor: 'emphasis' stamp: 'jmv 3/20/2009 10:27'!
derivativeFont: aStrikeFont at: index

	| newDeriv |
	(aStrikeFont isNil and: [ index = 0 ]) 
		ifTrue: [derivativeFonts := nil. ^ self].
	derivativeFonts ifNil: [derivativeFonts := Array new: 32].
	derivativeFonts size < 32 ifTrue: [
		newDeriv := Array new: 32.
		newDeriv replaceFrom: 1 to: derivativeFonts size with: derivativeFonts.
		derivativeFonts := newDeriv.
	].
	derivativeFonts at: index put: aStrikeFont.! !

!StrikeFont methodsFor: 'accessing' stamp: 'topa 6/13/2016 16:58'!
descent
	"Answer the receiver's maximum extent of characters below the baseline."

	^descent! !

!StrikeFont methodsFor: 'accessing' stamp: 'mt 6/16/2016 13:45'!
descentKern
	"Return the kern delta for descenders."

	self depth > 1 ifTrue: [^ 0].

	"Optimization for traditional 1-bit fonts."
	^ (emphasis allMask: 2)
		ifFalse: [0]
		ifTrue: [(self height-1-self ascent+4)//4 max: 0]  "See makeItalicGlyphs"

! !

!StrikeFont methodsFor: 'accessing' stamp: 'yo 1/6/2005 04:19'!
descentOf: aCharacter

	(self hasGlyphOf: aCharacter) ifFalse: [
		fallbackFont ifNotNil: [
			^ fallbackFont descentOf: aCharacter.
		].
	].
	^ self descent.
! !

!StrikeFont methodsFor: 'file in/out' stamp: ''!
displayChar: ascii form: charForm
	"Convenience utility used during conversion of BitFont files"
	| m bigForm |
	Display fillBlack: (0@0 extent: 20@14).
	ascii printString displayAt: 0@2.
	charForm width > 0 ifTrue:
		[m := 5.
		bigForm := charForm magnify: charForm boundingBox by: m@m.
		Display border: ((bigForm boundingBox expandBy: m) translateBy: 50@2) width: m.
		bigForm displayAt: 50@2.
		Display fillBlack: ((50@2)+((m*charForm width)@0) extent: 1@(m*self height))].! !

!StrikeFont methodsFor: 'displaying' stamp: 'tpr 3/15/2013 12:38'!
displayLine: aString at: aPoint 
	"Display the characters in aString, starting at position aPoint."

	self characters: (1 to: aString size)
		in: aString
		displayAt: aPoint
		clippedBy: Display boundingBox
		rule: Form over
		fillColor: nil
		kernDelta: 0
		on: (BitBlt toForm: Display).
! !

!StrikeFont methodsFor: 'displaying' stamp: 'tpr 9/3/2013 14:31'!
displayMultiString: aString on: aBitBlt from: startIndex to: stopIndex at: aPoint kern: kernDelta baselineY: baselineY
"display a multi-byte character string"
	| leftX rightX glyphInfo char destY form gfont destX destPt |
	destX := aPoint x.
	glyphInfo := Array new: 5.
	startIndex to: stopIndex do:[:charIndex|
		char := aString at: charIndex.
		(self hasGlyphOf: char) ifTrue: [
			"I have that character ok, so display it and move on"
			self glyphInfoOf: char into: glyphInfo.
			form := glyphInfo at: 1.
			leftX := glyphInfo at: 2.
			rightX := glyphInfo at: 3.
			destY := glyphInfo at: 4.
			gfont := glyphInfo at: 5.
			(gfont == aBitBlt lastFont) ifFalse: [gfont installOn: aBitBlt].
			destY := baselineY - destY. 
			aBitBlt displayGlyph: form at: destX @ destY left: leftX right: rightX font: self.
			destX := destX + (rightX - leftX + kernDelta).
		] ifFalse:[
			"I'm missing that character so pass the job off to my fallback font; if one wasn't previously setup a default fixedfacefont will get used and show question-mark char(s). We pass the entire job to the font since we must not expect it to be a StrikeFont"
			destPt := self fallbackFont displayString: aString on: aBitBlt from: charIndex to: charIndex at: destX @ aPoint y kern: kernDelta from: self baselineY: baselineY.
			destPt x = destX ifTrue:[
				"In some situations BitBlt doesn't return the advance width from the primitive.
				Work around the situation"
				destX := destX + (self widthOfString: aString from: charIndex to: charIndex) + kernDelta.
			] ifFalse:[destX := destPt x].
		].
	].
	^destX @ aPoint y
! !

!StrikeFont methodsFor: 'displaying' stamp: 'yo 12/20/2002 18:54'!
displayStringR2L: aString on: aBitBlt from: startIndex to: stopIndex at: aPoint kern: kernDelta
	"You are screwed if you reach this method."
	self halt.
	aBitBlt displayString: aString 
			from: startIndex 
			to: stopIndex 
			at: aPoint 
			strikeFont: self
			kern: kernDelta.! !

!StrikeFont methodsFor: 'displaying' stamp: 'ar 8/29/2009 23:05'!
displayString: aString on: aBitBlt from: startIndex to: stopIndex at: aPoint kern: kernDelta
	"Draw the given string from startIndex to stopIndex 
	at aPoint on the (already prepared) BitBlt."
	
	| pt |
	(aString isByteString) ifFalse: [^ self displayMultiString: aString on: aBitBlt from: startIndex to: stopIndex at: aPoint kern: kernDelta baselineY: aPoint y + self ascent.].

	pt := aBitBlt displayString: aString 
			from: startIndex 
			to: stopIndex 
			at: aPoint 
			strikeFont: self
			kern: kernDelta.
	pt = aPoint ifFalse:[^pt].
	"In some situations BitBlt doesn't return the advance width from the primitive.
	Work around the situation"
	^aPoint x + (self widthOfString: aString from: startIndex to: stopIndex) + (stopIndex-startIndex+1*kernDelta) @ aPoint y
! !

!StrikeFont methodsFor: 'displaying' stamp: 'ar 4/10/2005 18:06'!
displayString: aString on: aBitBlt from: startIndex to: stopIndex at: aPoint kern: kernDelta baselineY: baselineY
	"Draw the given string from startIndex to stopIndex 
	at aPoint on the (already prepared) BitBlt."
	
	(aString isByteString) ifFalse:[^ self displayMultiString: aString on: aBitBlt from: startIndex to: stopIndex at: aPoint kern: kernDelta baselineY: baselineY.].

	^ aBitBlt displayString: aString 
			from: startIndex 
			to: stopIndex 
			at: aPoint 
			strikeFont: self
			kern: kernDelta.! !

!StrikeFont methodsFor: 'character shapes' stamp: 'dtl 1/24/2010 11:39'!
edit: character 
	"Open a Bit Editor on the given character. Note that you must do an accept 
	(in the option menu of the bit editor) if you want this work. 
	Accepted edits will not take effect in the font until you leave or close the bit editor. 
	Also note that unaccepted edits will be lost when you leave or close."
	"Note that BitEditor only works in MVC currently."

	"(TextStyle default fontAt: 1) edit: $="

	Project current editCharacter: character ofFont: self! !

!StrikeFont methodsFor: 'emphasis' stamp: ''!
emphasis
	"Answer the integer code for synthetic bold, italic, underline, and 
	strike-out."

	^emphasis! !

!StrikeFont methodsFor: 'emphasis' stamp: ''!
emphasis: code 
	"Set the integer code for synthetic bold, itallic, underline, and strike-out, 
	where bold=1, italic=2, underlined=4, and struck out=8."

	emphasis := code! !

!StrikeFont methodsFor: 'emphasis' stamp: 'di 9/3/2000 13:22'!
emphasized: code 
	"Answer a copy of the receiver with emphasis set to include code."
	| derivative addedEmphasis base safeCode |
	code = 0 ifTrue: [^ self].
	(derivativeFonts == nil or: [derivativeFonts size = 0]) ifTrue: [^ self].
	derivative := derivativeFonts at: (safeCode := code min: derivativeFonts size).
	derivative == nil ifFalse: [^ derivative].  "Already have this style"

	"Dont have it -- derive from another with one with less emphasis"
	addedEmphasis := 1 bitShift: safeCode highBit - 1.
	base := self emphasized: safeCode - addedEmphasis.  "Order is Bold, Ital, Under, Narrow"
	addedEmphasis = 1 ifTrue:   "Compute synthetic bold version of the font"
		[derivative := (base copy ensureCleanBold name: base name , 'B') makeBoldGlyphs].
	addedEmphasis = 2 ifTrue:   "Compute synthetic italic version of the font"
		[ derivative := (base copy name: base name , 'I') makeItalicGlyphs].
	addedEmphasis = 4 ifTrue:   "Compute underlined version of the font"
		[derivative := (base copy name: base name , 'U') makeUnderlinedGlyphs].
	addedEmphasis = 8 ifTrue:   "Compute narrow version of the font"
		[derivative := (base copy name: base name , 'N') makeCondensedGlyphs].
	addedEmphasis = 16 ifTrue:   "Compute struck-out version of the font"
		[derivative := (base copy name: base name , 'X') makeStruckOutGlyphs].
	derivative emphasis: safeCode.
	derivativeFonts at: safeCode put: derivative.
	^ derivative! !

!StrikeFont methodsFor: 'character shapes' stamp: 'jmv 4/23/2007 22:30'!
ensureCleanBold 
	"This ensures that all character glyphs have at least one pixel of white space on the right
	so as not to cause artifacts in neighboring characters in bold or italic."

	| wider glyph |
	emphasis = 0 ifFalse: [^ self].
	minAscii to: maxAscii do:
		[:i | glyph := self characterFormAt: (Character value: i).
		(glyph copy: (glyph boundingBox topRight - (1@0)
					corner: glyph boundingBox bottomRight)) isAllWhite ifFalse: [
			wider := Form extent: (glyph width + 1)@glyph height depth: glyph depth.
			glyph depth > 1 ifTrue: [wider fillWhite].
			glyph displayOn: wider.
			self characterFormAt: (Character value: i) put: wider]].
"
StrikeFont allInstancesDo: [:f | f ensureCleanBold].
(StrikeFont familyName: 'NewYork' size: 21) ensureCleanBold.
StrikeFont shutDown.  'Flush synthetic fonts'.
"
! !

!StrikeFont methodsFor: 'character shapes' stamp: 'ar 5/23/2000 12:48'!
extendMaxAsciiTo: newMax
	"Extend the range of this font so that it can display glyphs up to newMax."

	(newMax+3) <= xTable size ifTrue: [^ self].  "No need to extend."
	xTable size = (maxAscii+3) ifFalse:
		[^ self error: 'This font is not well-formed.'].

	"Insert a bunch of zero-width characters..."
	xTable := (xTable copyFrom: 1 to: maxAscii+2) ,
			((maxAscii+1 to: newMax) collect: [:i | xTable at: maxAscii+2]) ,
			{ xTable at: maxAscii+3 }.
	maxAscii := newMax.
	self fillZeroWidthSlots.
	characterToGlyphMap := nil.! !

!StrikeFont methodsFor: 'accessing' stamp: 'ar 8/15/2009 11:25'!
fallbackFont
	"Answers the fallbackFont for the receiver. The fallback font must be some derivative of the receiver since it will not be asked to install itself properly on the target BitBlt so rendering a completely different font here is simply not possible. The default implementation uses a synthetic font that maps all characters to question marks."
	^ fallbackFont
		ifNil: [fallbackFont := FixedFaceFont new errorFont baseFont: self]! !

!StrikeFont methodsFor: 'accessing' stamp: 'yo 5/20/2004 11:01'!
fallbackFont: aFontSetOrNil

	fallbackFont := aFontSetOrNil.
! !

!StrikeFont methodsFor: 'accessing' stamp: 'jmv 8/6/2009 09:14'!
familyName
	^self name withoutJustTrailingDigits! !

!StrikeFont methodsFor: 'accessing' stamp: 'tk 6/26/1998 16:45'!
familySizeFace
	"Answer an array with familyName, a String, pointSize, an Integer, and
	faceCode, an Integer."

	^Array with: name
		with: self height
		with: emphasis

	"(1 to: 12) collect: [:x | (TextStyle default fontAt: x) familySizeFace]"! !

!StrikeFont methodsFor: 'character shapes' stamp: 'di 3/27/2000 16:10'!
fillZeroWidthSlots
	| nullGlyph |
	"Note: this is slow because it copies the font once for every replacement."

	nullGlyph := (Form extent: 1@glyphs height) fillGray.
	"Now fill the empty slots with narrow box characters."
	minAscii to: maxAscii do:
		[:i | (self widthOf: (Character value: i)) = 0 ifTrue:
			[self characterFormAt: (Character value: i) put: nullGlyph]].
! !

!StrikeFont methodsFor: 'multibyte character methods' stamp: 'yo 3/18/2004 00:10'!
fixAccuISO8859From: aStrikeFont

	| f |
	self reset.
	xTable := aStrikeFont xTable copy.
	glyphs := Form extent: aStrikeFont glyphs extent.
	maxAscii := 255.
	minAscii := 0.
	"stopConditions := nil."

	0 to: 127 do: [:i |
		f := aStrikeFont characterFormAt: (Character value: i) isoToSqueak.
		f width  = 0 ifTrue: [f := Form extent: 1@f height].
		
		self characterFormAt: (Character value: i) put: f.
	].
	128 to: 159 do: [:i |
		f := Form extent: 1@f height.
		self characterFormAt: (Character value: i) put: f.
	].
	160 to: 255 do: [:i |
		f := aStrikeFont characterFormAt: (Character value: i) isoToSqueak.
		f width  = 0 ifTrue: [f := Form extent: 1@f height].
		
		self characterFormAt: (Character value: i) put: f.
	].
		
	^ self.	
! !

!StrikeFont methodsFor: 'multibyte character methods' stamp: 'yo 11/12/2002 12:56'!
fixAscent: a andDescent: d head: h

	| bb newGlyphs |
	"(a + d) = (ascent + descent) ifTrue: ["
		ascent := a.
		descent := d.
		newGlyphs := Form extent: (glyphs width@(h + glyphs height)).
		bb := BitBlt toForm: newGlyphs.
		bb copy: (0@h extent: (glyphs extent)) from: 0@0 in: glyphs
			fillColor: nil rule: Form over.
		glyphs := newGlyphs.
	"]."
! !

!StrikeFont methodsFor: 'Mac reader' stamp: ''!
fixKerning: extraWidth
	"Insert one pixel (extraWidth) between each character.  And add the bits for the space character"
	"Create a space character Form.  Estimate width by ascent / 2 - 1"
	| characterForm char leftX |
	characterForm := Form extent: (ascent//2 - 1) @ self height.
	self characterFormAt: $  put: characterForm.

	"Put one pixel of space after every character.  Mac fonts have no space in the bitmap."
	extraWidth <= 0 ifTrue: [^ self].
	minAscii to: maxAscii do: [:ascii |
		char := Character value: ascii.
		leftX := xTable at: ascii + 1.
		characterForm := Form extent: 
			((self widthOf: char) + extraWidth) @ self height.
		characterForm 
			copy: (characterForm boundingBox extendBy: 
				(0-extraWidth@0))
			from: leftX@0 in: glyphs rule: Form over.
		self characterFormAt: char put: characterForm.
		].	! !

!StrikeFont methodsFor: 'character shapes' stamp: 'di 4/28/2000 16:10'!
fixOneWideChars 
	"This fixes all 1-wide characters to be 2 wide with blank on the right
	so as not to cause artifacts in neighboring characters in bold or italic."
	| twoWide |
	minAscii to: maxAscii do:
		[:i | (self widthOf: (Character value: i)) = 1 ifTrue:
			[twoWide := Form extent: 2@glyphs height.
			(self characterFormAt: (Character value: i)) displayOn: twoWide at: 0@0.
			self characterFormAt: (Character value: i) put: twoWide]].
"
StrikeFont allInstancesDo: [:f | f fixOneWideChars].
StrikeFont shutDown.  'Flush synthetic fonts'.
"
! !

!StrikeFont methodsFor: 'multibyte character methods' stamp: 'yo 8/28/2002 16:35'!
fixXTable

	| newXTable val |
	xTable size >= 258 ifTrue: [
		^ self.
	].

	newXTable := Array new: 258.
	1 to: xTable size do: [:i |
		newXTable at: i put: (xTable at: i).
	].

	val := xTable at: (xTable size).
	
	xTable size + 1 to: 258 do: [:i |
		newXTable at: i put: val.
	].
	minAscii := 0.
	maxAscii := 255.
	xTable := newXTable.
! !

!StrikeFont methodsFor: 'displaying' stamp: 'BG 3/16/2005 08:27'!
fontDisplay
	"TextStyle default defaultFont fontDisplay."

	Display restoreAfter:
		[(Form extent: 440@400) displayAt: 90@90.
		 0 to: 15 do:
			[:i |
			i storeStringHex displayAt: 100 @ (20 * i + 100).
			0 to: 15 do:
				[:j |
				((16*i+j) between: 1 and: (self xTable size - 2)) ifTrue:
					[(self characterFormAt: (16 * i + j) asCharacter)
						displayAt: (20 * j + 150) @ (20 * i + 100)]]].
			'Click to continue...' asDisplayText displayAt: 100@450]! !

!StrikeFont methodsFor: 'accessing' stamp: 'ar 9/21/2000 11:53'!
fontNameWithPointSize
	^self name withoutTrailingDigits, ' ', self pointSize printString! !

!StrikeFont methodsFor: 'accessing' stamp: 'nice 2/17/2014 23:14'!
glyphInfoOf: aCharacter into: glyphInfoArray 
	"return the glyph info for aCharacter; if I don't have such a character, try my fallback font, if I have one of those.
	Unlike some other implementors, the returned info for a missing character is not given for the question-mark but rather the zero-ascii char."
	| code |
	(self hasGlyphOf: aCharacter)
		ifTrue: [code := self codeForCharacter: aCharacter]
		ifFalse: [fallbackFont
				ifNotNil: [^ fallbackFont glyphInfoOf: aCharacter into: glyphInfoArray].
			code := 0].
	glyphInfoArray at: 1 put: glyphs;
		at: 2 put: (xTable at: code + 1);
		at: 3 put: (xTable at: code + 2);
		at: 4 put: (self ascentOf: aCharacter);
		 at: 5 put: self.
	^ glyphInfoArray! !

!StrikeFont methodsFor: 'accessing' stamp: 'nice 2/17/2014 23:14'!
glyphOf: aCharacter 
	"Answer the width of the argument as a character in the receiver."

	| code |
	(self hasGlyphOf: aCharacter) ifFalse: [
		fallbackFont ifNotNil: [
			^ fallbackFont glyphOf: aCharacter.
		].
		^ (Form extent: 1@self height) fillColor: Color white
	].
	code := self codeForCharacter: aCharacter.
	^ glyphs copy: (((xTable at: code + 1)@0) corner: (xTable at: code +2)@self height).
! !

!StrikeFont methodsFor: 'accessing' stamp: ''!
glyphs
	"Answer a Form containing the bits representing the characters of the 
	receiver."

	^glyphs! !

!StrikeFont methodsFor: 'multibyte character methods' stamp: 'nice 2/17/2014 23:10'!
hasGlyphForCode: aCharacterCode

	((aCharacterCode between: self minAscii and: self maxAscii) not) ifTrue: [
		^ false.
	].
	(xTable at: aCharacterCode + 1) < 0 ifTrue: [
		^ false.
	].
	^ true.
! !

!StrikeFont methodsFor: 'accessing' stamp: ''!
height
	"Answer the height of the receiver, total of maximum extents of 
	characters above and below the baseline."

	^self ascent + self descent! !

!StrikeFont methodsFor: 'accessing' stamp: 'yo 1/6/2005 04:19'!
heightOf: aCharacter

	(self hasGlyphOf: aCharacter) ifFalse: [
		fallbackFont ifNotNil: [
			^ fallbackFont heightOf: aCharacter.
		].
	].
	^ self height.
! !

!StrikeFont methodsFor: 'displaying' stamp: 'yo 1/5/2005 13:59'!
installOn: aDisplayContext

	^aDisplayContext installStrikeFont: self.
! !

!StrikeFont methodsFor: 'displaying' stamp: 'ar 5/19/2000 15:08'!
installOn: aDisplayContext foregroundColor: foregroundColor backgroundColor: backgroundColor
	^aDisplayContext 
		installStrikeFont: self
		foregroundColor: foregroundColor 
		backgroundColor: backgroundColor! !

!StrikeFont methodsFor: 'emphasis' stamp: 'jmv 4/26/2008 14:12'!
isSynthetic
	^type = 3! !

!StrikeFont methodsFor: 'emphasis' stamp: 'jmv 4/26/2008 14:11'!
isSynthetic: aBoolean
	type := aBoolean ifTrue: [3] ifFalse: [0]! !

!StrikeFont methodsFor: 'accessing' stamp: ''!
lineGrid
	^ ascent + descent! !

!StrikeFont methodsFor: 'make arrows' stamp: 'sps 10/15/2003 17:06'!
makeAssignArrow
"Replace the underline character with an arrow for this font"

	| arrowForm arrowCanvas arrowY arrowLeft arrowRight arrowHeadLength |

	arrowForm := (self characterFormAt: $_) copy.
	arrowCanvas := arrowForm getCanvas.
	arrowCanvas fillColor: Color white.
	arrowY := arrowForm height // 2.
	arrowLeft := 0. 
	arrowRight := arrowForm width - 2.
	arrowHeadLength := (arrowRight - arrowLeft) * 2 // 5.
	"Draw the lines"
	arrowCanvas line: (arrowLeft@arrowY) to: (arrowRight@arrowY) color: Color black.
	arrowCanvas 
		line: (arrowLeft@arrowY) 
		to: ((arrowLeft + arrowHeadLength)@(arrowY - arrowHeadLength)) 
		color: Color black.
	arrowCanvas 
		line: (arrowLeft@arrowY) 
		to: ((arrowLeft + arrowHeadLength)@(arrowY + arrowHeadLength)) 
		color: Color black.

	"Replace the glyph"
	self characterFormAt: $_ put: arrowForm.

! !

!StrikeFont methodsFor: 'emphasis' stamp: 'jmv 8/3/2009 09:17'!
makeBoldGlyphs
	"Make a bold set of glyphs with same widths by ORing 1 bit to the right
		(requires at least 1 pixel of intercharacter space)"
	| g bonkForm |
	g := glyphs deepCopy.
	bonkForm := (Form extent: 1@16) fillBlack offset: -1@0.
	self bonk: g with: bonkForm.
	glyphs depth = 1 ifTrue: [
		g copyBits: g boundingBox from: g at: (1@0)
			clippingBox: g boundingBox rule: Form under fillColor: nil]
		ifFalse: [
			0 to: g width - 2 do: [ :x | 0 to: g height-1 do: [ :y |
				(glyphs colorAt:  x@y) = Color white ifFalse: [
					g colorAt: x+1@y put: 
						((glyphs colorAt: x+1@y) = Color white 
							ifTrue: [glyphs colorAt:  x@y]
							ifFalse: [Color black])]]]].
	glyphs := g.
	self isSynthetic: true.
	fallbackFont ifNotNil: [
		fallbackFont := fallbackFont emphasized: 1
	].! !

!StrikeFont methodsFor: 'character shapes' stamp: 'RAA 7/6/2000 16:50'!
makeCarriageReturnsWhite
	| crForm |
	"Some larger fonts have a gray carriage return (from the zero wide fixup) make it white so it doesn't show"

	crForm := self characterFormAt: 13 asCharacter.
	crForm fillWhite.
	self characterFormAt: 13 asCharacter put: crForm.
! !

!StrikeFont methodsFor: 'emphasis' stamp: 'jmv 8/3/2009 09:17'!
makeCondensedGlyphs
	"Make a condensed set of glyphs with same widths.
	NOTE: this has been superceded by kerning -- should not get called"
	| g newXTable x x1 w |
	g := glyphs deepCopy.
	newXTable := Array new: xTable size.
	newXTable at: 1 put: (x := xTable at: 1).
	1 to: xTable size-1 do:
		[:i | x1 := xTable at: i.  w := (xTable at: i+1) - x1.
		w > 1 ifTrue: [w := w-1].  "Shrink every character wider than 1"
		g copy: (x@0 extent: w@g height) from: x1@0 in: glyphs rule: Form over.
		newXTable at: i+1 put: (x := x + w)].
	xTable := newXTable.
	glyphs := g.
	self isSynthetic: true.
	fallbackFont ifNotNil: [
		fallbackFont emphasized: 8
	].

"
(TextStyle default fontAt: 1) copy makeCondensedGlyphs
	displayLine: 'The quick brown fox jumps over the lazy dog'
	at: Sensor cursorPoint
"! !

!StrikeFont methodsFor: 'character shapes' stamp: 'jmv 3/27/2009 09:46'!
makeControlCharsVisible
	| glyph d|
	self characterToGlyphMap.
	glyph := self characterFormAt: (Character space).
	glyph border: glyph boundingBox width: 1 fillColor: Color blue.
	self characterFormAt: (Character value: 133) put: glyph.
	
	"Keep tab(9), lf(10), cr(13) and space(32) transparent or whatever the user chose"
	#(0 1 2 3 4 5 6 7 8 11 12 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31)
		do: [ :ascii |
			characterToGlyphMap at: ascii + 1 put: 133 ]! !

!StrikeFont methodsFor: 'emphasis' stamp: 'jmv 8/3/2009 09:19'!
makeItalicGlyphs
	"Make an italic set of glyphs with same widths by skewing left and right.
	In the process, characters would overlap, so we widen them all first.
	"
	| extraWidth newGlyphs newXTable x newX w extraOnLeft |  
	extraOnLeft := (self height-1-self ascent+4)//4 max: 0.
	extraWidth := ((self ascent-5+4)//4 max: 0) + extraOnLeft.
	newGlyphs := Form extent: (glyphs width + (maxAscii + 1 - minAscii*extraWidth)) @ glyphs height depth: glyphs depth.
	newGlyphs fillWhite.
	newXTable := xTable copy.

	"Copy glyphs into newGlyphs with room on left and right for overlap."
	minAscii to: maxAscii+1 do:
		[:ascii | x := xTable at: ascii+1.  w := (xTable at: ascii+2) - x.
		newX := newXTable at: ascii+1.
		newGlyphs copy: ((newX + extraOnLeft) @ 0 extent: w @ glyphs height)
			from: x @ 0 in: glyphs rule: Form over.
		newXTable at: ascii+2 put: newX + w + extraWidth].		
	glyphs := newGlyphs. 
	xTable := newXTable.
	"Slide the bitmaps left and right for synthetic italic effect."
	4 to: self ascent-1 by: 4 do:
		[:y | 		"Slide ascenders right..."
		glyphs copy: (1@0 extent: glyphs width @ (self ascent - y))
			from: 0@0 in: glyphs rule: Form over].
	self ascent to: self height-1 by: 4 do:
		[:y | 		"Slide descenders left..."
		glyphs copy: (0@y extent: glyphs width @ glyphs height)
			from: 1@y in: glyphs rule: Form over].
	self isSynthetic: true.
	fallbackFont ifNotNil: [
		fallbackFont := fallbackFont emphasized: 2
	].

! !

!StrikeFont methodsFor: 'character shapes' stamp: 'jmv 3/26/2009 14:40'!
makeLfInvisible
	self characterToGlyphMap.
	characterToGlyphMap at: 11 put: (11 < minAscii ifFalse: [11] ifTrue: [maxAscii+1])! !

!StrikeFont methodsFor: 'character shapes' stamp: 'jmv 3/27/2009 09:19'!
makeLfVisible
	| glyph |
	self characterToGlyphMap.
	glyph := self characterFormAt: (Character value: 163).
	glyph border: glyph boundingBox width: 1 fillColor: Color blue.
"	glyph := glyph reverse."
	self characterFormAt: (Character value: 132) put: glyph.
	characterToGlyphMap at: 11 put: 132! !

!StrikeFont methodsFor: 'make arrows' stamp: 'sps 10/15/2003 17:06'!
makeReturnArrow
"Replace the caret character with an arrow"

	| arrowForm arrowCanvas arrowHeadLength arrowX arrowTop arrowBottom |

	arrowForm := (self characterFormAt: $^) copy.
	arrowCanvas := arrowForm getCanvas.
	arrowCanvas fillColor: Color white.

	arrowHeadLength := ((arrowForm width - 2)// 2).
	arrowX := (arrowHeadLength max: (arrowForm width // 2)).
	arrowTop := arrowForm height // 4. 
	arrowBottom := (arrowTop + (arrowForm width * 4 // 5 )).
	arrowBottom := (arrowBottom min: arrowForm height) max: (arrowForm height * 2 // 3).

	"Draw the lines"
	arrowCanvas line: (arrowX@arrowTop) to: (arrowX@arrowBottom) color: Color black.
	arrowCanvas 
		line: (arrowX@arrowTop) 
		to: ((arrowX - arrowHeadLength)@(arrowTop + arrowHeadLength)) 
		color: Color black.
	arrowCanvas 
		line: (arrowX@arrowTop) 
		to: ((arrowX + arrowHeadLength)@(arrowTop + arrowHeadLength)) 
		color: Color black.

	"Replace the glyph"
	self characterFormAt: $^ put: arrowForm.

! !

!StrikeFont methodsFor: 'emphasis' stamp: 'jmv 8/3/2009 09:20'!
makeStruckOutGlyphs
	"Make a struck-out set of glyphs with same widths"
	| g |
	g := glyphs deepCopy.
	g fillBlack: (0 @ (self ascent - (self ascent//3)) extent: g width @ 1).
	glyphs := g.
	self isSynthetic: true.
	fallbackFont ifNotNil: [
		fallbackFont := fallbackFont emphasized: 16
	].
! !

!StrikeFont methodsFor: 'character shapes' stamp: 'jmv 3/26/2009 14:40'!
makeTabInvisible
	self characterToGlyphMap.
	characterToGlyphMap at: 10 put: (10 < minAscii ifFalse: [10] ifTrue:[maxAscii+1])! !

!StrikeFont methodsFor: 'character shapes' stamp: 'jmv 3/26/2009 14:41'!
makeTabVisible
	self characterToGlyphMap.
	characterToGlyphMap at: 10 put: 172! !

!StrikeFont methodsFor: 'emphasis' stamp: 'jmv 8/3/2009 09:20'!
makeUnderlinedGlyphs
	"Make an underlined set of glyphs with same widths"
	| g |
	g := glyphs deepCopy.
	g fillBlack: (0 @ (self ascent+1) extent: g width @ 1).
	glyphs := g.
	self isSynthetic: true.
	fallbackFont ifNotNil: [
		fallbackFont := fallbackFont emphasized: 4
	].
! !

!StrikeFont methodsFor: 'accessing' stamp: ''!
maxAscii
	"Answer the integer that is the last Ascii character value of the receiver."

	^maxAscii! !

!StrikeFont methodsFor: 'accessing' stamp: ''!
maxWidth
	"Answer the integer that is the width of the receiver's widest character."

	^maxWidth! !

!StrikeFont methodsFor: 'accessing' stamp: ''!
minAscii
	"Answer the integer that is the first Ascii character value of the receiver."

	^minAscii! !

!StrikeFont methodsFor: 'accessing' stamp: 'ls 3/27/2000 19:54'!
name
	"Answer the receiver's name."

	^name ifNil: ['(unnamed)']! !

!StrikeFont methodsFor: 'accessing' stamp: ''!
name: aString
	"Set the receiver's name."

	name := aString! !

!StrikeFont methodsFor: 'file in/out' stamp: 'md 11/14/2003 17:25'!
newFromStrike: fileName
	"Build an instance from the strike font file name. The '.strike' extension
	is optional."

	| strike startName raster16 |
	name := fileName copyUpTo: $..	"assumes extension (if any) is '.strike'"
	strike := FileStream readOnlyFileNamed: name, '.strike.'.
	strike binary.

	"strip off direcory name if any"
	startName := name size.
	[startName > 0 and: [((name at: startName) ~= $>) & ((name at: startName) ~= $])]]
		whileTrue: [startName := startName - 1].
	name := name copyFrom: startName+1 to: name size.

	type			:=		strike nextWord.		"type is ignored now -- simplest
												assumed.  Kept here to make
												writing and consistency more
												straightforward."
	minAscii		:=		strike nextWord.
	maxAscii		:=		strike nextWord.
	maxWidth		:=		strike nextWord.
	strikeLength	:=		strike nextWord.
	ascent			:=		strike nextWord.
	descent			:=		strike nextWord.
	"xOffset			:="		strike nextWord. 	
	raster16			:=		strike nextWord.	
	superscript		:=		ascent - descent // 3.	
	subscript		:=		descent - ascent // 3.	
	emphasis		:=		0.
	glyphs			:=	Form extent: (raster16 * 16) @ (self height)  
							offset: 0@0.
		glyphs bits fromByteStream: strike.

	xTable := (Array new: maxAscii + 3) atAllPut: 0.
	(minAscii + 1 to: maxAscii + 3) do:
		[:index | xTable at: index put: strike nextWord].

	"Set up space character"
	((xTable at: (Space asciiValue + 2))  = 0 or:
			[(xTable at: (Space asciiValue + 2)) = (xTable at: (Space asciiValue + 1))])
		ifTrue:	[(Space asciiValue + 2) to: xTable size do:
					[:index | xTable at: index put: ((xTable at: index) + DefaultSpace)]].
	strike close.
	characterToGlyphMap := nil.! !

!StrikeFont methodsFor: 'file in/out' stamp: 'tk 9/28/2000 15:50'!
objectForDataStream: refStrm
	| dp |
	"I am about to be written on an object file.  Write a reference to a known Font in the other system instead.  "

	"A path to me"
	(TextConstants at: #forceFontWriting ifAbsent: [false]) ifTrue: [^ self].
		"special case for saving the default fonts on the disk.  See collectionFromFileNamed:"

	dp := DiskProxy global: #StrikeFont selector: #familyName:size:emphasized:
			args: (Array with: self familyName   with: self height
					with: self emphasis).
	refStrm replace: self with: dp.
	^ dp! !

!StrikeFont methodsFor: 'accessing' stamp: 'sw 1/18/2000 20:54'!
pointSize
	^ pointSize! !

!StrikeFont methodsFor: 'accessing' stamp: 'sma 5/5/2000 14:21'!
pointSize: anInteger
	pointSize := anInteger! !

!StrikeFont methodsFor: 'copying' stamp: 'BG 12/9/2004 17:35'!
postCopy
 " the receiver is a just created shallow copy. This method gives it the final touch. " 
 
    glyphs := glyphs copy.
    xTable := xTable copy.
    characterToGlyphMap := characterToGlyphMap copy.
 
    self reset.  " takes care of the derivative fonts "! !

!StrikeFont methodsFor: 'file in/out' stamp: 'sma 6/1/2000 09:32'!
printOn: aStream
	super printOn: aStream.
	aStream
		nextPut: $(;
		nextPutAll: self name;
		space;
		print: self height;
		nextPut: $)! !

!StrikeFont methodsFor: 'printing' stamp: 'nice 10/12/2013 02:11'!
printShortDescriptionOn: aStream
	aStream space; nextPutAll: self name! !

!StrikeFont methodsFor: 'accessing' stamp: ''!
raster
	"Answer an integer that specifies the layout of the glyphs' form."

	^raster! !

!StrikeFont methodsFor: 'file in/out' stamp: 'ar 10/25/2005 00:21'!
readBDFFromFile: fileName name: aString 
	"This builds a StrikeFont instance by reading the X11 Binary 
	Distribution Format font source file.  See the BDFFontReader class
	comment."

	"StrikeFont new readBDFFromFile: 'helvR12' name: 'Helvetica12'."

	| fontReader stream |
	fontReader := BDFFontReader openFileNamed: fileName.
	stream := ReadStream on: fontReader read.
	xTable := stream next.
	glyphs := stream next.
	minAscii := stream next.
	maxAscii := stream next.
	maxWidth := stream next.
	ascent := stream next.
	descent := stream next.
	pointSize := stream next.
	name := aString.
"	xTable size <= 256 ifTrue: [self setStopConditions]."
	type := 0.	"no one see this"
	superscript := (ascent - descent) // 3.
	subscript := (descent - ascent) // 3.
	emphasis := 0.
	self reset! !

!StrikeFont methodsFor: 'file in/out' stamp: ''!
readBFHeaderFrom: f
	name := self restOfLine: 'Font name = ' from: f.
	ascent := (self restOfLine: 'Ascent = ' from: f) asNumber.
	descent := (self restOfLine: 'Descent = ' from: f) asNumber.
	maxWidth := (self restOfLine: 'Maximum width = ' from: f) asNumber.
	pointSize := (self restOfLine: 'Font size = ' from: f) asNumber.
	name := (name copyWithout: Character space) ,
				(pointSize < 10
					ifTrue: ['0' , pointSize printString]
					ifFalse: [pointSize printString]).
	minAscii := 258.
	maxAscii := 0.
	superscript := ascent - descent // 3.	
	subscript := descent - ascent // 3.	
	emphasis := 0.
	type := 0.  "ignored for now"
! !

!StrikeFont methodsFor: 'multibyte character methods' stamp: 'yo 8/28/2002 16:37'!
readCharacter: aBits from: aStream

	| pos |
	pos := 0.
	12 timesRepeat: [
		1 to: 2 do: [ :w |
			aBits byteAt: (pos+w) put: (aStream next ). 
		].
		pos := pos + 4.
	].
! !

!StrikeFont methodsFor: 'file in/out' stamp: 'nice 6/11/2010 21:29'!
readFromBitFont: fileName
	"This builds a StrikeFont instance by reading the data file format
	produced by BitFont, a widely available font conversion utility
	written by Peter DiCamillo at Brown University"
	"StrikeFont new readFromBitFont: 'Palatino10.BF' "
	| f lastAscii charLine width ascii charForm line missingForm tempGlyphs iRect p rectLine left tokens right |
	f := FileStream readOnlyFileNamed: fileName.
	self readBFHeaderFrom: f.

	"NOTE: if font has been scaled (and in any case),
	the REAL bitmap dimensions come after the header."
	self restOfLine: 'Extent information for entire font' from: f.
	"Parse the following line (including mispelling!!)"
	"Image rectange: left = -2, right = 8, bottom = -2, top = 7"
	tokens := f nextLine  findTokens: ' '.
	iRect := Rectangle left: (tokens at: 5) asNumber right: (tokens at: 8) asNumber
				top: (tokens at: 14) asNumber bottom: (tokens at: 11) asNumber.
	ascent := iRect top.
	descent := iRect bottom negated.
	
	tempGlyphs := Form extent: (maxWidth*257) @ self height.
	xTable := (Array new: 258) atAllPut: 0.
	xTable at: 1 put: 0.

	"Read character forms and blt into tempGlyphs"
	lastAscii := -1.
	[charLine := self restOfLine: 'Character: ' from: f.
	charLine == nil ifFalse:
		[p := f position.
		rectLine := f nextLine.
		(rectLine beginsWith: 'Image rectange: left = ')
			ifTrue: [tokens := rectLine findTokens: ' '.
					left := (tokens at: 5) asNumber. right := (tokens at: 8) asNumber]
			ifFalse: [left := right := 0. f position: p].
		width:= (self restOfLine: 'Width (final pen position) = ' from: f) asNumber - left
					max: (right-left+1).
		(charLine beginsWith: 'Missing character') ifTrue: [ascii := 256].
		('x''*' match: charLine) ifTrue:
			[ascii := Number readFrom: (charLine copyFrom: 3 to: 4) asUppercase base: 16].
		charForm := Form extent: width@self height.
		('*[all blank]' match: charLine) ifFalse:
			[self restOfLine: '  +' from: f.
			1 to: self height do:
				[:y | line := f nextLine.
				4 to: (width + 3 min: line size + iRect left - left) do:
					[:x | (line at: x - iRect left + left) = $*
						ifTrue: [charForm pixelValueAt: (x-4)@(y-1) put: 1]]]]].
	charLine == nil]
		whileFalse:
			[self displayChar: ascii form: charForm.
			ascii = 256
				ifTrue: [missingForm := charForm deepCopy]
				ifFalse:
				[minAscii := minAscii min: ascii.
				maxAscii := maxAscii max: ascii.
				lastAscii+1 to: ascii-1 do: [:a | xTable at: a+2 put: (xTable at: a+1)].
				tempGlyphs copy: ((xTable at: ascii+1)@0
										extent: charForm extent)
							from: 0@0 in: charForm rule: Form over.
				xTable at: ascii+2 put: (xTable at: ascii+1) + width.
				lastAscii := ascii]].
	f close.
	lastAscii+1 to: maxAscii+1 do: [:a | xTable at: a+2 put: (xTable at: a+1)].
	missingForm == nil ifFalse:
		[tempGlyphs copy: missingForm boundingBox from: missingForm
				to: (xTable at: maxAscii+2)@0 rule: Form over.
		xTable at: maxAscii+3 put: (xTable at: maxAscii+2) + missingForm width].
	glyphs := Form extent: (xTable at: maxAscii+3) @ self height.
	glyphs copy: glyphs boundingBox from: 0@0 in: tempGlyphs rule: Form over.
	xTable := xTable copyFrom: 1 to: maxAscii+3.
	characterToGlyphMap := nil.! !

!StrikeFont methodsFor: 'file in/out' stamp: 'ar 5/23/2000 12:53'!
readFromStrike2Stream: file 
	"Build an instance from the supplied binary stream on data in strike2 format"
	type := file nextInt32.  type = 2 ifFalse: [file close. self error: 'not strike2 format'].
	minAscii := file nextInt32.
	maxAscii := file nextInt32.
	maxWidth := file nextInt32.
	ascent := file nextInt32.
	descent := file nextInt32.
	pointSize := file nextInt32.
	superscript := ascent - descent // 3.	
	subscript := descent - ascent // 3.	
	emphasis := file nextInt32.
	xTable := (Array new: maxAscii + 3) atAllPut: 0.
	(minAscii + 1 to: maxAscii + 3) do:
		[:index | xTable at: index put: file nextInt32].
	glyphs := Form new readFrom: file.

	"Set up space character"
	((xTable at: (Space asciiValue + 2))  = 0 or:
			[(xTable at: (Space asciiValue + 2)) = (xTable at: (Space asciiValue + 1))])
		ifTrue:	[(Space asciiValue + 2) to: xTable size do:
					[:index | xTable at: index put: ((xTable at: index) + DefaultSpace)]].
	characterToGlyphMap := nil.! !

!StrikeFont methodsFor: 'file in/out' stamp: 'tpr 6/11/2014 17:58'!
readFromStrike2: fileName  "StrikeFont new readFromStrike2: 'Palatino14.sf2'"
	"Build an instance from the strike font stored in strike2 format.
	fileName is of the form: <family name><pointSize>.sf2"
	| file |
	('*.sf2' match: fileName) ifFalse: [self halt.  "likely incompatible"].
	name := FileDirectory baseNameFor: ( FileDirectory localNameFor: fileName).  "Drop filename extension"
	file := FileStream readOnlyFileNamed: fileName.
	file binary.
	[self readFromStrike2Stream: file] ensure: [file close]! !

!StrikeFont methodsFor: 'Mac reader' stamp: 'ar 5/23/2000 12:49'!
readMacFontHex: fileName
	"Read the hex version of a Mac FONT type resource.  See the method aComment for how to prepare the input file. 4/26/96 tk"
	| file hh fRectWidth |
	name := fileName.	"Palatino 12"
	file := FileStream readOnlyFileNamed: fileName, ' hex'.

	"See Inside Macintosh page IV-42 for this record"
	"FontType := " Number readFrom: (file next: 4) base: 16.
	emphasis		:=		0.
	minAscii := Number readFrom: (file next: 4) base: 16.
	maxAscii := Number readFrom: (file next: 4) base: 16.
	maxWidth		:= Number readFrom: (file next: 4) base: 16.
	"kernMax := " Number readFrom: (file next: 4) base: 16.
	"NDescent := " Number readFrom: (file next: 4) base: 16.
	fRectWidth :=  Number readFrom: (file next: 4) base: 16.
	hh :=  Number readFrom: (file next: 4) base: 16.
	"OWTLoc := " Number readFrom: (file next: 4) base: 16.
	ascent			:= Number readFrom: (file next: 4) base: 16.
	descent			:= Number readFrom: (file next: 4) base: 16.
	"leading := " Number readFrom: (file next: 4) base: 16.
	xOffset			:=		0. 	
	raster			:= Number readFrom: (file next: 4) base: 16.

	strikeLength	:=		raster*16.
	superscript		:=		ascent - descent // 3.	
	subscript		:=		descent - ascent // 3.	
	self strikeFromHex: file width: raster height: hh.
	self xTableFromHex: file.
	file close.

	"Insert one pixel between each character.  And add space character."
	self fixKerning: (fRectWidth - maxWidth).	

	"Recompute character to glyph mapping"
	characterToGlyphMap := nil.! !

!StrikeFont methodsFor: 'emphasis' stamp: 'nk 3/15/2004 18:46'!
releaseCachedState

	self reset.! !

!StrikeFont methodsFor: 'emphasis' stamp: 'jmv 8/3/2009 09:22'!
reset
	"Reset the cache of derivative emphasized fonts"

	fallbackFont class = FixedFaceFont
		ifTrue: [fallbackFont := nil].
		
	derivativeFonts notNil ifTrue: [
		derivativeFonts withIndexDo: [ :f :i |
			(f notNil and: [f isSynthetic]) ifTrue: [derivativeFonts at: i put: nil]]].
	"
	derivativeFonts := Array new: 32.
	#('B' 'I' 'BI') doWithIndex:
		[:tag :index | 
		(style := TextStyle named: self familyName) ifNotNil:
			[(font := style fontArray
				detect: [:each | each name = (self name , tag)]
				ifNone: [nil]) ifNotNil: [derivativeFonts at: index put: font]]]
	"! !

!StrikeFont methodsFor: 'file in/out' stamp: 'nice 6/11/2010 21:29'!
restOfLine: leadString from: file
	"Utility method to assist reading of BitFont data files"
	| line |
	[line := file nextLine.
	line size < leadString size or: [leadString ~= (line copyFrom: 1 to: leadString size)]]
	whileTrue: [file atEnd ifTrue: [^ nil]].
	^ line copyFrom: leadString size+1 to: line size! !

!StrikeFont methodsFor: 'building' stamp: 'jmv 10/18/2008 23:50'!
setGlyphsDepthAtMost: aNumber
	glyphs depth > aNumber ifTrue: [
		glyphs := glyphs asFormOfDepth: aNumber ]! !

!StrikeFont methodsFor: 'accessing' stamp: ''!
setGlyphs: newGlyphs
	"Replace the glyphs form.  Used to make a synthetic bold or italic font quickly."

	glyphs := newGlyphs! !

!StrikeFont methodsFor: 'emphasis' stamp: 'rej 9/29/2007 09:02'!
setupDefaultFallbackFont
	"This used to be the default textstyle, but it needs to be a StrikeFont and not a TTCFont and sometimes the default textstyle is a TTCFont.  So, we use a typical StrikeFont as the default fallback font."
	self fallbackFont: (StrikeFont defaultSized: self height).
	self reset.

! !

!StrikeFont methodsFor: 'Mac reader' stamp: ''!
strikeFromHex: file width: w height: h
	"read in just the raw strike bits from a hex file.  No spaces or returns.  W is in words (2 bytes), h in pixels." 
	| newForm theBits offsetX offsetY str num cnt |
	offsetX  := 0.
	offsetY := 0.
	offsetX > 32767 ifTrue: [offsetX := offsetX - 65536]. "stored two's-complement"
	offsetY > 32767 ifTrue: [offsetY := offsetY - 65536]. "stored two's-complement"
	newForm := Form extent: strikeLength @ h offset: offsetX @ offsetY.
	theBits := newForm bits.
	cnt := 0.		"raster may be 16 bits, but theBits width is 32" 
	1 to: theBits size do: [:i | 
		(cnt := cnt + 32) > strikeLength 
		  ifTrue: [cnt := 0.
			num := Number readFrom: (str := file next: 4) base: 16]
		  ifFalse: [
			cnt = strikeLength ifTrue: [cnt := 0].
			num := Number readFrom: (str := file next: 8) base: 16].
		theBits at: i put: num].
	glyphs := newForm.! !

!StrikeFont methodsFor: 'building' stamp: 'jmv 6/19/2008 16:55'!
stripHighGlyphs
	"Remove glyphs for characters above 128"
	| i |
	maxAscii := 127.
	
	xTable := xTable copyFrom: 1 to: maxAscii + 3.
	i := xTable at: maxAscii + 1.
	xTable at: maxAscii + 2 put: i.
	xTable at: maxAscii + 3 put: i.
	glyphs := glyphs copy: (0@0 extent: i@glyphs height).
	maxWidth := 0.
	2 to: xTable size do: [ :ii |
		maxWidth := maxWidth max: (xTable at: ii) - (xTable at: ii-1)-1 ].
	characterToGlyphMap := nil.
	self reset! !

!StrikeFont methodsFor: 'accessing' stamp: ''!
subscript
	"Answer an integer that is the further vertical offset relative to the 
	baseline for positioning characters as subscripts."

	^subscript! !

!StrikeFont methodsFor: 'accessing' stamp: ''!
superscript
	"Answer an integer that is the further vertical offset relative to the 
	baseline for positioning characters as superscripts."

	^superscript! !

!StrikeFont methodsFor: 'accessing' stamp: 'nk 6/17/2003 14:26'!
textStyle
	^ TextStyle actualTextStyles detect:
		[:aStyle | aStyle fontArray includes: self] ifNone: [nil]! !

!StrikeFont methodsFor: 'character shapes' stamp: 'jmv 3/26/2009 15:17'!
useLeftArrow
	self characterToGlyphMap.
	characterToGlyphMap at: 96 put: 95.
	characterToGlyphMap at: 95 put: 94! !

!StrikeFont methodsFor: 'character shapes' stamp: 'jmv 3/26/2009 14:49'!
useUnderscore
	self characterToGlyphMap.
	characterToGlyphMap at: 96 put: 129.
	characterToGlyphMap at: 95 put: 128! !

!StrikeFont methodsFor: 'character shapes' stamp: 'jmv 8/6/2009 14:23'!
useUnderscoreIfOver1bpp

	glyphs depth = 1 ifTrue: [
		characterToGlyphMap ifNotNil: [	
			characterToGlyphMap at: 96 put: 95.
			characterToGlyphMap at: 95 put: 94 ].
		^self ].
	
	self characterToGlyphMap.
	characterToGlyphMap at: 96 put: 129.
	characterToGlyphMap at: 95 put: 128! !

!StrikeFont methodsFor: 'copying' stamp: 'tk 8/19/1998 16:15'!
veryDeepCopyWith: deepCopier
	"Return self.  I am shared.  Do not record me."! !

!StrikeFont methodsFor: 'character shapes' stamp: 'nice 12/26/2009 22:06'!
widen: char by: delta
	^ self alter: char formBlock:  "Make a new form, wider or narrower..."
		[:charForm |
		| newForm |
		newForm := Form extent: charForm extent + (delta@0).
		charForm displayOn: newForm.  "Copy this image into it"
		newForm]    "and substitute it in the font"! !

!StrikeFont methodsFor: 'accessing' stamp: 'ul 2/14/2011 03:49'!
widthOf: aCharacter 
	"Answer the width of the argument as a character in the receiver."
	| code |
	code := aCharacter charCode.
	(self characterToGlyphMap notNil and: [ 
		characterToGlyphMap size > code ]) ifTrue: [
			code := characterToGlyphMap at: code + 1 ].
	((code < minAscii or: [maxAscii < code]) 
		or: [(xTable at: code + 1) < 0])
			ifTrue: [^ self fallbackFont widthOf: aCharacter].
	^ (xTable at: code + 2) - (xTable at: code + 1)! !

!StrikeFont methodsFor: 'file in/out' stamp: 'ls 4/11/2000 18:57'!
writeAsStrike2named: fileName
	"Write me onto a file in strike2 format.
	fileName should be of the form: <family name><pointSize>.sf2"
	| file |
	file := FileStream fileNamed: fileName.
	self writeAsStrike2On: file.
	file close.! !

!StrikeFont methodsFor: 'file in/out' stamp: 'ls 3/27/2000 17:43'!
writeAsStrike2On: file
	"Write me onto a file in strike2 format.
	fileName should be of the form: <family name><pointSize>.sf2"
	file binary.
	file nextInt32Put: 2.
	file nextInt32Put: minAscii.
	file nextInt32Put: maxAscii.
	file nextInt32Put: maxWidth.
	file nextInt32Put: ascent.
	file nextInt32Put: descent.
	file nextInt32Put: pointSize.
	superscript := ascent - descent // 3.	
	subscript := descent - ascent // 3.	
	file nextInt32Put: emphasis.
	(minAscii + 1 to: maxAscii + 3) do:
		[:index | file nextInt32Put: (xTable at: index)].
	glyphs writeOn: file.
	file close.
! !

!StrikeFont methodsFor: 'accessing' stamp: ''!
xTable
	"Answer an Array of the left x-coordinate of characters in glyphs."

	^xTable! !

!StrikeFont methodsFor: 'Mac reader' stamp: 'nice 12/26/2009 22:07'!
xTableFromHex: file

	| strike num wid |
	strike := file.
	xTable := (Array new: maxAscii + 3) atAllPut: 0.
	minAscii + 1 to: maxAscii + 3 do:
		[:index | 
			num := Number readFrom: (strike next: 4) base: 16. 
			xTable at: index put: num].

	1 to: xTable size - 1 do: [:ind |
		wid := (xTable at: ind+1) - (xTable at: ind).
		(wid < 0) | (wid > 40) ifTrue: [
			file close.
			self error: 'illegal character width']].
! !

!StrikeFont methodsFor: 'accessing' stamp: 'yo 8/28/2002 16:33'!
xTable: anObject

	xTable := anObject.
! !

Object subclass: #TextLine
	instanceVariableNames: 'left right top bottom firstIndex lastIndex internalSpaces paddingWidth baseline leftMargin'
	classVariableNames: ''
	poolDictionaries: 'TextConstants'
	category: 'Graphics-Text'!

!TextLine commentStamp: '<historical>' prior: 0!
A TextLine embodies the layout of a line of composed text.
	left right top bottom		The full line rectangle
	firstIndex lastIndex		Starting and stopping indices in the full text
	internalSpaces		Number of spaces to share paddingWidth
	paddingWidth		Number of pixels of extra space in full line
	baseline				Distance of baseline below the top of the line
	leftMargin			Left margin due to paragraph indentation
TextLine's rather verbose message protocol is required for compatibility with the old CharacterScanners.!

!TextLine class methodsFor: 'instance creation' stamp: 'di 10/20/97 23:08'!
start: startInteger stop: stopInteger internalSpaces: spacesInteger paddingWidth: padWidthInteger
	"Answer an instance of me with the arguments as the start, stop points, 
	number of spaces in the line, and width of the padding."
	| line |
	line := self new firstIndex: startInteger lastIndex: stopInteger.
	^ line internalSpaces: spacesInteger paddingWidth: padWidthInteger! !

!TextLine methodsFor: 'accessing' stamp: ''!
baseline
	^ baseline! !

!TextLine methodsFor: 'accessing' stamp: 'di 10/23/97 19:58'!
bottom
	^ bottom! !

!TextLine methodsFor: 'accessing' stamp: 'di 10/23/97 19:58'!
bottomRight
	^ right@bottom! !

!TextLine methodsFor: 'accessing' stamp: 'di 10/21/97 20:12'!
first
	^ firstIndex! !

!TextLine methodsFor: 'private' stamp: 'di 10/20/97 23:08'!
firstIndex: firstInteger lastIndex: lastInteger
	firstIndex := firstInteger.
	lastIndex := lastInteger! !

!TextLine methodsFor: 'comparing' stamp: 'ar 9/9/2003 22:03'!
hash
	"#hash is re-implemented because #= is re-implemented"
	^firstIndex hash bitXor: lastIndex hash! !

!TextLine methodsFor: 'accessing' stamp: ''!
internalSpaces
	"Answer the number of spaces in the line."

	^internalSpaces! !

!TextLine methodsFor: 'accessing' stamp: ''!
internalSpaces: spacesInteger 
	"Set the number of spaces in the line to be spacesInteger."

	internalSpaces := spacesInteger! !

!TextLine methodsFor: 'private' stamp: ''!
internalSpaces: spacesInteger paddingWidth: padWidthInteger

	internalSpaces := spacesInteger.
	paddingWidth := padWidthInteger! !

!TextLine methodsFor: 'scanning' stamp: 'tween 4/6/2007 12:48'!
justifiedPadFor: spaceIndex font: aFont
	"Compute the width of pad for a given space in a line of justified text."

	| pad |
	internalSpaces = 0 ifTrue: [^0].
	^(aFont notNil and:[aFont isSubPixelPositioned])
		ifTrue:[paddingWidth * 1.0 / internalSpaces]
		ifFalse:[
			pad := paddingWidth // internalSpaces.
			spaceIndex <= (paddingWidth \\ internalSpaces)
				ifTrue: [pad + 1]
				ifFalse: [pad]]
		! !

!TextLine methodsFor: 'scanning' stamp: ''!
justifiedTabDeltaFor: spaceIndex 
	"Compute the delta for a tab in a line of justified text, so tab falls 
	somewhere plausible when line is justified."

	| pad extraPad |
	internalSpaces = 0 ifTrue: [^0].
	pad := paddingWidth // internalSpaces.
	extraPad := paddingWidth \\ internalSpaces.
	spaceIndex <= extraPad
		ifTrue: [^spaceIndex * (pad + 1)]
		ifFalse: [^extraPad * (pad + 1) + (spaceIndex - extraPad * pad)]! !

!TextLine methodsFor: 'accessing' stamp: 'di 10/21/97 20:14'!
last
	^ lastIndex! !

!TextLine methodsFor: 'accessing' stamp: 'di 10/23/97 19:58'!
left
	^ left! !

!TextLine methodsFor: 'accessing' stamp: 'di 10/21/97 20:42'!
leftMargin
	"This has to get fixed -- store during composition"
	^ self left! !

!TextLine methodsFor: 'accessing' stamp: 'nice 3/6/2008 22:44'!
leftMarginForAlignment: alignmentCode
	alignmentCode = RightFlush ifTrue: [^ self left + paddingWidth].
	alignmentCode = Centered ifTrue: [^ self left + (paddingWidth//2)].
	^ self left  "leftFlush and justified"! !

!TextLine methodsFor: 'accessing' stamp: 'hmm 2/9/2001 11:58'!
leftMargin: lm
	left := lm! !

!TextLine methodsFor: 'accessing' stamp: 'di 10/23/97 19:58'!
lineHeight
	^ bottom - top! !

!TextLine methodsFor: 'private' stamp: 'di 10/23/97 19:57'!
lineHeight: height baseline: ascent
	bottom := top + height.
	baseline := ascent! !

!TextLine methodsFor: 'updating' stamp: 'di 11/7/97 08:32'!
moveBy: delta 
	"Move my rectangle by the given delta"
	left := left + delta x.
	right := right + delta x.
	top := top + delta y.
	bottom := bottom + delta y.
! !

!TextLine methodsFor: 'accessing' stamp: ''!
paddingWidth
	"Answer the amount of space to be added to the font."

	^paddingWidth! !

!TextLine methodsFor: 'accessing' stamp: ''!
paddingWidth: padWidthInteger 
	"Set the amount of space to be added to the font to be padWidthInteger."

	paddingWidth := padWidthInteger! !

!TextLine methodsFor: 'printing' stamp: 'di 10/23/97 23:19'!
printOn: aStream
	super printOn: aStream.
	aStream space; print: firstIndex; nextPutAll: ' to: '; print: lastIndex! !

!TextLine methodsFor: 'accessing' stamp: 'di 10/23/97 20:00'!
rectangle
	^ self topLeft corner: self bottomRight! !

!TextLine methodsFor: 'accessing' stamp: 'hmm 2/9/2001 11:58'!
rectangle: lineRectangle
	left := lineRectangle left.
	right := lineRectangle right.
	top := lineRectangle top.
	bottom := lineRectangle bottom! !

!TextLine methodsFor: 'accessing' stamp: 'di 10/23/97 19:58'!
right
	^ right! !

!TextLine methodsFor: 'accessing' stamp: 'di 10/21/97 20:42'!
rightMargin
	"This has to get fixed -- store during composition"
	^ self right! !

!TextLine methodsFor: 'accessing' stamp: 'di 11/26/97 16:18'!
setRight: x
	right := x! !

!TextLine methodsFor: 'updating' stamp: 'di 4/28/1999 11:12'!
slideIndexBy: delta andMoveTopTo: newTop
	"Relocate my character indices and y-values.
	Used to slide constant text up or down in the wake of a text replacement."

	firstIndex := firstIndex + delta.
	lastIndex := lastIndex + delta.
	bottom := bottom + (newTop - top).
	top := newTop.
! !

!TextLine methodsFor: 'updating' stamp: 'di 10/20/97 23:25'!
slide: delta 
	"Change the starting and stopping points of the line by delta."

	firstIndex := firstIndex + delta.
	lastIndex := lastIndex + delta! !

!TextLine methodsFor: 'accessing' stamp: 'di 10/20/97 23:27'!
stop: stopInteger 
	"Set the stopping point in the string of the line to be stopInteger."

	lastIndex := stopInteger! !

!TextLine methodsFor: 'accessing' stamp: 'di 10/23/97 19:58'!
top
	^ top! !

!TextLine methodsFor: 'accessing' stamp: 'di 10/23/97 19:58'!
topLeft
	^ left @ top! !

!TextLine methodsFor: 'accessing' stamp: 'di 11/26/97 16:58'!
width
	^ right - left! !

!TextLine methodsFor: 'comparing' stamp: 'di 10/20/97 23:24'!
= line

	self species = line species
		ifTrue: [^((firstIndex = line first and: [lastIndex = line last])
				and: [internalSpaces = line internalSpaces])
				and: [paddingWidth = line paddingWidth]]
		ifFalse: [^false]! !

Object subclass: #TextStyle
	instanceVariableNames: 'fontArray fontFamilySize lineGrid baseline alignment firstIndent restIndent rightIndent tabsArray marginTabsArray leading defaultFontIndex'
	classVariableNames: ''
	poolDictionaries: 'TextConstants'
	category: 'Graphics-Text'!

!TextStyle commentStamp: '<historical>' prior: 0!
A textStyle comprises the formatting information for composing and displaying a unit (usually a paragraph) of text.  Typically one makes a copy of a master textStyle (such as TextStyle default), and then that copy may get altered in the process of editing.  Bad things can happen if you do not copy first.

Each of my instances consists of...
	fontArray		An array of StrikeFonts
	fontFamilySize	unused
	lineGrid			An integer; default line spacing for paragraphs
	baseline			An integer; default baseline (dist from line top to bottom of an 'a')
	alignment		An integer; text alignment, see TextStyle alignment:
	firstIndent		An integer; indent of first line in pixels
	restIndent		An integer; indent of remaining lines in pixels
	rightIndent		An integer; indent of right margin rel to section
	tabsArray		An array of integers giving tab offsets in pixels
	marginTabsArray	An array of margin tabs
	leading			An integer giving default vertical line separation

For a concrete example, look at TextStyle default copy inspect!

!TextStyle class methodsFor: 'TextConstants access' stamp: 'nk 9/1/2004 11:00'!
actualTextStyles
	| aDict |
	"TextStyle actualTextStyles"

	"Answer dictionary whose keys are the names of styles in the system and whose values are the actual styles"

	aDict := TextConstants select: [:thang | thang isKindOf: self ].
	self defaultFamilyNames do: [ :sym | aDict removeKey: sym ].
	^ aDict! !

!TextStyle class methodsFor: 'instance creation' stamp: 'ar 8/6/2009 18:36'!
changeDefaultFontSizeBy: delta      "TextStyle changeDefaultFontSizeBy: 1"
	"This sample method recreates the default textStyle, with font 1 being a size
	larger than the smallest.  It then initializes most references in the system
	as well, although most windows will have to beclosed and reopened to get the effect."
	| allFonts |
	allFonts := TextStyle default fontArray asSortedCollection: [:a :b | a height < b height].
	TextConstants at: #DefaultTextStyle put:
		(TextStyle fontArray: ((1 to: allFonts size) collect: [:i | allFonts atWrap: i+delta])).
	#(ListParagraph PopUpMenu StandardSystemView) do:[:className|
		Smalltalk at: className ifPresent:[:aClass| aClass initialize].
	].! !

!TextStyle class methodsFor: 'mime file in/out' stamp: 'nice 12/27/2009 03:11'!
collectionFromCompressedMIMEString: aString
	"aString holds a compressed, Base64 representation of a SmartRefStream storage of a TextStyle.
	Install the TextStyle."

	| this newName style data |
	data := (Base64MimeConverter mimeDecode: aString as: String) unzipped.
	(RWBinaryOrTextStream with: data) reset; fileIn.
	this := SmartRefStream scannedObject.

	"now install it"

	newName := this fontArray first familyName.
	this fontArray do: [:aFont | aFont familyName = newName ifFalse: [
		self error: 'All must be same family']].
	style := TextConstants at: newName asSymbol ifAbsent: [
		^ TextConstants at: newName asSymbol put: this].		"new family"
	this fontArray do: [:aFont | | heights | "add new fonts"
		heights := style fontArray collect: [:bFont | bFont height].
		(heights includes: aFont height) ifFalse: [
			style fontAt: style fontArray size + 1 put: aFont]].
! !

!TextStyle class methodsFor: 'utilities' stamp: 'nk 3/25/2004 17:55'!
decodeStyleName: styleName 
	"Given a string styleName, return a collection with: 
	 
	* [1] the probable Squeak emphasis code, which is a bit combination of: 
	1	bold 
	2	italic 
	4	underlined 
	8	narrow 
	16	strikeout 
	 
	* [2] the base style name without the modifiers (can be empty)
	* [3] the modifiers in the order they were found 
	* [4] the codes for those modifiers, in the same order
	"
	| decoder keys modifiers modifierCodes baseName styleCode matchedKey |

	decoder := self styleDecoder.

	modifiers := OrderedCollection new.
	modifierCodes := OrderedCollection new.
	keys := decoder keys asArray
				sort: [:a :b | a size > b size].
	styleCode := 0.
	baseName := styleName asString.
	[matchedKey := keys
				detect: [:k | baseName endsWith: k]
				ifNone: [].
	matchedKey notNil]
		whileTrue: [| last code | 
			last := baseName size - matchedKey size.
			last > 0
				ifTrue: [('- ' includes: (baseName at: last))
						ifTrue: [last := last - 1]].
			baseName := baseName copyFrom: 1 to: last.
			code := decoder at: matchedKey.
			styleCode := styleCode + code.
			modifiers addFirst: matchedKey.
			modifierCodes addFirst: code.
	].
	^ {styleCode. baseName. modifiers. modifierCodes }! !

!TextStyle class methodsFor: 'constants' stamp: ''!
default
	"Answer the system default text style."

	^DefaultTextStyle! !

!TextStyle class methodsFor: 'TextConstants access' stamp: 'nk 9/1/2004 10:59'!
defaultFamilyNames
	^#(DefaultTextStyle DefaultFixedTextStyle DefaultMultiStyle)! !

!TextStyle class methodsFor: 'constants' stamp: 'sw 12/6/1999 12:32'!
defaultFont
	"Answer the default system font"

	^ DefaultTextStyle defaultFont! !

!TextStyle class methodsFor: 'TextConstants access' stamp: 'nk 7/3/2003 19:06'!
fontArrayForStyle: aName
	"Answer the fonts in the style named aName,
	or an empty Array if no such named style."

	"TextStyle fontArrayForStyle: #Atlanta"
	"TextStyle fontPointSizesFor: 'NewYork'"

	^ ((self named: aName) ifNil: [ ^#() ]) fontArray
! !

!TextStyle class methodsFor: 'instance creation' stamp: ''!
fontArray: anArray 
	"Answer an instance of me with fonts those in the argument, anArray."

	^self new newFontArray: anArray! !

!TextStyle class methodsFor: 'TextConstants access' stamp: 'nk 7/3/2003 18:56'!
fontPointSizesFor: aName
	"Answer the point sizes for all the fonts in the given text style"

	"TextStyle fontPointSizesFor: 'Arial'"
	"TextStyle fontPointSizesFor: 'NewYork'"

	^ (self fontArrayForStyle: aName) collect: [:f | f pointSize]
! !

!TextStyle class methodsFor: 'utilities' stamp: 'mt 8/2/2016 12:58'!
fontSizeSummary
	"Open a text window with a simple summary of the available sizes in each of the fonts in the system."

	"TextStyle fontSizeSummary"

	(StringHolder new contents: self fontSizeSummaryContents)
		openLabel: 'Font styles and sizes' translated! !

!TextStyle class methodsFor: 'utilities' stamp: 'mt 8/2/2016 12:58'!
fontSizeSummaryContents

	^ String streamContents:
		[:aStream |
			self knownTextStyles do: [:aStyleName |
				aStream nextPutAll:
					aStyleName, '  ',
					(self fontPointSizesFor: aStyleName) asArray storeString.
				aStream cr]].! !

!TextStyle class methodsFor: 'TextConstants access' stamp: 'nk 7/3/2003 18:58'!
fontSizesFor: aName
	"Answer the pixel sizes for all the fonts in the given text style"

	"TextStyle fontSizesFor: 'Arial'"
	"TextStyle fontSizesFor: 'NewYork'"

	^ (self fontArrayForStyle: aName) collect: [:f | f height ]
! !

!TextStyle class methodsFor: 'TextConstants access' stamp: 'nk 7/3/2003 18:58'!
fontWidthsFor: aName
	"Answer the widths for all the fonts in the given text style"

	"TextStyle fontWidthsFor: 'ComicPlain'"
	^ (self fontArrayForStyle: aName) collect: [:f | f maxWidth]
! !

!TextStyle class methodsFor: 'user interface' stamp: 'nice 12/27/2009 03:11'!
importFontsFromStyleFiles
	"Import any and all of the fonts found in the default directory in files named ComicBold.style, ComicPlain.style, NewYork.style, Palatino.style, Courier.style"

	
	#('ComicBold' 'ComicPlain' 'NewYork' 'Palatino' 'Courier') do:
		[:frag | | aName |
			(TextStyle knownTextStyles includes: frag) ifFalse:
				[(FileDirectory default fileExists: (aName := frag, '.style'))
						ifTrue:
							[TextStyle default collectionFromFileNamed: aName]]].! !

!TextStyle class methodsFor: 'instance creation' stamp: ''!
initDefaultFontsAndStyle
	"This provides the system with 10 and 12-pt basal fonts.
	Bold and italic versions will be automatically generated as needed"
	| fontArray |	
	fontArray := Array new: 2.
	fontArray at: 1 put: (StrikeFont new readFromStrike2: 'NewYork10.sf2').
	fontArray at: 2 put: (StrikeFont new readFromStrike2: 'NewYork12.sf2').
	TextConstants at: #DefaultTextStyle put:
		(TextStyle fontArray: fontArray).

	"TextStyle initDefaultFontsAndStyle."! !

!TextStyle class methodsFor: 'class initialization' stamp: 'nk 3/25/2004 17:51'!
initialize
	self initializeStyleDecoder.! !

!TextStyle class methodsFor: 'class initialization' stamp: 'nk 3/25/2004 17:53'!
initializeStyleDecoder
	TextConstants at: #StyleDecoder put: nil.
	self styleDecoder.! !

!TextStyle class methodsFor: 'TextConstants access' stamp: 'nice 10/21/2009 00:16'!
knownTextStyles
	"Answer the names of the known text styles, sorted in alphabetical order"

	"TextStyle knownTextStyles"
	^ (TextConstants select: [:thang | thang isKindOf: TextStyle]) keys asArray sort

! !

!TextStyle class methodsFor: 'TextConstants access' stamp: 'nk 9/1/2004 11:08'!
knownTextStylesWithoutDefault
	"Answer the names of the known text styles, sorted in alphabetical order without default"

	"TextStyle knownTextStylesWithoutDefault"
	| result |
	result := self knownTextStyles asOrderedCollection.
	^ result copyWithoutAll: self defaultFamilyNames

! !

!TextStyle class methodsFor: 'mime file in/out' stamp: 'nk 3/15/2004 19:37'!
looseFontsFromFamily: familyName
	"
	TextStyle looseFontsFromFamily: 'Accuny'
	TextStyle looseFontsFromFamily: 'Accujen'
	TextStyle actualTextStyles keys collect: [ :k | TextStyle looseFontsFromFamily: k ]
	"

	| looseFonts realStyle classes |
	realStyle := TextStyle named: familyName.
	classes := ((realStyle fontArray copyWithout: nil) collect: [ :f | f class ]) asSet.
	classes do: [ :cls | cls allSubInstancesDo: [ :f | f releaseCachedState ]].
	Smalltalk garbageCollect.
	looseFonts := IdentitySet new.
	classes do: [ :cls |
		looseFonts addAll: ((cls allSubInstances select: [ :ea | ea familyName = familyName ])
			reject: [ :f | realStyle fontArray anySatisfy: [ :fn | fn == f or: [ fn derivativeFonts includes: f ] ]]) ].
	^looseFonts! !

!TextStyle class methodsFor: 'constants' stamp: 'nk 7/3/2003 19:11'!
named: familyName
	"Answer the TextStyle with the given name, or nil."
	"TextStyle named: 'NewYork'"
	| textStyle |
	textStyle := TextConstants at: familyName ifAbsent: [ ^nil ].
	(textStyle isKindOf: self) ifFalse: [ ^nil ].
	^textStyle! !

!TextStyle class methodsFor: 'instance creation' stamp: ''!
new
	^ super new leading: 2! !

!TextStyle class methodsFor: 'utilities' stamp: 'nk 4/2/2004 11:26'!
pixelsPerInch
	"Answer the nominal resolution of the screen."

	^TextConstants at: #pixelsPerInch ifAbsentPut: [ 96.0 ].! !

!TextStyle class methodsFor: 'utilities' stamp: 'nk 4/2/2004 11:24'!
pixelsPerInch: aNumber
	"Set the nominal number of pixels per inch to aNumber."
	TextConstants at: #pixelsPerInch put: aNumber asFloat.
	AbstractFont allSubInstancesDo: [ :font | font pixelsPerInchChanged ].! !

!TextStyle class methodsFor: 'utilities' stamp: 'nk 4/2/2004 11:23'!
pixelsToPoints: pixels
	^pixels * 72.0 / self pixelsPerInch! !

!TextStyle class methodsFor: 'TextConstants access' stamp: 'nk 7/3/2003 19:11'!
pointSizesFor: aName
	"Answer all the point sizes for the given text style name"

	"TextStyle pointSizesFor: 'NewYork'"
	^ (self fontArrayForStyle: aName) collect: [:f | f pointSize]
! !

!TextStyle class methodsFor: 'utilities' stamp: 'nk 4/2/2004 11:22'!
pointsToPixels: points
	^points * self pixelsPerInch / 72.0! !

!TextStyle class methodsFor: 'mime file in/out' stamp: 'ar 9/5/2010 09:02'!
replaceFontsIn: oldFontArray with: newStyle
	"
	TextStyle replaceFontsIn: (TextStyle looseFontsFromFamily: #Accuny) with: (TextStyle named: #Accuny)
	"
	"Try to find corresponding fonts in newStyle and substitute them for the fonts in oldFontArray"

	newStyle fontArray do: [ :newFont | newFont releaseCachedState ].

	oldFontArray do: [ :oldFont | | newFont |
		oldFont reset.
		newFont := (newStyle fontOfPointSize: oldFont pointSize) emphasis: oldFont emphasis.
		oldFont becomeForward: newFont ].

	Smalltalk at: #StringMorph ifPresent:[:cls| cls allSubInstancesDo: [ :s | s layoutChanged]].
	Smalltalk at: #TextMorph ifPresent:[:cls| cls allSubInstancesDo: [ :s | s layoutChanged]].
	Smalltalk at: #SystemWindow ifPresent:[:cls| 
		cls allInstancesDo: [ :w | [ w update: #relabel ] on: Error do: [ :ex | ] ]].
	World ifNotNil: [ :w | w changed ].! !

!TextStyle class methodsFor: 'mime file in/out' stamp: 'nk 9/1/2004 11:03'!
replaceStyle: oldStyle with: newStyle
	"
	TextStyle replaceStyle: (TextStyle named: #AccunyOLD) with: (TextStyle named: #Accuny)
	"
	"Try to find corresponding fonts in newStyle and substitute the fonts in oldStyle for them."
	| oldKeys |
	oldKeys := Set new.
	TextConstants keysAndValuesDo: [ :k :v | v = oldStyle ifTrue: [ oldKeys add: k ]].
	oldKeys removeAllFoundIn: self defaultFamilyNames.

	self replaceFontsIn: oldStyle fontArray with: newStyle.

	oldStyle becomeForward: newStyle.
	oldKeys do: [ :k | TextConstants removeKey: k ].
! !

!TextStyle class methodsFor: 'constants' stamp: 'ar 1/27/2002 20:36'!
setDefault: aTextStyle
	"Answer the system default text style."

	DefaultTextStyle := aTextStyle.! !

!TextStyle class methodsFor: 'class initialization' stamp: 'bf 7/31/2009 18:21'!
styleDecoder
	TextConstants at: #StyleDecoder ifPresent: [ :dict | dict ifNotNil: [ ^dict ]].
	^TextConstants at: #StyleDecoder put: (
		Dictionary new at: 'Regular' put: 0;
				 at: 'Roman' put: 0;
				 at: 'Medium' put: 0;
				 at: 'Light' put: 0;
				 at: 'Normal' put: 0;
				 at: 'Plain' put: 0;
				 at: 'Book' put: 0;
				 at: 'Demi' put: 0;
				 at: 'Demibold' put: 0;
				 at: 'Semibold' put: 0;
				 at: 'SemiBold' put: 0;
				 at: 'ExtraBold' put: 1;
				 at: 'SuperBold' put: 1;
				 at: 'Negreta' put: 1;
				 at: 'B' put: 1;
				 at: 'I' put: 2;
				 at: 'U' put: 4;
				 at: 'X' put: 16;
				 at: 'N' put: 8;
				 at: 'Bold' put: 1;
				 at: 'Italic' put: 2;
				 at: 'Oblique' put: 2;
				 at: 'Narrow' put: 8;
				 at: 'Condensed' put: 8;
				 at: 'Underlined' put: 4;
				 yourself )! !

!TextStyle methodsFor: 'accessing' stamp: ''!
alignment
	"Answer the code for the current setting of the alignment."

	^alignment! !

!TextStyle methodsFor: 'accessing' stamp: 'ar 9/21/2000 15:16'!
alignmentSymbol
	"Answer the symbol for the current setting of the alignment."
	alignment = LeftFlush ifTrue:[^#leftFlush].
	alignment = Centered ifTrue:[^#centered].
	alignment = RightFlush ifTrue:[^#rightFlush].
	alignment = Justified ifTrue:[^#justified].
	^#leftFlush! !

!TextStyle methodsFor: 'accessing' stamp: 'ar 9/21/2000 15:17'!
alignment: anInteger 
	"Set the current setting of the alignment to be anInteger:
	0=left flush, 1=right flush, 2=centered, 3=justified."

	alignment := anInteger \\ (Justified + 1)! !

!TextStyle methodsFor: 'accessing' stamp: 'topa 6/1/2016 20:22'!
asStringOrText
	"be fancy"
	^ self defaultFont familyName asText
		addAttribute: (TextFontReference toFont: self defaultFont);
		yourself! !

!TextStyle methodsFor: 'accessing' stamp: ''!
baseline
	"Answer the distance from the top of the line to the bottom of most of the 
	characters (by convention, bottom of the letter 'A')."

	^baseline! !

!TextStyle methodsFor: 'accessing' stamp: ''!
baseline: anInteger 
	"Set the distance from the top of the line to the bottom of most of the 
	characters."

	baseline := anInteger! !

!TextStyle methodsFor: 'accessing' stamp: ''!
centered
	alignment := 2! !

!TextStyle methodsFor: 'tabs and margins' stamp: ''!
clearIndents
	"Reset all the margin (index) settings to be 0."

	self firstIndent: 0.
	self restIndent: 0.
	self rightIndent: 0! !

!TextStyle methodsFor: 'fonts and font indexes' stamp: 'nice 12/27/2009 03:11'!
collectionFromFileNamed: fileName
	"Read the file.  It is an TextStyle whose StrikeFonts are to be added to the system.  (Written by fooling SmartRefStream, so it won't write a DiskProxy!!)  These fonts will be added to the master TextSytle for this font family.  
	To write out fonts: 
		| ff | ff := ReferenceStream fileNamed: 'new fonts'.
		TextConstants at: #forceFontWriting put: true.
		ff nextPut: (TextConstants at: #AFontName).
			'do not mix font families in the TextStyle written out'.
		TextConstants at: #forceFontWriting put: false.
		ff close.

	To read: (TextStyle default collectionFromFileNamed: 'new fonts')
*** Do not remove this method *** "

	| ff this newName style |
	ff := ReferenceStream fileNamed: fileName.
	this := ff nextAndClose.	"Only works if file created by special code above"
	newName := this fontArray first familyName.
	this fontArray do: [:aFont | aFont familyName = newName ifFalse: [
		self error: 'All must be same family']].
	style := TextConstants at: newName asSymbol ifAbsent: [
		^ TextConstants at: newName asSymbol put: this].		"new family"
	this fontArray do: [:aFont | | heights | "add new fonts"
		heights := style fontArray collect: [:bFont | bFont height].
		(heights includes: aFont height) ifFalse: [
			style fontAt: style fontArray size + 1 put: aFont]].
! !

!TextStyle methodsFor: 'mime file in/out' stamp: 'nice 7/17/2014 23:41:04.734'!
compressedMIMEEncoded
	"Answer a String with my compressed, stored representation as Base64"

	| s ff |
	self fontArray do: [:f | f releaseCachedState].
	s := RWBinaryOrTextStream on: ''.
	ff := SmartRefStream on: s reset.
	TextConstants at: #forceFontWriting put: true.
	[ff nextPut: self] 
		ensure: [TextConstants at: #forceFontWriting put: false].
	^s contents asByteArray zipped base64Encoded! !

!TextStyle methodsFor: 'fonts and font indexes' stamp: 'sw 12/8/1999 18:02'!
consistOnlyOf: aFont
	fontArray := Array with: aFont.
	defaultFontIndex := 1! !

!TextStyle methodsFor: 'private' stamp: ''!
consolidate
	"If this style includes any fonts that are also in the default style,
	then replace them with references to the default ones."
"
	TextStyle allInstancesDo: [:s | s == TextStyle default ifFalse: [s consolidate]]
"
	| defFonts font |
	defFonts := TextStyle default fontArray.
	1 to: fontArray size do:
		[:i | font := fontArray at: i.
		1 to: defFonts size do:
			[:j | (font name asUppercase copyWithout: $ )
			= ((defFonts at: j) name asUppercase copyWithout: $ )
			ifTrue: [fontArray at: i put: (defFonts at: j)]]]! !

!TextStyle methodsFor: 'accessing' stamp: 'sw 12/6/1999 12:31'!
defaultFont
	^ fontArray at: self defaultFontIndex! !

!TextStyle methodsFor: 'default font' stamp: 'sw 12/6/1999 12:30'!
defaultFontIndex
	^ defaultFontIndex ifNil: [defaultFontIndex := 1]! !

!TextStyle methodsFor: 'default font' stamp: 'sw 12/6/1999 13:50'!
defaultFontIndex: anIndex
	defaultFontIndex := anIndex! !

!TextStyle methodsFor: 'accessing' stamp: ''!
firstIndent
	"Answer the horizontal indenting of the first line of a paragraph in the 
	style of the receiver."

	^firstIndent! !

!TextStyle methodsFor: 'accessing' stamp: ''!
firstIndent: anInteger 
	"Set the horizontal indenting of the first line of a paragraph in the style 
	of the receiver to be the argument, anInteger."

	firstIndent := anInteger! !

!TextStyle methodsFor: 'fonts and font indexes' stamp: ''!
flushFonts
	"Clean out the fonts, an aid when snapshotting claims too many are 
	holding onto Display."

	(self confirm: 
'flushFonts is very dangerous.
Are you foolish or clever enough to proceed?')
		ifTrue: [1 to: fontArray size do: [:index | fontArray at: index put: nil]]
		ifFalse: [Transcript cr; show: 'flushFonts cancelled']

	"TextStyle default flushFonts"! !

!TextStyle methodsFor: 'private' stamp: ''!
fontArray
	"Only for writing out fonts, etc.  8/16/96 tk"
	^ fontArray! !

!TextStyle methodsFor: 'private' stamp: 'di 3/20/1999 22:31'!
fontAt: index 
	"This is private because no object outside TextStyle should depend on the 
	representation of the font family in fontArray."

	^ fontArray atPin: index! !

!TextStyle methodsFor: 'private' stamp: ''!
fontAt: index put: font
	"Automatically grow the array.  8/20/96 tk"
	index > fontArray size ifTrue: [
		fontArray := fontArray, (Array new: index - fontArray size)].
	fontArray at: index put: font! !

!TextStyle methodsFor: 'fonts and font indexes' stamp: 'nk 6/12/2004 16:31'!
fontIndexOfPointSize: desiredPointSize
	"Returns an index in fontArray of the font with pointSize <= desiredPointSize"
	"Leading is not inluded in the comparison"
	| bestMatch bestIndex d |
	bestMatch := 9999.  bestIndex := 1.
	1 to: fontArray size do:
		[:i | d := desiredPointSize - (fontArray at: i) pointSize.
		d = 0 ifTrue: [^ i].
		(d > 0 and: [d < bestMatch]) ifTrue: [bestIndex := i. bestMatch := d]].
	^ bestIndex! !

!TextStyle methodsFor: 'fonts and font indexes' stamp: 'di 10/11/97 09:23'!
fontIndexOfSize: desiredHeight
	"Returns an index in fontArray of the font with height <= desiredHeight"
	"Leading is not inluded in the comparison"
	| bestMatch bestIndex d |
	bestMatch := 9999.  bestIndex := 1.
	1 to: fontArray size do:
		[:i | d := desiredHeight - (fontArray at: i) height.
		d = 0 ifTrue: [^ i].
		(d > 0 and: [d < bestMatch]) ifTrue: [bestIndex := i. bestMatch := d]].
	^ bestIndex! !

!TextStyle methodsFor: 'fonts and font indexes' stamp: 'sw 12/6/1999 13:54'!
fontIndexOf: aFont
	^ fontArray indexOf: aFont ifAbsent: [nil]! !

!TextStyle methodsFor: 'accessing' stamp: ''!
fontNamed: fontName  "TextStyle default fontNamed: 'TimesRoman10'"
	^ fontArray detect: [:x | x name sameAs: fontName]! !

!TextStyle methodsFor: 'accessing' stamp: ''!
fontNames  "TextStyle default fontNames"
	^ fontArray collect: [:x | x name]! !

!TextStyle methodsFor: 'accessing' stamp: 'tk 6/26/1998 15:03'!
fontNamesAndSizes  "TextStyle default fontNames"
	^ fontArray collect: [:x | x name, ' ', x height printString]! !

!TextStyle methodsFor: 'accessing' stamp: 'ar 9/21/2000 11:53'!
fontNamesWithPointSizes
	^ fontArray collect:
		[:x | x fontNameWithPointSize]

  "TextStyle default fontNamesWithPointSizes"! !

!TextStyle methodsFor: 'fonts and font indexes' stamp: 'nk 6/12/2004 16:33'!
fontOfPointSize: aPointSize
	^ fontArray at: (self fontIndexOfPointSize: aPointSize)! !

!TextStyle methodsFor: 'fonts and font indexes' stamp: 'di 10/11/97 09:33'!
fontOfSize: aHeight
	"See fontIndexOfSize.
	Returns the actual font.  Leading not considered."

	^ fontArray at: (self fontIndexOfSize: aHeight)! !

!TextStyle methodsFor: 'accessing' stamp: 'ar 12/16/2001 16:58'!
fonts
	"Return a collection of fonts contained in this text style"
	^fontArray! !

!TextStyle methodsFor: 'private' stamp: ''!
gridForFont: fontIndex withLead: leadInteger 
	"Force whole style to suit one of its fonts. Assumes only one font referred
	to by runs."
	| font |
	font := self fontAt: fontIndex.
	self lineGrid: font height + leadInteger.
	self baseline: font ascent.
	self leading: leadInteger! !

!TextStyle methodsFor: 'comparing' stamp: 'ar 9/9/2003 22:04'!
hash
	"#hash is re-implemented because #= is re-implemented"
	^fontArray hash
! !

!TextStyle methodsFor: 'accessing' stamp: 'nk 6/25/2003 12:54'!
isTTCStyle

	^ fontArray first isTTCFont.
! !

!TextStyle methodsFor: 'accessing' stamp: ''!
justified
	alignment := 3! !

!TextStyle methodsFor: 'accessing' stamp: ''!
leading
	"Leading (from typographers historical use of extra lead (type metal))
	is the extra spacing above and beyond that needed just to accomodate
	the various font heights in the set."
	^ leading! !

!TextStyle methodsFor: 'accessing' stamp: ''!
leading: yDelta

	leading := yDelta! !

!TextStyle methodsFor: 'accessing' stamp: ''!
leftFlush
	alignment := 0! !

!TextStyle methodsFor: 'tabs and margins' stamp: ''!
leftMarginTabAt: marginIndex 
	"Set the 'nesting' level of left margin indents of the paragraph in the 
	style of the receiver to be the argument, marginIndex."

	(marginIndex > 0 and: [marginIndex < marginTabsArray size])
		ifTrue: [^(marginTabsArray at: marginIndex) at: 1]
		ifFalse: [^0]	
	"The marginTabsArray is an Array of tuples.  The Array is indexed according 
	to the marginIndex, the 'nesting' level of the requestor."
! !

!TextStyle methodsFor: 'accessing' stamp: ''!
lineGrid
	"Answer the relative space between lines of a paragraph in the style of 
	the receiver."

	^lineGrid! !

!TextStyle methodsFor: 'accessing' stamp: ''!
lineGrid: anInteger 
	"Set the relative space between lines of a paragraph in the style of the 
	receiver to be the argument, anInteger."

	lineGrid := anInteger! !

!TextStyle methodsFor: 'make arrows' stamp: 'sps 10/15/2003 17:09'!
makeArrows
"
TextStyle default makeArrows.
"
	fontArray do: [ :font |
		(font isKindOf: StrikeFont) ifTrue:[ 
			font 
				makeAssignArrow; 
				makeReturnArrow.
		]
	].
! !

!TextStyle methodsFor: 'private' stamp: ''!
marginTabAt: marginIndex side: sideIndex 
	"The marginTabsArray is an Array of tuples.  The Array is indexed
	according to the marginIndex, the 'nesting' level of the requestor.
	sideIndex is 1 for left, 2 for right."

	(marginIndex > 0 and: [marginIndex < marginTabsArray size])
		ifTrue: [^(marginTabsArray at: marginIndex) at: sideIndex]
		ifFalse: [^0]! !

!TextStyle methodsFor: 'accessing' stamp: 'mt 5/9/2016 17:00'!
maxDepth

	^ (self fonts collect: [:font | font depth]) max! !

!TextStyle methodsFor: 'private' stamp: 'tk 8/20/96'!
newFontArray: anArray
	"Currently there is no supporting protocol for changing these arrays. If an editor wishes to implement margin setting, then a copy of the default should be stored with these instance variables.  
	, Make size depend on first font."

	fontArray := anArray.
	lineGrid := (fontArray at: 1) height + leading.	"For whole family"
	baseline := (fontArray at: 1) ascent + leading.
	alignment := 0.
	firstIndent := 0.
	restIndent := 0.
	rightIndent := 0.
	tabsArray := DefaultTabsArray.
	marginTabsArray := DefaultMarginTabsArray
"
TextStyle allInstancesDo: [:ts | ts newFontArray: TextStyle default fontArray].
"! !

!TextStyle methodsFor: 'tabs and margins' stamp: ''!
nextTabXFrom: anX leftMargin: leftMargin rightMargin: rightMargin 
	"Tab stops are distances from the left margin. Set the distance into the 
	argument, anX, normalized for the paragraph's left margin."

	| normalizedX tabX |
	normalizedX := anX - leftMargin.
	1 to: tabsArray size do: 
		[:i | (tabX := tabsArray at: i) > normalizedX 
				ifTrue: [^leftMargin + tabX min: rightMargin]].
	^rightMargin! !

!TextStyle methodsFor: 'accessing' stamp: 'ar 12/16/2001 16:43'!
pointSizes
	^ fontArray collect:
		[:x | x pointSize]

  "TextStyle default fontNamesWithPointSizes"! !

!TextStyle methodsFor: 'accessing' stamp: 'nice 10/12/2013 02:12'!
printOn: aStream

	super printOn: aStream.
	self defaultFont printShortDescriptionOn: aStream
! !

!TextStyle methodsFor: 'accessing' stamp: ''!
restIndent
	"Answer the indent for all but the first line of a paragraph in the style 
	of the receiver."

	^restIndent! !

!TextStyle methodsFor: 'accessing' stamp: ''!
restIndent: anInteger 
	"Set the indent for all but the first line of a paragraph in the style of the 
	receiver to be the argument, anInteger."

	restIndent := anInteger! !

!TextStyle methodsFor: 'accessing' stamp: ''!
rightFlush
	alignment := 1! !

!TextStyle methodsFor: 'accessing' stamp: ''!
rightIndent
	"Answer the right margin indent for the lines of a paragraph in the style 
	of the receiver."

	^rightIndent! !

!TextStyle methodsFor: 'accessing' stamp: ''!
rightIndent: anInteger 
	"Answer the right margin indent for the lines of a paragraph in the style 
	of the receiver to be the argument, anInteger."

	rightIndent := anInteger! !

!TextStyle methodsFor: 'tabs and margins' stamp: ''!
rightMarginTabAt: marginIndex 
	"Set the 'nesting' level of right margin indents of the paragraph in the 
	style of the receiver to be marginIndex."

	(marginIndex > 0 and: [marginIndex < marginTabsArray size])
		ifTrue: [^(marginTabsArray at: marginIndex) at: 2]
		ifFalse: [^0]
	"The marginTabsArray is an Array of tuples.  The Array is indexed according 
	to the marginIndex, the 'nesting' level of the requestor."
! !

!TextStyle methodsFor: 'comparing' stamp: 'tk 7/5/2001 22:18'!
species

	^TextStyle! !

!TextStyle methodsFor: 'Disk I/O' stamp: 'tk 9/25/2000 10:10'!
storeDataOn: aDataStream
	"The shared arrays in tabsArray and marginTabsArray are the globals DefaultTabsArray and DefaultMarginTabsArray.  DiskProxies will be substituted for these in (Array objectForDataStream:)."

	^ super storeDataOn: aDataStream! !

!TextStyle methodsFor: 'tabs and margins' stamp: ''!
tabWidth
	"Answer the width of a tab."

	^DefaultTab! !

!TextStyle methodsFor: 'Disk I/O' stamp: 'nice 1/12/2010 20:24'!
veryDeepCopyWith: deepCopier
	"All inst vars are meant to be shared"

	self == #veryDeepCopyWith:.	"to satisfy checkVariables"
	^ deepCopier references at: self ifAbsentPut: [self clone].	"remember"! !

!TextStyle methodsFor: 'comparing' stamp: 'tk 7/5/2001 22:18'!
= other

	self species == other species ifFalse: [^ false].
	1 to: self class instSize do:
		[:i | (self instVarAt: i) == (other instVarAt: i) ifFalse: [^ false]].
	^ true! !

!WideString methodsFor: '*Graphics-Text' stamp: 'tpr 10/2/2013 17:28'!
scanCharactersFrom: startIndex to: stopIndex with: aCharacterScanner rightX: rightX  font: aFont
	"NB: strongly consider getting almost all these parameters from the scanner"
	"Since I'm a wide char string, I know that we have to scan multi-byte characters and handle encodings etc"
	| charSet |
	startIndex > stopIndex
		ifTrue: [^aCharacterScanner handleEndOfRunAt: stopIndex].
	charSet := self encodedCharSetAt: startIndex.
	^charSet scanMultibyteCharactersFrom: startIndex to: stopIndex in: self with: aCharacterScanner rightX: rightX font: aFont	! !

ArrayedCollection variableWordSubclass: #Bitmap
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Primitives'!

!Bitmap commentStamp: '<historical>' prior: 0!
My instances provide contiguous storage of bits, primarily to hold the graphical data of Forms. Forms and their subclasses provide the additional structural information as to how the bits should be interpreted in two dimensions.!

!Bitmap class methodsFor: 'instance creation' stamp: 'di 2/9/98 16:02'!
decodeIntFrom: s
	"Decode an integer in stream s as follows...
		0-223	0-223
		224-254	(0-30)*256 + next byte (0-7935)
		255		next 4 bytes	"		
	| int |
	int := s next.
	int <= 223 ifTrue: [^ int].
	int <= 254 ifTrue: [^ (int-224)*256 + s next].
	int := s next.
	1 to: 3 do: [:j | int := (int bitShift: 8) + s next].
	^ int! !

!Bitmap class methodsFor: 'instance creation' stamp: 'di 2/12/98 14:34'!
decompressFromByteArray: byteArray
	| s bitmap size |
	s := ReadStream on: byteArray.
	size := self decodeIntFrom: s.
	bitmap := self new: size.
	bitmap decompress: bitmap fromByteArray: byteArray at: s position+1.
	^ bitmap! !

!Bitmap class methodsFor: 'instance creation' stamp: 'ar 12/23/1999 14:35'!
newFromStream: s
	| len |
	s next = 16r80 ifTrue:
		["New compressed format"
		len := self decodeIntFrom: s.
		^ Bitmap decompressFromByteArray: (s nextInto: (ByteArray new: len))].
	s skip: -1.
	len := s nextInt32.
	len <= 0
		ifTrue: ["Old compressed format"
				^ (self new: len negated) readCompressedFrom: s]
		ifFalse: ["Old raw data format"
				^ s nextWordsInto: (self new: len)]! !

!Bitmap class methodsFor: 'utilities' stamp: 'sd 6/28/2003 09:33'!
swapBytesIn: aNonPointerThing from: start to: stop
	"Perform a bigEndian/littleEndian byte reversal of my words.
	We only intend this for non-pointer arrays.  Do nothing if I contain pointers."
	| hack blt |
	"The implementation is a hack, but fast for large ranges"
	hack := Form new hackBits: aNonPointerThing.
	blt := (BitBlt toForm: hack) sourceForm: hack.
	blt combinationRule: Form reverse.  "XOR"
	blt sourceY: start-1; destY: start-1; height: stop-start+1; width: 1.
	blt sourceX: 0; destX: 3; copyBits.  "Exchange bytes 0 and 3"
	blt sourceX: 3; destX: 0; copyBits.
	blt sourceX: 0; destX: 3; copyBits.
	blt sourceX: 1; destX: 2; copyBits.  "Exchange bytes 1 and 2"
	blt sourceX: 2; destX: 1; copyBits.
	blt sourceX: 1; destX: 2; copyBits.
! !

!Bitmap methodsFor: 'converting' stamp: 'fbs 7/25/2013 07:07'!
asByteArray
	"Faster way to make a byte array from me.
	copyFromByteArray: makes equal Bitmap."
	| f bytes hack |
	f := Form extent: 4@self size depth: 8 bits: self.
	bytes := ByteArray new: self size * 4.
	hack := Form new hackBits: bytes.
	Smalltalk isLittleEndian ifTrue:[hack swapEndianness].
	hack copyBits: f boundingBox
		from: f
		at: (0@0)
		clippingBox: hack boundingBox
		rule: Form over
		fillColor: nil
		map: nil.

	"f displayOn: hack."
	^ bytes.
! !

!Bitmap methodsFor: 'accessing' stamp: 'ar 3/3/2001 16:11'!
atAllPut: value
	"Fill the receiver, an indexable bytes or words object, with the given positive integer. The range of possible fill values is [0..255] for byte arrays and [0..(2^32 - 1)] for word arrays."
	<primitive: 145>
	super atAllPut: value.! !

!Bitmap methodsFor: 'accessing' stamp: ''!
bitPatternForDepth: depth
	"The raw call on BitBlt needs a Bitmap to represent this color.  I already am Bitmap like.  I am already adjusted for a specific depth.  Interpret me as an array of (32/depth) Color pixelValues.  BitBlt aligns the first element of this array with the top scanline of the destinationForm, the second with the second, and so on, cycling through the color array as necessary. 6/18/96 tk"

	^ self! !

!Bitmap methodsFor: 'accessing' stamp: ''!
byteAt: byteAddress
	"Extract a byte from a Bitmap.  Note that this is a byte address and it is one-order.  For repeated use, create an instance of BitBlt and use pixelAt:.  See Form pixelAt:  7/1/96 tk"
	| lowBits |
	lowBits := byteAddress - 1 bitAnd: 3.
	^((self at: byteAddress - 1 - lowBits // 4 + 1)
		bitShift: (lowBits - 3) * 8)
		bitAnd: 16rFF! !

!Bitmap methodsFor: 'accessing' stamp: 'ar 9/21/2001 23:06'!
byteAt: byteAddress put: byte
	"Insert a byte into a Bitmap.  Note that this is a byte address and it is one-order.  For repeated use, create an instance of BitBlt and use pixelAt:put:.  See Form pixelAt:put:  7/1/96 tk"
	| longWord shift lowBits longAddr |
	(byte < 0 or:[byte > 255]) ifTrue:[^self errorImproperStore].
	lowBits := byteAddress - 1 bitAnd: 3.
	longWord := self at: (longAddr := (byteAddress - 1 - lowBits) // 4 + 1).
	shift := (3 - lowBits) * 8.
	longWord := longWord - (longWord bitAnd: (16rFF bitShift: shift)) 
		+ (byte bitShift: shift).
	self at: longAddr put: longWord.
	^ byte! !

!Bitmap methodsFor: 'accessing' stamp: 'ar 3/3/2001 16:18'!
byteSize
	^self size * 4! !

!Bitmap methodsFor: 'filing' stamp: 'nice 7/22/2014 23:18'!
compressGZip
	| ba hackwa hackba blt rowsAtATime sourceOrigin rowsRemaining bufferStream gZipStream |

"just hacking around to see if further compression would help Nebraska"

	bufferStream := WriteStream on: (ByteArray new: 5000).
	gZipStream := GZipWriteStream on: bufferStream.

	ba := nil.
	rowsAtATime := 20000.		"or 80000 bytes"
	hackwa := Form new hackBits: self.
	sourceOrigin := 0@0.
	[(rowsRemaining := hackwa height - sourceOrigin y) > 0] whileTrue: [
		rowsAtATime := rowsAtATime min: rowsRemaining.
		(ba isNil or: [ba size ~= (rowsAtATime * 4)]) ifTrue: [
			ba := ByteArray new: rowsAtATime * 4.
			hackba := Form new hackBits: ba.
			blt := (BitBlt toForm: hackba) sourceForm: hackwa.
		].
		blt 
			combinationRule: Form over;
			sourceOrigin: sourceOrigin;
			destX: 0 destY: 0 width: 4 height: rowsAtATime;
			copyBits.
		"bufferStream nextPutAll: ba."
		sourceOrigin := sourceOrigin x @ (sourceOrigin y + rowsAtATime).
	].
	gZipStream close.
	^bufferStream contents
! !

!Bitmap methodsFor: 'filing' stamp: 'di 8/5/1998 11:31'!
compressToByteArray
	"Return a run-coded compression of this bitmap into a byteArray"		
	| byteArray lastByte |
	"Without skip codes, it is unlikely that the compressed bitmap will be any larger than was the original.  The run-code cases are...
	N >= 1 words of equal bytes:  4N bytes -> 2 bytes (at worst 4 -> 2)
	N > 1 equal words:  4N bytes -> 5 bytes (at worst 8 -> 5)
	N > 1 unequal words:  4N bytes -> 4N + M, where M is the number of bytes required to encode the run length.

The worst that can happen is that the method begins with unequal words, and than has interspersed occurrences of a word with equal bytes.  Thus we require a run-length at the beginning, and after every interspersed word of equal bytes.  However, each of these saves 2 bytes, so it must be followed by a run of 1984 (7936//4) or more (for which M jumps from 2 to 5) to add any extra overhead.  Therefore the worst case is a series of runs of 1984 or more, with single interspersed words of equal bytes.  At each break we save 2 bytes, but add 5.  Thus the overhead would be no more than 5 (encoded size) + 2 (first run len) + (S//1984*3)."
	
"NOTE: This code is copied in Form hibernate for reasons given there."
	byteArray := ByteArray new: (self size*4) + 7 + (self size//1984*3).
	lastByte := self compress: self toByteArray: byteArray.
	^ byteArray copyFrom: 1 to: lastByte! !

!Bitmap methodsFor: 'filing' stamp: 'dtl 10/24/2010 12:47'!
compress: bm toByteArray: ba
	"Store a run-coded compression of the receiver into the byteArray ba,
	and return the last index stored into. ba is assumed to be large enough.
	The encoding is as follows...
		S {N D}*.
		S is the size of the original bitmap, followed by run-coded pairs.
		N is a run-length * 4 + data code.
		D, the data, depends on the data code...
			0	skip N words, D is absent
			1	N words with all 4 bytes = D (1 byte)
			2	N words all = D (4 bytes)
			3	N words follow in D (4N bytes)
		S and N are encoded as follows...
			0-223	0-223
			224-254	(0-30)*256 + next byte (0-7935)
			255		next 4 bytes"		
	| size k word j lowByte eqBytes i |
	<primitive: 'primitiveCompressToByteArray' module: 'MiscPrimitivePlugin'>
	<var: #bm declareC: 'int *bm'>
	<var: #ba declareC: 'unsigned char *ba'>
	size := bm size.
	i := self encodeInt: size in: ba at: 1.
	k := 1.
	[k <= size] whileTrue:
		[word := bm at: k.
		lowByte := word bitAnd: 16rFF.
		eqBytes := ((word >> 8) bitAnd: 16rFF) = lowByte
				and: [((word >> 16) bitAnd: 16rFF) = lowByte
				and: [((word >> 24) bitAnd: 16rFF) = lowByte]].
		j := k.
		[j < size and: [word = (bm at: j+1)]]  "scan for = words..."
			whileTrue: [j := j+1].
		j > k ifTrue:
			["We have two or more = words, ending at j"
			eqBytes
				ifTrue: ["Actually words of = bytes"
						i := self encodeInt: j-k+1*4+1 in: ba at: i.
						ba at: i put: lowByte.  i := i+1]
				ifFalse: [i := self encodeInt: j-k+1*4+2 in: ba at: i.
						i := self encodeBytesOf: word in: ba at: i].
			k := j+1]
			ifFalse:
			["Check for word of 4 = bytes"
			eqBytes ifTrue:
				["Note 1 word of 4 = bytes"
				i := self encodeInt: 1*4+1 in: ba at: i.
				ba at: i put: lowByte.  i := i+1.
				k := k + 1]
				ifFalse:
				["Finally, check for junk"
				[j < size and: [(bm at: j) ~= (bm at: j+1)]]  "scan for ~= words..."
					whileTrue: [j := j+1].
				j = size ifTrue: [j := j + 1].
				"We have one or more unmatching words, ending at j-1"
				i := self encodeInt: j-k*4+3 in: ba at: i.
				k to: j-1 do:
					[:m | i := self encodeBytesOf: (bm at: m) in: ba at: i].
				k := j]]].
	^ i - 1  "number of bytes actually stored"
"
Space check:
 | n rawBytes myBytes b |
n := rawBytes := myBytes := 0.
Form allInstancesDo:
	[:f | f unhibernate.
	b := f bits.
	n := n + 1.
	rawBytes := rawBytes + (b size*4).
	myBytes := myBytes + (b compressToByteArray size).
	f hibernate].
Array with: n with: rawBytes with: myBytes
ColorForms: (116 230324 160318 )
Forms: (113 1887808 1325055 )

Integerity check:
Form allInstances do:
	[:f | f unhibernate.
	f bits = (Bitmap decompressFromByteArray: f bits compressToByteArray)
		ifFalse: [self halt].
	f hibernate]

Speed test:
MessageTally spyOn: [Form allInstances do:
	[:f | Bitmap decompressFromByteArray: f bits compressToByteArray]]
"! !

!Bitmap methodsFor: 'copying' stamp: 'RAA 7/28/2000 21:51'!
copy

	^self clone! !

!Bitmap methodsFor: 'accessing' stamp: 'fbs 7/25/2013 07:07'!
copyFromByteArray: byteArray 
	"This method should work with either byte orderings"

	| myHack byteHack |
	myHack := Form new hackBits: self.
	byteHack := Form new hackBits: byteArray.
	Smalltalk  isLittleEndian ifTrue: [byteHack swapEndianness].
	byteHack displayOn: myHack! !

!Bitmap methodsFor: 'filing' stamp: 'dtl 10/24/2010 12:46'!
decompress: bm fromByteArray: ba at: index
	"Decompress the body of a byteArray encoded by compressToByteArray (qv)...
	The format is simply a sequence of run-coded pairs, {N D}*.
		N is a run-length * 4 + data code.
		D, the data, depends on the data code...
			0	skip N words, D is absent
				(could be used to skip from one raster line to the next)
			1	N words with all 4 bytes = D (1 byte)
			2	N words all = D (4 bytes)
			3	N words follow in D (4N bytes)
		S and N are encoded as follows (see decodeIntFrom:)...
			0-223	0-223
			224-254	(0-30)*256 + next byte (0-7935)
			255		next 4 bytes"	
	"NOTE:  If fed with garbage, this routine could read past the end of ba, but it should fail before writing past the ned of bm."
	| i code n anInt data end k pastEnd |
	<primitive: 'primitiveDecompressFromByteArray' module: 'MiscPrimitivePlugin'>
	<var: #bm declareC: 'int *bm'>
	<var: #ba declareC: 'unsigned char *ba'>
	i := index.  "byteArray read index"
	end := ba size.
	k := 1.  "bitmap write index"
	pastEnd := bm size + 1.
	[i <= end] whileTrue:
		["Decode next run start N"
		anInt := ba at: i.  i := i+1.
		anInt <= 223 ifFalse:
			[anInt <= 254
				ifTrue: [anInt := (anInt-224)*256 + (ba at: i).  i := i+1]
				ifFalse: [anInt := 0.
						1 to: 4 do: [:j | anInt := (anInt bitShift: 8) + (ba at: i).  i := i+1]]].
		n := anInt >> 2.
		(k + n) > pastEnd ifTrue: [^ self primitiveFail].
		code := anInt bitAnd: 3.
		code = 0 ifTrue: ["skip"].
		code = 1 ifTrue: ["n consecutive words of 4 bytes = the following byte"
						data := ba at: i.  i := i+1.
						data := data bitOr: (data bitShift: 8).
						data := data bitOr: (data bitShift: 16).
						1 to: n do: [:j | bm at: k put: data.  k := k+1]].
		code = 2 ifTrue: ["n consecutive words = 4 following bytes"
						data := 0.
						1 to: 4 do: [:j | data := (data bitShift: 8) bitOr: (ba at: i).  i := i+1].
						1 to: n do: [:j | bm at: k put: data.  k := k+1]].
		code = 3 ifTrue: ["n consecutive words from the data..."
						1 to: n do:
							[:m | data := 0.
							1 to: 4 do: [:j | data := (data bitShift: 8) bitOr: (ba at: i).  i := i+1].
							bm at: k put: data.  k := k+1]]]! !

!Bitmap methodsFor: 'accessing' stamp: 'ar 11/2/1998 12:19'!
defaultElement
	"Return the default element of the receiver"
	^0! !

!Bitmap methodsFor: 'filing' stamp: 'dtl 10/24/2010 12:47'!
encodeBytesOf: anInt in: ba at: i
	"Copy the integer anInt into byteArray ba at index i, and return the next index"

	<inline: true>
	<var: #ba declareC: 'unsigned char *ba'>
	0 to: 3 do:
		[:j | ba at: i+j put: (anInt >> (3-j*8) bitAnd: 16rFF)].
	^ i+4! !

!Bitmap methodsFor: 'filing' stamp: 'jm 2/12/98 17:32'!
encodeInt: int
	"Encode the integer int as per encodeInt:in:at:, and return it as a ByteArray"
	| byteArray next |
	byteArray := ByteArray new: 5.
	next := self encodeInt: int in: byteArray at: 1.
	^ byteArray copyFrom: 1 to: next - 1
! !

!Bitmap methodsFor: 'filing' stamp: 'dtl 10/24/2010 12:46'!
encodeInt: anInt in: ba at: i
	"Encode the integer anInt in byteArray ba at index i, and return the next index.
	The encoding is as follows...
		0-223	0-223
		224-254	(0-30)*256 + next byte (0-7935)
		255		next 4 bytes"		

	<inline: true>
	<var: #ba declareC: 'unsigned char *ba'>
	anInt <= 223 ifTrue: [ba at: i put: anInt. ^ i+1].
	anInt <= 7935 ifTrue: [ba at: i put: anInt//256+224. ba at: i+1 put: anInt\\256.  ^ i+2].
	ba at: i put: 255.
	^ self encodeBytesOf: anInt in: ba at: i+1! !

!Bitmap methodsFor: 'initialize-release' stamp: 'ar 12/23/1999 14:35'!
fromByteStream: aStream 
	"Initialize the array of bits by reading integers from the argument, 
	aStream."
	aStream nextWordsInto: self! !

!Bitmap methodsFor: 'accessing' stamp: 'ar 3/3/2001 22:41'!
integerAt: index
	"Return the integer at the given index"
	| word |
	<primitive: 165>
	word := self basicAt: index.
	word < 16r3FFFFFFF ifTrue:[^word]. "Avoid LargeInteger computations"
	^word >= 16r80000000	"Negative?!!"
		ifTrue:["word - 16r100000000"
				(word bitInvert32 + 1) negated]
		ifFalse:[word]! !

!Bitmap methodsFor: 'accessing' stamp: 'ar 3/3/2001 22:42'!
integerAt: index put: anInteger
	"Store the integer at the given index"
	| word |
	<primitive: 166>
	anInteger < 0
		ifTrue:["word := 16r100000000 + anInteger"
				word := (anInteger + 1) negated bitInvert32]
		ifFalse:[word := anInteger].
	self  basicAt: index put: word.
	^anInteger! !

!Bitmap methodsFor: 'testing' stamp: 'ar 5/25/2000 19:42'!
isColormap
	"Bitmaps were used as color maps for BitBlt.
	This method allows to recognize real color maps."
	^false! !

!Bitmap methodsFor: 'accessing' stamp: 'tk 3/15/97'!
pixelValueForDepth: depth
	"Self is being used to represent a single color.  Answer bits that appear in ONE pixel of this color in a Bitmap of the given depth. The depth must be one of 1, 2, 4, 8, 16, or 32.  Returns an integer.  First pixel only.  "

	^ (self at: 1) bitAnd: (1 bitShift: depth) - 1! !

!Bitmap methodsFor: 'accessing' stamp: ''!
primFill: aPositiveInteger
	"Fill the receiver, an indexable bytes or words object, with the given positive integer. The range of possible fill values is [0..255] for byte arrays and [0..(2^32 - 1)] for word arrays."

	<primitive: 145>
	self errorImproperStore.! !

!Bitmap methodsFor: 'printing' stamp: 'sma 6/1/2000 09:42'!
printOn: aStream
	self printNameOn: aStream.
	aStream nextPutAll: ' of length '; print: self size! !

!Bitmap methodsFor: 'filing' stamp: 'di 2/11/98 21:34'!
readCompressedFrom: strm
	"Decompress an old-style run-coded stream into this bitmap:
		[0 means end of runs]
		[n = 1..127] [(n+3) copies of next byte]
		[n = 128..191] [(n-127) next bytes as is]
		[n = 192..255] [(n-190) copies of next 4 bytes]"
	| n byte out outBuff bytes |
	out := WriteStream on: (outBuff := ByteArray new: self size*4).
	[(n := strm next) > 0] whileTrue:
		[(n between: 1 and: 127) ifTrue:
			[byte := strm next.
			1 to: n+3 do: [:i | out nextPut: byte]].
		(n between: 128 and: 191) ifTrue:
			[1 to: n-127 do: [:i | out nextPut: strm next]].
		(n between: 192 and: 255) ifTrue:
			[bytes := (1 to: 4) collect: [:i | strm next].
			1 to: n-190 do: [:i | bytes do: [:b | out nextPut: b]]]].
	out position = outBuff size ifFalse: [self error: 'Decompression size error'].
	"Copy the final byteArray into self"
	self copyFromByteArray: outBuff.! !

!Bitmap methodsFor: 'accessing' stamp: ''!
replaceFrom: start to: stop with: replacement startingAt: repStart 
	"Primitive. This destructively replaces elements from start to stop in the receiver starting at index, repStart, in the collection, replacement. Answer the receiver. Range checks are performed in the primitive only. Optional. See Object documentation whatIsAPrimitive."
	<primitive: 105>
	super replaceFrom: start to: stop with: replacement startingAt: repStart! !

!Bitmap methodsFor: 'filing' stamp: 'tk 1/24/2000 22:37'!
restoreEndianness
	"This word object was just read in from a stream.  Bitmaps are always compressed and serialized in a machine-independent way.  Do not correct the Endianness."

	"^ self"
! !

!Bitmap methodsFor: 'filing' stamp: 'nk 12/31/2003 16:02'!
storeBits: startBit to: stopBit on: aStream 
	"Store my bits as a hex string, breaking the lines every 100 bytes or 
	so to comply with the maximum line length limits of Postscript (255 
	bytes). "
	| lineWidth |
	lineWidth := 0.
	self
		do: [:word | 
			startBit
				to: stopBit
				by: -4
				do: [:shift | 
					aStream nextPut: (word >> shift bitAnd: 15) asHexDigit.
					lineWidth := lineWidth + 1].
			(lineWidth > 100)
				ifTrue: [aStream cr.
					lineWidth := 0]].
	lineWidth > 0 ifTrue: [ aStream cr ].! !

!Bitmap methodsFor: 'filing' stamp: 'jm 2/18/98 14:19'!
writeOn: aStream 
	"Store the array of bits onto the argument, aStream. A leading byte of 16r80 identifies this as compressed by compressToByteArray (qv)."

	| b |
	aStream nextPut: 16r80.
	b := self compressToByteArray.
	aStream
		nextPutAll: (self encodeInt: b size);
		nextPutAll: b.
! !

!Bitmap methodsFor: 'filing' stamp: 'tk 2/19/1999 07:36'!
writeUncompressedOn: aStream 
	"Store the array of bits onto the argument, aStream.
	(leading byte ~= 16r80) identifies this as raw bits (uncompressed)."

	aStream nextInt32Put: self size.
	aStream nextPutAll: self
! !

!EventSensor methodsFor: '*Graphics-KernelExtensions' stamp: 'BG 3/16/2005 08:23'!
testJoystick: index
	"Sensor testJoystick: 3"

	| f pt buttons status |
	f := Form extent: 110@50.
	[Sensor anyButtonPressed] whileFalse: [
		pt := Sensor joystickXY: index.
		buttons := Sensor joystickButtons: index.
		status :=
'xy: ', pt printString, '
buttons: ', buttons printStringHex.
		f fillWhite.
		status displayOn: f at: 10@10.
		f displayOn: Display at: 10@10.
	].
! !

!SmartRefStream methodsFor: '*Graphics-conversion' stamp: 'tk 1/14/1999 13:16'!
transparentColorrcc0
	^ TranslucentColor! !

ReadStream subclass: #JPEGReadStream
	instanceVariableNames: 'bitBuffer bitsInBuffer'
	classVariableNames: 'MaxBits'
	poolDictionaries: ''
	category: 'Graphics-Files'!

!JPEGReadStream commentStamp: '<historical>' prior: 0!
Encapsulates huffman encoded access to JPEG data.

The following layout is fixed for the JPEG primitives to work:

	collection	<ByteArray | String>
	position		<SmallInteger>
	readLimit	<SmallInteger>
	bitBuffer	<SmallInteger>
	bitsInBuffer	<SmallInteger>!

!JPEGReadStream class methodsFor: 'class initialization' stamp: 'ar 3/4/2001 18:32'!
initialize
	"JPEGReadStream initialize"
	MaxBits := 16.! !

!JPEGReadStream methodsFor: 'huffman trees' stamp: 'ar 3/4/2001 21:06'!
buildLookupTable: values counts: counts
	| min max |
	min := max := nil.
	1 to: counts size do:[:i|
		(counts at: i) = 0 ifFalse:[
			min ifNil:[min := i-1].
			max := i]].
	^self
		createHuffmanTables: values 
		counts: {0},counts 
		from: min+1 
		to: max.! !

!JPEGReadStream methodsFor: 'huffman trees' stamp: 'ar 3/4/2001 18:46'!
createHuffmanTables: values counts: counts from: minBits to: maxBits
	"Create the actual tables"
	| table tableStart tableSize tableEnd 
	valueIndex tableStack numValues deltaBits maxEntries
	lastTable lastTableStart tableIndex lastTableIndex |

	table := WordArray new: ((4 bitShift: minBits) max: 16).

	"Create the first entry - this is a dummy.
	It gives us information about how many bits to fetch initially."
	table at: 1 put: (minBits bitShift: 24) + 2. "First actual table starts at index 2"

	"Create the first table from scratch."
	tableStart := 2. "See above"
	tableSize := 1 bitShift: minBits.
	tableEnd := tableStart + tableSize.
	"Store the terminal symbols"
	valueIndex := (counts at: minBits+1).
	tableIndex := 0.
	1 to: valueIndex do:[:i|
		table at: tableStart + tableIndex put: (values at: i).
		tableIndex := tableIndex + 1].
	"Fill up remaining entries with invalid entries"
	tableStack := OrderedCollection new: 10. "Should be more than enough"
	tableStack addLast: 
		(Array 
			with: minBits	"Number of bits (e.g., depth) for this table"
			with: tableStart	"Start of table"
			with: tableIndex "Next index in table"
			with: minBits	"Number of delta bits encoded in table"
			with: tableSize - valueIndex "Entries remaining in table").
	"Go to next value index"
	valueIndex := valueIndex + 1.
	"Walk over remaining bit lengths and create new subtables"
	minBits+1 to: maxBits do:[:bits|
		numValues := counts at: bits+1.
		[numValues > 0] whileTrue:["Create a new subtable"
			lastTable := tableStack last.
			lastTableStart := lastTable at: 2.
			lastTableIndex := lastTable at: 3.
			deltaBits := bits - (lastTable at: 1).
			"Make up a table of deltaBits size"
			tableSize := 1 bitShift: deltaBits.
			tableStart := tableEnd.
			tableEnd := tableEnd + tableSize.
			[tableEnd > table size ]
				whileTrue:[table := self growHuffmanTable: table].
			"Connect to last table"
			self assert:[(table at: lastTableStart + lastTableIndex) = 0]."Entry must be unused"
			table at: lastTableStart + lastTableIndex put: (deltaBits bitShift: 24) + tableStart.
			lastTable at: 3 put: lastTableIndex+1.
			lastTable at: 5 put: (lastTable at: 5) - 1.
			self assert:[(lastTable at: 5) >= 0]. "Don't exceed tableSize"
			"Store terminal values"
			maxEntries := numValues min: tableSize.
			tableIndex := 0.
			1 to: maxEntries do:[:i|
				table at: tableStart + tableIndex put: (values at: valueIndex).
				valueIndex := valueIndex + 1.
				numValues := numValues - 1.
				tableIndex := tableIndex+1].
			"Check if we have filled up the current table completely"
			maxEntries = tableSize ifTrue:[
				"Table has been filled. Back up to the last table with space left."
				[tableStack isEmpty not and:[(tableStack last at: 5) = 0]]
						whileTrue:[tableStack removeLast].
			] ifFalse:[
				"Table not yet filled. Put it back on the stack."
				tableStack addLast:
					(Array
						with: bits		"Nr. of bits in this table"
						with: tableStart	"Start of table"
						with: tableIndex "Index in table"
						with: deltaBits	"delta bits of table"
						with: tableSize - maxEntries "Unused entries in table").
			].
		].
	].
	 ^table copyFrom: 1 to: tableEnd-1! !

!JPEGReadStream methodsFor: 'huffman trees' stamp: 'ar 3/4/2001 18:44'!
decodeValueFrom: table
	"Decode the next value in the receiver using the given huffman table."
	| bits bitsNeeded tableIndex value |
	bitsNeeded := (table at: 1) bitShift: -24.	"Initial bits needed"
	tableIndex := 2.							"First real table"
	[bits := self getBits: bitsNeeded.			"Get bits"
	value := table at: (tableIndex + bits).		"Lookup entry in table"
	(value bitAnd: 16r3F000000) = 0] 			"Check if it is a non-leaf node"
		whileFalse:["Fetch sub table"
			tableIndex := value bitAnd: 16rFFFF.	"Table offset in low 16 bit"
			bitsNeeded := (value bitShift: -24) bitAnd: 255. "Additional bits in high 8 bit"
			bitsNeeded > MaxBits ifTrue:[^self error:'Invalid huffman table entry']].
	^value! !

!JPEGReadStream methodsFor: 'accessing' stamp: 'ar 3/4/2001 20:42'!
fillBuffer

	| byte |
	[bitsInBuffer <= 16]
		whileTrue:[
			byte := self next.
			(byte = 16rFF and: [(self peekFor: 16r00) not])
					ifTrue:
						[self position: self position - 1.
						^0].
			bitBuffer := (bitBuffer bitShift: 8) bitOr: byte.
			bitsInBuffer := bitsInBuffer + 8].
	^ bitsInBuffer! !

!JPEGReadStream methodsFor: 'accessing' stamp: 'ar 3/4/2001 18:43'!
getBits: requestedBits
	| value |
	requestedBits > bitsInBuffer ifTrue:[
		self fillBuffer.
		requestedBits > bitsInBuffer ifTrue:[
			self error: 'not enough bits available to decode']].
	value := bitBuffer bitShift: (requestedBits - bitsInBuffer).
	bitBuffer := bitBuffer bitAnd: (1 bitShift: (bitsInBuffer - requestedBits)) -1.
	bitsInBuffer := bitsInBuffer - requestedBits.
	^ value! !

!JPEGReadStream methodsFor: 'huffman trees' stamp: 'ar 3/4/2001 18:21'!
growHuffmanTable: table
	| newTable |
	newTable := table species new: table size * 2.
	newTable replaceFrom: 1 to: table size with: table startingAt: 1.
	^newTable! !

!JPEGReadStream methodsFor: 'accessing' stamp: 'ar 3/6/2001 12:34'!
nextByte
	^self next asInteger! !

!JPEGReadStream methodsFor: 'accessing' stamp: 'ar 3/6/2001 12:35'!
nextBytes: n
	^(self next: n) asByteArray! !

!JPEGReadStream methodsFor: 'accessing' stamp: 'ar 3/4/2001 17:40'!
reset
	super reset.
	self resetBitBuffer! !

!JPEGReadStream methodsFor: 'accessing' stamp: 'ar 3/4/2001 18:44'!
resetBitBuffer
	bitBuffer := 0.
	bitsInBuffer := 0.
! !

!WideSymbol methodsFor: '*Graphics-Text' stamp: 'nice 10/9/2013 01:47'!
scanCharactersFrom: startIndex to: stopIndex with: aCharacterScanner rightX: rightX  font: aFont
	"NB: strongly consider getting almost all these parameters from the scanner"
	"Since I'm a wide char string, I know that we have to scan multi-byte characters and handle encodings etc"
	| charSet |
	startIndex > stopIndex
		ifTrue: [^aCharacterScanner handleEndOfRunAt: stopIndex].
	charSet := self encodedCharSetAt: startIndex.
	^charSet scanMultibyteCharactersFrom: startIndex to: stopIndex in: self with: aCharacterScanner rightX: rightX font: aFont	! !

Notification subclass: #MissingFont
	instanceVariableNames: 'familyName pixelSize'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Graphics-Fonts'!

!MissingFont commentStamp: '<historical>' prior: 0!
signaled by font loading code when reading a DiskProxy that calls for a missing font.!

!MissingFont class methodsFor: 'instance creation' stamp: 'nk 11/8/2004 15:07'!
forFamilyName: aName pixelSize: aSize
	^(self new)
		familyName: aName;
		pixelSize: aSize;
		yourself.! !

!MissingFont methodsFor: 'handling' stamp: 'nk 11/8/2004 15:04'!
defaultAction
	familyName ifNil: [ familyName := 'NoName' ].
	pixelSize ifNil: [ pixelSize := 12 ].

	^((familyName beginsWith: 'Comic')
		ifTrue: [ TextStyle named: (Preferences standardEToysFont familyName) ]
		ifFalse: [ TextStyle default ]) fontOfSize: pixelSize.! !

!MissingFont methodsFor: 'accessing' stamp: 'nk 11/8/2004 15:01'!
familyName
	"Answer the value of familyName"

	^ familyName! !

!MissingFont methodsFor: 'accessing' stamp: 'nk 11/8/2004 15:01'!
familyName: anObject
	"Set the value of familyName"

	familyName := anObject! !

!MissingFont methodsFor: 'accessing' stamp: 'nk 11/8/2004 15:01'!
pixelSize
	"Answer the value of pixelSize"

	^ pixelSize! !

!MissingFont methodsFor: 'accessing' stamp: 'nk 11/8/2004 15:01'!
pixelSize: anObject
	"Set the value of pixelSize"

	pixelSize := anObject! !

!MissingFont methodsFor: 'printing' stamp: 'nk 11/8/2004 16:55'!
printOn: aStream
	super printOn: aStream.
	aStream nextPut: $(;
		nextPutAll: familyName;
		nextPut: $-;
		print: pixelSize;
		nextPut: $).! !

!ProcessorScheduler class methodsFor: '*Graphics-KernelExtensions' stamp: 'ul 6/17/2011 12:41'!
sweepHandIdleProcess
	"A default background process which shows a sweeping circle of XOR-ed bits on the screen."

	| sweepHand |
	sweepHand := Pen new.
	sweepHand defaultNib: 2.
	sweepHand combinationRule: 6.
	[
		2 timesRepeat: [
			sweepHand north.
			36 timesRepeat: [
				sweepHand place: Display boundingBox topRight + (-25@25).
				sweepHand go: 20.
				sweepHand turn: 10]].
		self relinquishProcessorForMicroseconds: 10000] repeat
! !

!Number methodsFor: '*Graphics-converting' stamp: ''!
@ y 
	"Primitive. Answer a Point whose x value is the receiver and whose y 
	value is the argument. Optional. No Lookup. See Object documentation 
	whatIsAPrimitive."

	<primitive: 18>
	^Point x: self y: y! !

DisplayScreen subclass: #DisplayHostWindow
	instanceVariableNames: 'windowProxy title windowType eventQueue'
	classVariableNames: ''
	poolDictionaries: 'EventSensorConstants'
	category: 'Graphics-External-Ffenestri'!

!DisplayHostWindow commentStamp: '<historical>' prior: 0!
A subclass of DisplayScreen that uses a (platform appropriate) HostWindowProxy
to do its displaying in a separate host OS window. This is just one example of a
client for HostWindowProxy.
See #test #test2 and HostWindowTests for example usage.!

!DisplayHostWindow class methodsFor: 'examples' stamp: 'bf 1/5/2012 18:30'!
examplePaint
	"DisplayHostWindow examplePaint inspect"
	"Should
		a) open a window
		b) fork a process to allow painting with mouse
		c) survive saving and re-opening the image
		d) close and terminate the process when clicking close box or pressing ESC or garbage collect
	This relies on the Morphic main loop repeatedly fetching events from Sensor.
	"
	| win evt pen |
	win := DisplayHostWindow extent: 400@400 depth: 32.
	win offset: 50@50; open; windowTitle: 'Paint Test'.
	pen := nil.
	[
		[win isOpen] whileTrue: [
			evt := win nextEvent.
			"check for ESC event"
			((evt at: 1) = EventTypeKeyboard and: [(evt at: 4) = EventKeyChar and: [(evt at: 3) = 27]])
				ifTrue: [win close].
			"process for mouse events"
			(evt at: 1) = EventTypeMouse ifTrue: [
				(evt at: 5) > 0	"button pressed"
					ifTrue: [
						pen ifNil: [
							pen := Pen newOnForm: win.
							pen roundNib: 5; color: Color random.
							pen place: (evt at: 3)@(evt at: 4)].
						pen goto: (evt at: 3)@(evt at: 4)]
					ifFalse: [pen := nil]].
			win forceToScreen.
		].
	] forkNamed: thisContext asString.
	^win! !

!DisplayHostWindow methodsFor: 'snapshots' stamp: 'tpr 10/14/2004 16:13'!
actualScreenSize
"return the host window size as if it were 'the' screen"
	^self windowSize! !

!DisplayHostWindow methodsFor: 'initialize-release' stamp: 'lr 7/4/2009 10:42'!
close
	"close this window"
	windowProxy ifNil: [ ^ self error: 'cannot close never opened window' ].
	"We don't use 'self windowProxy close' here because if we've never setup the window why do it now only to close it immediately?"
	windowProxy close.
	windowProxy := nil! !

!DisplayHostWindow methodsFor: 'accessing' stamp: 'bf 1/5/2012 16:25'!
eventQueue
	^eventQueue ifNil: [eventQueue := SharedQueue new]
! !

!DisplayHostWindow methodsFor: 'basic api' stamp: 'tpr 9/21/2004 16:57'!
forceToScreen
	"update the area defined by my bounds"
	self forceToScreen: self boundingBox! !

!DisplayHostWindow methodsFor: 'basic api' stamp: 'tpr 10/7/2004 10:51'!
forceToScreen: damageRectangle 
	"update the area defined by damageRectangle"
	windowProxy ifNotNil:[ windowProxy forceToScreen: damageRectangle]! !

!DisplayHostWindow methodsFor: 'private-events' stamp: 'bf 1/4/2012 15:46'!
handleActivated
	"window made active - some platforms only - do not rely upon this"! !

!DisplayHostWindow methodsFor: 'private-events' stamp: 'bf 1/4/2012 18:29'!
handleClose
	"window close icon pressed"

	self close.
! !

!DisplayHostWindow methodsFor: 'private-events' stamp: 'bf 1/4/2012 15:46'!
handleIconise
	"window iconised or hidden etc"! !

!DisplayHostWindow methodsFor: 'private-events' stamp: 'bf 1/4/2012 18:23'!
handleMetricChange: aRectangle
	"size or position of window changed"

	offset := aRectangle origin.

	(width = aRectangle width and: [height = aRectangle height])
		ifFalse: [self setExtent: aRectangle extent depth: depth].
! !

!DisplayHostWindow methodsFor: 'private-events' stamp: 'bf 1/4/2012 18:22'!
handlePaint: aRectangle
	"window area needs updating. Some platforms do not need to send this, do not rely on it in image"

	self forceToScreen: aRectangle.
! !

!DisplayHostWindow methodsFor: 'accessing' stamp: 'bf 1/5/2012 16:20'!
isOpen
	^windowProxy notNil! !

!DisplayHostWindow methodsFor: 'accessing' stamp: 'bf 1/5/2012 16:26'!
nextEvent
	^self eventQueue next! !

!DisplayHostWindow methodsFor: 'accessing' stamp: 'bf 1/5/2012 16:27'!
nextEventOrNil
	^self eventQueue nextOrNil! !

!DisplayHostWindow methodsFor: 'initialize-release' stamp: 'bf 1/4/2012 18:50'!
open
	"open the host window"
	windowProxy ifNil: [ windowProxy := HostWindowProxy on: self ].
	windowType ifNil: [ windowType := #defaultWindowType ].
	windowProxy perform: windowType.
	windowProxy open.
	title ifNotNil: [ windowProxy windowTitle: title ].
! !

!DisplayHostWindow methodsFor: 'private-events' stamp: 'bf 1/4/2012 19:08'!
processEvent: evt
	"evt is a raw event buffer from VM. Check for window events (close etc.). Queue events if queue exists"
	(evt at: 1) = EventTypeWindow
		ifTrue: [self processWindowEvent: evt].
	self queueEvent: evt.
! !

!DisplayHostWindow methodsFor: 'private-events' stamp: 'bf 1/4/2012 18:27'!
processWindowEvent: evt
	(evt at: 3) caseOf: {
		[WindowEventMetricChange] -> [self handleMetricChange: ((evt at: 4)@(evt at: 5) corner: (evt at: 6)@(evt at: 7)) ].
		[WindowEventClose] ->	 [self handleClose].
		[WindowEventIconise] -> [self handleIconise]. 
		[WindowEventActivated] -> [self handleActivated]. 
		[WindowEventPaint] -> [self handlePaint: ((evt at: 4)@(evt at: 5) corner: (evt at: 6)@(evt at: 7))].
	} otherwise: ["unknown"]
! !

!DisplayHostWindow methodsFor: 'private-events' stamp: 'bf 1/5/2012 16:26'!
queueEvent: evt
	"Queue the given event in the event queue (if any).
	Note that the event buffer must be copied since it
	will be reused later on."
	eventQueue ifNil: [^self].	"queue gets created by client"
	eventQueue nextPut: evt clone.
! !

!DisplayHostWindow methodsFor: 'snapshots' stamp: 'lr 7/4/2009 10:42'!
resetProxy
	"private - for use when resuming a snapshot file only. If the windowProxy had previously been created, nil it and reopen cleanly. IF you try to use this in a 'live' system it will NOT close the windows since startup conditions assume that proxies are invalid so we don't attempt to close them - since that could cause other problems"
	windowProxy ifNotNil: 
		[ windowProxy := nil.
		self open ]! !

!DisplayHostWindow methodsFor: 'testing' stamp: 'lr 7/4/2009 10:42'!
test
	"((DisplayHostWindow extent: 400@400 depth: 16 ) translateBy: 210@450) test"
	"Should
		a) open a window with the upper left portion of the current Display
		b) find the window size
		f) close the window"
	| size |
	self open.
	Display displayOn: self.
	self forceToScreen: self boundingBox.
	size := self windowSize.
	self close.
	^ size! !

!DisplayHostWindow methodsFor: 'testing' stamp: 'nice 3/5/2010 22:31'!
test2
	"((DisplayHostWindow extent: 400 @ 400 depth: 16 ) translateBy: 210 @ 450) test2"
	"Should
		a) open a window with the upper left portion of the current Display
		b) update the middle area with part of Display
		c) move the window from 210 @ 450 to 300 @ 300
		d) change the window title
		e) change the window size from 400 @ 400 to 600 @ 400
		f) wait 4 seconds so you can see the result
		g) close the window via the garbage collecttor finalizing it"
	self open.
	Display displayOn: self.
	self forceToScreen.
	Display displayOn: self at: -100 @ -200.
	self forceToScreen: (100 @ 100 extent: 200 @ 200).
	self windowPosition: 300 @ 300.
	self windowTitle: 'YooHoo!! New title'.
	self windowSize: 600 @ 400.
	(Delay forSeconds: 4) wait.! !

!DisplayHostWindow methodsFor: 'basic api' stamp: 'tpr 10/11/2004 16:56'!
windowPosition
	"return the current position of the window"
		
	^windowProxy ifNotNil:[ windowProxy windowPosition]! !

!DisplayHostWindow methodsFor: 'basic api' stamp: 'tpr 10/11/2004 16:56'!
windowPosition: aPoint
	"set the position of the window and then return the new position"
	^windowProxy ifNotNil:[ windowProxy windowPosition: aPoint]! !

!DisplayHostWindow methodsFor: 'basic api' stamp: 'tpr 10/11/2004 16:56'!
windowSize
	"return the current size of the window - not neccessarily the same as my bitmap"

	^windowProxy ifNotNil:[ windowProxy windowSize]! !

!DisplayHostWindow methodsFor: 'basic api' stamp: 'tpr 10/11/2004 16:56'!
windowSize: aPoint
	"Set the size of the window and then return the current size of the window -
not neccessarily the same "
		
	^windowProxy ifNotNil:[ windowProxy windowSize: aPoint]! !

!DisplayHostWindow methodsFor: 'basic api' stamp: 'lr 7/4/2009 10:42'!
windowTitle: titleString 
	"set the label in the window titlebar to titleString"
	title := titleString.
	windowProxy ifNotNil: [ windowProxy windowTitle: title ]! !

!Integer methodsFor: '*Graphics-converting' stamp: 'ar 10/31/1998 23:04'!
asColorOfDepth: d
	"Return a color value representing the receiver as color of the given depth"
	^Color colorFromPixelValue: self depth: d! !

!ByteString methodsFor: '*Graphics-Text' stamp: 'tpr 10/2/2013 17:36'!
scanCharactersFrom: startIndex to: stopIndex with: aCharacterScanner rightX: rightX  font: aFont
	"NB: strongly consider getting almost all these parameters from the scanner"
	"Since I'm a byte char string, I know that we have to scan single-byte characters and don't have to handle encodings etc"
	startIndex > stopIndex
		ifTrue: [^aCharacterScanner handleEndOfRunAt: stopIndex].
	^aFont scanByteCharactersFrom: startIndex to: stopIndex in: self with: aCharacterScanner rightX: rightX! !
BitBlt initialize!
Color initialize!
Cursor initialize!
Form initialize!
IdentityTransform initialize!
HostWindowProxy initialize!
GIFReadWriter initialize!
JPEGReadWriter initialize!
PNGReadWriter initialize!
XBMReadWriter initialize!
JPEGHuffmanTable initialize!
TextPrinter initialize!
CharacterScanner initialize!
StrikeFont initialize!
TextStyle initialize!
JPEGReadStream initialize!
